/*******************************************************************************
*
* File:         s20P_demo.c
* Description:  系统测试文件
* Version:      V0.1
* Date:         2020-02-22
* Author:       Tempest
 *******************************************************************************/

#include "S21P_demo.h"
#include "ArmCM0.h"
#include "tau_device_datatype.h"
#include "tau_log.h"
#include "tau_operations.h"
#include "tau_common.h"
#include "tau_delay.h"
#include "hal_dsi_rx_ctrl.h"
#include "hal_dsi_tx_ctrl.h"
#include "hal_swire.h"
#include "hal_timer.h"
#include "hal_system.h"
#include "hal_gpio.h"
#include "test_cfg_global.h"
#include "app_tp_st_touch.h"

#ifdef LOG_TAG
#undef LOG_TAG
#endif
#define LOG_TAG "S21P_demo"

/********************基本参数配置*********************/

//S20+ MIPI数据信息
/* 输入分辨率 */
#define INPUT_WIDTH  1080 //1080
#define INPUT_HEIGHT 2400 //2400
/* 输入 MIPI lane rate,video mode需要正确配置，cmd mode可随便配置 */
#define INPUT_MIPI_LANE_RATE 1600000000
/* 输入图像格式 */
#define INPUT_COLOR_MODE DSI_RGB888
/* 输出数据格式(DSI_DATA_CMD_MODE , DSI_DATA_VIDEO_MODE) */
#define INPUT_DATA_MODE DSI_DATA_CMD_MODE
/* 输入mipi lane数量(DSI_RX_LANE_x     x为1-4) */
#define INPUT_MIPI_LANE_NUM DSI_LANE_4
/* 输入为video mode 时数据格式 */
#define INPUT_VIDEO_MODEL DSI_NONBURST_EVENT
/* 输入虚拟通道(0-3) */
#define INPUT_VC DSI_VC_0
/* 输入的帧率(60/90/120/144Hz) */
#define INPUT_FRAME_RATE DSI_FRAME_RATE_60HZ
/* 输入数据是否DSC压缩 */
#define INPUT_COMPRESS true


#define  AMOLED_NT37701   0

#if AMOLED_NT37701
//almoled NT37280输出MIPI数据信息
/* 输出分辨率配置 */
#define OUTPUT_WIDTH 1080
#define OUTPUT_HEIGHT 2280
/* 输出虚拟通道(0-3) */
#define OUTPUT_VC DSI_VC_0
/* 输出mipi lane数量(DSI_RX_LANE_x     x为1-4) */
#define OUTPUT_LANE_NUMBER DSI_LANE_4
/* 输出为video mode 的数据格式 */
#define OUTPUT_VIDEO_MODEL DSI_BURST_MODE
/* 输出 VSA */
#define OUTPUT_VSA  4
/* 输出 VBP */
#define OUTPUT_VBP  28
/* 输出 VBP */
#define OUTPUT_VFP  10
/* 输出 VSA */
#define OUTPUT_HSA  8
/* 输出 HBP */
#define OUTPUT_HBP  16
/* 输出 HFP */
#define OUTPUT_HFP  36
/* 初始化模式命令传输类型 */
#define _CMD_TYPE            DSI_CMD_TX_LP      //0-HS,1-LP;

#else

/* 输出分辨率配置 */
#define OUTPUT_WIDTH 1080
#define OUTPUT_HEIGHT 2400
/* 输出虚拟通道(0-3) */
#define OUTPUT_VC DSI_VC_0
/* 输出mipi lane数量(DSI_RX_LANE_x     x为1-4) */
#define OUTPUT_LANE_NUMBER DSI_LANE_4
/* 输出为video mode 的数据格式 */
#define OUTPUT_VIDEO_MODEL DSI_BURST_MODE
/* 输出 VSA */
#define OUTPUT_VSA  4
/* 输出 VBP */
#define OUTPUT_VBP  8
/* 输出 VBP */
#define OUTPUT_VFP  60  // 50
/* 输出 VSA */
#define OUTPUT_HSA  8  // 4
/* 输出 HBP */
#define OUTPUT_HBP  16 //16
/* 输出 HFP */
#define OUTPUT_HFP  30 // 20
/* 初始化模式命令传输类型 */
#define _CMD_TYPE            DSI_CMD_TX_LP      //0-HS,1-LP;
#endif

#define SWIRE_TIMER TIMER_NUM1
#define TE_TIMER    TIMER_NUM2

#define SYNC_LIN_NUMBER         2000  //2600//2000

#define  g_swire_num			40
#define  SWIRE_MAX_NUM			10

#define AUTO_CAL_TP             0
#define RUN_TEST                0
#define ENABLE_SOFT_TIMER_TE       false

#if AUTO_CAL_TP
static uint16_t g_cal_cnt = 300;    //3s倒计时进入TP校准
#endif
/*
RX Filter 1~3 数字越大，水波纹会大一些，边缘锯齿会增加，但是字体会更清晰
TX Filter 1~3 值越大字体越清晰，但是字体边缘锯齿会增加，值越小字体越模糊，但边缘锯齿越小，对水波纹没有大影响
*/
uint32_t s_heartbeat = 0;

#if ENABLE_TP_WAKE_UP
static bool g_need_enter_sleep_mode = false;
static bool g_ap_reset_cb = false;
#endif

/******************************************************/
static hal_dsi_rx_ctrl_handle_t* g_rx_ctrl_handle = NULL;
static hal_dsi_tx_ctrl_handle_t* g_tx_ctrl_handle = NULL;

/* 默认false,初始化屏标志位,屏端使用TP1.8V,AC 初始化屏需要等TP1.8V有电 */
static volatile bool start_display_on = true;
/* 屏初始化完成标志位 */
static bool panel_display_done = true;
static bool g_exit_sleep_mode = false;
extern volatile bool s_calibration_flag;

bool	s_sys_power_up_flag = false;

uint8_t  s_swire_pwm_counter = 0;

bool s_power_up_flag = false;
uint16_t s_tp_delay_count = 0;

bool s_power_off_flag = false;

// 帧率切换标志
static uint8_t frame_rate = 100;

/// 清晰度较好
uint32_t rx_filter_1080_h_4_96[32][2] =
{
    0xB029EC0A, 0x0000000F,
    0x904DF003, 0x0000000F,
    0x6871F9FB, 0x0000000F,
    0x4899FBF4, 0x0000000F,
    0x28C1FDED, 0x0000000F,
    0x08EDFBE7, 0x0000000F,
    0xE119FDE0, 0x0000000E,
    0xC145F9DB, 0x0000000E,
    0xA175F3D6, 0x0000000E,
    0x81A9EBD1, 0x0000000E,
    0x69D9E1CD, 0x0000000E,
    0x520DD5C9, 0x0000000E,
    0x3A3DC7C7, 0x0000000E,
    0x2A71B7C4, 0x0000000E,
    0x1A9DA7C3, 0x0000000E,
    0x12CD93C2, 0x0000000E,
    0x12F97DC2, 0x0000000E,
    0x132567C2, 0x0000000E,
    0x1B4D4FC3, 0x0000000E,
    0x236D39C5, 0x0000000E,
    0x3B8D1FC7, 0x0000000E,
    0x4BA907CA, 0x0000000E,
    0x6BC0EDCD, 0x0000000E,
    0x8BD4D5D0, 0x0000000E,
    0xB3E4BBD4, 0x0000000E,
    0xDBF0A3D8, 0x0000000E,
    0x03F88DDC, 0x0000000F,
    0x3BF477E1, 0x0000000F,
    0x6BF861E5, 0x0000000F,
    0xA3F44DE9, 0x0000000F,
    0xDBF039ED, 0x0000000F,
    0x1BE027F2, 0x00000000
};


uint32_t rx_filter_2400_v_4_96[32][2] =
{
    0xB029EC0A, 0x0000000F,
    0x904DF003, 0x0000000F,
    0x6871F9FB, 0x0000000F,
    0x4899FBF4, 0x0000000F,
    0x28C1FDED, 0x0000000F,
    0x08EDFBE7, 0x0000000F,
    0xE119FDE0, 0x0000000E,
    0xC145F9DB, 0x0000000E,
    0xA175F3D6, 0x0000000E,
    0x81A9EBD1, 0x0000000E,
    0x69D9E1CD, 0x0000000E,
    0x520DD5C9, 0x0000000E,
    0x3A3DC7C7, 0x0000000E,
    0x2A71B7C4, 0x0000000E,
    0x1A9DA7C3, 0x0000000E,
    0x12CD93C2, 0x0000000E,
    0x12F97DC2, 0x0000000E,
    0x132567C2, 0x0000000E,
    0x1B4D4FC3, 0x0000000E,
    0x236D39C5, 0x0000000E,
    0x3B8D1FC7, 0x0000000E,
    0x4BA907CA, 0x0000000E,
    0x6BC0EDCD, 0x0000000E,
    0x8BD4D5D0, 0x0000000E,
    0xB3E4BBD4, 0x0000000E,
    0xDBF0A3D8, 0x0000000E,
    0x03F88DDC, 0x0000000F,
    0x3BF477E1, 0x0000000F,
    0x6BF861E5, 0x0000000F,
    0xA3F44DE9, 0x0000000F,
    0xDBF039ED, 0x0000000F,
    0x1BE027F2, 0x00000000
};

static void soft_swire_init(void);
static void open_mipi_rx(void);
static void init_mipi_tx(void);

#if ENABLE_TP_WAKE_UP
#if 1
static void ap_reset_cb(void* data)
{
    /* 切换电源 */
    //    hal_gpio_set_output_data_ex(POWER_IO_B, IO_LVL_HIGH, POWER_IO_A, IO_LVL_LOW);
//	hal_gpio_set_output_data(POWER_IO_A, IO_LVL_LOW);//
	
	hal_gpio_set_output_data(IO_PAD_TD_LEDPWM, IO_LVL_LOW);
	
	// 打开VCC供电 //
//	TAU_LOGD("disable reset!!!!!!!!!!!!!");
//	delayMs(5);
//	hal_gpio_set_output_data(IO_PAD_AP_INT, IO_LVL_LOW);
//	delayMs(1);
//	hal_gpio_set_output_data(IO_PAD_AP_INT, IO_LVL_HIGH);
//	hal_system_set_pvd(true);
//	hal_system_set_vcc(true);
//	NVIC_SystemReset();
	g_ap_reset_cb = true;
	
}
static void ap_reset_exec(void)
{
	if(g_ap_reset_cb == true)
	{	
		hal_gpio_set_output_data(IO_PAD_AP_INT, IO_LVL_HIGH);
		g_ap_reset_cb = false;
		open_mipi_rx();
		hal_gpio_set_output_data(IO_PAD_AP_INT, IO_LVL_HIGH);
		
    	TAU_LOGD("S21P restart \n");
    	init_mipi_tx();
		start_display_on = true;
		frame_rate = 100;   // 复位帧率切换标志，用于120hz唤醒后不切换帧率，卡顿问题
	}
}

#else
static void ap_reset_cb(void* data)
{
    /* 切换电源 */
    //    hal_gpio_set_output_data_ex(POWER_IO_B, IO_LVL_HIGH, POWER_IO_A, IO_LVL_LOW);
//	hal_gpio_set_output_data(POWER_IO_A, IO_LVL_LOW);//
	
//	hal_gpio_set_output_data(IO_PAD_TD_LEDPWM, IO_LVL_LOW);
	// 打开VCC供电 //
//	TAU_LOGD("disable reset!!!!!!!!!!!!!");
//	hal_system_set_pvd(true);
//	hal_system_set_vcc(true);
//	NVIC_SystemReset();
	g_ap_reset_cb = true;
}

static void ap_reset_exec(void)
{
    /* 切换电源 */
    //    hal_gpio_set_output_data_ex(POWER_IO_B, IO_LVL_HIGH, POWER_IO_A, IO_LVL_LOW);
//	hal_gpio_set_output_data(POWER_IO_A, IO_LVL_LOW);//
	if(g_ap_reset_cb == true)
	{
		g_ap_reset_cb = false;
//		hal_gpio_set_output_data(IO_PAD_TD_LEDPWM, IO_LVL_LOW);
	    /* 打开VCC供电 */
	    TAU_LOGD("disable reset!");
			delayMs(80);
//		TAU_LOGD("disable");
//		delayMs(10);
		hal_gpio_set_output_data(IO_PAD_TD_LEDPWM, IO_LVL_LOW);
	    hal_system_set_pvd(true);
	    hal_system_set_vcc(true);
	    NVIC_SystemReset();
	}
	
}
#endif

#endif

static bool ap_dcs_read(uint8_t data_type, uint8_t dcs_cmd, uint8_t param)
{
    if(dcs_cmd == 0xEE)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0x00);
    }
	else if(dcs_cmd == 0x0A)
    {
        uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 3)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         3, 0x9F, 0x9F, 0x9F);
        }
        else
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                         DSI_VC_0,
                                         1, 0x9F);
        }
    }
    else if(dcs_cmd == 0x05)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0x00);
    }
    else if(dcs_cmd == 0x0E)
    {
    	uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 3)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         3, 0x80, 0x80, 0x80);
        }
        else
        {
        	hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
 	                                  1, 0x80);
        }
        
    }
    else if(dcs_cmd == 0x0F)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0xC0);
    }
    else if(dcs_cmd == 0xEA)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_LONG_RESPONSE,
                                     DSI_VC_0,
                                     5, 0x00, 0x00, 0x00, 0x00, 0x00);
    }
    else if(dcs_cmd == 0xE9)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_LONG_RESPONSE,
                                     DSI_VC_0,
                                     2, 0x00, 0x00);
    }
	else if(dcs_cmd == 0x04)
    {
    	s_power_up_flag = true;
		s_sys_power_up_flag = true;
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_LONG_RESPONSE,
                                     DSI_VC_0,
                                     3, 0xA1, 0x15, 0x05);
    }
    else if(dcs_cmd == 0xDC)
    {
    	s_power_up_flag = true;
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0x05);
    }
    else if(dcs_cmd == 0xDB)
    {
    	s_power_up_flag = true;
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     //        1,0x11);
                                     1, 0x15);
    }
    else if(dcs_cmd == 0xDA)
    {
    	s_power_up_flag = true;
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0xA1);
		s_sys_power_up_flag = true;
    }
    else if(dcs_cmd == 0xD6)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_LONG_RESPONSE,
                                     DSI_VC_0,
                                     5, 0xA3, 0x00, 0x71, 0x48, 0xA6);
    }
    else if(dcs_cmd == 0xC9)
    {
        uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 10)
        {
            static uint8_t ret_C9_count = 0;
            if(ret_C9_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x05, 0x21, 0x5C, 0x6B, 0x0C, 0x32, 0xE0);
                ret_C9_count = 1;
            }
            else if(ret_C9_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE8, 0x0D, 0xA3, 0x25, 0x03, 0x11, 0xC4, 0x0D, 0x4A, 0x14);
                ret_C9_count = 2;
            }
            else if(ret_C9_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x94, 0xB1, 0x79, 0x17, 0x75, 0x59, 0xAB, 0x1C, 0x46, 0x79);
                ret_C9_count = 3;
            }
            else if(ret_C9_count == 3)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xFF, 0x22, 0xF8, 0x06, 0x72, 0x28, 0x39, 0x36, 0xD0, 0x00);
                ret_C9_count = 4;
            }
            else if(ret_C9_count == 4)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1F, 0x1F, 0x1F, 0x0A, 0x92, 0xA8, 0xC5, 0x0C, 0x52, 0xEC);
                ret_C9_count = 5;
            }
            else if(ret_C9_count == 5)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE7, 0x0D, 0xB3, 0x29, 0x00, 0x11, 0x33, 0xE5, 0x3F, 0x13);
                ret_C9_count = 6;
            }
            else if(ret_C9_count == 6)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xC4, 0x79, 0x6B, 0x16, 0x75, 0x19, 0x99, 0x1A, 0xD6, 0x19);
                ret_C9_count = 7;
            }
            else if(ret_C9_count == 7)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE5, 0x20, 0xA7, 0x72, 0x4A, 0x24, 0xC8, 0x66, 0x94, 0x29);
                ret_C9_count = 8;
            }
            else if(ret_C9_count == 8)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1F, 0x1F, 0x1F, 0x0B, 0x22, 0xC8, 0xCF, 0x0C, 0xA3, 0x08);
                ret_C9_count = 9;
            }
            else if(ret_C9_count == 9)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xEB, 0x0D, 0xD3, 0x39, 0x02, 0x11, 0x43, 0xF1, 0x40, 0x13);
                ret_C9_count = 10;
            }
            else if(ret_C9_count == 10)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xD4, 0x81, 0x6C, 0x16, 0x75, 0x19, 0x98, 0x1A, 0xD6, 0x19);
                ret_C9_count = 11;
            }
            else if(ret_C9_count == 11)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE5, 0x20, 0xD7, 0x7E, 0x4C, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C9_count = 12;
            }
            else if(ret_C9_count == 12)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1F, 0x1F, 0x1F, 0x0C, 0xC3, 0x3C, 0xF0, 0x0D, 0xA3, 0x65);
                ret_C9_count = 13;
            }
            else if(ret_C9_count == 13)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x00, 0x0E, 0x83, 0x85, 0x10, 0x11, 0x84, 0x11, 0x44, 0x13);
                ret_C9_count = 14;
            }
            else if(ret_C9_count == 14)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE4, 0x91, 0x6D, 0x16, 0x65, 0x21, 0x98, 0x1A, 0xC6, 0x19);
                ret_C9_count = 15;
            }
            else if(ret_C9_count == 15)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE4, 0x20, 0xB7, 0x76, 0x4A, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C9_count = 16;
            }
            else if(ret_C9_count == 16)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1F, 0x1F, 0x1F, 0x0E, 0x33, 0xA9, 0x0B, 0x0E, 0xF3, 0xC9);
                ret_C9_count = 17;
            }
            else if(ret_C9_count == 17)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x18, 0x0F, 0x93, 0xE1, 0x23, 0x11, 0xE4, 0x41, 0x4B, 0x14);
                ret_C9_count = 18;
            }
            else if(ret_C9_count == 18)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x14, 0xAD, 0x71, 0x16, 0x85, 0x31, 0x9A, 0x1A, 0xC6, 0x1D);
                ret_C9_count = 19;
            }
            else if(ret_C9_count == 19)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE4, 0x20, 0x77, 0x6E, 0x48, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C9_count = 20;
            }
            else if(ret_C9_count == 20)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1F, 0x1F, 0x1F, 0x0F, 0x84, 0x21, 0x2B, 0x10, 0x44, 0x3D);
                ret_C9_count = 21;
            }
            else if(ret_C9_count == 21)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x36, 0x10, 0xC4, 0x4D, 0x3D, 0x12, 0xA4, 0x91, 0x5B, 0x14);
                ret_C9_count = 22;
            }
            else if(ret_C9_count == 22)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x74, 0xDD, 0x78, 0x16, 0xB5, 0x4D, 0x9F, 0x1A, 0xC6, 0x29);
                ret_C9_count = 23;
            }
            else if(ret_C9_count == 23)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE5, 0x20, 0x67, 0x66, 0x46, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C9_count = 0;
            }
            else
            {
                //printf("C9 err return_size[%d] ret_C9_count[%d]\n", return_size, ret_C9_count);
            }
        }
        else if(return_size == 3)
        {
            static uint8_t ret_C9_count = 0;
            if(ret_C9_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             3, 0xF2, 0x1F, 0x1F);
                ret_C9_count = 1;
            }
            else if(ret_C9_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             3, 0xA9, 0x86, 0xEE);
                ret_C9_count = 2;
            }
            else if(ret_C9_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             3, 0xD9, 0x92, 0xF2);
                ret_C9_count = 0;
            }
            else
            {
                //printf("C9 err return_size[%d] ret_C9_count[%d]\n", return_size, ret_C9_count);
            }
        }
        else if(return_size == 4)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         4, 0x29, 0xD9, 0x92, 0xF2);
        }
        else if(return_size == 39)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         39, 0x1A, 0x1A, 0x1A, 0x05, 0x21, 0x5C, 0x6B, 0x0C, 0x32, 0xE0, 0xE8, 0x0D, 0xA3, 0x25, 0x03, 0x11, 0xC4, 0x0D, 0x4A, 0x14, 0x94, 0xB1, 0x79, 0x17, 0x75, 0x59, 0xAB, 0x1C, 0x46, 0x79, 0xFF, 0x22, 0xF8, 0x06, 0x72, 0x28, 0x39, 0x36, 0xD0);
        }
        else if(return_size == 43)
        {
            static uint8_t ret_C9_count = 0;
            if(ret_C9_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1F, 0x1F, 0x1F, 0x0A, 0x92, 0xA8, 0xC5, 0x0C, 0x52, 0xEC, 0xE7, 0x0D, 0xB3, 0x29, 0x00, 0x11, 0x33, 0xE5, 0x3F, 0x13, 0xC4, 0x79, 0x6B, 0x16, 0x75, 0x19, 0x99, 0x1A, 0xD6, 0x19, 0xE5, 0x20, 0xA7, 0x72, 0x4A, 0x24, 0xC8, 0x66, 0x94, 0x29, 0xA9, 0x86, 0xEE);
                ret_C9_count = 1;
            }
            else if(ret_C9_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1F, 0x1F, 0x1F, 0x0B, 0x22, 0xC8, 0xCF, 0x0C, 0xA3, 0x08, 0xEB, 0x0D, 0xD3, 0x39, 0x02, 0x11, 0x43, 0xF1, 0x40, 0x13, 0xD4, 0x81, 0x6C, 0x16, 0x75, 0x19, 0x98, 0x1A, 0xD6, 0x19, 0xE5, 0x20, 0xD7, 0x7E, 0x4C, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C9_count = 2;
            }
            else if(ret_C9_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1F, 0x1F, 0x1F, 0x0C, 0xC3, 0x3C, 0xF0, 0x0D, 0xA3, 0x65, 0x00, 0x0E, 0x83, 0x85, 0x10, 0x11, 0x84, 0x11, 0x44, 0x13, 0xE4, 0x91, 0x6D, 0x16, 0x65, 0x21, 0x98, 0x1A, 0xC6, 0x19, 0xE4, 0x20, 0xB7, 0x76, 0x4A, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C9_count = 3;
            }
            else if(ret_C9_count == 3)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1F, 0x1F, 0x1F, 0x0E, 0x33, 0xA9, 0x0B, 0x0E, 0xF3, 0xC9, 0x18, 0x0F, 0x93, 0xE1, 0x23, 0x11, 0xE4, 0x41, 0x4B, 0x14, 0x14, 0xAD, 0x71, 0x16, 0x85, 0x31, 0x9A, 0x1A, 0xC6, 0x1D, 0xE4, 0x20, 0x77, 0x6E, 0x48, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C9_count = 4;
            }
            else if(ret_C9_count == 4)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1F, 0x1F, 0x1F, 0x0F, 0x84, 0x21, 0x2B, 0x10, 0x44, 0x3D, 0x36, 0x10, 0xC4, 0x4D, 0x3D, 0x12, 0xA4, 0x91, 0x5B, 0x14, 0x74, 0xDD, 0x78, 0x16, 0xB5, 0x4D, 0x9F, 0x1A, 0xC6, 0x29, 0xE5, 0x20, 0x67, 0x66, 0x46, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C9_count = 0;
            }
            else
            {
                //printf("C9 err return_size[%d] ret_C9_count[%d]\n", return_size, ret_C9_count);
            }
        }
        else
        {
            TAU_LOGD("C9 resp error [%d]!\n", return_size);
        }
    }
    else if(dcs_cmd == 0xC7)
    {
        uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 10)
        {
            static uint8_t ret_C7_count = 0;
            if(ret_C7_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1F, 0x1F, 0x1F, 0x10, 0x84, 0x9D, 0x23, 0x11, 0xE4, 0xB5);
                ret_C7_count = 1;
            }
            else if(ret_C7_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x55, 0x12, 0x44, 0xC1, 0x5A, 0x13, 0xB4, 0xF1, 0x6F, 0x15);
                ret_C7_count = 2;
            }
            else if(ret_C7_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x25, 0x25, 0x86, 0x17, 0x05, 0x7D, 0xA6, 0x1A, 0xD6, 0x3D);
                ret_C7_count = 3;
            }
            else if(ret_C7_count == 3)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE7, 0x20, 0x67, 0x66, 0x46, 0x29, 0xD9, 0x92, 0xF2, 0x00);
                ret_C7_count = 4;
            }
            else if(ret_C7_count == 4)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1F, 0x1F, 0x1F, 0x09, 0x42, 0x68, 0xB1, 0x14, 0x15, 0x41);
                ret_C7_count = 5;
            }
            else if(ret_C7_count == 5)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x78, 0x14, 0x15, 0x49, 0x7D, 0x15, 0x05, 0x6D, 0x8B, 0x16);
                ret_C7_count = 6;
            }
            else if(ret_C7_count == 6)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x35, 0x8D, 0x9A, 0x17, 0x95, 0xC1, 0xB1, 0x1A, 0xA6, 0x4D);
                ret_C7_count = 7;
            }
            else if(ret_C7_count == 7)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE5, 0x1F, 0x97, 0x42, 0x39, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C7_count = 8;
            }
            else if(ret_C7_count == 8)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x13, 0x13, 0x13, 0x05, 0x01, 0x48, 0x70, 0x0B, 0x52, 0x94);
                ret_C7_count = 9;
            }
            else if(ret_C7_count == 9)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xDB, 0x0D, 0x22, 0xF4, 0xFB, 0x11, 0x93, 0xF5, 0x47, 0x14);
                ret_C7_count = 10;
            }
            else if(ret_C7_count == 10)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x84, 0xA1, 0x7B, 0x17, 0x75, 0x55, 0xAD, 0x1C, 0x46, 0x6E);
                ret_C7_count = 11;
            }
            else if(ret_C7_count == 11)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x01, 0x22, 0xF8, 0x02, 0x74, 0x28, 0x49, 0x36, 0xD1, 0x2F);
                ret_C7_count = 12;
            }
            else if(ret_C7_count == 12)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x08, 0x52, 0x18, 0xA6, 0x0B, 0x52, 0x98);
                ret_C7_count = 13;
            }
            else if(ret_C7_count == 13)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xD8, 0x0D, 0x22, 0xF0, 0xF8, 0x11, 0x03, 0xD1, 0x3C, 0x13);
                ret_C7_count = 14;
            }
            else if(ret_C7_count == 14)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xB4, 0x71, 0x6A, 0x16, 0x75, 0x15, 0x99, 0x1A, 0xE6, 0x1D);
                ret_C7_count = 15;
            }
            else if(ret_C7_count == 15)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE6, 0x20, 0xB7, 0x76, 0x4B, 0x24, 0xE8, 0x6E, 0x96, 0x29);
                ret_C7_count = 16;
            }
            else if(ret_C7_count == 16)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x08, 0xB2, 0x34, 0xAE, 0x0B, 0x62, 0xA4);
                ret_C7_count = 17;
            }
            else if(ret_C7_count == 17)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xDB, 0x0D, 0x22, 0xF4, 0xF8, 0x11, 0x13, 0xD9, 0x3D, 0x13);
                ret_C7_count = 18;
            }
            else if(ret_C7_count == 18)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xB4, 0x71, 0x69, 0x16, 0x65, 0x11, 0x99, 0x1A, 0xE6, 0x21);
                ret_C7_count = 19;
            }
            else if(ret_C7_count == 19)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE7, 0x20, 0xD7, 0x86, 0x4E, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C7_count = 20;
            }
            else if(ret_C7_count == 20)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x09, 0xF2, 0x94, 0xC9, 0x0B, 0xD2, 0xD8);
                ret_C7_count = 21;
            }
            else if(ret_C7_count == 21)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE8, 0x0D, 0x43, 0x14, 0xFE, 0x11, 0x13, 0xE5, 0x3E, 0x13);
                ret_C7_count = 22;
            }
            else if(ret_C7_count == 22)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xA4, 0x79, 0x6B, 0x16, 0x65, 0x19, 0x98, 0x1A, 0xC6, 0x19);
                ret_C7_count = 23;
            }
            else if(ret_C7_count == 23)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE5, 0x20, 0xC7, 0x7E, 0x4C, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C7_count = 0;
            }
            else
            {
                //printf("C7 err return_size[%d] ret_C7_count[%d]\n", return_size, ret_C7_count);
            }
        }
        else if(return_size == 3)
        {
            static uint8_t ret_C7_count = 0;
            if(ret_C7_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             3, 0x00, 0x00, 0x00);
                ret_C7_count = 1;
            }
            else if(ret_C7_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             3, 0xD9, 0x92, 0xF2);
                ret_C7_count = 2;
            }
            else if(ret_C7_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             3, 0x5A, 0xD7, 0x52);
                ret_C7_count = 0;
            }
            else
            {
                //printf("C7 err return_size[%d] ret_C7_count[%d]\n", return_size, ret_C7_count);
            }
        }
        else if(return_size == 39)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         39, 0x1F, 0x1F, 0x1F, 0x10, 0x84, 0x9D, 0x23, 0x11, 0xE4, 0xB5, 0x55, 0x12, 0x44, 0xC1, 0x5A, 0x13, 0xB4, 0xF1, 0x6F, 0x15, 0x25, 0x25, 0x86, 0x17, 0x05, 0x7D, 0xA6, 0x1A, 0xD6, 0x3D, 0xE7, 0x20, 0x67, 0x66, 0x46, 0x29, 0xD9, 0x92, 0xF2);
        }
        else if(return_size == 43)
        {
            static uint8_t ret_C7_count = 0;
            if(ret_C7_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1F, 0x1F, 0x1F, 0x09, 0x42, 0x68, 0xB1, 0x14, 0x15, 0x41, 0x78, 0x14, 0x15, 0x49, 0x7D, 0x15, 0x05, 0x6D, 0x8B, 0x16, 0x35, 0x8D, 0x9A, 0x17, 0x95, 0xC1, 0xB1, 0x1A, 0xA6, 0x4D, 0xE5, 0x1F, 0x97, 0x42, 0x39, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C7_count = 1;
            }
            else if(ret_C7_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x13, 0x13, 0x13, 0x05, 0x01, 0x48, 0x70, 0x0B, 0x52, 0x94, 0xDB, 0x0D, 0x22, 0xF4, 0xFB, 0x11, 0x93, 0xF5, 0x47, 0x14, 0x84, 0xA1, 0x7B, 0x17, 0x75, 0x55, 0xAD, 0x1C, 0x46, 0x6E, 0x01, 0x22, 0xF8, 0x02, 0x74, 0x28, 0x49, 0x36, 0xD1, 0x2F, 0x5A, 0xD7, 0x52);
                ret_C7_count = 2;
            }
            else if(ret_C7_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1A, 0x1A, 0x1A, 0x08, 0x52, 0x18, 0xA6, 0x0B, 0x52, 0x98, 0xD8, 0x0D, 0x22, 0xF0, 0xF8, 0x11, 0x03, 0xD1, 0x3C, 0x13, 0xB4, 0x71, 0x6A, 0x16, 0x75, 0x15, 0x99, 0x1A, 0xE6, 0x1D, 0xE6, 0x20, 0xB7, 0x76, 0x4B, 0x24, 0xE8, 0x6E, 0x96, 0x29, 0xD9, 0x92, 0xF2);
                ret_C7_count = 3;
            }
            else if(ret_C7_count == 3)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1A, 0x1A, 0x1A, 0x08, 0xB2, 0x34, 0xAE, 0x0B, 0x62, 0xA4, 0xDB, 0x0D, 0x22, 0xF4, 0xF8, 0x11, 0x13, 0xD9, 0x3D, 0x13, 0xB4, 0x71, 0x69, 0x16, 0x65, 0x11, 0x99, 0x1A, 0xE6, 0x21, 0xE7, 0x20, 0xD7, 0x86, 0x4E, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C7_count = 4;
            }
            else if(ret_C7_count == 4)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1A, 0x1A, 0x1A, 0x09, 0xF2, 0x94, 0xC9, 0x0B, 0xD2, 0xD8, 0xE8, 0x0D, 0x43, 0x14, 0xFE, 0x11, 0x13, 0xE5, 0x3E, 0x13, 0xA4, 0x79, 0x6B, 0x16, 0x65, 0x19, 0x98, 0x1A, 0xC6, 0x19, 0xE5, 0x20, 0xC7, 0x7E, 0x4C, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C7_count = 0;
            }
            else
            {
                //printf("C7 err return_size[%d] ret_C7_count[%d]\n", return_size, ret_C7_count);
            }
        }
        else
        {
            TAU_LOGD("C7 resp error [%d]!\n", return_size);
        }
    }
    else if(dcs_cmd == 0xC6)
    {
        uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 1)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                         DSI_VC_0,
                                         1, 0x53);
        }
        else if(return_size == 10)
        {
            static uint8_t ret_C6_count = 0;
            if(ret_C6_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x0B, 0x32, 0xE4, 0xE1, 0x0C, 0x93, 0x1C);
                ret_C6_count = 1;
            }
            else if(ret_C6_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xF6, 0x0D, 0x93, 0x4D, 0x08, 0x11, 0x03, 0xF9, 0x40, 0x13);
                ret_C6_count = 2;
            }
            else if(ret_C6_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xA4, 0x85, 0x6B, 0x16, 0x55, 0x19, 0x98, 0x1A, 0xB6, 0x19);
                ret_C6_count = 3;
            }
            else if(ret_C6_count == 3)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE4, 0x20, 0xA7, 0x72, 0x4A, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C6_count = 4;
            }
            else if(ret_C6_count == 4)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x0C, 0xA3, 0x38, 0xFB, 0x0D, 0xA3, 0x71);
                ret_C6_count = 5;
            }
            else if(ret_C6_count == 5)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x0D, 0x0E, 0x53, 0x91, 0x1A, 0x11, 0x54, 0x19, 0x46, 0x13);
                ret_C6_count = 6;
            }
            else if(ret_C6_count == 6)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xC4, 0x99, 0x6F, 0x16, 0x55, 0x25, 0x9A, 0x1A, 0xB6, 0x19);
                ret_C6_count = 7;
            }
            else if(ret_C6_count == 7)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE4, 0x20, 0x87, 0x72, 0x49, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C6_count = 8;
            }
            else if(ret_C6_count == 8)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x0E, 0x33, 0xA9, 0x02, 0x0E, 0xA3, 0xCD);
                ret_C6_count = 9;
            }
            else if(ret_C6_count == 9)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x25, 0x0F, 0x33, 0xE1, 0x2D, 0x11, 0xC4, 0x4D, 0x54, 0x13);
                ret_C6_count = 10;
            }
            else if(ret_C6_count == 10)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE4, 0xB9, 0x76, 0x16, 0x55, 0x39, 0x9D, 0x1A, 0x96, 0x1D);
                ret_C6_count = 11;
            }
            else if(ret_C6_count == 11)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xE4, 0x20, 0x77, 0x66, 0x47, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C6_count = 12;
            }
            else if(ret_C6_count == 12)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x1A, 0x1A, 0x1A, 0x09, 0x12, 0x48, 0xAF, 0x10, 0x34, 0x49);
                ret_C6_count = 13;
            }
            else if(ret_C6_count == 13)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x40, 0x10, 0x94, 0x4D, 0x48, 0x12, 0x54, 0x99, 0x65, 0x13);
                ret_C6_count = 14;
            }
            else if(ret_C6_count == 14)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xF4, 0xE5, 0x7D, 0x16, 0x05, 0x45, 0x9E, 0x1A, 0x06, 0x0D);
                ret_C6_count = 15;
            }
            else if(ret_C6_count == 15)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0xDE, 0x1F, 0x87, 0x36, 0x38, 0x29, 0xD9, 0x92, 0xF2, 0x29);
                ret_C6_count = 0;
            }
            else
            {
                //printf("C6 err return_size[%d] ret_C6_count[%d]\n", return_size, ret_C6_count);
            }
        }
        else if(return_size == 43)
        {
            static uint8_t ret_C6_count = 0;
            if(ret_C6_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1A, 0x1A, 0x1A, 0x0B, 0x32, 0xE4, 0xE1, 0x0C, 0x93, 0x1C, 0xF6, 0x0D, 0x93, 0x4D, 0x08, 0x11, 0x03, 0xF9, 0x40, 0x13, 0xA4, 0x85, 0x6B, 0x16, 0x55, 0x19, 0x98, 0x1A, 0xB6, 0x19, 0xE4, 0x20, 0xA7, 0x72, 0x4A, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C6_count = 1;
            }
            else if(ret_C6_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1A, 0x1A, 0x1A, 0x0C, 0xA3, 0x38, 0xFB, 0x0D, 0xA3, 0x71, 0x0D, 0x0E, 0x53, 0x91, 0x1A, 0x11, 0x54, 0x19, 0x46, 0x13, 0xC4, 0x99, 0x6F, 0x16, 0x55, 0x25, 0x9A, 0x1A, 0xB6, 0x19, 0xE4, 0x20, 0x87, 0x72, 0x49, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C6_count = 2;
            }
            else if(ret_C6_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1A, 0x1A, 0x1A, 0x0E, 0x33, 0xA9, 0x02, 0x0E, 0xA3, 0xCD, 0x25, 0x0F, 0x33, 0xE1, 0x2D, 0x11, 0xC4, 0x4D, 0x54, 0x13, 0xE4, 0xB9, 0x76, 0x16, 0x55, 0x39, 0x9D, 0x1A, 0x96, 0x1D, 0xE4, 0x20, 0x77, 0x66, 0x47, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C6_count = 3;
            }
            else if(ret_C6_count == 3)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             43, 0x1A, 0x1A, 0x1A, 0x09, 0x12, 0x48, 0xAF, 0x10, 0x34, 0x49, 0x40, 0x10, 0x94, 0x4D, 0x48, 0x12, 0x54, 0x99, 0x65, 0x13, 0xF4, 0xE5, 0x7D, 0x16, 0x05, 0x45, 0x9E, 0x1A, 0x06, 0x0D, 0xDE, 0x1F, 0x87, 0x36, 0x38, 0x29, 0xD9, 0x92, 0xF2, 0x29, 0xD9, 0x92, 0xF2);
                ret_C6_count = 0;
            }
            else
            {
                //printf("C6 err return_size[%d] ret_C6_count[%d]\n", return_size, ret_C6_count);
            }
        }
        else if(return_size == 3)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         3, 0xD9, 0x92, 0xF2);
        }
        else
        {
            TAU_LOGD("C6 resp error [%d]!\n", return_size);
        }
    }
    else if(dcs_cmd == 0xA1)
    {
        uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 1)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                         DSI_VC_0,
                                         1, 0x80);
        }
        else if(return_size == 10)
        {
            static uint8_t ret_A1_count = 0;
            if(ret_A1_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x0B, 0xEB, 0x0C, 0x86, 0x9B, 0x19, 0x11, 0x01, 0x11, 0x14);
                ret_A1_count = 1;
            }
            else if(ret_A1_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x40, 0x01, 0x01, 0xF5, 0x41, 0x34, 0x58, 0x55, 0x32, 0x53);
                ret_A1_count = 2;
            }
            else if(ret_A1_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x4A, 0x41, 0x46, 0x45, 0x35, 0x41, 0x52, 0x30, 0x31, 0x38);
                ret_A1_count = 0;
            }
            else
            {
                //printf("A1 err return_size[%d] ret_A1_count[%d]\n", return_size, ret_A1_count);
            }
        }
        else if(return_size == 20)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         20, 0x40, 0x01, 0x01, 0xF5, 0x41, 0x34, 0x58, 0x55, 0x32, 0x53, 0x4A, 0x41, 0x46, 0x45, 0x35, 0x41, 0x52, 0x30, 0x31, 0x38);
        }
        else if(return_size == 4)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         4, 0x0B, 0xEB, 0x0C, 0x86);
        }
        else if(return_size == 7)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         7, 0x9B, 0x19, 0x11, 0x01, 0x11, 0x14, 0x80);
        }
        else
        {
            TAU_LOGD("A1 resp error [%d]!\n", return_size);
        }
    }
    else if(dcs_cmd == 0x7F)
    {
        uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 3)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         3, 0xFF, 0x00, 0x00);
        }
        else  if(return_size == 4)
        {
            hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                         DSI_ACK_DT_DSC_LONG_RESPONSE,
                                         DSI_VC_0,
                                         4, 0xC0, 0x64, 0x17, 0x88);
        }
        else if(return_size == 10)
        {
            static uint8_t ret_7F_count = 0;
            if(ret_7F_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x40, 0x04, 0x00, 0x00, 0x00, 0x00, 0x0C, 0x64, 0x17, 0x88);
                ret_7F_count = 1;
            }
            else if(ret_7F_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00);
                ret_7F_count = 2;
            }
            else if(ret_7F_count == 2)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00);
                ret_7F_count = 0;
            }
            else
            {
                //printf("7F err return_size[%d] ret_7F_count[%d]\n", return_size, ret_7F_count);
            }
        }
        else
        {
            TAU_LOGD("7F resp error [%d]!\n", return_size);
        }
    }
    else if(dcs_cmd == 0x9A)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_LONG_RESPONSE,
                                     DSI_VC_0,
                                     4, 0x2F, 0x3A, 0xCF, 0x50);
    }
    
    else if(dcs_cmd == 0x87)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0x00);
    }
    else if(dcs_cmd == 0xFE)
    {
        hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                     DSI_ACK_DT_DSC_SHORT_RESPONSE_1B,
                                     DSI_VC_0,
                                     1, 0x10);
    }
    
    else if(dcs_cmd == 0x5A)
    {
        uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
        if(return_size == 41)
        {
            static uint8_t ret_5A_count = 0;
            if(ret_5A_count == 0)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             41, 0x01, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00);
                ret_5A_count = 1;
            }
            else if(ret_5A_count == 1)
            {
                hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
                                             DSI_ACK_DT_DSC_LONG_RESPONSE,
                                             DSI_VC_0,
                                             41, 0x01, 0x00, 0x03, 0x00, 0x1C, 0x01, 0xFF, 0x00, 0x03, 0x01, 0xFF, 0x00, 0xEF, 0x00, 0xEE, 0x00, 0xF7, 0x00, 0xAA, 0x00, 0xA7, 0x00, 0xC8, 0x00, 0xAA, 0x00, 0xA7, 0x00, 0xC8, 0x00, 0xAA, 0x00, 0xA7, 0x00, 0xC8, 0x00, 0xAA, 0x00, 0xA7, 0x00, 0xC8);
                ret_5A_count = 0;
            }
            else
            {
                TAU_LOGD("5A err return_size[%d] ret_5A_count[%d]\n", return_size, ret_5A_count);
            }
        }
        else
        {
            TAU_LOGD("resp error [%d]!\n", return_size);
        }
    }
    else if(dcs_cmd == 0x01)
    {
        ap_get_tp_calibration_status_01(g_rx_ctrl_handle, param);
    }
    else
 //	if(s_power_off_flag)
    {
        TAU_LOGD("r %x ng need return [%d]\n", dcs_cmd, hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle));
    }
	
//	if(s_power_off_flag)
//		TAU_LOGD("resp error [%d]!\n\n",hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle));  // 为解决G996BDS基板息屏慢，造成快速唤醒慢问题
//	delayMs(1);
	
    return true;
}
/* PPS update callback 用于分辨率切换case */
static bool pps_update_handle(uint8_t* pps, uint8_t size, uint32_t pic_width, uint32_t pic_height)
{
    /* AVDD 上电, 用于解决息屏开屏PPS不更新问题 */
//    hal_gpio_set_output_data(IO_PAD_PWMEN, IO_LVL_HIGH);
//    if(pic_width != g_rx_ctrl_handle->base_info.src_w || pic_height != g_rx_ctrl_handle->base_info.src_h)
    {
        /* PPS Update 且分辨率发生变化 */
        g_rx_ctrl_handle->base_info.src_w = pic_width;
        g_rx_ctrl_handle->base_info.src_h = pic_height;
        /* 注意部分基板更新PPS前不发 Compression Mode Command的情况 */
        g_rx_ctrl_handle->compress_en = true;
        g_tx_ctrl_handle->base_info.src_w = pic_width;
        g_tx_ctrl_handle->base_info.src_h = pic_height;
    //    hal_dsi_rx_ctrl_toggle_resolution(g_rx_ctrl_handle);
		hal_dsi_rx_ctrl_toggle_resolution_ex(g_rx_ctrl_handle);
//        TAU_LOGD("resolution update w[%d] h[%d] compress[%d]\n", pic_width, pic_height, g_rx_ctrl_handle->compress_en);
    }
    g_exit_sleep_mode = true;
    TAU_LOGD("PPS Update\n");
//	hal_dsi_rx_ctrl_set_hw_tear_mode(g_rx_ctrl_handle);
    return true;
}

static bool ap_set_display_on(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
    TAU_LOGD("disp on \n");
	// 解决AOD无触情况下，ST无报点问题
	
    return true;
}

static bool ap_set_display_off(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
//   hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x28);

//   hal_gpio_set_output_data(IO_PAD_PWMEN, IO_LVL_LOW);

	s_power_off_flag = true;
	hal_system_set_pvd(false);	 //

    hal_dsi_rx_ctrl_set_sw_tear_mode(g_rx_ctrl_handle);
    hal_dsi_tx_ctrl_write_cmd(0x29, 0, 3, 0x51, 0x00, 0x00);
    delayMs(10);
    hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x28);
   delayMs(50);
    hal_gpio_set_output_data(IO_PAD_ADCIN, IO_LVL_LOW);

    hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x10);
 //   delayMs(50);
    hal_gpio_set_output_data(IO_PAD_PWMEN, IO_LVL_LOW);
	hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_LOW);
#if ENABLE_TP_WAKE_UP
 //   g_need_enter_sleep_mode = true;
	g_exit_sleep_mode = false;

#endif
    TAU_LOGD("disp off \n");
    return true;
}

static bool ap_set_enter_sleep_mode(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
    /*    hal_dsi_rx_ctrl_set_sw_tear_mode(g_rx_ctrl_handle);
        hal_dsi_tx_ctrl_write_cmd(0x29, 0, 3, 0x51, 0x00, 0x00);
        delayMs(10);
        hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x28);
     //   delayMs(50);
        hal_gpio_set_output_data(IO_PAD_ADCIN, IO_LVL_LOW);

        hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x10);
        delayMs(50);
        hal_gpio_set_output_data(IO_PAD_PWMEN, IO_LVL_LOW);
    #if ENABLE_TP_WAKE_UP
    	g_need_enter_sleep_mode = true;
    #endif
    */
    TAU_LOGD("enter sleep mode");
    g_exit_sleep_mode = false;
	g_need_enter_sleep_mode = true;
    return true;
}

static bool ap_set_exit_sleep_mode(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
    TAU_LOGD("enter exit sleep mode\n");
    g_exit_sleep_mode = true;
	s_power_off_flag = false;
    /* AVDD 上电, 用于解决息屏开屏PPS不更新问题 */
//   hal_gpio_set_output_data(IO_PAD_PWMEN, IO_LVL_HIGH);
//	hal_gpio_set_output_data(IO_PAD_ADCIN, IO_LVL_HIGH);
    return true;
}

static bool ap_update_frame_rate(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
//    static uint8_t frame_rate = 100;

//	TAU_LOGD("frame_rate:%x, %x, len=%d", dcs_packet->packet_param[0], dcs_packet->packet_param[1], dcs_packet->param_length);


//	if (resolution_change_flag )
//	{
//		resolution_change_flag = 0;
//	}
//	else
    {
//		if (dcs_packet->packet_param[0] == 0x08)
        {
            //0x08是动态适应 120hz，0x00是固定频率60hz
            if(frame_rate != dcs_packet->packet_param[0])
            {
                frame_rate = dcs_packet->packet_param[0];
                if(frame_rate == 0x00)
                {
                    hal_dsi_rx_ctrl_set_tear_mode_ex(g_rx_ctrl_handle, INPUT_HEIGHT, TE_HW_MODE);
//                    hal_dsi_rx_ctrl_toggle_input_frame_rate(g_rx_ctrl_handle, DSI_FRAME_RATE_60HZ);
//                    TAU_LOGD("60");
                }
                else if(frame_rate == 0x20)
                {
                    //120Hz
                    hal_dsi_rx_ctrl_set_tear_mode_ex(g_rx_ctrl_handle, INPUT_HEIGHT, TE_SOFT_120HZ_MODE);
//                    TAU_LOGD("120");
//                    hal_dsi_rx_ctrl_toggle_input_frame_rate(g_rx_ctrl_handle, DSI_FRAME_RATE_120HZ);
                }
//				TAU_LOGD("frame_rate:%x",frame_rate);
            }

//			TAU_LOGD("frame_rate:%x, %x",frame_rate,dcs_packet->packet_param[0]);
        }
    }
    return true;
}

static bool ap_set_backlight_51(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
    uint8_t cmd_data[2];

	
    cmd_data[0] = dcs_packet->packet_param[0];
    cmd_data[1] = dcs_packet->packet_param[1];
//	TAU_LOGD("51:[%x]", (cmd_data[0] << 8) | cmd_data[1]);
	
//    if(cmd_data[0] == 0x00 && cmd_data[1] == 0x08) return true;
    hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x51, cmd_data[0], cmd_data[1]);

    return true;
}

static bool ap_set_hbm_53(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{

    if(dcs_packet->packet_param[0] == 0x22 || dcs_packet->packet_param[0] == 0x23)	// 进入AOD模式
    {
        g_tp_sleep_in = true;
		hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x51, 0x01, 0x80);
    }
    else
    {
        g_tp_sleep_in = false;
    }
 //   TAU_LOGD("53:[%2x]", dcs_packet->packet_param[0]);

    return true;
}


static bool ap_get_reg_df(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
{
    uint8_t panel_ccm_en = dcs_packet->packet_param[0x00];
    uint16_t   panel_r = 255;
    uint16_t   panel_g = 255;
    uint16_t   panel_b = 255;

    if(panel_ccm_en == 0x00) //护眼开                                  /* CCM adjust for screen in eye-shield mode */
    {
        //TAU_LOGD("00");
        panel_g = dcs_packet->packet_param[0x33];
        panel_b = dcs_packet->packet_param[0x35];
    }
    else if(panel_ccm_en == 0x01)     //鲜明                      /* CCM adjust for screen in self-adaption mode */
    {
        //TAU_LOGD("01");

        panel_r = dcs_packet->packet_param[0x31];
        panel_g = dcs_packet->packet_param[0x33];
        panel_b = dcs_packet->packet_param[0x35];
    }
    else if(panel_ccm_en == 0x11)             ////自然
    {
        //TAU_LOGD("11");

        panel_g = dcs_packet->packet_param[0x33];
        panel_b = dcs_packet->packet_param[0x35];
    }

    /* CCM control red, green, blue */
    ccm_coef_t  coef ;
    coef.coef_c00 = panel_r;
    coef.coef_c01 = 0;
    coef.coef_c02 = 0;
    coef.coef_c10 = 0;
    coef.coef_c11 = panel_g;
    coef.coef_c12 = 0;
    coef.coef_c20 = 0;
    coef.coef_c21 = 0;
    coef.coef_c22 = panel_b;
    hal_dsi_tx_ctrl_set_ccm(coef);
    return true;
}
//static bool ap_MIPI_RX_CMD_77(hal_dsi_rx_ctrl_handle_t* handler, hal_dcs_packet_t* dcs_packet)
//{
//    for(int i = 0; i < dcs_packet->param_length; i++)
//    {
//        TAU_LOGD("77_[%d]   [%x] \n", i, dcs_packet->packet_param[i]) ;
//    }
//    if(dcs_packet->packet_param[0] == 0x28)
//    {
//        hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x51, 0x02, 0x80);
//    }
//    return true;
//}
/////////////////
/* 客制化DCS command 处理函数表格 */
static const hal_dcs_execute_entry_t g_cus_rx_dcs_execute_table[] =
{
    {DCS_SET_DISPLAY_ON, ap_set_display_on, true},
    {DCS_SET_DISPLAY_OFF, ap_set_display_off, true},
    {0x51, ap_set_backlight_51, false},   //leo S21U是用51调光的
    {0x53, ap_set_hbm_53, false},   //leo S21U是用51调光的
    {0xDF, ap_get_reg_df, false},  //蓝光
//	{0x77, ap_MIPI_RX_CMD_77, false},//息屏时钟亮度
    //  TP calibration
    {0x04, ap_set_tp_calibration_04, true},
    {DCS_ENTER_SLEEP_MODE, ap_set_enter_sleep_mode, true},
    {DCS_EXIT_SLEEP_MODE, ap_set_exit_sleep_mode, true},
    {0x60, ap_update_frame_rate, true},
    {0, NULL, false}                        //{0,NULL,false} 数组最后一个固定成员，作为table结尾的判断标准
};

static void tx_panel_reset(void)
{
    hal_dsi_tx_ctrl_panel_reset_pin(IO_LVL_HIGH);
    delayMs(10);                //10ms
    hal_dsi_tx_ctrl_panel_reset_pin(IO_LVL_LOW);
    delayMs(10);                //10ms
    hal_dsi_tx_ctrl_panel_reset_pin(IO_LVL_HIGH);
    delayMs(20);
}


static void send_panel_init_code(uint32_t size, uint8_t* data)
{
    uint32_t data_offeset = 0;
    uint8_t data_type;
    uint8_t vc;
    uint8_t data_size;
    uint8_t* p_data;

    while(data_offeset < size)
    {
        data_type = data[data_offeset];
        vc = data[data_offeset + 1];
        data_size = data[data_offeset + 2];
        p_data = &data[data_offeset + 3];
        hal_dsi_tx_ctrl_write_array_cmd(data_type, vc, data_size, p_data);
        data_offeset = data_offeset + data_size + 3;
        delayUs(50);
    }
}

#define  USE_PARAS_OLED_VIDEO
//#define  USE_PARAS_OLED_HD_1101

#if 1
const uint8_t panel_init_code[] =
{

#if 1  //S21P ICNA3511
    0x29, 0, 3, 0x9C, 0xA5, 0xA5,
    0x29, 0, 3, 0xFD, 0x5A, 0x5A,
    0x29, 0, 2, 0x9F, 0x0F,
    0x29, 0, 2, 0xB3, 0x00,
    0x29, 0, 2, 0x9F, 0x01,
    0x29, 0, 2, 0xD0, 0x01,
//	0x39,0,2,0xD3,0x01,			// command mode 屏蔽后为 video mode
    0x29, 0, 4, 0xB2, 0x5A, 0x04, 0xAF,
    0x29, 0, 36, 0xB3, 0x00, 0xD0, 0xA0, 0x10, 0xBC, 0x00, 0x00, 0xDD, 0x00, 0x10, 0x10, 0x00, 0x00, 0xB3, 0x00, 0x10, 0x10, 0x00, 0x00, 0xB3, 0x00, 0x10, 0x10, 0x22, 0x00, 0xEF, 0x00, 0x10, 0x10, 0x33, 0x18, 0x18, 0x18, 0x18, 0x18,
    0x29, 0, 17, 0xCA, 0x03, 0x01, 0x03, 0x03, 0x04, 0xE5, 0x06, 0x06, 0x04, 0xE5, 0x06, 0x06, 0x04, 0xE5, 0x06, 0x06,
    0x29, 0, 15, 0xCB, 0x03, 0x03, 0x05, 0x85, 0x07, 0x07, 0x05, 0x85, 0x07, 0x07, 0x05, 0x85, 0x07, 0x07,
    0x29, 0, 4, 0xD7, 0x00, 0x00, 0x02,
    0x29, 0, 2, 0x9F, 0x02,
    0x29, 0, 26, 0xB2, 0x00, 0xC0, 0x31, 0x10, 0x11, 0x12, 0x12, 0x10, 0x18, 0x78, 0x90, 0x50, 0x11, 0x11, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x11, 0x17,
    0x29, 0, 10, 0xB3, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 13, 0xB4, 0x00, 0x8A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 7, 0xB5, 0x00, 0x30, 0x30, 0x30, 0x30, 0x2B,
    0x29, 0, 20, 0xB6, 0x01, 0x01, 0x00, 0x11, 0x11, 0x11, 0x1C, 0x1F, 0x1F, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22,
    0x29, 0, 11, 0xB7, 0x00, 0x10, 0x0F, 0x10, 0x10, 0x15, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 14, 0xB8, 0x00, 0x00, 0x00, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28,
    0x29, 0, 13, 0xB9, 0x00, 0x00, 0x50, 0x00, 0x00, 0x0A, 0x0F, 0x00, 0x00, 0x00, 0x19, 0x0A,
    0x29, 0, 9, 0xBA, 0x00, 0xFF, 0x44, 0x04, 0x44, 0x04, 0x44, 0x04,
    0x29, 0, 26, 0xBB, 0x01, 0x4A, 0x64, 0x16, 0x17, 0x01, 0x4A, 0x64, 0x16, 0x17, 0x01, 0x4A, 0x64, 0x16, 0x14, 0x01, 0x4A, 0x64, 0x16, 0x14, 0x01, 0x31, 0x64, 0x16, 0x0F,
    0x29, 0, 17, 0xC1, 0x00, 0x00, 0x00, 0x23, 0x23, 0x24, 0x24, 0x05, 0x05, 0x21, 0x21, 0x22, 0x22, 0x01, 0x01, 0x00,
    0x29, 0, 17, 0xC2, 0x00, 0x00, 0x00, 0x23, 0x23, 0x24, 0x24, 0x05, 0x05, 0x21, 0x21, 0x22, 0x22, 0x01, 0x01, 0x00,
    0x29, 0, 8, 0xC3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 15, 0xC4, 0x00, 0x05, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x1F, 0x00, 0x00, 0x06,
    0x29, 0, 26, 0xC6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x03, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x55, 0x00, 0x01,
    0x29, 0, 14, 0xC7, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x30, 0x30,
    0x29, 0, 14, 0xC8, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x30, 0x30,
    0x29, 0, 27, 0xCC, 0x00, 0x57, 0xBA, 0x57, 0xBA, 0x00, 0x57, 0xBA, 0x57, 0xBA, 0x00, 0x57, 0xBC, 0x00, 0x30, 0x6C, 0x30, 0x6C, 0x00, 0x30, 0x6C, 0x30, 0x6C, 0x00, 0x30, 0x6C,
    0x29, 0, 17, 0xD2, 0x00, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09,
    0x29, 0, 12, 0xD7, 0x44, 0x01, 0x3F, 0x26, 0x37, 0x26, 0x37, 0x01, 0x11, 0x00, 0x00,
    0x29, 0, 26, 0xD8, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x00, 0x00,
    0x29, 0, 12, 0xD9, 0x10, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x30,
    0x29, 0, 6, 0xE1, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 26, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 13, 0xE3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 6, 0xEF, 0x00, 0x80, 0x85, 0x81, 0x82,
    0x29, 0, 9, 0xBE, 0x5F, 0x16, 0x04, 0x5F, 0x75, 0x00, 0x00, 0x00,
    0x29, 0, 2, 0xBF, 0x08,
    0x29, 0, 2, 0x9F, 0x04,
    0x29, 0, 3, 0xB2, 0x01, 0x00,
    0x29, 0, 19, 0xB3, 0x00, 0x00, 0x10, 0x00, 0x30, 0x50, 0x00, 0x70, 0x90, 0x00, 0xB0, 0xF0, 0x11, 0x30, 0x70, 0x12, 0xF0, 0x70,
    0x29, 0, 21, 0xB4, 0x23, 0xF0, 0x70, 0x34, 0xF0, 0xF0, 0x56, 0xF0, 0xF0, 0x78, 0xF0, 0xF0, 0xCE, 0xF0, 0xF0, 0xFF, 0x70, 0xF0, 0x0F, 0xFF,
    0x29, 0, 14, 0xB5, 0x11, 0x10, 0x27, 0x1C, 0xD0, 0x00, 0x64, 0x64, 0x10, 0x3F, 0xFF, 0xFF, 0xFF,
    0x29, 0, 7, 0xB6, 0x11, 0x00, 0x00, 0x0F, 0xF0, 0x10,
    0x29, 0, 3, 0xB9, 0x91, 0x83,
    //  0x29, 0, 3, 0xBA, 0x10, 0x00,
    0x29, 0, 5, 0xC4, 0x01, 0x10, 0x00, 0x00,
    0x29, 0, 20, 0xC5, 0x00, 0x20, 0x88, 0xC1, 0xCF, 0x50, 0x4F, 0x00, 0x4E, 0x57, 0x35, 0x22, 0x22, 0x2A, 0x05, 0x3F, 0x00, 0x20, 0x0F,
    0x29, 0, 13, 0xC6, 0x4B, 0x00, 0x90, 0x00, 0x02, 0xD5, 0x00, 0x02, 0xCB, 0x01, 0x10, 0x43,
    0x29, 0, 5, 0xC8, 0x29, 0x29, 0x28, 0x28,
    0x29, 0, 21, 0xC9, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x29, 0, 21, 0xCA, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x29, 0, 21, 0xCB, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x29, 0, 21, 0xCC, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x29, 0, 21, 0xCD, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 21, 0xCE, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 21, 0xCF, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 21, 0xD0, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 21, 0xD1, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 21, 0xD2, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 21, 0xD3, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 21, 0xD4, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x29, 0, 2, 0x9F, 0x05,
    0x29, 0, 7, 0xB2, 0x24, 0x20, 0x05, 0x0F, 0xFF, 0xFF,
    0x29, 0, 9, 0xB3, 0xA0, 0x00, 0x28, 0x00, 0x00, 0x00, 0x3F, 0xFF,
    0x29, 0, 11, 0xB4, 0x00, 0x60, 0x0E, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 16, 0xB5, 0x33, 0xFE, 0x6E, 0x22, 0xEC, 0x68, 0x11, 0xE4, 0x64, 0x10, 0x62, 0xEC, 0x00, 0x76, 0x02,
    0x29, 0, 7, 0xB6, 0x31, 0xFE, 0xD8, 0x00, 0x58, 0x00,
    0x29, 0, 16, 0xB9, 0x71, 0x20, 0x05, 0x78, 0x70, 0x5A, 0x3C, 0x78, 0x70, 0x5A, 0x3C, 0x78, 0x70, 0x5A, 0x3C,
    0x29, 0, 2, 0x9F, 0x07,
    0x29, 0, 8, 0xB2, 0x08, 0x08, 0x08, 0x08, 0x04, 0x02, 0xA8,
    0x29, 0, 8, 0xB3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x03, 0x8C,
    0x29, 0, 8, 0xB4, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x29, 0, 8, 0xB5, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x29, 0, 8, 0xB6, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x29, 0, 8, 0xB7, 0x08, 0x08, 0x08, 0x08, 0x02, 0x0B, 0xB8,
    0x29, 0, 8, 0xB8, 0x02, 0x04, 0x04, 0x04, 0x01, 0x0A, 0xBE,
    0x29, 0, 17, 0xB9, 0x01, 0x05, 0x03, 0x07, 0x02, 0x06, 0x04, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 17, 0xBA, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 17, 0xBB, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 17, 0xBC, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 17, 0xBD, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 17, 0xBE, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 17, 0xBF, 0x01, 0x02, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 16, 0xC0, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x29, 0, 16, 0xC1, 0x33, 0x8C, 0x8C, 0x33, 0x8C, 0x8C, 0x32, 0x20, 0x18, 0x10, 0x0C, 0x58, 0x00, 0x2C, 0x2C,
    0x29, 0, 16, 0xC2, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x29, 0, 16, 0xC3, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x29, 0, 7, 0xC4, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8,
    0x29, 0, 7, 0xC5, 0x97, 0xC4, 0xD0, 0x76, 0x08, 0x40,
    0x29, 0, 4, 0xC6, 0x97, 0x2E, 0x9E,
    0x29, 0, 3, 0xC7, 0x02, 0x00,
    0x29, 0, 8, 0xC8, 0x10, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x29, 0, 8, 0xC9, 0x0F, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x29, 0, 8, 0xCA, 0x0E, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x29, 0, 8, 0xCB, 0x0D, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x29, 0, 17, 0xCC, 0x01, 0x09, 0x03, 0x0B, 0x05, 0x0D, 0x07, 0x0F, 0x02, 0x0A, 0x04, 0x0C, 0x06, 0x0E, 0x08, 0x10,
    0x29, 0, 17, 0xCD, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x0F, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x0E, 0x00,
    0x29, 0, 17, 0xCE, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x0E, 0x00, 0x00,
    0x29, 0, 17, 0xCF, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x00, 0x00, 0x00,
    0x29, 0, 16, 0xD0, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x29, 0, 16, 0xD1, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x29, 0, 16, 0xD2, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x29, 0, 16, 0xD3, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x29, 0, 2, 0x9F, 0x0F,
    0x29, 0, 2, 0xF8, 0x11,
    0x29, 0, 2, 0x9F, 0x00,
    0x29, 0, 2, 0x48, 0x00,
    0x29, 0, 3, 0x51, 0x00, 0x00,
    0x29, 0, 2, 0x53, 0xE0,
    0x29, 0, 2, 0x35, 0x00,
    0x29, 0, 1, 0x11,

    0x29, 0, 2, 0x9F, 0x05,
    0x29, 0, 2, 0xF9, 0x80,
    0x29, 0, 2, 0xF7, 0x10,
    0x29, 0, 2, 0x9F, 0x06,
    0x29, 0, 41, 0xB2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 41, 0xB3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 21, 0xB4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 41, 0xB5, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
    0x29, 0, 41, 0xB6, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
    0x29, 0, 21, 0xB7, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
#if 1

#if  0
	/////////////GAMMA1  20230818 ///////////////
	0x39,0,2,0X9F,0X04,
	0x39,0,19,0XB3,0X00,0X00,0X10,0X00,0X30,0X50,0X00,0X70,0X90,0X00,0XB0,0XF0,0X11,0X30,0X70,0X12,0XF0,0X70,
	0x39,0,21,0XB4,0X23,0XF0,0X70,0X34,0XF0,0XF0,0X56,0XF0,0XF0,0X78,0XF0,0XF0,0XCE,0XF0,0XF0,0XFF,0X70,0XF0,0X0F,0XFF,
	0x39,0,2,0X9F,0X05,
	0x39,0,16,0XB5,0X33,0XFF,0X6E,0X21,0X61,0X40,0X11,0X40,0X01,0X00,0XAF,0X5B,0X00,0X36,0X00,
	0x39,0,16,0XB6,0X33,0XFF,0X6E,0X00,0X6E,0X01,0XFA,0XFF,0XAA,0X50,0X55,0X00,0X00,0X00,0X00,
	0x39,0,2,0X9F,0X05,
	0x39,0,2,0XF9,0X80,
	0x39,0,2,0XF7,0X10,
	0x39,0,2,0X9F,0X06,
	0x39,0,3,0XFF,0X00,0X01,
	0x39,0,5,0XFE,0X01,0X00,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X49,0X01,0XC5,0X28,0X12,0X7D,0X0F,0X22,0X8A,0XF3,0X34,0XA2,0X32,0X45,0XB1,0X23,
	0x39,0,18,0XF2,0X56,0X8F,0X4C,0X67,0XF5,0X92,0X88,0X22,0XAF,0XAB,0XC4,0XD3,0XCC,0X18,0X6B,0XC0,0X6B,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X53,0X01,0XA8,0X35,0X12,0XAB,0X10,0X23,0XB9,0X42,0X34,0XB5,0X1B,
	0x39,0,18,0XF4,0X45,0X7C,0X25,0X56,0XBA,0X45,0X67,0XC6,0X45,0X99,0X0C,0XED,0XAA,0X25,0X6B,0XA0,0X6B,
	0x39,0,22,0XF5,0X00,0X2F,0X93,0X01,0X94,0X31,0X12,0XB9,0X2E,0X23,0X90,0X33,0X34,0XB7,0X28,0X45,0XE7,0X87,0X66,0X12,0X91,
	0x39,0,18,0XF6,0X77,0X09,0XD9,0X89,0X91,0X41,0X9A,0XE5,0X8A,0XDE,0X00,0X54,0XEF,0XB1,0X23,0XF0,0X23,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X01,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X6F,0X01,0XD9,0X34,0X12,0X84,0X10,0X22,0X88,0XED,0X34,0X97,0X25,0X45,0XA2,0X11,
	0x39,0,18,0XF2,0X56,0X78,0X32,0X67,0XD6,0X6E,0X78,0XFB,0X80,0XAB,0X7A,0X7A,0XBC,0XBB,0X00,0XC0,0X00,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X13,0X67,0X01,0XB3,0X37,0X12,0XA8,0X07,0X23,0XAC,0X31,0X34,0XA3,0X08,
	0x39,0,18,0XF4,0X45,0X63,0X08,0X56,0X9A,0X21,0X67,0X9F,0X16,0X89,0XCA,0XA1,0X9A,0XD8,0X0D,0XA0,0X0D,
	0x39,0,22,0XF5,0X00,0X00,0X4D,0X01,0XA2,0X48,0X12,0XC5,0X32,0X23,0X92,0X31,0X34,0XB2,0X1F,0X45,0XD9,0X76,0X66,0X01,0X7C,
	0x39,0,18,0XF6,0X67,0XEE,0XBA,0X89,0X6D,0X16,0X9A,0XB5,0X51,0XCD,0XA9,0XE9,0XEE,0X3F,0X9C,0XE0,0X9C,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X02,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X16,0X00,0X7A,0XC6,0X11,0X0C,0X85,0X12,0XEF,0X4E,0X23,0XE9,0X6A,0X34,0XD9,0X3D,
	0x39,0,18,0XF2,0X45,0X97,0X3A,0X56,0XCA,0X51,0X67,0XC8,0X39,0X89,0XCA,0X84,0X99,0XB3,0XE0,0X90,0XE0,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X42,0XB5,0X11,0X19,0X70,0X22,0X02,0X7F,0X23,0XEA,0X48,
	0x39,0,18,0XF4,0X34,0X9A,0X2D,0X45,0XAC,0X1E,0X55,0X8C,0XF2,0X77,0X58,0XFA,0X88,0X23,0X49,0X80,0X49,
	0x39,0,22,0XF5,0X00,0X00,0X30,0X00,0X98,0XEF,0X11,0X55,0XAE,0X22,0X03,0X93,0X33,0X0D,0X73,0X44,0X1A,0XA7,0X55,0X22,0X90,
	0x39,0,18,0XF6,0X56,0XF5,0XAB,0X77,0X47,0XD6,0X88,0X5D,0XDA,0XAB,0XA5,0X82,0XBB,0XB6,0XF2,0XB0,0XF2,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X03,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X18,0X00,0X4E,0XAB,0X01,0XFB,0X43,0X12,0XC1,0X2D,0X22,0X8B,0XDF,
	0x39,0,18,0XF2,0X33,0X2A,0XAE,0X44,0X20,0X87,0X45,0XE5,0X3C,0X66,0X66,0XEC,0X77,0X0B,0X2A,0X70,0X2A,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X32,0X77,0X01,0XEC,0X52,0X11,0XAB,0XF8,
	0x39,0,18,0XF4,0X22,0X41,0XC0,0X33,0X2C,0X8B,0X34,0XDF,0X2E,0X55,0X36,0XAC,0X55,0XC8,0XE3,0X50,0XE3,
	0x39,0,22,0XF5,0X00,0X00,0X01,0X00,0X5A,0X8D,0X00,0XC2,0XF0,0X11,0X23,0X8F,0X12,0XF0,0X48,0X23,0XD8,0X4E,0X34,0XB4,0X0F,
	0x39,0,18,0XF6,0X44,0X61,0XF3,0X55,0X71,0XE3,0X66,0X4C,0XAD,0X78,0XF4,0X86,0X88,0XA7,0XCB,0X80,0XCB,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X04,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X22,0X96,0X01,0XF4,0X43,0X12,0XC7,0X38,0X22,0X9B,0XF1,
	0x39,0,18,0XF2,0X33,0X40,0XC9,0X44,0X3C,0XA6,0X55,0X08,0X63,0X67,0X91,0X18,0X77,0X36,0X57,0X70,0X57,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X2D,0X75,0X01,0XF0,0X5A,0X12,0XB5,0X06,
	0x39,0,18,0XF4,0X22,0X52,0XD6,0X33,0X44,0XA4,0X34,0XFC,0X4E,0X55,0X5B,0XD3,0X56,0XF0,0X0C,0X60,0X0C,
	0x39,0,22,0XF5,0X00,0X00,0X01,0X00,0X56,0X6F,0X00,0XAB,0XEE,0X11,0X2D,0X97,0X12,0XFB,0X57,0X23,0XEC,0X68,0X34,0XCF,0X2C,
	0x39,0,18,0XF6,0X45,0X81,0X15,0X56,0X95,0X0A,0X66,0X75,0XD8,0X88,0X25,0XBA,0X89,0XDD,0X04,0X90,0X04,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X05,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X25,0X98,0X01,0XF7,0X47,0X12,0XD2,0X48,0X23,0XB0,0X08,
	0x39,0,18,0XF2,0X33,0X58,0XE2,0X44,0X5D,0XC6,0X55,0X2A,0X84,0X67,0XBA,0X45,0X77,0X65,0X85,0X70,0X85,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X2D,0X75,0X01,0XF3,0X5E,0X12,0XBE,0X14,
	0x39,0,18,0XF4,0X22,0X64,0XEC,0X33,0X5E,0XC0,0X44,0X18,0X6B,0X55,0X7E,0XFA,0X66,0X17,0X34,0X60,0X34,
	0x39,0,22,0XF5,0X00,0X00,0X01,0X00,0X92,0XDA,0X01,0XDB,0X11,0X11,0X4A,0XB1,0X22,0X18,0X71,0X33,0X0B,0X85,0X34,0XF0,0X4B,
	0x39,0,18,0XF6,0X45,0XA0,0X35,0X56,0XBB,0X30,0X66,0X9B,0XFF,0X88,0X51,0XEE,0X99,0X11,0X38,0X90,0X38,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X06,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X34,0XAA,0X11,0X0D,0X6A,0X22,0X11,0X98,0X33,0X03,0X66,
	0x39,0,18,0XF2,0X34,0XB7,0X49,0X45,0XCC,0X42,0X56,0XA8,0X09,0X77,0X51,0XE3,0X88,0X02,0X27,0X80,0X27,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X3E,0X8C,0X11,0X14,0X94,0X22,0X03,0X67,
	0x39,0,18,0XF4,0X23,0XB9,0X47,0X34,0XC2,0X2A,0X44,0X88,0XDF,0X66,0X04,0X87,0X66,0XA5,0XC4,0X60,0XC4,
	0x39,0,22,0XF5,0X00,0X00,0X01,0X01,0XB2,0X1A,0X11,0X5A,0X5B,0X12,0X97,0X0A,0X22,0X6E,0XCB,0X33,0X66,0XE7,0X44,0X53,0XB9,
	0x39,0,18,0XF6,0X55,0X10,0XAC,0X66,0X39,0XB7,0X77,0X2A,0X92,0X89,0XFB,0XA5,0X99,0XC0,0XED,0X90,0XED,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X07,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X47,0X00,0X86,0XF6,0X11,0X65,0XD6,0X23,0X8E,0X1D,0X34,0X9B,0X05,
	0x39,0,18,0XF2,0X45,0X5E,0X02,0X56,0X90,0X0F,0X66,0X81,0XF0,0X89,0X5C,0X00,0X99,0X23,0X4C,0X90,0X4C,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X1D,0X00,0X70,0XBF,0X12,0X69,0X04,0X22,0X88,0XF3,
	0x39,0,18,0XF4,0X33,0X50,0XEC,0X44,0X6E,0XE1,0X55,0X49,0XAB,0X67,0XF2,0X81,0X77,0XA4,0XC5,0X70,0XC5,
	0x39,0,22,0XF5,0X00,0X00,0X03,0X11,0X41,0X8A,0X12,0XC6,0X04,0X22,0X44,0XB6,0X33,0X20,0X79,0X44,0X12,0X99,0X55,0X10,0X7B,
	0x39,0,18,0XF6,0X56,0XD6,0X85,0X77,0X1D,0XA5,0X88,0X20,0X96,0XAA,0X36,0XF8,0XBB,0X28,0X52,0XB0,0X52,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X08,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X30,0X7A,0X01,0XB2,0X2C,0X12,0XAE,0X27,0X23,0XE6,0X82,0X44,0X05,0X77,
	0x39,0,18,0XF2,0X45,0XDB,0X87,0X66,0X1E,0XA3,0X77,0X1B,0X94,0X99,0X28,0XD8,0X9A,0XFE,0X2F,0XA0,0X2F,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X30,0X00,0X7F,0XD4,0X12,0X9A,0X51,0X23,0XDF,0X4F,
	0x39,0,18,0XF4,0X34,0XB6,0X5C,0X45,0XE9,0X63,0X56,0XD6,0X3B,0X78,0X9B,0X38,0X88,0X5E,0X82,0X80,0X82,
	0x39,0,22,0XF5,0X00,0X00,0X01,0X02,0XFB,0X3B,0X22,0X64,0X9F,0X23,0XDB,0X44,0X34,0XA9,0X02,0X45,0X98,0X28,0X56,0XA0,0X10,
	0x39,0,18,0XF6,0X67,0X75,0X28,0X78,0XC5,0X52,0X89,0XD8,0X58,0XBC,0X29,0X04,0XCC,0X34,0X6D,0XC0,0X6D,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
	0x39,0,5,0XFE,0X01,0X09,0X00,0X00,
	0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X05,0X50,0X00,0X73,0XDE,0X11,0X38,0XA6,0X22,0X66,0XFD,0X33,0X7C,0XDD,
	0x39,0,18,0XF2,0X44,0X4A,0XF1,0X55,0X7E,0XFC,0X66,0X70,0XD4,0X88,0X3A,0XE6,0X99,0X0E,0X34,0X90,0X34,
	0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X3D,0X7F,0X11,0X0B,0XB0,0X22,0X46,0XBC,
	0x39,0,18,0XF4,0X33,0X26,0XCA,0X44,0X52,0XCA,0X55,0X34,0X8C,0X67,0XD1,0X68,0X77,0X8B,0XAC,0X70,0XAC,
	0x39,0,22,0XF5,0X00,0X00,0X01,0X02,0X92,0X1B,0X22,0X3D,0X72,0X22,0XA2,0XF8,0X33,0X55,0XA5,0X44,0X34,0XAB,0X55,0X1F,0X7C,
	0x39,0,18,0XF6,0X56,0XE2,0X88,0X77,0X1C,0XA3,0X88,0X1B,0X85,0XAA,0X14,0XE0,0XBB,0X0E,0X3A,0XB0,0X3A,
	0x39,0,2,0XFF,0X01,
//	delayMs(1);
//	0x39,0,2,0X9F,0X05,
//	0x39,0,2,0XF9,0X00,
//	0x39,0,2,0XF7,0X00,
//	0x39,0,2,0X9F,0X06,
//	0x39,0,3,0XFF,0X00,0X00,

#else

///////////////GAMMA1///////////////
//    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x39, 0xC7, 0x11, 0x48, 0xB0, 0x22, 0x0B, 0x96, 0x33, 0x12, 0x79, 0x44, 0x1D, 0xA3, 0x55, 0x21, 0x8D,
//    0x39, 0, 18, 0xF2, 0x56, 0xF4, 0xA3, 0x77, 0x3C, 0xC9, 0x88, 0x50, 0xD6, 0xAB, 0xCE, 0xCB, 0xCC, 0x14, 0x51, 0xC0, 0x51,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x0B, 0x5B, 0x01, 0xB9, 0x05, 0x11, 0x58, 0xD7, 0x22, 0x46, 0xAA, 0x33, 0x44, 0xBE, 0x44, 0x29, 0x8C,
//    0x39, 0, 18, 0xF4, 0x45, 0xE8, 0x8C, 0x66, 0x1E, 0x98, 0x77, 0x11, 0x83, 0x99, 0x2E, 0xFE, 0xAA, 0x37, 0x68, 0xA0, 0x68,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xE1, 0x11, 0x4D, 0xC3, 0x22, 0x36, 0x94, 0x23, 0xEC, 0x78, 0x34, 0xEE, 0x59, 0x55, 0x0A, 0x97, 0x66, 0x18, 0x87,
//    0x39, 0, 18, 0xF6, 0x67, 0xEF, 0xA5, 0x88, 0x47, 0xD9, 0x99, 0x71, 0xFB, 0xCD, 0x17, 0x2D, 0xDD, 0x79, 0xBC, 0xD0, 0xBC,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x2B, 0x00, 0x7D, 0xDC, 0x11, 0x44, 0xA1, 0x12, 0xF5, 0x82, 0x23, 0xF0, 0x4A, 0x34, 0xEA, 0x72, 0x45, 0xE3, 0x4C,
//    0x39, 0, 18, 0xF2, 0x56, 0xAB, 0x58, 0x67, 0xED, 0x73, 0x78, 0xEF, 0x65, 0xAB, 0x2C, 0x0E, 0xBB, 0x43, 0x7B, 0xB0, 0x7B,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x37, 0x00, 0x62, 0x8D, 0x01, 0xCA, 0x0A, 0x11, 0x4D, 0xC6, 0x22, 0x29, 0x7C, 0x33, 0x13, 0x8E, 0x34, 0xEF, 0x4F,
//    0x39, 0, 18, 0xF4, 0x45, 0xA6, 0x43, 0x56, 0xC9, 0x46, 0x67, 0xB5, 0x1E, 0x89, 0xA0, 0x56, 0x99, 0x83, 0xB7, 0x90, 0xB7,
//    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x2C, 0x11, 0x77, 0xCF, 0x22, 0x2F, 0x86, 0x23, 0xD5, 0x60, 0x34, 0xCC, 0x29, 0x45, 0xD4, 0x63, 0x56, 0xDC, 0x46,
//    0x39, 0, 18, 0xF6, 0x67, 0xA8, 0x58, 0x78, 0xF4, 0x7F, 0x99, 0x05, 0x82, 0xBC, 0x6C, 0x60, 0xCC, 0x99, 0xD1, 0xC0, 0xD1,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x09, 0x00, 0x5A, 0x9A, 0x01, 0xE3, 0x2F, 0x11, 0x78, 0xEF, 0x22, 0x5A, 0xB1, 0x33, 0x46, 0xBD, 0x44, 0x23, 0x7E,
//    0x39, 0, 18, 0xF2, 0x45, 0xD6, 0x6E, 0x56, 0xF3, 0x68, 0x67, 0xD9, 0x3D, 0x89, 0x9F, 0x44, 0x99, 0x6D, 0x95, 0x90, 0x95,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x26, 0x00, 0x52, 0x6E, 0x00, 0x91, 0xBE, 0x01, 0xED, 0x46, 0x11, 0xA0, 0xF0, 0x22, 0x79, 0xE6, 0x33, 0x45, 0x98,
//    0x39, 0, 18, 0xF4, 0x34, 0xE5, 0x6E, 0x45, 0xE5, 0x51, 0x56, 0xB5, 0x14, 0x77, 0x4D, 0xDE, 0x78, 0xFE, 0x26, 0x80, 0x26,
//    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x25, 0x11, 0x57, 0x92, 0x12, 0xD5, 0x1B, 0x22, 0x5E, 0xD0, 0x33, 0x38, 0x8F, 0x44, 0x23, 0xA2, 0x55, 0x10, 0x70,
//    0x39, 0, 18, 0xF6, 0x56, 0xCC, 0x6A, 0x67, 0xF0, 0x6A, 0x78, 0xDF, 0x46, 0x9A, 0xC0, 0x74, 0xAA, 0x9F, 0xCD, 0xA0, 0xCD,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x36, 0x5C, 0x00, 0x7D, 0xA2, 0x01, 0xCD, 0x23, 0x11, 0x75, 0xC1, 0x22, 0x3E, 0xAA, 0x33, 0x06, 0x53,
//    0x39, 0, 18, 0xF2, 0x34, 0x96, 0x0F, 0x44, 0x79, 0xE5, 0x55, 0x3D, 0x90, 0x67, 0xA4, 0x1A, 0x77, 0x37, 0x51, 0x70, 0x51,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x3F, 0x55, 0x00, 0x60, 0x6F, 0x00, 0x84, 0xB5, 0x01, 0xEB, 0x23, 0x11, 0x8A, 0xE8, 0x22, 0x3C, 0x84,
//    0x39, 0, 18, 0xF4, 0x23, 0xC2, 0x35, 0x33, 0x95, 0xF1, 0x44, 0x41, 0x8C, 0x55, 0x87, 0xF4, 0x66, 0x0F, 0x25, 0x60, 0x25,
//    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x01, 0x11, 0x37, 0x59, 0x11, 0x75, 0x99, 0x12, 0xC0, 0x10, 0x22, 0x5F, 0xA6, 0x33, 0x1D, 0x88, 0x34, 0xE2, 0x33,
//    0x39, 0, 18, 0xF6, 0x44, 0x7A, 0xFD, 0x55, 0x6C, 0xDD, 0x66, 0x38, 0x8C, 0x78, 0xA8, 0x24, 0x88, 0x41, 0x5D, 0x80, 0x5D,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x03, 0x2D, 0x00, 0x59, 0x86, 0x01, 0xB9, 0x1B, 0x11, 0x71, 0xBF, 0x22, 0x45, 0xB3, 0x33, 0x14, 0x63,
//    0x39, 0, 18, 0xF2, 0x34, 0xAE, 0x2B, 0x45, 0x9A, 0x01, 0x55, 0x5B, 0xAF, 0x67, 0xC9, 0x44, 0x77, 0x61, 0x7F, 0x70, 0x7F,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x2E, 0x42, 0x00, 0x52, 0x61, 0x00, 0x76, 0xAB, 0x01, 0xE3, 0x1F, 0x11, 0x89, 0xEE, 0x22, 0x44, 0x8E,
//    0x39, 0, 18, 0xF4, 0x23, 0xD4, 0x4A, 0x34, 0xAE, 0x08, 0x44, 0x5C, 0xA7, 0x56, 0xA9, 0x1A, 0x66, 0x33, 0x4E, 0x60, 0x4E,
//    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x07, 0x11, 0x34, 0x53, 0x11, 0x74, 0x9A, 0x12, 0xC2, 0x16, 0x22, 0x65, 0xAC, 0x33, 0x2F, 0x9C, 0x34, 0xFA, 0x4B,
//    0x39, 0, 18, 0xF6, 0x45, 0x99, 0x1E, 0x55, 0x91, 0xFE, 0x66, 0x59, 0xAE, 0x78, 0xD2, 0x51, 0x88, 0x70, 0x8F, 0x80, 0x8F,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x27, 0x00, 0x4F, 0x7B, 0x01, 0xA4, 0x02, 0x11, 0x57, 0xA5, 0x22, 0x2D, 0xA4, 0x23, 0xFF, 0x55,
//    0x39, 0, 18, 0xF2, 0x34, 0x9F, 0x1D, 0x44, 0x8E, 0xF1, 0x55, 0x4B, 0x9A, 0x67, 0xB5, 0x32, 0x77, 0x4A, 0x67, 0x70, 0x67,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x3A, 0x4E, 0x00, 0x5F, 0x6D, 0x00, 0x80, 0xA9, 0x01, 0xDD, 0x10, 0x11, 0x76, 0xDD, 0x22, 0x2F, 0x7E,
//    0x39, 0, 18, 0xF4, 0x23, 0xC6, 0x3E, 0x33, 0xA4, 0xFB, 0x44, 0x4D, 0x94, 0x56, 0x96, 0x07, 0x66, 0x20, 0x3A, 0x60, 0x3A,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xD6, 0x11, 0x56, 0x70, 0x11, 0x91, 0xB0, 0x12, 0xD2, 0x21, 0x22, 0x6E, 0xB4, 0x33, 0x2F, 0x9C, 0x34, 0xF0, 0x44,
//    0x39, 0, 18, 0xF6, 0x45, 0x92, 0x15, 0x55, 0x89, 0xF1, 0x66, 0x4C, 0x9C, 0x78, 0xBE, 0x3F, 0x88, 0x59, 0x79, 0x80, 0x79,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x22, 0x00, 0x41, 0x63, 0x00, 0x87, 0xD7, 0x11, 0x24, 0x76, 0x22, 0x10, 0x90, 0x23, 0xF2, 0x4E,
//    0x39, 0, 18, 0xF2, 0x34, 0x96, 0x1B, 0x44, 0x90, 0xEE, 0x55, 0x4E, 0x9A, 0x67, 0xB9, 0x31, 0x77, 0x4B, 0x5C, 0x70, 0x5C,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x5D, 0x78, 0x00, 0x85, 0x92, 0x00, 0xA2, 0xC0, 0x01, 0xE1, 0x0C, 0x11, 0x68, 0xD1, 0x22, 0x26, 0x7A,
//    0x39, 0, 18, 0xF4, 0x23, 0xBD, 0x39, 0x33, 0xA5, 0xF7, 0x44, 0x4E, 0x96, 0x56, 0x99, 0x08, 0x66, 0x20, 0x2E, 0x60, 0x2E,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xAC, 0x11, 0xA0, 0xBE, 0x11, 0xD8, 0xF4, 0x22, 0x10, 0x51, 0x22, 0x90, 0xD0, 0x33, 0x43, 0xAC, 0x34, 0xFF, 0x52,
//    0x39, 0, 18, 0xF6, 0x45, 0x98, 0x1F, 0x55, 0x94, 0xF6, 0x66, 0x54, 0xA0, 0x78, 0xC4, 0x40, 0x88, 0x5B, 0x6B, 0x80, 0x6B,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x39, 0x00, 0x63, 0x7E, 0x00, 0x98, 0xC9, 0x01, 0xFF, 0x40, 0x12, 0xCE, 0x5C, 0x23, 0xD3, 0x2F,
//    0x39, 0, 18, 0xF2, 0x34, 0x86, 0x08, 0x44, 0x8C, 0xEF, 0x55, 0x4C, 0x9F, 0x67, 0xB9, 0x2A, 0x77, 0x51, 0x65, 0x70, 0x65,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0xCE, 0x00, 0xE0, 0xEF, 0x01, 0xFA, 0x11, 0x11, 0x25, 0x40, 0x11, 0x83, 0xD4, 0x22, 0x26, 0x6F,
//    0x39, 0, 18, 0xF4, 0x23, 0xBB, 0x31, 0x33, 0xA2, 0xFA, 0x44, 0x4F, 0x9A, 0x56, 0x9A, 0x03, 0x66, 0x24, 0x37, 0x60, 0x37,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x2B, 0x22, 0x59, 0x73, 0x22, 0x85, 0x9A, 0x22, 0xB3, 0xDB, 0x33, 0x05, 0x31, 0x33, 0x87, 0xDD, 0x44, 0x31, 0x78,
//    0x39, 0, 18, 0xF6, 0x45, 0xC0, 0x36, 0x56, 0xB0, 0x10, 0x66, 0x68, 0xB7, 0x78, 0xCE, 0x43, 0x88, 0x6A, 0x80, 0x80, 0x80,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x62, 0x8D, 0x00, 0xA2, 0xC9, 0x01, 0xF9, 0x2A, 0x12, 0xA7, 0x3B, 0x23, 0xBF, 0x2B,
//    0x39, 0, 18, 0xF2, 0x34, 0x84, 0x1B, 0x45, 0x9C, 0x05, 0x55, 0x69, 0xC0, 0x67, 0xDF, 0x5E, 0x77, 0x78, 0x95, 0x70, 0x95,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x18, 0x11, 0x25, 0x3C, 0x11, 0x4B, 0x64, 0x11, 0x81, 0x96, 0x12, 0xCC, 0x0E, 0x22, 0x53, 0x9A,
//    0x39, 0, 18, 0xF4, 0x23, 0xDC, 0x53, 0x34, 0xBB, 0x18, 0x44, 0x6B, 0xBB, 0x56, 0xBE, 0x34, 0x66, 0x4F, 0x66, 0x60, 0x66,
//    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x29, 0x23, 0x15, 0x1E, 0x33, 0x30, 0x3D, 0x33, 0x4C, 0x6C, 0x33, 0x8E, 0xB1, 0x34, 0xF0, 0x3C, 0x44, 0x82, 0xC8,
//    0x39, 0, 18, 0xF6, 0x55, 0x06, 0x82, 0x56, 0xF0, 0x4B, 0x66, 0xA4, 0xF0, 0x88, 0x07, 0x8C, 0x88, 0xA1, 0xBD, 0x80, 0xBD,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x00, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x70, 0x9C, 0x00, 0xB3, 0xD2, 0x11, 0x04, 0x4C, 0x12, 0xA5, 0x06,
//    0x39, 0, 18, 0xF2, 0x23, 0x69, 0x03, 0x33, 0x84, 0xE4, 0x44, 0x42, 0x90, 0x56, 0x98, 0x06, 0x66, 0x21, 0x36, 0x60, 0x36,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x08, 0x0E, 0x11, 0x28, 0x40, 0x11, 0x55, 0x64, 0x11, 0x82, 0xA3, 0x11, 0xC9, 0xF2,
//    0x39, 0, 18, 0xF4, 0x22, 0x23, 0x7B, 0x23, 0xD9, 0x23, 0x33, 0x6E, 0xAD, 0x44, 0x93, 0xF6, 0x55, 0x0E, 0x23, 0x50, 0x23,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x02, 0x11, 0x72, 0xB8, 0x33, 0x1E, 0x24, 0x33, 0x2E, 0x42, 0x33, 0x59, 0x6D, 0x33, 0x98, 0xC1, 0x34, 0xF0, 0x1E,
//    0x39, 0, 18, 0xF6, 0x44, 0x52, 0xA9, 0x55, 0x05, 0x53, 0x55, 0x9C, 0xE1, 0x67, 0xCE, 0x34, 0x77, 0x4E, 0x64, 0x70, 0x64,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0xE4, 0x11, 0x37, 0x96, 0x12, 0xF5, 0x4D, 0x23, 0x9A, 0x20, 0x33, 0x8E, 0xEE, 0x45, 0x8C, 0x0D, 0x55, 0x7E, 0xE6,
//    0x39, 0, 18, 0xF2, 0x66, 0x44, 0xF2, 0x78, 0x8A, 0x16, 0x89, 0x97, 0x19, 0xAB, 0xF7, 0xE5, 0xCC, 0x20, 0x62, 0xC0, 0x62,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0xF8, 0x11, 0x28, 0x57, 0x11, 0x8E, 0xC8, 0x22, 0x02, 0x71, 0x23, 0xD1, 0x28, 0x34, 0xBB, 0x32, 0x44, 0x99, 0xF5,
//    0x39, 0, 18, 0xF4, 0x55, 0x4A, 0xE0, 0x66, 0x68, 0xE4, 0x77, 0x57, 0xC6, 0x9A, 0x5D, 0x23, 0xAA, 0x56, 0x8E, 0xA0, 0x8E,
//    0x39, 0, 22, 0xF5, 0x01, 0x00, 0xF9, 0x22, 0x47, 0x96, 0x23, 0xEC, 0x3B, 0x34, 0x86, 0x09, 0x44, 0x76, 0xD6, 0x56, 0x7A, 0x03, 0x66, 0x7A, 0xE6,
//    0x39, 0, 18, 0xF6, 0x77, 0x4A, 0xFF, 0x89, 0x9E, 0x33, 0x9A, 0xBE, 0x47, 0xCD, 0x4A, 0x55, 0xDD, 0x9B, 0xE0, 0xD0, 0xE0,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x4F, 0x11, 0x8D, 0xCF, 0x22, 0x1B, 0x66, 0x23, 0xAD, 0x29, 0x33, 0x92, 0xEE, 0x45, 0x86, 0x07, 0x55, 0x75, 0xDA,
//    0x39, 0, 18, 0xF2, 0x66, 0x39, 0xE1, 0x77, 0x73, 0xF9, 0x88, 0x7A, 0xF3, 0xAB, 0xC0, 0xA4, 0xBC, 0xE0, 0x1B, 0xC0, 0x1B,
//    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5F, 0x11, 0x82, 0xA2, 0x11, 0xC6, 0xF1, 0x22, 0x22, 0x81, 0x23, 0xDA, 0x2A, 0x34, 0xB4, 0x29, 0x44, 0x8C, 0xE6,
//    0x39, 0, 18, 0xF4, 0x55, 0x39, 0xCD, 0x66, 0x50, 0xC8, 0x77, 0x3A, 0xA4, 0x99, 0x2B, 0xEB, 0xAA, 0x1C, 0x4B, 0xA0, 0x4B,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x43, 0x22, 0x83, 0xC4, 0x33, 0x0C, 0x51, 0x34, 0x96, 0x0F, 0x44, 0x78, 0xD4, 0x55, 0x74, 0xFA, 0x66, 0x6F, 0xD9,
//    0x39, 0, 18, 0xF6, 0x77, 0x3B, 0xEA, 0x89, 0x84, 0x13, 0x9A, 0x9C, 0x1D, 0xCD, 0x0B, 0x0F, 0xDD, 0x56, 0x93, 0xD0, 0x93,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x48, 0x11, 0x87, 0xC5, 0x22, 0x09, 0x51, 0x23, 0x94, 0x0B, 0x33, 0x73, 0xCD, 0x44, 0x61, 0xDD, 0x55, 0x4C, 0xAF,
//    0x39, 0, 18, 0xF2, 0x66, 0x09, 0xA9, 0x77, 0x3A, 0xBD, 0x88, 0x38, 0xA9, 0xAB, 0x5B, 0x31, 0xBB, 0x66, 0x94, 0xB0, 0x94,
//    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5E, 0x11, 0x80, 0x9C, 0x11, 0xBE, 0xE5, 0x22, 0x11, 0x6B, 0x23, 0xC0, 0x0C, 0x34, 0x92, 0x03, 0x44, 0x66, 0xBF,
//    0x39, 0, 18, 0xF4, 0x55, 0x0F, 0x9E, 0x66, 0x1C, 0x91, 0x67, 0xFD, 0x62, 0x89, 0xD7, 0x8C, 0x99, 0xB8, 0xE3, 0x90, 0xE3,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x22, 0x7D, 0xB9, 0x23, 0xFB, 0x3C, 0x33, 0x7E, 0xF3, 0x44, 0x59, 0xB3, 0x55, 0x4D, 0xD0, 0x66, 0x44, 0xAD,
//    0x39, 0, 18, 0xF6, 0x77, 0x0A, 0xB2, 0x88, 0x48, 0xD2, 0x99, 0x54, 0xCF, 0xBC, 0x9E, 0x8B, 0xCC, 0xC8, 0xFE, 0xC0, 0xFE,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x59, 0x11, 0x76, 0xA2, 0x12, 0xD2, 0x07, 0x22, 0x3F, 0xA9, 0x33, 0x04, 0x56, 0x34, 0xDF, 0x53, 0x45, 0xB9, 0x10,
//    0x39, 0, 18, 0xF2, 0x55, 0x62, 0xF5, 0x66, 0x76, 0xED, 0x77, 0x59, 0xBA, 0x99, 0x23, 0xCB, 0x9A, 0xF3, 0x23, 0xA0, 0x23,
//    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x4E, 0x11, 0x78, 0x8D, 0x11, 0xA3, 0xBC, 0x12, 0xDB, 0x1F, 0x22, 0x65, 0xA7, 0x33, 0x1E, 0x85, 0x34, 0xE2, 0x32,
//    0x39, 0, 18, 0xF4, 0x44, 0x7A, 0xFE, 0x55, 0x71, 0xD6, 0x66, 0x36, 0x8F, 0x78, 0xCE, 0x5C, 0x88, 0x81, 0xA4, 0x80, 0xA4,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x37, 0x22, 0x6C, 0x97, 0x22, 0xC5, 0xF8, 0x33, 0x2E, 0x91, 0x34, 0xEC, 0x3D, 0x45, 0xC6, 0x3E, 0x56, 0xAA, 0x06,
//    0x39, 0, 18, 0xF6, 0x66, 0x5B, 0xF5, 0x77, 0x7B, 0xF6, 0x88, 0x66, 0xCF, 0xAB, 0x50, 0x04, 0xBB, 0x32, 0x5A, 0xB0, 0x5A,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x61, 0x7E, 0x11, 0x9E, 0xC3, 0x12, 0xEA, 0x3A, 0x22, 0x88, 0xD0, 0x33, 0x4E, 0xBA, 0x44, 0x16, 0x66,
//    0x39, 0, 18, 0xF2, 0x45, 0xB1, 0x33, 0x56, 0xA4, 0x0B, 0x66, 0x6A, 0xBF, 0x78, 0xF4, 0x7A, 0x88, 0x9A, 0xB9, 0x80, 0xB9,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x6B, 0x7E, 0x11, 0x8E, 0x9F, 0x11, 0xB0, 0xDA, 0x22, 0x0A, 0x3D, 0x22, 0xA0, 0xFA, 0x33, 0x4C, 0x96,
//    0x39, 0, 18, 0xF4, 0x34, 0xD9, 0x50, 0x45, 0xB6, 0x11, 0x55, 0x65, 0xB4, 0x67, 0xC3, 0x3B, 0x77, 0x58, 0x74, 0x70, 0x74,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x32, 0x22, 0x61, 0x80, 0x22, 0x9F, 0xC2, 0x23, 0xE5, 0x32, 0x33, 0x7B, 0xC3, 0x44, 0x3C, 0xA5, 0x55, 0x03, 0x56,
//    0x39, 0, 18, 0xF6, 0x56, 0xA3, 0x2C, 0x67, 0xA2, 0x0D, 0x77, 0x72, 0xCF, 0x99, 0x0F, 0x9E, 0x99, 0xC1, 0xE1, 0x90, 0xE1,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x42, 0x65, 0x11, 0x82, 0xA1, 0x12, 0xC2, 0x07, 0x22, 0x50, 0x97, 0x33, 0x14, 0x7E, 0x34, 0xDA, 0x2A,
//    0x39, 0, 18, 0xF2, 0x44, 0x71, 0xED, 0x55, 0x5C, 0xBB, 0x66, 0x16, 0x69, 0x78, 0x8B, 0x03, 0x88, 0x26, 0x39, 0x80, 0x39,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x7F, 0x90, 0x11, 0x9D, 0xAA, 0x11, 0xB7, 0xD5, 0x12, 0xF7, 0x20, 0x22, 0x78, 0xCC, 0x33, 0x18, 0x60,
//    0x39, 0, 18, 0xF4, 0x34, 0xA0, 0x11, 0x44, 0x74, 0xCB, 0x55, 0x1A, 0x64, 0x66, 0x5F, 0xD2, 0x67, 0xEC, 0x06, 0x70, 0x06,
//    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x49, 0x22, 0x7C, 0x97, 0x22, 0xB3, 0xCD, 0x23, 0xE9, 0x26, 0x33, 0x64, 0xA1, 0x44, 0x11, 0x75, 0x45, 0xCA, 0x1B,
//    0x39, 0, 18, 0xF6, 0x55, 0x64, 0xE4, 0x66, 0x58, 0xBD, 0x77, 0x1B, 0x70, 0x89, 0x9A, 0x1E, 0x99, 0x3D, 0x5D, 0x90, 0x5D,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x97, 0xBB, 0x12, 0xDD, 0x03, 0x22, 0x2E, 0x87, 0x23, 0xDA, 0x2B, 0x34, 0xB6, 0x23, 0x44, 0x83, 0xD9,
//    0x39, 0, 18, 0xF2, 0x55, 0x29, 0xAD, 0x66, 0x2B, 0x97, 0x67, 0xFB, 0x58, 0x89, 0x9A, 0x2C, 0x99, 0x4E, 0x76, 0x90, 0x76,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0xE5, 0xF8, 0x22, 0x08, 0x17, 0x22, 0x28, 0x50, 0x22, 0x7B, 0xAC, 0x33, 0x0F, 0x6B, 0x34, 0xBF, 0x09,
//    0x39, 0, 18, 0xF4, 0x44, 0x4E, 0xC5, 0x55, 0x31, 0x90, 0x56, 0xEA, 0x3C, 0x77, 0x59, 0xD6, 0x78, 0xF3, 0x11, 0x80, 0x11,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x0E, 0x23, 0xF8, 0x15, 0x33, 0x35, 0x54, 0x33, 0x75, 0xB9, 0x34, 0xFB, 0x3E, 0x45, 0xB8, 0x21, 0x55, 0x80, 0xD7,
//    0x39, 0, 18, 0xF6, 0x66, 0x29, 0xB5, 0x77, 0x33, 0xA4, 0x88, 0x0B, 0x6A, 0x9A, 0xC0, 0x5C, 0xAA, 0x81, 0xA4, 0xA0, 0xA4,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x22, 0x25, 0x55, 0x22, 0x75, 0x93, 0x23, 0xB9, 0x06, 0x33, 0x52, 0x99, 0x44, 0x1D, 0x93, 0x45, 0xF4, 0x4A,
//    0x39, 0, 18, 0xF2, 0x56, 0x99, 0x2A, 0x67, 0xA9, 0x1A, 0x77, 0x85, 0xE8, 0x99, 0x41, 0xDF, 0xAA, 0x05, 0x27, 0xA0, 0x27,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x22, 0xB8, 0xD1, 0x22, 0xE2, 0xEF, 0x23, 0xFB, 0x15, 0x33, 0x35, 0x58, 0x33, 0xA4, 0xF3, 0x44, 0x3F, 0x87,
//    0x39, 0, 18, 0xF4, 0x45, 0xC8, 0x41, 0x56, 0xAC, 0x0D, 0x66, 0x6B, 0xC0, 0x78, 0xEB, 0x6E, 0x88, 0x8E, 0xAD, 0x80, 0xAD,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x2C, 0x33, 0xEB, 0xFF, 0x44, 0x15, 0x2A, 0x44, 0x43, 0x77, 0x44, 0xAC, 0xE0, 0x55, 0x4A, 0xB2, 0x66, 0x0D, 0x63,
//    0x39, 0, 18, 0xF6, 0x67, 0xB0, 0x40, 0x78, 0xC1, 0x33, 0x89, 0xA0, 0x08, 0xAB, 0x77, 0x20, 0xBB, 0x49, 0x6F, 0xB0, 0x6F,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x22, 0xC7, 0xDD, 0x23, 0xF0, 0x18, 0x33, 0x3F, 0x6E, 0x34, 0xC3, 0x16, 0x44, 0x64, 0xAD,
//    0x39, 0, 18, 0xF2, 0x45, 0xF3, 0x73, 0x56, 0xDF, 0x3F, 0x66, 0x99, 0xEE, 0x88, 0x12, 0x91, 0x88, 0xB0, 0xC8, 0x80, 0xC8,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x03, 0x02, 0x54, 0x33, 0x6C, 0x79, 0x33, 0x83, 0x90, 0x33, 0xA0, 0xAF, 0x33, 0xCD, 0xF0, 0x44, 0x17, 0x41,
//    0x39, 0, 18, 0xF4, 0x44, 0x6B, 0xC2, 0x55, 0x18, 0x67, 0x55, 0xB1, 0xF7, 0x67, 0xEE, 0x5C, 0x77, 0x76, 0x8E, 0x70, 0x8E,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x63, 0x34, 0x9F, 0x96, 0x44, 0xA7, 0xB4, 0x44, 0xBC, 0xD5, 0x45, 0xED, 0x08, 0x55, 0x44, 0x7E, 0x55, 0xB9, 0xF7,
//    0x39, 0, 18, 0xF6, 0x66, 0x33, 0xA6, 0x77, 0x0C, 0x6A, 0x78, 0xC2, 0x16, 0x99, 0x40, 0xC6, 0x9A, 0xE6, 0x03, 0xA0, 0x03,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x01, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x55, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xA4,
//    0x39, 0, 18, 0xF2, 0x34, 0xBC, 0x0C, 0x44, 0x56, 0x9D, 0x45, 0xE1, 0x25, 0x56, 0xF9, 0x54, 0x66, 0x6A, 0x7C, 0x60, 0x7C,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x07, 0x04, 0xB0, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xCD,
//    0x39, 0, 18, 0xF4, 0x33, 0xC9, 0xEA, 0x44, 0x11, 0x37, 0x44, 0x5F, 0x89, 0x55, 0x2E, 0x78, 0x55, 0x8A, 0x9B, 0x50, 0x9B,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x37, 0x0F, 0xD5, 0xEF, 0xB7, 0xFD, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF5, 0xFA, 0x36,
//    0x39, 0, 18, 0xF6, 0x55, 0x3E, 0x76, 0x55, 0xB0, 0xEA, 0x66, 0x23, 0x5F, 0x77, 0x27, 0x7F, 0x77, 0x94, 0xA7, 0x70, 0xA7,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x00, 0x6B, 0xC7, 0x11, 0x1B, 0xA8, 0x22, 0x1C, 0x88, 0x33, 0x34, 0xBF, 0x44, 0x35, 0xA7,
//    0x39, 0, 18, 0xF2, 0x55, 0x0C, 0xC7, 0x67, 0x73, 0x05, 0x78, 0x9D, 0x1E, 0xAB, 0x35, 0x46, 0xBB, 0x92, 0xCA, 0xB0, 0xCA,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x3F, 0x00, 0x7B, 0xED, 0x11, 0x53, 0xB1, 0x22, 0x50, 0xD1, 0x33, 0x40, 0xA1,
//    0x39, 0, 18, 0xF4, 0x34, 0xFB, 0x9F, 0x55, 0x38, 0xBF, 0x66, 0x40, 0xB9, 0x89, 0x78, 0x55, 0x99, 0x93, 0xC5, 0x90, 0xC5,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0xD3, 0x21, 0x11, 0x75, 0xC5, 0x22, 0x0F, 0x97, 0x33, 0x0E, 0x77, 0x44, 0x1C, 0xB1, 0x55, 0x39, 0xAD,
//    0x39, 0, 18, 0xF6, 0x66, 0x19, 0xD9, 0x78, 0x87, 0x27, 0x89, 0xBF, 0x50, 0xBC, 0x8F, 0xB8, 0xDD, 0x06, 0x42, 0xD0, 0x42,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x15, 0x4A, 0x00, 0x8C, 0xD2, 0x11, 0x17, 0x96, 0x22, 0x03, 0x61, 0x33, 0x00, 0x88, 0x34, 0xF9, 0x60,
//    0x39, 0, 18, 0xF2, 0x45, 0xC7, 0x76, 0x66, 0x15, 0xA4, 0x77, 0x29, 0xAC, 0x9A, 0x84, 0x74, 0xAA, 0xAD, 0xE9, 0xA0, 0xE9,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x1E, 0x00, 0x3F, 0x65, 0x00, 0x92, 0xED, 0x11, 0x43, 0x95, 0x22, 0x23, 0x9F, 0x33, 0x07, 0x64,
//    0x39, 0, 18, 0xF4, 0x34, 0xBB, 0x54, 0x45, 0xE0, 0x62, 0x56, 0xDA, 0x4B, 0x78, 0xDD, 0xA0, 0x89, 0xD2, 0x08, 0x90, 0x08,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x11, 0x19, 0x4D, 0x11, 0x8A, 0xCB, 0x22, 0x08, 0x82, 0x23, 0xED, 0x4D, 0x34, 0xEB, 0x7A, 0x45, 0xF2, 0x65,
//    0x39, 0, 18, 0xF6, 0x56, 0xCD, 0x85, 0x77, 0x29, 0xBD, 0x88, 0x48, 0xD1, 0xAB, 0xD5, 0xD5, 0xCC, 0x15, 0x52, 0xC0, 0x52,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x03, 0x26, 0x00, 0x4F, 0x7E, 0x01, 0xB0, 0x16, 0x11, 0x75, 0xC9, 0x22, 0x58, 0xD4, 0x33, 0x3C, 0x98,
//    0x39, 0, 18, 0xF2, 0x34, 0xEB, 0x85, 0x55, 0x0D, 0x8A, 0x56, 0xFF, 0x69, 0x78, 0xE6, 0x98, 0x88, 0xC0, 0xE8, 0x80, 0xE8,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x0C, 0x00, 0x21, 0x38, 0x00, 0x54, 0x91, 0x01, 0xD2, 0x14, 0x11, 0x8C, 0xF9, 0x22, 0x59, 0xAD,
//    0x39, 0, 18, 0xF4, 0x23, 0xFB, 0x82, 0x34, 0xF7, 0x65, 0x45, 0xCB, 0x2C, 0x67, 0x7F, 0x15, 0x77, 0x39, 0x60, 0x70, 0x60,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xC9, 0x11, 0x04, 0x2B, 0x11, 0x51, 0x7E, 0x12, 0xAD, 0x09, 0x22, 0x63, 0xB9, 0x33, 0x44, 0xBE, 0x44, 0x26, 0x89,
//    0x39, 0, 18, 0xF6, 0x45, 0xE4, 0x89, 0x66, 0x19, 0x9A, 0x77, 0x10, 0x81, 0x99, 0x13, 0xD1, 0x9A, 0xFE, 0x2D, 0xA0, 0x2D,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x14, 0x2A, 0x00, 0x41, 0x77, 0x00, 0xB2, 0xEA, 0x11, 0x5B, 0xBF, 0x22, 0x17, 0x64,
//    0x39, 0, 18, 0xF2, 0x23, 0xAC, 0x28, 0x33, 0x97, 0xF7, 0x44, 0x4D, 0xA4, 0x56, 0xCA, 0x47, 0x66, 0x67, 0x86, 0x60, 0x86,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x0D, 0x00, 0x1B, 0x34, 0x00, 0x53, 0x76, 0x01, 0xC1, 0x0B, 0x11, 0x54, 0x97,
//    0x39, 0, 18, 0xF4, 0x12, 0xD6, 0x48, 0x23, 0xAC, 0x04, 0x33, 0x54, 0x9D, 0x45, 0x9D, 0x0D, 0x55, 0x29, 0x45, 0x50, 0x45,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x20, 0x01, 0xE7, 0x02, 0x11, 0x18, 0x2F, 0x11, 0x45, 0x76, 0x11, 0xAB, 0xE3, 0x22, 0x48, 0xAB, 0x33, 0x04, 0x50,
//    0x39, 0, 18, 0xF6, 0x34, 0x9A, 0x13, 0x44, 0x88, 0xF0, 0x55, 0x53, 0xAC, 0x67, 0xDC, 0x5E, 0x77, 0x7F, 0x9F, 0x70, 0x9F,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x09, 0x23, 0x00, 0x3B, 0x77, 0x00, 0xAF, 0xEC, 0x11, 0x64, 0xCC, 0x22, 0x24, 0x78,
//    0x39, 0, 18, 0xF2, 0x23, 0xC1, 0x43, 0x34, 0xB2, 0x10, 0x44, 0x6E, 0xC4, 0x56, 0xF4, 0x78, 0x66, 0x8F, 0xAF, 0x60, 0xAF,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x0B, 0x00, 0x16, 0x32, 0x00, 0x52, 0x78, 0x01, 0xC6, 0x14, 0x11, 0x60, 0xA5,
//    0x39, 0, 18, 0xF4, 0x12, 0xE6, 0x5C, 0x23, 0xC3, 0x1D, 0x33, 0x6F, 0xB7, 0x45, 0xC0, 0x31, 0x55, 0x4C, 0x68, 0x50, 0x68,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0xED, 0x06, 0x11, 0x20, 0x38, 0x11, 0x4B, 0x80, 0x11, 0xB9, 0xF3, 0x22, 0x5D, 0xC3, 0x33, 0x1C, 0x6B,
//    0x39, 0, 18, 0xF6, 0x34, 0xB4, 0x31, 0x45, 0xA9, 0x13, 0x55, 0x77, 0xCE, 0x77, 0x05, 0x8D, 0x77, 0xAD, 0xCA, 0x70, 0xCA,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x15, 0x00, 0x28, 0x3C, 0x00, 0x4D, 0x7F, 0x00, 0xB2, 0xE7, 0x11, 0x54, 0xBB, 0x22, 0x12, 0x65,
//    0x39, 0, 18, 0xF2, 0x23, 0xAB, 0x2F, 0x33, 0x99, 0xF9, 0x44, 0x52, 0xA6, 0x56, 0xCC, 0x4C, 0x66, 0x6A, 0x85, 0x60, 0x85,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x13, 0x00, 0x1F, 0x2D, 0x00, 0x36, 0x4E, 0x00, 0x68, 0x86, 0x01, 0xC8, 0x0F, 0x11, 0x57, 0x9B,
//    0x39, 0, 18, 0xF4, 0x12, 0xDA, 0x4B, 0x23, 0xAF, 0x07, 0x33, 0x57, 0xA0, 0x45, 0x9F, 0x10, 0x55, 0x2A, 0x45, 0x50, 0x45,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x43, 0x11, 0x23, 0x3F, 0x11, 0x50, 0x65, 0x11, 0x79, 0xA4, 0x12, 0xD4, 0x05, 0x22, 0x66, 0xC3, 0x33, 0x18, 0x63,
//    0x39, 0, 18, 0xF6, 0x34, 0xA7, 0x24, 0x44, 0x94, 0xFB, 0x55, 0x5C, 0xB6, 0x67, 0xE2, 0x66, 0x77, 0x85, 0xA5, 0x70, 0xA5,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x2A, 0x00, 0x40, 0x51, 0x00, 0x63, 0x8B, 0x00, 0xB7, 0xE9, 0x11, 0x55, 0xB8, 0x22, 0x12, 0x64,
//    0x39, 0, 18, 0xF2, 0x23, 0xAF, 0x2F, 0x33, 0x9B, 0xFB, 0x44, 0x56, 0xA9, 0x56, 0xC9, 0x46, 0x66, 0x62, 0x84, 0x60, 0x84,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x44, 0x5B, 0x00, 0x6C, 0x77, 0x00, 0x83, 0x95, 0x00, 0xAA, 0xC2, 0x01, 0xF8, 0x33, 0x11, 0x72, 0xAD,
//    0x39, 0, 18, 0xF4, 0x12, 0xEA, 0x5A, 0x23, 0xB9, 0x0E, 0x33, 0x5E, 0xA5, 0x45, 0xA1, 0x0C, 0x55, 0x28, 0x42, 0x50, 0x42,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xBE, 0x11, 0x8A, 0xA3, 0x11, 0xB8, 0xC9, 0x12, 0xDD, 0x00, 0x22, 0x22, 0x49, 0x22, 0x9B, 0xE7, 0x33, 0x33, 0x7A,
//    0x39, 0, 18, 0xF6, 0x34, 0xBE, 0x32, 0x45, 0xA0, 0x06, 0x55, 0x67, 0xBC, 0x67, 0xE0, 0x62, 0x77, 0x7D, 0x9E, 0x70, 0x9E,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x98, 0x00, 0xC5, 0xD5, 0x01, 0xE6, 0x05, 0x11, 0x25, 0x45, 0x11, 0x92, 0xE3, 0x22, 0x34, 0x7D,
//    0x39, 0, 18, 0xF2, 0x23, 0xC4, 0x3D, 0x34, 0xAB, 0x04, 0x44, 0x61, 0xB3, 0x56, 0xCF, 0x49, 0x66, 0x6B, 0x84, 0x60, 0x84,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0x02, 0x1F, 0x11, 0x36, 0x41, 0x11, 0x4E, 0x60, 0x11, 0x70, 0x82, 0x11, 0x9F, 0xC0, 0x12, 0xE7, 0x11,
//    0x39, 0, 18, 0xF4, 0x22, 0x3D, 0x90, 0x23, 0xE2, 0x2D, 0x33, 0x7A, 0xBB, 0x45, 0xAE, 0x18, 0x55, 0x34, 0x4B, 0x50, 0x4B,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x7A, 0x22, 0x80, 0x96, 0x22, 0xA4, 0xB3, 0x22, 0xBF, 0xD4, 0x23, 0xED, 0x06, 0x33, 0x36, 0x66, 0x33, 0xA0, 0xD4,
//    0x39, 0, 18, 0xF6, 0x44, 0x0A, 0x72, 0x45, 0xDB, 0x34, 0x55, 0x8C, 0xDF, 0x67, 0xF8, 0x73, 0x77, 0x92, 0xAC, 0x70, 0xAC,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x1F, 0x11, 0x0F, 0x57, 0x11, 0x70, 0x8B, 0x11, 0xA7, 0xC4, 0x22, 0x04, 0x41, 0x22, 0x80, 0xC0,
//    0x39, 0, 18, 0xF2, 0x33, 0x00, 0x70, 0x34, 0xD8, 0x38, 0x44, 0x90, 0xE4, 0x66, 0x01, 0x7C, 0x66, 0x98, 0xB5, 0x60, 0xB5,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x08, 0x11, 0xEB, 0xFF, 0x22, 0x0A, 0x1C, 0x22, 0x29, 0x37, 0x22, 0x4D, 0x66, 0x22, 0x82, 0x9C,
//    0x39, 0, 18, 0xF4, 0x22, 0xB9, 0xF9, 0x33, 0x3D, 0x7B, 0x33, 0xBB, 0xFB, 0x45, 0xE3, 0x4B, 0x55, 0x65, 0x82, 0x50, 0x82,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x13, 0x03, 0x23, 0x33, 0x72, 0x7B, 0x33, 0x85, 0x96, 0x33, 0xA7, 0xBA, 0x34, 0xE2, 0x03, 0x44, 0x2D, 0x5A,
//    0x39, 0, 18, 0xF6, 0x44, 0x87, 0xE0, 0x55, 0x38, 0x8F, 0x56, 0xE5, 0x30, 0x77, 0x41, 0xBA, 0x77, 0xD7, 0xF0, 0x70, 0xF0,
//    0x39, 0, 2, 0xFF, 0x01,
//    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x02, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x28, 0x01, 0xB4, 0x61, 0x11, 0x7A, 0x8A, 0x11, 0xAF, 0xD7, 0x22, 0x02, 0x2C,
//    0x39, 0, 18, 0xF2, 0x22, 0x54, 0xAA, 0x23, 0xF6, 0x48, 0x33, 0x8E, 0xCC, 0x45, 0xC1, 0x25, 0x55, 0x3F, 0x5B, 0x50, 0x5B,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0x7E, 0x12, 0xF1, 0x03, 0x22, 0x11, 0x1C, 0x22, 0x2C, 0x40, 0x22, 0x4C, 0x5D,
//    0x39, 0, 18, 0xF4, 0x22, 0x6E, 0x90, 0x22, 0xB9, 0xE0, 0x33, 0x0A, 0x33, 0x34, 0xE2, 0x2F, 0x44, 0x46, 0x5A, 0x40, 0x5A,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x97, 0x02, 0xE4, 0xB3, 0x33, 0x53, 0x66, 0x33, 0x71, 0x80, 0x33, 0x8B, 0x96, 0x33, 0xAD, 0xC6, 0x33, 0xE1, 0xFB,
//    0x39, 0, 18, 0xF6, 0x44, 0x0F, 0x48, 0x44, 0x82, 0xC1, 0x45, 0xFC, 0x34, 0x66, 0x14, 0x70, 0x66, 0x87, 0xA1, 0x60, 0xA1,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x04, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x24, 0x53, 0x00, 0x87, 0xF5, 0x11, 0x4D, 0xB6, 0x22, 0x4E, 0xCD, 0x33, 0x42, 0xA0,
//    0x39, 0, 18, 0xF2, 0x34, 0xFE, 0x90, 0x55, 0x14, 0x89, 0x56, 0xFC, 0x61, 0x78, 0xA1, 0x34, 0x88, 0x50, 0x74, 0x80, 0x74,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x05, 0x15, 0x00, 0x26, 0x37, 0x00, 0x4A, 0x7C, 0x00, 0xAC, 0xF5, 0x11, 0x70, 0xDF, 0x22, 0x48, 0x9E,
//    0x39, 0, 18, 0xF4, 0x23, 0xFA, 0x7A, 0x34, 0xF3, 0x59, 0x45, 0xC1, 0x15, 0x66, 0x4B, 0xCA, 0x67, 0xEC, 0x05, 0x70, 0x05,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x83, 0x01, 0xEC, 0x0C, 0x11, 0x38, 0x6B, 0x12, 0x9F, 0x0A, 0x22, 0x60, 0xC5, 0x33, 0x5D, 0xDD, 0x44, 0x4B, 0xB6,
//    0x39, 0, 18, 0xF6, 0x55, 0x1B, 0xBA, 0x66, 0x40, 0xB9, 0x77, 0x26, 0x89, 0x89, 0xDB, 0x72, 0x99, 0x91, 0xB9, 0x90, 0xB9,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x04, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x22, 0xA1, 0xA8, 0x22, 0xAF, 0xB6, 0x22, 0xBD, 0xC4, 0x22, 0xCB, 0xD2, 0x23, 0xD9, 0x1C,
//    0x39, 0, 18, 0xF2, 0x33, 0x6E, 0xFE, 0x44, 0x79, 0xEB, 0x55, 0x50, 0xB5, 0x67, 0xE5, 0x66, 0x77, 0x7E, 0xA0, 0x70, 0xA0,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0xEA, 0xAD, 0x11, 0xB0, 0xB7, 0x11, 0xBE, 0xC5, 0x11, 0xCC, 0xD3, 0x11, 0xDA, 0xE1, 0x12, 0xE8, 0x21,
//    0x39, 0, 18, 0xF4, 0x22, 0x6E, 0xF7, 0x33, 0x66, 0xCC, 0x44, 0x22, 0x7C, 0x56, 0x97, 0x0F, 0x66, 0x2E, 0x47, 0x60, 0x47,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x33, 0xA9, 0xAC, 0x33, 0xAF, 0xB6, 0x33, 0xBD, 0xC4, 0x33, 0xCB, 0xD2, 0x33, 0xD9, 0xE0, 0x34, 0xE7, 0x2C,
//    0x39, 0, 18, 0xF6, 0x45, 0x80, 0x1A, 0x56, 0x9E, 0x13, 0x66, 0x7D, 0xDD, 0x88, 0x14, 0x99, 0x88, 0xBA, 0xD9, 0x80, 0xD9,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x04, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x06, 0x04, 0x80, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
//    0x39, 0, 18, 0xF2, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x0F, 0x02, 0x99, 0xFF, 0x9C, 0x9F, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
//    0x39, 0, 18, 0xF4, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
//    0x39, 0, 22, 0xF5, 0x02, 0x00, 0xF4, 0xFF, 0x96, 0x99, 0xFF, 0x9C, 0x9F, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
//    0x39, 0, 18, 0xF6, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
//    0x39, 0, 2, 0xFF, 0x01,

//    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x04, 0x00,
//    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x06, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
//    0x39, 0, 18, 0xF2, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
//    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0xFF, 0xA0, 0xA3, 0xFF, 0xA6, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
//    0x39, 0, 18, 0xF4, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
//    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x40, 0xFF, 0x9A, 0x9D, 0xFF, 0xA0, 0xA3, 0xFF, 0xA6, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
//    0x39, 0, 18, 0xF6, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
//    0x39, 0, 2, 0xFF, 0x01,
//////////////////////////GAMMA1 END///////////////////////////////


//////////////////////////1号650 START///////////////////////////////
//0x39,0,2,0x9F,0x04,
//0x39,0,19,0xB3,0x00,0x00,0x10,0x00,0x30,0x50,0x00,0x70,0x90,0x00,0xB0,0xF0,0x11,0x30,0x70,0x12,0xF0,0x70,
//0x39,0,21,0xB4,0x23,0xF0,0x70,0x34,0xF0,0xF0,0x56,0xF0,0xF0,0x78,0xF0,0xF0,0xCE,0xF0,0xF0,0xFF,0x70,0xF0,0x0F,0xFF,
//0x39,0,2,0x9F,0x05,
//0x39,0,16,0xB5,0x33,0xFF,0x6E,0x21,0x61,0x40,0x11,0x40,0x01,0x00,0xAF,0x5B,0x00,0x36,0x00,
//0x39,0,16,0xB6,0x33,0xFF,0x6E,0x00,0x6E,0x01,0xFA,0xFF,0xAA,0x50,0x55,0x00,0x00,0x00,0x00,
//0x39,0,2,0x9F,0x05,
//0x39,0,2,0xF9,0x80,
//0x39,0,2,0xF7,0x10,
//0x39,0,2,0x9F,0x06,
//0x39,0,3,0xFF,0x00,0x01,
//0x39,0,5,0xFE,0x01,0x00,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x32,0x01,0xAA,0x0D,0x11,0x61,0xF2,0x22,0x6B,0xD1,0x34,0x7A,0x0A,0x44,0x87,0xF3,
//0x39,0,18,0xF2,0x56,0x5B,0x13,0x67,0xB7,0x4D,0x78,0xD8,0x5D,0xAB,0x4E,0x4C,0xBB,0x87,0xC2,0xB0,0xC2,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x3D,0x01,0x92,0x1D,0x11,0x90,0xF2,0x23,0x96,0x1E,0x33,0x8F,0xF2,
//0x39,0,18,0xF4,0x44,0x4F,0xF2,0x56,0x84,0x09,0x66,0x84,0xFE,0x89,0xA9,0x7A,0x99,0xAD,0xE0,0x90,0xE0,
//0x39,0,22,0xF5,0x00,0x00,0x07,0x01,0x95,0x24,0x12,0xA4,0x12,0x23,0x74,0x14,0x34,0x95,0x04,0x45,0xBC,0x5A,0x56,0xE5,0x5C,
//0x39,0,18,0xF6,0x67,0xCF,0x9A,0x88,0x4F,0xF3,0x9A,0x90,0x2A,0xCD,0x73,0x9E,0xDE,0xEE,0x3E,0xE0,0x3E,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x01,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x33,0x01,0xBC,0x17,0x11,0x65,0xED,0x22,0x60,0xC5,0x33,0x6B,0xF6,0x44,0x6E,0xDA,
//0x39,0,18,0xF2,0x55,0x3E,0xF0,0x67,0x8E,0x21,0x78,0xA8,0x27,0x9A,0xF8,0xE6,0xBB,0x1F,0x58,0xB0,0x58,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x05,0x54,0x01,0x9C,0x1B,0x11,0x87,0xE4,0x23,0x84,0x07,0x33,0x76,0xD7,
//0x39,0,18,0xF4,0x44,0x31,0xCF,0x55,0x5B,0xDD,0x66,0x55,0xC9,0x89,0x5E,0x25,0x99,0x51,0x84,0x90,0x84,
//0x39,0,22,0xF5,0x00,0x00,0x24,0x01,0x95,0x24,0x12,0xAF,0x16,0x23,0x72,0x0B,0x33,0x88,0xF4,0x45,0xAA,0x44,0x56,0xC8,0x3F,
//0x39,0,18,0xF6,0x67,0xAE,0x72,0x88,0x1F,0xBF,0x99,0x56,0xE8,0xCD,0x12,0x27,0xDD,0x71,0xBA,0xD0,0xBA,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x02,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x0E,0x00,0x68,0xB9,0x01,0xF9,0x72,0x12,0xD9,0x37,0x23,0xD1,0x50,0x34,0xBF,0x21,
//0x39,0,18,0xF2,0x45,0x79,0x19,0x56,0xA6,0x27,0x67,0x9B,0x0C,0x89,0x8E,0x3F,0x99,0x6F,0x99,0x90,0x99,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x3B,0xAA,0x11,0x0A,0x5F,0x12,0xF0,0x6A,0x23,0xD4,0x2F,
//0x39,0,18,0xF4,0x34,0x81,0x10,0x44,0x8D,0xFF,0x55,0x67,0xCB,0x77,0x23,0xC1,0x78,0xE9,0x0E,0x80,0x0E,
//0x39,0,22,0xF5,0x00,0x00,0x3F,0x00,0x99,0xF3,0x11,0x4E,0xA7,0x12,0xF6,0x83,0x23,0xF7,0x5B,0x44,0x01,0x8C,0x55,0x06,0x72,
//0x39,0,18,0xF6,0x56,0xD4,0x85,0x77,0x20,0xB0,0x88,0x2D,0xA9,0xAB,0x61,0x32,0xBB,0x6B,0x9C,0xB0,0x9C,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x03,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x18,0x19,0x00,0x4E,0xAB,0x01,0xFA,0x42,0x12,0xBE,0x2C,0x22,0x8A,0xDE,
//0x39,0,18,0xF2,0x33,0x2A,0xAC,0x44,0x1E,0x85,0x45,0xE2,0x3B,0x66,0x65,0xE9,0x77,0x07,0x25,0x70,0x25,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x3A,0x7C,0x01,0xEF,0x55,0x11,0xAD,0xFA,
//0x39,0,18,0xF4,0x22,0x44,0xC1,0x33,0x2D,0x8B,0x34,0xDF,0x2E,0x55,0x36,0xAB,0x55,0xC7,0xE0,0x50,0xE0,
//0x39,0,22,0xF5,0x00,0x00,0x16,0x00,0x65,0xD7,0x00,0xFA,0xFB,0x11,0x33,0x98,0x12,0xF5,0x49,0x23,0xD7,0x50,0x34,0xB4,0x0E,
//0x39,0,18,0xF6,0x44,0x61,0xF2,0x55,0x70,0xE2,0x66,0x4A,0xAC,0x78,0xF3,0x83,0x88,0xA6,0xC8,0x80,0xC8,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x04,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x1F,0x96,0x01,0xF2,0x41,0x12,0xC6,0x38,0x22,0x9A,0xF0,
//0x39,0,18,0xF2,0x33,0x3F,0xC8,0x44,0x3D,0xA6,0x55,0x08,0x63,0x67,0x93,0x17,0x77,0x37,0x56,0x70,0x56,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x33,0x79,0x01,0xF4,0x5D,0x12,0xB7,0x08,
//0x39,0,18,0xF4,0x22,0x54,0xD8,0x33,0x46,0xA7,0x34,0xFD,0x4F,0x55,0x5D,0xD3,0x56,0xF0,0x0D,0x60,0x0D,
//0x39,0,22,0xF5,0x00,0x00,0x08,0x00,0x57,0x91,0x00,0xC7,0xFC,0x11,0x34,0xA0,0x22,0x00,0x57,0x23,0xEE,0x68,0x34,0xD0,0x2C,
//0x39,0,18,0xF6,0x45,0x80,0x14,0x56,0x94,0x09,0x66,0x74,0xD8,0x88,0x24,0xB8,0x88,0xDC,0xFE,0x80,0xFE,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x05,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x22,0x96,0x01,0xF4,0x46,0x12,0xD0,0x48,0x23,0xB0,0x07,
//0x39,0,18,0xF2,0x33,0x58,0xE3,0x44,0x59,0xC4,0x55,0x2A,0x86,0x67,0xBA,0x3D,0x77,0x60,0x81,0x70,0x81,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x34,0x7B,0x01,0xF7,0x61,0x12,0xC1,0x15,
//0x39,0,18,0xF4,0x22,0x68,0xEF,0x33,0x5F,0xC2,0x44,0x1B,0x6C,0x55,0x80,0xF5,0x66,0x12,0x33,0x60,0x33,
//0x39,0,22,0xF5,0x00,0x00,0x12,0x00,0x7E,0xF0,0x11,0x14,0x15,0x11,0x4C,0xB9,0x22,0x1C,0x77,0x33,0x0C,0x86,0x34,0xEF,0x4A,
//0x39,0,18,0xF6,0x45,0xA2,0x37,0x56,0xB8,0x2E,0x67,0x9D,0x01,0x88,0x53,0xE6,0x99,0x0C,0x30,0x90,0x30,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x06,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x31,0xA6,0x11,0x0B,0x6C,0x22,0x0E,0x97,0x33,0x02,0x61,
//0x39,0,18,0xF2,0x34,0xB5,0x4A,0x45,0xC8,0x39,0x56,0x9E,0x05,0x77,0x4C,0xDE,0x88,0x01,0x21,0x80,0x21,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x46,0x91,0x11,0x18,0x97,0x22,0x03,0x67,
//0x39,0,18,0xF4,0x23,0xBB,0x4A,0x34,0xBD,0x26,0x44,0x7F,0xDD,0x66,0x00,0x84,0x66,0xA2,0xBF,0x60,0xBF,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x01,0x95,0x24,0x11,0x25,0x5C,0x12,0x96,0x0B,0x22,0x74,0xD0,0x33,0x68,0xE7,0x44,0x53,0xB6,
//0x39,0,18,0xF6,0x55,0x10,0xAF,0x66,0x36,0xB3,0x77,0x20,0x8E,0x89,0xF5,0x9B,0x99,0xC2,0xE8,0x90,0xE8,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x07,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x39,0x00,0x7A,0xEB,0x11,0x5A,0xCE,0x23,0x8A,0x1F,0x34,0x97,0x03,
//0x39,0,18,0xF2,0x45,0x51,0x00,0x56,0x8C,0x0B,0x66,0x77,0xE8,0x88,0x58,0xF9,0x99,0x22,0x49,0x90,0x49,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x1F,0x00,0x6F,0xC0,0x11,0x64,0xFF,0x22,0x81,0xF3,
//0x39,0,18,0xF4,0x33,0x47,0xEA,0x44,0x6A,0xDD,0x55,0x42,0xA5,0x67,0xEF,0x7D,0x77,0xA1,0xC0,0x70,0xC0,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x11,0x5F,0x93,0x12,0xC5,0x0D,0x22,0x44,0xB9,0x33,0x20,0x79,0x44,0x17,0x9B,0x55,0x0F,0x7B,
//0x39,0,18,0xF6,0x56,0xCF,0x84,0x77,0x19,0xA1,0x88,0x18,0x91,0xAA,0x2F,0xEE,0xBB,0x1B,0x4A,0xB0,0x4A,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x08,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x16,0x66,0x01,0xA4,0x13,0x12,0x93,0x12,0x23,0xE0,0x7D,0x34,0xF8,0x73,
//0x39,0,18,0xF2,0x45,0xD7,0x82,0x66,0x07,0x95,0x77,0x1D,0x8E,0x99,0x14,0xD3,0x9A,0xFD,0x27,0xA0,0x27,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x2E,0x00,0x7E,0xCD,0x12,0x8F,0x49,0x23,0xD5,0x4F,
//0x39,0,18,0xF4,0x34,0xB1,0x57,0x45,0xD8,0x59,0x56,0xD0,0x36,0x78,0x92,0x33,0x88,0x55,0x7C,0x80,0x7C,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x12,0x8B,0x2A,0x22,0x6E,0xA4,0x23,0xDD,0x45,0x33,0xA6,0xFE,0x45,0x9C,0x26,0x56,0x9B,0x0F,
//0x39,0,18,0xF6,0x67,0x73,0x22,0x78,0xB0,0x44,0x89,0xD3,0x54,0xBB,0x17,0xFD,0xCC,0x2B,0x62,0xC0,0x62,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x09,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x36,0x00,0x63,0xBE,0x11,0x25,0x90,0x22,0x56,0xF9,0x33,0x79,0xE5,
//0x39,0,18,0xF2,0x44,0x46,0xEB,0x55,0x78,0xF7,0x66,0x69,0xD1,0x88,0x3E,0xE0,0x99,0x06,0x2D,0x90,0x2D,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x38,0x7C,0x11,0x04,0xA9,0x22,0x42,0xBA,
//0x39,0,18,0xF4,0x33,0x21,0xC7,0x44,0x4E,0xC4,0x55,0x2D,0x8E,0x67,0xD5,0x65,0x77,0x86,0xA7,0x70,0xA7,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x12,0x3B,0x05,0x22,0x43,0x73,0x23,0xA8,0x00,0x33,0x53,0xA5,0x44,0x32,0xB2,0x55,0x1F,0x86,
//0x39,0,18,0xF6,0x56,0xE4,0x86,0x77,0x18,0x9D,0x88,0x16,0x83,0xAA,0x20,0xDA,0xBB,0x07,0x34,0xB0,0x34,
//0x39,0,2,0xFF,0x01,
//0x39,0,2,0x9F,0x05,
//0x39,0,2,0xF9,0x00,
//0x39,0,2,0xF7,0x00,
//0x39,0,2,0x9F,0x06,

//////////////////////////1号650 END///////////////////////////////



//////////////////////////1号600 START///////////////////////////////

//0x39,0,2,0x9F,0x04,
//0x39,0,19,0xB3,0x00,0x00,0x10,0x00,0x30,0x50,0x00,0x70,0x90,0x00,0xB0,0xF0,0x11,0x30,0x70,0x12,0xF0,0x70,
//0x39,0,21,0xB4,0x23,0xF0,0x70,0x34,0xF0,0xF0,0x56,0xF0,0xF0,0x78,0xF0,0xF0,0xCE,0xF0,0xF0,0xFF,0x70,0xF0,0x0F,0xFF,
//0x39,0,2,0x9F,0x05,
//0x39,0,16,0xB5,0x33,0xFF,0x6E,0x21,0x61,0x40,0x11,0x40,0x01,0x00,0xAF,0x5B,0x00,0x36,0x00,
//0x39,0,16,0xB6,0x33,0xFF,0x6E,0x00,0x6E,0x01,0xFA,0xFF,0xAA,0x50,0x55,0x00,0x00,0x00,0x00,
//0x39,0,2,0x9F,0x05,
//0x39,0,2,0xF9,0x80,
//0x39,0,2,0xF7,0x10,
//0x39,0,2,0x9F,0x06,
//0x39,0,3,0xFF,0x00,0x01,
//0x39,0,5,0xFE,0x01,0x00,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x2D,0x01,0xA2,0x05,0x11,0x59,0xE4,0x22,0x5D,0xC2,0x33,0x6A,0xF7,0x44,0x70,0xDD,
//0x39,0,18,0xF2,0x55,0x44,0xF8,0x67,0x99,0x2E,0x78,0xB6,0x38,0xAB,0x18,0x0C,0xBB,0x45,0x82,0xB0,0x82,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x33,0x01,0x87,0x0F,0x11,0x82,0xE3,0x23,0x86,0x0D,0x33,0x7E,0xE0,
//0x39,0,18,0xF4,0x44,0x3C,0xDD,0x55,0x6B,0xEF,0x66,0x67,0xDE,0x89,0x82,0x49,0x99,0x7C,0xAE,0x90,0xAE,
//0x39,0,22,0xF5,0x00,0x29,0x8D,0x01,0x8E,0x19,0x12,0x97,0x04,0x23,0x65,0x02,0x33,0x84,0xF0,0x45,0xA7,0x44,0x56,0xCA,0x42,
//0x39,0,18,0xF6,0x67,0xB3,0x7C,0x88,0x2A,0xCE,0x99,0x66,0xFB,0xCD,0x32,0x4F,0xDD,0x99,0xE3,0xD0,0xE3,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x01,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x51,0x01,0xBA,0x0D,0x11,0x5A,0xDF,0x22,0x51,0xB5,0x33,0x57,0xDF,0x44,0x56,0xC0,
//0x39,0,18,0xF2,0x55,0x23,0xD2,0x66,0x6C,0xFA,0x77,0x7F,0xFB,0x9A,0xC1,0x9D,0xAB,0xDA,0x0E,0xB0,0x0E,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x48,0x01,0x91,0x0D,0x11,0x77,0xD5,0x22,0x71,0xF3,0x33,0x61,0xC1,
//0x39,0,18,0xF4,0x44,0x1A,0xB6,0x55,0x3E,0xBC,0x66,0x34,0xA3,0x88,0x31,0xEA,0x99,0x1B,0x49,0x90,0x49,
//0x39,0,22,0xF5,0x00,0x00,0x4F,0x01,0xBD,0x31,0x12,0xA1,0x07,0x22,0x61,0xF8,0x33,0x74,0xE0,0x45,0x91,0x27,0x56,0xAD,0x21,
//0x39,0,18,0xF6,0x67,0x8E,0x51,0x78,0xF9,0x93,0x99,0x27,0xB3,0xBC,0xC2,0xCD,0xDD,0x0D,0x55,0xD0,0x55,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x02,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x08,0x00,0x64,0xAF,0x01,0xF3,0x66,0x12,0xCC,0x26,0x23,0xBE,0x3A,0x34,0xA7,0x09,
//0x39,0,18,0xF2,0x44,0x60,0xFC,0x56,0x85,0x03,0x66,0x76,0xE2,0x89,0x5B,0x07,0x99,0x35,0x5E,0x90,0x5E,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x30,0x9C,0x01,0xFA,0x4E,0x12,0xDD,0x54,0x23,0xBC,0x19,
//0x39,0,18,0xF4,0x33,0x6A,0xF5,0x44,0x71,0xE1,0x55,0x48,0xA7,0x67,0xF7,0x91,0x77,0xB9,0xDC,0x70,0xDC,
//0x39,0,22,0xF5,0x00,0x00,0x36,0x00,0x94,0xE9,0x11,0x42,0x98,0x12,0xE5,0x6F,0x23,0xE3,0x46,0x34,0xE9,0x71,0x45,0xE8,0x55,
//0x39,0,18,0xF6,0x56,0xB6,0x62,0x67,0xFA,0x84,0x88,0x03,0x78,0xAA,0x21,0xEE,0xBB,0x1F,0x51,0xB0,0x51,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x03,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x21,0x22,0x00,0x53,0xB5,0x11,0x03,0x4B,0x12,0xC6,0x32,0x22,0x90,0xE4,
//0x39,0,18,0xF2,0x33,0x2F,0xB2,0x44,0x24,0x8B,0x45,0xE9,0x41,0x66,0x6C,0xED,0x77,0x0B,0x2B,0x70,0x2B,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x40,0x82,0x01,0xF4,0x5A,0x11,0xB2,0xFF,
//0x39,0,18,0xF4,0x22,0x48,0xC8,0x33,0x33,0x90,0x34,0xE5,0x34,0x55,0x3D,0xAF,0x55,0xCC,0xE6,0x50,0xE6,
//0x39,0,22,0xF5,0x00,0x00,0x1C,0x00,0x66,0xD7,0x00,0xFC,0xFD,0x11,0x36,0x9B,0x12,0xFC,0x4E,0x23,0xDC,0x53,0x34,0xB8,0x12,
//0x39,0,18,0xF6,0x44,0x65,0xF6,0x55,0x75,0xE6,0x66,0x4E,0xB0,0x78,0xF7,0x82,0x88,0xA8,0xCB,0x80,0xCB,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x04,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x27,0x9E,0x01,0xF9,0x49,0x12,0xCE,0x3E,0x22,0xA2,0xF7,
//0x39,0,18,0xF2,0x33,0x45,0xCD,0x44,0x42,0xAA,0x55,0x0C,0x65,0x67,0x96,0x1A,0x77,0x3B,0x59,0x70,0x59,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x37,0x7D,0x01,0xFA,0x61,0x12,0xBD,0x0E,
//0x39,0,18,0xF4,0x22,0x59,0xDB,0x33,0x4A,0xAA,0x44,0x02,0x52,0x55,0x63,0xD9,0x56,0xF3,0x11,0x60,0x11,
//0x39,0,22,0xF5,0x00,0x00,0x09,0x00,0x5F,0x8F,0x01,0xC6,0x04,0x11,0x3B,0xA4,0x22,0x04,0x5B,0x23,0xF4,0x6B,0x34,0xD4,0x30,
//0x39,0,18,0xF6,0x45,0x85,0x18,0x56,0x98,0x0C,0x66,0x77,0xD9,0x88,0x22,0xB9,0x89,0xDD,0x01,0x90,0x01,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x05,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x29,0x9B,0x01,0xFB,0x4C,0x12,0xD5,0x4D,0x23,0xB3,0x0D,
//0x39,0,18,0xF2,0x33,0x5C,0xE6,0x44,0x61,0xCC,0x55,0x2B,0x87,0x67,0xBA,0x45,0x77,0x65,0x84,0x70,0x84,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x37,0x7D,0x01,0xF9,0x66,0x12,0xC6,0x1C,
//0x39,0,18,0xF4,0x22,0x6B,0xF3,0x33,0x65,0xC6,0x44,0x1D,0x70,0x55,0x82,0xFC,0x66,0x18,0x35,0x60,0x35,
//0x39,0,22,0xF5,0x00,0x00,0x05,0x00,0x7C,0xAE,0x01,0xDF,0x16,0x11,0x4E,0xBA,0x22,0x20,0x79,0x33,0x0E,0x8A,0x34,0xF1,0x4E,
//0x39,0,18,0xF6,0x45,0xA4,0x39,0x56,0xBF,0x34,0x67,0x9C,0x01,0x88,0x4F,0xEB,0x99,0x0E,0x31,0x90,0x31,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x06,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x35,0xAC,0x11,0x11,0x74,0x22,0x14,0x9A,0x33,0x0A,0x66,
//0x39,0,18,0xF2,0x34,0xBA,0x50,0x45,0xCF,0x40,0x56,0xA9,0x0C,0x77,0x4B,0xDF,0x88,0x04,0x27,0x80,0x27,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x49,0x94,0x11,0x1D,0x9B,0x22,0x09,0x6D,
//0x39,0,18,0xF4,0x23,0xC0,0x51,0x34,0xC5,0x2C,0x44,0x8C,0xE4,0x66,0x01,0x85,0x66,0xA6,0xC6,0x60,0xC6,
//0x39,0,22,0xF5,0x00,0x00,0x1C,0x01,0x8C,0x19,0x11,0x23,0x61,0x12,0x9B,0x0E,0x22,0x7B,0xD6,0x33,0x6D,0xEB,0x44,0x59,0xBB,
//0x39,0,18,0xF6,0x55,0x13,0xB3,0x66,0x3B,0xB7,0x77,0x27,0x94,0x89,0xF2,0x97,0x99,0xBB,0xEC,0x90,0xEC,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x07,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x42,0x00,0x7D,0xF1,0x11,0x61,0xD5,0x23,0x92,0x22,0x34,0xA0,0x07,
//0x39,0,18,0xF2,0x45,0x63,0x04,0x56,0x91,0x10,0x66,0x80,0xED,0x88,0x5D,0xF8,0x99,0x25,0x4B,0x90,0x4B,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x20,0x00,0x74,0xC3,0x12,0x6A,0x08,0x22,0x8C,0xF6,
//0x39,0,18,0xF4,0x33,0x53,0xEE,0x44,0x70,0xE3,0x55,0x49,0xAA,0x67,0xF6,0x7D,0x77,0xA5,0xC5,0x70,0xC5,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x11,0x40,0x95,0x12,0xD2,0x0B,0x22,0x48,0xBB,0x33,0x27,0x7F,0x44,0x1C,0x9F,0x55,0x16,0x7E,
//0x39,0,18,0xF6,0x56,0xDE,0x88,0x77,0x1D,0xA5,0x88,0x1D,0x90,0xAA,0x32,0xEA,0xBB,0x20,0x4D,0xB0,0x4D,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x08,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x2A,0x6E,0x01,0xA9,0x1B,0x12,0x9F,0x1D,0x23,0xEA,0x85,0x44,0x03,0x77,
//0x39,0,18,0xF2,0x45,0xDA,0x87,0x66,0x1F,0xA6,0x77,0x23,0x95,0x99,0x23,0xCC,0xAA,0x02,0x2F,0xA0,0x2F,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x2F,0x00,0x7E,0xD2,0x12,0x96,0x4E,0x23,0xDE,0x53,
//0x39,0,18,0xF4,0x34,0xB6,0x5C,0x45,0xEB,0x67,0x56,0xD6,0x3D,0x78,0x9F,0x2E,0x88,0x5C,0x81,0x80,0x81,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x12,0x7C,0x32,0x22,0x69,0xAA,0x23,0xE7,0x4C,0x34,0xAA,0x04,0x45,0xA3,0x2D,0x56,0xA2,0x13,
//0x39,0,18,0xF6,0x67,0x76,0x27,0x78,0xC7,0x54,0x89,0xDA,0x55,0xBB,0x25,0xF1,0xCC,0x30,0x67,0xC0,0x67,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x09,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x27,0x00,0x6D,0xCE,0x11,0x33,0x9B,0x22,0x62,0xFD,0x33,0x80,0xE7,
//0x39,0,18,0xF2,0x44,0x4C,0xF4,0x55,0x7F,0xFD,0x66,0x6C,0xD8,0x88,0x46,0xE2,0x99,0x0A,0x31,0x90,0x31,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x3B,0x80,0x11,0x09,0xAE,0x22,0x48,0xC2,
//0x39,0,18,0xF4,0x33,0x28,0xCD,0x44,0x55,0xCC,0x55,0x31,0x93,0x67,0xDA,0x64,0x77,0x8A,0xAB,0x70,0xAB,
//0x39,0,22,0xF5,0x00,0x00,0x22,0x02,0xD0,0x28,0x22,0x49,0x7B,0x23,0xA8,0x09,0x33,0x5A,0xAA,0x44,0x37,0xB5,0x55,0x27,0x89,
//0x39,0,18,0xF6,0x56,0xE9,0x8E,0x77,0x1E,0xA3,0x88,0x16,0x8A,0xAA,0x21,0xD9,0xBB,0x08,0x37,0xB0,0x37,
//0x39,0,2,0xFF,0x01,
//0x39,0,2,0x9F,0x05,
//0x39,0,2,0xF9,0x00,
//0x39,0,2,0xF7,0x00,
//0x39,0,2,0x9F,0x06,
//0x39,0,3,0xFF,0x00,0x00,

//////////////////////////1号600 END///////////////////////////////


//////////////////////////1号550 START///////////////////////////////


//0x39,0,2,0x9F,0x04,
//0x39,0,19,0xB3,0x00,0x00,0x10,0x00,0x30,0x50,0x00,0x70,0x90,0x00,0xB0,0xF0,0x11,0x30,0x70,0x12,0xF0,0x70,
//0x39,0,21,0xB4,0x23,0xF0,0x70,0x34,0xF0,0xF0,0x56,0xF0,0xF0,0x78,0xF0,0xF0,0xCE,0xF0,0xF0,0xFF,0x70,0xF0,0x0F,0xFF,
//0x39,0,2,0x9F,0x05,
//0x39,0,16,0xB5,0x33,0xFF,0x6E,0x21,0x61,0x40,0x11,0x40,0x01,0x00,0xAF,0x5B,0x00,0x36,0x00,
//0x39,0,16,0xB6,0x33,0xFF,0x6E,0x00,0x6E,0x01,0xFA,0xFF,0xAA,0x50,0x55,0x00,0x00,0x00,0x00,
//0x39,0,2,0x9F,0x05,
//0x39,0,2,0xF9,0x80,
//0x39,0,2,0xF7,0x10,
//0x39,0,2,0x9F,0x06,
//0x39,0,3,0xFF,0x00,0x01,
//0x39,0,5,0xFE,0x01,0x00,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x21,0x00,0x97,0xF9,0x11,0x4A,0xD2,0x22,0x4A,0xAF,0x33,0x53,0xE0,0x44,0x58,0xC3,
//0x39,0,18,0xF2,0x55,0x27,0xD8,0x67,0x77,0x0A,0x78,0x8E,0x0E,0x9A,0xE1,0xC8,0xAB,0xFF,0x3A,0xB0,0x3A,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x27,0x00,0x79,0xFE,0x11,0x70,0xD0,0x22,0x71,0xF7,0x33,0x67,0xC8,
//0x39,0,18,0xF4,0x44,0x21,0xBF,0x55,0x4C,0xCC,0x66,0x44,0xB7,0x89,0x4E,0x0F,0x99,0x3F,0x72,0x90,0x72,
//0x39,0,22,0xF5,0x00,0x24,0x88,0x01,0x89,0x0F,0x11,0x8A,0xF6,0x22,0x55,0xF0,0x33,0x70,0xDB,0x45,0x8F,0x2A,0x56,0xAF,0x26,
//0x39,0,18,0xF6,0x67,0x93,0x57,0x88,0x06,0xA7,0x99,0x3A,0xCA,0xBC,0xEE,0xFD,0xDD,0x41,0x89,0xD0,0x89,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x01,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x47,0x00,0x97,0xFF,0x11,0x4B,0xCB,0x22,0x3B,0x9C,0x33,0x3D,0xC3,0x44,0x38,0xA1,
//0x39,0,18,0xF2,0x55,0x01,0xAD,0x66,0x46,0xD0,0x77,0x51,0xCB,0x9A,0x7A,0x4E,0xAA,0x86,0xBA,0xA0,0xBA,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x3B,0x00,0x81,0xFA,0x11,0x62,0xBD,0x22,0x57,0xD8,0x33,0x46,0xA5,
//0x39,0,18,0xF4,0x34,0xFB,0x94,0x55,0x1D,0x97,0x66,0x0A,0x76,0x78,0xF6,0xAC,0x89,0xD4,0x02,0x90,0x02,
//0x39,0,22,0xF5,0x00,0x00,0x51,0x01,0x86,0x27,0x11,0x89,0xF6,0x22,0x4E,0xE2,0x33,0x5C,0xC5,0x45,0x75,0x09,0x55,0x8B,0xFF,
//0x39,0,18,0xF6,0x67,0x6A,0x26,0x78,0xCE,0x63,0x89,0xF3,0x7D,0xBC,0x71,0x6D,0xCC,0xB3,0xF2,0xC0,0xF2,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x02,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x04,0x00,0x5C,0xA7,0x01,0xE7,0x5B,0x12,0xBD,0x16,0x23,0xAE,0x28,0x33,0x93,0xF3,
//0x39,0,18,0xF2,0x44,0x4B,0xE4,0x55,0x6D,0xE8,0x66,0x5A,0xC5,0x88,0x37,0xE0,0x99,0x08,0x31,0x90,0x31,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x27,0x90,0x01,0xED,0x40,0x12,0xCD,0x43,0x23,0xAA,0x05,
//0x39,0,18,0xF4,0x33,0x56,0xE1,0x44,0x5B,0xC9,0x55,0x2E,0x8D,0x67,0xD6,0x6D,0x77,0x92,0xB5,0x70,0xB5,
//0x39,0,22,0xF5,0x00,0x00,0x3E,0x00,0x94,0xE5,0x11,0x3A,0x8E,0x12,0xD8,0x60,0x23,0xD3,0x36,0x34,0xD7,0x5E,0x45,0xD3,0x3E,
//0x39,0,18,0xF6,0x56,0x9F,0x49,0x67,0xDF,0x68,0x78,0xE4,0x57,0x9A,0xF5,0xBF,0xAB,0xF0,0x1E,0xB0,0x1E,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x03,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x21,0x22,0x00,0x56,0xB4,0x11,0x04,0x4D,0x12,0xC8,0x33,0x22,0x93,0xE6,
//0x39,0,18,0xF2,0x33,0x32,0xB4,0x44,0x27,0x8D,0x45,0xEB,0x42,0x66,0x6C,0xEF,0x77,0x0D,0x2C,0x70,0x2C,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x41,0x83,0x01,0xF7,0x5B,0x12,0xB4,0x02,
//0x39,0,18,0xF4,0x22,0x4C,0xC9,0x33,0x34,0x93,0x34,0xE7,0x35,0x55,0x3D,0xB2,0x55,0xCC,0xE7,0x50,0xE7,
//0x39,0,22,0xF5,0x00,0x00,0x1A,0x00,0x69,0xDC,0x00,0xFE,0xFF,0x11,0x37,0x9D,0x12,0xFB,0x51,0x23,0xE0,0x56,0x34,0xBB,0x15,
//0x39,0,18,0xF6,0x44,0x68,0xF8,0x55,0x77,0xE9,0x66,0x51,0xB1,0x78,0xF9,0x87,0x88,0xA8,0xCD,0x80,0xCD,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x04,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x29,0x9F,0x01,0xFB,0x4B,0x12,0xD0,0x41,0x22,0xA5,0xF9,
//0x39,0,18,0xF2,0x33,0x48,0xCF,0x44,0x45,0xAE,0x55,0x0E,0x68,0x67,0x92,0x1D,0x77,0x3E,0x5D,0x70,0x5D,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x38,0x81,0x01,0xFB,0x64,0x12,0xBF,0x0F,
//0x39,0,18,0xF4,0x22,0x5C,0xDE,0x33,0x4C,0xAF,0x44,0x03,0x54,0x55,0x61,0xD9,0x56,0xF5,0x13,0x60,0x13,
//0x39,0,22,0xF5,0x00,0x00,0x1B,0x00,0x63,0x98,0x01,0xCB,0x01,0x11,0x3F,0xA6,0x22,0x07,0x61,0x23,0xF4,0x6F,0x34,0xD8,0x33,
//0x39,0,18,0xF6,0x45,0x88,0x1A,0x56,0x9C,0x11,0x66,0x7A,0xDC,0x88,0x23,0xBD,0x89,0xE1,0x04,0x90,0x04,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x05,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x2B,0x9C,0x01,0xFF,0x50,0x12,0xDB,0x50,0x23,0xB5,0x0F,
//0x39,0,18,0xF2,0x33,0x62,0xE8,0x44,0x61,0xCA,0x55,0x30,0x8B,0x67,0xBC,0x46,0x77,0x65,0x89,0x70,0x89,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x38,0x81,0x01,0xFF,0x69,0x12,0xC7,0x1D,
//0x39,0,18,0xF4,0x22,0x6F,0xF4,0x33,0x68,0xC6,0x44,0x22,0x73,0x55,0x83,0xFD,0x66,0x19,0x39,0x60,0x39,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x00,0x7A,0xB3,0x01,0xE6,0x1B,0x11,0x51,0xBD,0x22,0x21,0x7F,0x33,0x15,0x8C,0x34,0xF4,0x52,
//0x39,0,18,0xF6,0x45,0xA9,0x3B,0x56,0xBF,0x34,0x67,0xA3,0x06,0x88,0x55,0xED,0x99,0x0E,0x37,0x90,0x37,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x06,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x39,0xAE,0x11,0x15,0x75,0x22,0x17,0x9D,0x33,0x0B,0x6B,
//0x39,0,18,0xF2,0x34,0xBF,0x51,0x45,0xD1,0x40,0x56,0xAD,0x0B,0x77,0x55,0xE4,0x88,0x06,0x2A,0x80,0x2A,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x4B,0x98,0x11,0x1E,0x9C,0x22,0x0B,0x6E,
//0x39,0,18,0xF4,0x23,0xC4,0x52,0x34,0xC6,0x2C,0x44,0x8D,0xE2,0x66,0x09,0x8A,0x66,0xA8,0xC9,0x60,0xC9,
//0x39,0,22,0xF5,0x00,0x00,0x0E,0x00,0xBC,0xF5,0x11,0x2A,0x60,0x12,0x9E,0x12,0x22,0x7B,0xD8,0x33,0x70,0xEF,0x44,0x5B,0xBF,
//0x39,0,18,0xF6,0x55,0x18,0xB4,0x66,0x3D,0xB8,0x77,0x2E,0x94,0x99,0x00,0x9C,0x99,0xC5,0xED,0x90,0xED,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x07,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x48,0x00,0x85,0xF1,0x11,0x5E,0xDD,0x23,0x94,0x28,0x34,0xA3,0x0A,
//0x39,0,18,0xF2,0x45,0x67,0x07,0x56,0x93,0x10,0x66,0x83,0xEC,0x89,0x5E,0x01,0x99,0x2A,0x4E,0x90,0x4E,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x22,0x00,0x74,0xC4,0x12,0x6E,0x0A,0x22,0x8E,0xF8,
//0x39,0,18,0xF4,0x33,0x57,0xF0,0x44,0x73,0xE1,0x55,0x49,0xA8,0x67,0xF4,0x84,0x77,0xA7,0xC7,0x70,0xC7,
//0x39,0,22,0xF5,0x00,0x00,0x03,0x11,0x5C,0x8E,0x12,0xD5,0x12,0x22,0x4E,0xBF,0x33,0x27,0x83,0x44,0x20,0xA3,0x55,0x19,0x81,
//0x39,0,18,0xF6,0x56,0xE2,0x8A,0x77,0x23,0xA5,0x88,0x20,0x91,0xAA,0x32,0xF6,0xBB,0x24,0x50,0xB0,0x50,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x08,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x23,0x70,0x01,0xAF,0x1F,0x12,0xA4,0x23,0x23,0xEB,0x83,0x44,0x09,0x7A,
//0x39,0,18,0xF2,0x45,0xDD,0x8B,0x66,0x22,0xA9,0x77,0x23,0x97,0x99,0x25,0xD8,0xAA,0x06,0x30,0xA0,0x30,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x32,0x00,0x82,0xD3,0x12,0x9B,0x4D,0x23,0xE3,0x57,
//0x39,0,18,0xF4,0x34,0xB7,0x62,0x45,0xEB,0x66,0x56,0xD6,0x3E,0x78,0xA0,0x39,0x88,0x60,0x83,0x80,0x83,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x12,0x54,0x26,0x22,0x70,0xA9,0x23,0xE3,0x4D,0x34,0xAF,0x06,0x45,0xA8,0x2C,0x56,0xA9,0x17,
//0x39,0,18,0xF6,0x67,0x78,0x2E,0x78,0xC9,0x56,0x89,0xDB,0x59,0xBB,0x28,0xFF,0xCC,0x34,0x68,0xC0,0x68,
//0x39,0,2,0xFF,0x01,
//0x39,0,5,0xFE,0x01,0x09,0x00,0x00,
//0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x3A,0x00,0x75,0xDB,0x11,0x33,0xA6,0x23,0x67,0x01,0x33,0x83,0xEE,
//0x39,0,18,0xF2,0x44,0x4E,0xF4,0x55,0x7B,0xFE,0x66,0x71,0xDC,0x88,0x48,0xE5,0x99,0x0E,0x34,0x90,0x34,
//0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x3E,0x7F,0x11,0x0A,0xB2,0x22,0x4C,0xC3,
//0x39,0,18,0xF4,0x33,0x29,0xCE,0x44,0x52,0xCC,0x55,0x34,0x95,0x67,0xDC,0x6A,0x77,0x8C,0xAD,0x70,0xAD,
//0x39,0,22,0xF5,0x00,0x00,0x01,0x12,0x60,0x0A,0x22,0x45,0x7B,0x23,0xAE,0x04,0x33,0x5E,0xAB,0x44,0x3A,0xB9,0x55,0x2A,0x8E,
//0x39,0,18,0xF6,0x56,0xED,0x8F,0x77,0x1C,0xA5,0x88,0x1D,0x8D,0xAA,0x23,0xDF,0xBB,0x0C,0x36,0xB0,0x36,
//0x39,0,2,0xFF,0x01,
//0x39,0,2,0x9F,0x05,
//0x39,0,2,0xF9,0x00,
//0x39,0,2,0xF7,0x00,
//0x39,0,2,0x9F,0x06,
//0x39,0,3,0xFF,0x00,0x00,
//////////////////////////1号550 END///////////////////////////////


//////////////////////////1号 0.295-0.315 ——700///////////////////////////////
0x39,0,2,0X9F,0X04,
0x39,0,19,0XB3,0X00,0X00,0X10,0X00,0X30,0X50,0X00,0X70,0X90,0X00,0XB0,0XF0,0X11,0X30,0X70,0X12,0XF0,0X70,
0x39,0,21,0XB4,0X23,0XF0,0X70,0X34,0XF0,0XF0,0X56,0XF0,0XF0,0X78,0XF0,0XF0,0XCE,0XF0,0XF0,0XFF,0X70,0XF0,0X0F,0XFF,
0x39,0,2,0X9F,0X05,
0x39,0,16,0XB5,0X33,0XFF,0X6E,0X21,0X61,0X40,0X11,0X40,0X01,0X00,0XAF,0X5B,0X00,0X36,0X00,
0x39,0,16,0XB6,0X33,0XFF,0X6E,0X00,0X6E,0X01,0XFA,0XFF,0XAA,0X50,0X55,0X00,0X00,0X00,0X00,
0x39,0,2,0X9F,0X05,
0x39,0,2,0XF9,0X80,
0x39,0,2,0XF7,0X10,
0x39,0,2,0X9F,0X06,
0x39,0,3,0XFF,0X00,0X01,
0x39,0,5,0XFE,0X01,0X00,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X3B,0X01,0XB5,0X13,0X11,0X69,0XF7,0X22,0X6F,0XD9,0X34,0X85,0X13,0X44,0X90,0XFF,
0x39,0,18,0XF2,0X56,0X6A,0X23,0X67,0XC8,0X62,0X78,0XF0,0X77,0XAB,0X74,0X78,0XBB,0XBD,0XFF,0XB0,0XFF,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X5C,0X01,0XB3,0X40,0X12,0XB5,0X1B,0X23,0XC5,0X4D,0X34,0XC2,0X27,
0x39,0,18,0XF4,0X45,0X88,0X31,0X56,0XC7,0X52,0X67,0XD4,0X53,0X99,0X17,0XF4,0XAA,0X33,0X6E,0XA0,0X6E,
0x39,0,22,0XF5,0X00,0X00,0X06,0X01,0X8C,0X29,0X12,0XA8,0X15,0X23,0X77,0X15,0X34,0X94,0X04,0X45,0XBF,0X5C,0X56,0XE7,0X60,
0x39,0,18,0XF6,0X67,0XD6,0XA1,0X88,0X55,0XFF,0X9A,0X9E,0X3B,0XCD,0X93,0XCE,0XEE,0X17,0X76,0XE0,0X76,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X01,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X5F,0X01,0XCA,0X1F,0X11,0X6F,0XF7,0X22,0X6E,0XD3,0X34,0X7B,0X06,0X44,0X81,0XEF,
0x39,0,18,0XF2,0X56,0X52,0X08,0X67,0XA8,0X3E,0X78,0XC9,0X4A,0XAB,0X30,0X26,0XBB,0X68,0XA4,0XB0,0XA4,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X1E,0X70,0X01,0XBD,0X40,0X12,0XB1,0X12,0X23,0XB7,0X3B,0X34,0XAE,0X13,
0x39,0,18,0XF4,0X45,0X6F,0X14,0X56,0XA6,0X2D,0X67,0XAC,0X25,0X89,0XD6,0XAC,0X9A,0XE2,0X18,0XA0,0X18,
0x39,0,22,0XF5,0X00,0X00,0X4B,0X01,0X8C,0X3D,0X12,0XB4,0X1B,0X23,0X78,0X15,0X33,0X91,0XFC,0X45,0XB3,0X4C,0X56,0XD3,0X4D,
0x39,0,18,0XF6,0X67,0XBB,0X83,0X88,0X31,0XD5,0X9A,0X71,0X05,0XCD,0X43,0X6A,0XDE,0XB6,0X0C,0XE0,0X0C,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X02,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X0B,0X00,0X66,0XB7,0X01,0XF8,0X71,0X12,0XD6,0X33,0X23,0XCE,0X4D,0X34,0XBA,0X1C,
0x39,0,18,0XF2,0X45,0X76,0X15,0X56,0XA2,0X22,0X67,0X9A,0X0A,0X89,0X90,0X45,0X99,0X74,0X9E,0X90,0X9E,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X0D,0X00,0X4C,0XBE,0X11,0X21,0X78,0X22,0X0D,0X8A,0X23,0XF4,0X51,
0x39,0,18,0XF4,0X34,0XA5,0X37,0X45,0XB7,0X2B,0X55,0X99,0XFF,0X78,0X66,0X07,0X88,0X2F,0X55,0X80,0X55,
0x39,0,22,0XF5,0X00,0X00,0X3D,0X00,0X91,0XEC,0X11,0X49,0XA2,0X12,0XEF,0X79,0X23,0XEE,0X51,0X34,0XF6,0X81,0X45,0XF9,0X66,
0x39,0,18,0XF6,0X56,0XC9,0X78,0X77,0X11,0X9F,0X88,0X23,0X9C,0XAB,0X52,0X2B,0XBB,0X5E,0X94,0XB0,0X94,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X03,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X07,0X00,0X3F,0X98,0X01,0XE8,0X2D,0X12,0XAB,0X13,0X22,0X70,0XC4,
0x39,0,18,0XF2,0X33,0X0D,0X8F,0X34,0XFE,0X65,0X45,0XC1,0X17,0X66,0X3C,0XBC,0X66,0XDD,0XF9,0X60,0XF9,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X3A,0X7E,0X01,0XF6,0X5A,0X12,0XB3,0X03,
0x39,0,18,0XF4,0X22,0X4B,0XCA,0X33,0X34,0X93,0X34,0XE9,0X38,0X55,0X42,0XB8,0X55,0XD4,0XEF,0X50,0XEF,
0x39,0,22,0XF5,0X00,0X00,0X23,0X00,0X5C,0X8B,0X00,0XB6,0XE9,0X11,0X1D,0X7F,0X12,0XDA,0X2C,0X23,0XBD,0X2F,0X33,0X93,0XEC,
0x39,0,18,0XF6,0X44,0X3B,0XCA,0X55,0X45,0XB6,0X66,0X1D,0X7A,0X78,0XBC,0X49,0X88,0X6B,0X8D,0X80,0X8D,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X04,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X0B,0X7F,0X01,0XDC,0X2C,0X12,0XB1,0X1E,0X22,0X81,0XD7,
0x39,0,18,0XF2,0X33,0X23,0XA9,0X44,0X1C,0X84,0X45,0XE5,0X3B,0X66,0X65,0XEC,0X77,0X0C,0X2B,0X70,0X2B,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X36,0X7D,0X01,0XFB,0X62,0X12,0XBF,0X11,
0x39,0,18,0XF4,0X22,0X5C,0XDF,0X33,0X4E,0XAF,0X44,0X08,0X57,0X55,0X69,0XE2,0X56,0XFE,0X1B,0X60,0X1B,
0x39,0,22,0XF5,0X00,0X00,0X1D,0X00,0X4A,0XC7,0X00,0XE8,0XE9,0X11,0X22,0X88,0X12,0XE6,0X3A,0X23,0XD0,0X46,0X34,0XAE,0X09,
0x39,0,18,0XF6,0X44,0X5B,0XEC,0X55,0X6A,0XDB,0X66,0X47,0XA5,0X78,0XE9,0X7E,0X88,0XA0,0XC6,0X80,0XC6,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X05,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X0E,0X80,0X01,0XE2,0X2F,0X12,0XB7,0X2C,0X22,0X93,0XED,
0x39,0,18,0XF2,0X33,0X3B,0XC2,0X44,0X37,0XA1,0X55,0X01,0X5C,0X67,0X8E,0X17,0X77,0X31,0X52,0X70,0X52,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X37,0X7E,0X01,0XFD,0X69,0X12,0XC9,0X20,
0x39,0,18,0XF4,0X22,0X70,0XF6,0X33,0X66,0XCA,0X44,0X22,0X75,0X56,0X8C,0X09,0X66,0X20,0X3D,0X60,0X3D,
0x39,0,22,0XF5,0X00,0X00,0X03,0X00,0X78,0XA1,0X01,0XD0,0X02,0X11,0X36,0XA0,0X22,0X03,0X57,0X23,0XEE,0X64,0X34,0XCD,0X29,
0x39,0,18,0XF6,0X45,0X7A,0X0C,0X56,0X8B,0X00,0X66,0X69,0XCB,0X88,0X1A,0XB0,0X88,0XCD,0XF1,0X80,0XF1,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X06,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X1D,0X91,0X01,0XF5,0X51,0X12,0XF5,0X78,0X23,0XE4,0X44,
0x39,0,18,0XF2,0X34,0X98,0X2A,0X45,0XA1,0X18,0X55,0X7E,0XDD,0X77,0X20,0XB2,0X77,0XD4,0XF4,0X70,0XF4,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X07,0X00,0X4D,0X97,0X11,0X22,0XA0,0X22,0X0C,0X6E,
0x39,0,18,0XF4,0X23,0XC6,0X54,0X34,0XC5,0X33,0X44,0X92,0XE9,0X66,0X10,0X96,0X66,0XB6,0XD4,0X60,0XD4,
0x39,0,22,0XF5,0X00,0X00,0X05,0X00,0XB1,0XE6,0X11,0X15,0X48,0X11,0X7F,0XF1,0X22,0X54,0XB1,0X33,0X49,0XC5,0X44,0X30,0X90,
0x39,0,18,0XF6,0X45,0XE9,0X83,0X66,0X03,0X86,0X67,0XF5,0X5B,0X89,0XBA,0X5C,0X99,0X85,0XA8,0X90,0XA8,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X07,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X27,0X00,0X67,0XD2,0X11,0X3E,0XAD,0X22,0X6A,0XFC,0X33,0X7A,0XE2,
0x39,0,18,0XF2,0X44,0X3C,0XD9,0X55,0X68,0XE4,0X66,0X55,0XBC,0X88,0X28,0XB8,0X89,0XEE,0X13,0X90,0X13,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X24,0X00,0X78,0XC9,0X12,0X76,0X11,0X22,0X93,0XFF,
0x39,0,18,0XF4,0X33,0X5A,0XF4,0X44,0X77,0XEB,0X55,0X56,0XB5,0X77,0X01,0X87,0X77,0XB7,0XD6,0X70,0XD6,
0x39,0,22,0XF5,0X00,0X00,0X06,0X11,0X4B,0X8C,0X11,0XB9,0XF1,0X22,0X27,0X96,0X33,0X00,0X59,0X34,0XF5,0X75,0X45,0XEB,0X51,
0x39,0,18,0XF6,0X56,0XAE,0X52,0X67,0XE9,0X6E,0X78,0XE6,0X56,0X9A,0XEC,0X95,0XAB,0XD7,0X02,0XB0,0X02,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X08,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X51,0X01,0X90,0X04,0X11,0X75,0XF6,0X23,0XC2,0X5C,0X34,0XD8,0X4E,
0x39,0,18,0XF2,0X45,0XB2,0X5E,0X56,0XF2,0X78,0X67,0XF1,0X66,0X89,0XEB,0X97,0X99,0XC3,0XED,0X90,0XED,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X35,0X00,0X85,0XDD,0X12,0XA7,0X5D,0X23,0XE9,0X5A,
0x39,0,18,0XF4,0X34,0XBE,0X69,0X45,0XF5,0X6F,0X56,0XE1,0X4C,0X78,0XB0,0X49,0X88,0X70,0X94,0X80,0X94,
0x39,0,22,0XF5,0X00,0X00,0X13,0X02,0XFF,0X30,0X22,0X4E,0X8B,0X23,0XC3,0X25,0X33,0X84,0XE0,0X45,0X7C,0X01,0X55,0X74,0XE6,
0x39,0,18,0XF6,0X66,0X46,0XF4,0X78,0X90,0X1B,0X89,0X9D,0X1A,0XAB,0XDA,0XA4,0XBC,0XD8,0X0B,0XC0,0X0B,
0x39,0,2,0XFF,0X01,

0x39,0,5,0XFE,0X01,0X09,0X00,0X00,
0x39,0,22,0XF1,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X16,0X00,0X5D,0XBA,0X11,0X12,0X77,0X22,0X37,0XD9,0X33,0X56,0XC3,
0x39,0,18,0XF2,0X44,0X20,0XCB,0X55,0X55,0XD1,0X66,0X42,0XAF,0X88,0X11,0X9D,0X88,0XD0,0XFA,0X80,0XFA,
0x39,0,22,0XF3,0X00,0X00,0X01,0X00,0X02,0X03,0X00,0X04,0X05,0X00,0X06,0X08,0X00,0X43,0X87,0X11,0X14,0XC0,0X22,0X54,0XC9,
0x39,0,18,0XF4,0X33,0X30,0XD6,0X44,0X5E,0XD3,0X55,0X3C,0XA2,0X67,0XE8,0X6B,0X77,0X97,0XBD,0X70,0XBD,
0x39,0,22,0XF5,0X00,0X00,0X0F,0X12,0X31,0X01,0X22,0X3E,0X63,0X22,0X8B,0XE6,0X33,0X36,0X84,0X44,0X11,0X8D,0X45,0XFC,0X5E,
0x39,0,18,0XF6,0X56,0XBA,0X5D,0X67,0XEC,0X6C,0X78,0XE2,0X53,0X9A,0XD8,0X7E,0XAA,0XBB,0XEB,0XA0,0XEB,
0x39,0,2,0XFF,0X01,

0x39,0,2,0X9F,0X05,
0x39,0,2,0XF9,0X00,
0x39,0,2,0XF7,0X00,
0x39,0,2,0X9F,0X06,
0x39,0,3,0XFF,0X00,0X00,





#endif

#else

/////////////GAMMA2///////////////
    0x29, 0, 5, 0xFE, 0x01, 0x00, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x39, 0xC7, 0x11, 0x48, 0xB0, 0x22, 0x0B, 0x96, 0x33, 0x12, 0x79, 0x44, 0x1D, 0xA3, 0x55, 0x21, 0x8D,
    0x29, 0, 18, 0xF2, 0x56, 0xF4, 0xA3, 0x77, 0x3C, 0xC9, 0x88, 0x50, 0xD6, 0xAB, 0xCE, 0xCB, 0xCC, 0x14, 0x51, 0xC0, 0x51,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x0B, 0x5B, 0x01, 0xB9, 0x05, 0x11, 0x58, 0xD7, 0x22, 0x46, 0xAA, 0x33, 0x44, 0xBE, 0x44, 0x29, 0x8C,
    0x29, 0, 18, 0xF4, 0x45, 0xE8, 0x8C, 0x66, 0x1E, 0x98, 0x77, 0x11, 0x83, 0x99, 0x2E, 0xFE, 0xAA, 0x37, 0x68, 0xA0, 0x68,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0xE1, 0x11, 0x4D, 0xC3, 0x22, 0x36, 0x94, 0x23, 0xEC, 0x78, 0x34, 0xEE, 0x59, 0x55, 0x0A, 0x97, 0x66, 0x18, 0x87,
    0x29, 0, 18, 0xF6, 0x67, 0xEF, 0xA5, 0x88, 0x47, 0xD9, 0x99, 0x71, 0xFB, 0xCD, 0x17, 0x2D, 0xDD, 0x79, 0xBC, 0xD0, 0xBC,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x01, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x2B, 0x00, 0x7D, 0xDC, 0x11, 0x44, 0xA1, 0x12, 0xF5, 0x82, 0x23, 0xF0, 0x4A, 0x34, 0xEA, 0x72, 0x45, 0xE3, 0x4C,
    0x29, 0, 18, 0xF2, 0x56, 0xAB, 0x58, 0x67, 0xED, 0x73, 0x78, 0xEF, 0x65, 0xAB, 0x2C, 0x0E, 0xBB, 0x43, 0x7B, 0xB0, 0x7B,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x37, 0x00, 0x62, 0x8D, 0x01, 0xCA, 0x0A, 0x11, 0x4D, 0xC6, 0x22, 0x29, 0x7C, 0x33, 0x13, 0x8E, 0x34, 0xEF, 0x4F,
    0x29, 0, 18, 0xF4, 0x45, 0xA6, 0x43, 0x56, 0xC9, 0x46, 0x67, 0xB5, 0x1E, 0x89, 0xA0, 0x56, 0x99, 0x83, 0xB7, 0x90, 0xB7,
    0x29, 0, 22, 0xF5, 0x01, 0x00, 0x2C, 0x11, 0x77, 0xCF, 0x22, 0x2F, 0x86, 0x23, 0xD5, 0x60, 0x34, 0xCC, 0x29, 0x45, 0xD4, 0x63, 0x56, 0xDC, 0x46,
    0x29, 0, 18, 0xF6, 0x67, 0xA8, 0x58, 0x78, 0xF4, 0x7F, 0x99, 0x05, 0x82, 0xBC, 0x6C, 0x60, 0xCC, 0x99, 0xD1, 0xC0, 0xD1,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x02, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x09, 0x00, 0x5A, 0x9A, 0x01, 0xE3, 0x2F, 0x11, 0x78, 0xEF, 0x22, 0x5A, 0xB1, 0x33, 0x46, 0xBD, 0x44, 0x23, 0x7E,
    0x29, 0, 18, 0xF2, 0x45, 0xD6, 0x6E, 0x56, 0xF3, 0x68, 0x67, 0xD9, 0x3D, 0x89, 0x9F, 0x44, 0x99, 0x6D, 0x95, 0x90, 0x95,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x26, 0x00, 0x52, 0x6E, 0x00, 0x91, 0xBE, 0x01, 0xED, 0x46, 0x11, 0xA0, 0xF0, 0x22, 0x79, 0xE6, 0x33, 0x45, 0x98,
    0x29, 0, 18, 0xF4, 0x34, 0xE5, 0x6E, 0x45, 0xE5, 0x51, 0x56, 0xB5, 0x14, 0x77, 0x4D, 0xDE, 0x78, 0xFE, 0x26, 0x80, 0x26,
    0x29, 0, 22, 0xF5, 0x01, 0x00, 0x25, 0x11, 0x57, 0x92, 0x12, 0xD5, 0x1B, 0x22, 0x5E, 0xD0, 0x33, 0x38, 0x8F, 0x44, 0x23, 0xA2, 0x55, 0x10, 0x70,
    0x29, 0, 18, 0xF6, 0x56, 0xCC, 0x6A, 0x67, 0xF0, 0x6A, 0x78, 0xDF, 0x46, 0x9A, 0xC0, 0x74, 0xAA, 0x9F, 0xCD, 0xA0, 0xCD,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x03, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x36, 0x5C, 0x00, 0x7D, 0xA2, 0x01, 0xCD, 0x23, 0x11, 0x75, 0xC1, 0x22, 0x3E, 0xAA, 0x33, 0x06, 0x53,
    0x29, 0, 18, 0xF2, 0x34, 0x96, 0x0F, 0x44, 0x79, 0xE5, 0x55, 0x3D, 0x90, 0x67, 0xA4, 0x1A, 0x77, 0x37, 0x51, 0x70, 0x51,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x3F, 0x55, 0x00, 0x60, 0x6F, 0x00, 0x84, 0xB5, 0x01, 0xEB, 0x23, 0x11, 0x8A, 0xE8, 0x22, 0x3C, 0x84,
    0x29, 0, 18, 0xF4, 0x23, 0xC2, 0x35, 0x33, 0x95, 0xF1, 0x44, 0x41, 0x8C, 0x55, 0x87, 0xF4, 0x66, 0x0F, 0x25, 0x60, 0x25,
    0x29, 0, 22, 0xF5, 0x01, 0x00, 0x01, 0x11, 0x37, 0x59, 0x11, 0x75, 0x99, 0x12, 0xC0, 0x10, 0x22, 0x5F, 0xA6, 0x33, 0x1D, 0x88, 0x34, 0xE2, 0x33,
    0x29, 0, 18, 0xF6, 0x44, 0x7A, 0xFD, 0x55, 0x6C, 0xDD, 0x66, 0x38, 0x8C, 0x78, 0xA8, 0x24, 0x88, 0x41, 0x5D, 0x80, 0x5D,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x04, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x03, 0x2D, 0x00, 0x59, 0x86, 0x01, 0xB9, 0x1B, 0x11, 0x71, 0xBF, 0x22, 0x45, 0xB3, 0x33, 0x14, 0x63,
    0x29, 0, 18, 0xF2, 0x34, 0xAE, 0x2B, 0x45, 0x9A, 0x01, 0x55, 0x5B, 0xAF, 0x67, 0xC9, 0x44, 0x77, 0x61, 0x7F, 0x70, 0x7F,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x2E, 0x42, 0x00, 0x52, 0x61, 0x00, 0x76, 0xAB, 0x01, 0xE3, 0x1F, 0x11, 0x89, 0xEE, 0x22, 0x44, 0x8E,
    0x29, 0, 18, 0xF4, 0x23, 0xD4, 0x4A, 0x34, 0xAE, 0x08, 0x44, 0x5C, 0xA7, 0x56, 0xA9, 0x1A, 0x66, 0x33, 0x4E, 0x60, 0x4E,
    0x29, 0, 22, 0xF5, 0x01, 0x00, 0x07, 0x11, 0x34, 0x53, 0x11, 0x74, 0x9A, 0x12, 0xC2, 0x16, 0x22, 0x65, 0xAC, 0x33, 0x2F, 0x9C, 0x34, 0xFA, 0x4B,
    0x29, 0, 18, 0xF6, 0x45, 0x99, 0x1E, 0x55, 0x91, 0xFE, 0x66, 0x59, 0xAE, 0x78, 0xD2, 0x51, 0x88, 0x70, 0x8F, 0x80, 0x8F,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x05, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x27, 0x00, 0x4F, 0x7B, 0x01, 0xA4, 0x02, 0x11, 0x57, 0xA5, 0x22, 0x2D, 0xA4, 0x23, 0xFF, 0x55,
    0x29, 0, 18, 0xF2, 0x34, 0x9F, 0x1D, 0x44, 0x8E, 0xF1, 0x55, 0x4B, 0x9A, 0x67, 0xB5, 0x32, 0x77, 0x4A, 0x67, 0x70, 0x67,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x3A, 0x4E, 0x00, 0x5F, 0x6D, 0x00, 0x80, 0xA9, 0x01, 0xDD, 0x10, 0x11, 0x76, 0xDD, 0x22, 0x2F, 0x7E,
    0x29, 0, 18, 0xF4, 0x23, 0xC6, 0x3E, 0x33, 0xA4, 0xFB, 0x44, 0x4D, 0x94, 0x56, 0x96, 0x07, 0x66, 0x20, 0x3A, 0x60, 0x3A,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0xD6, 0x11, 0x56, 0x70, 0x11, 0x91, 0xB0, 0x12, 0xD2, 0x21, 0x22, 0x6E, 0xB4, 0x33, 0x2F, 0x9C, 0x34, 0xF0, 0x44,
    0x29, 0, 18, 0xF6, 0x45, 0x92, 0x15, 0x55, 0x89, 0xF1, 0x66, 0x4C, 0x9C, 0x78, 0xBE, 0x3F, 0x88, 0x59, 0x79, 0x80, 0x79,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x06, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x22, 0x00, 0x41, 0x63, 0x00, 0x87, 0xD7, 0x11, 0x24, 0x76, 0x22, 0x10, 0x90, 0x23, 0xF2, 0x4E,
    0x29, 0, 18, 0xF2, 0x34, 0x96, 0x1B, 0x44, 0x90, 0xEE, 0x55, 0x4E, 0x9A, 0x67, 0xB9, 0x31, 0x77, 0x4B, 0x5C, 0x70, 0x5C,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x5D, 0x78, 0x00, 0x85, 0x92, 0x00, 0xA2, 0xC0, 0x01, 0xE1, 0x0C, 0x11, 0x68, 0xD1, 0x22, 0x26, 0x7A,
    0x29, 0, 18, 0xF4, 0x23, 0xBD, 0x39, 0x33, 0xA5, 0xF7, 0x44, 0x4E, 0x96, 0x56, 0x99, 0x08, 0x66, 0x20, 0x2E, 0x60, 0x2E,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0xAC, 0x11, 0xA0, 0xBE, 0x11, 0xD8, 0xF4, 0x22, 0x10, 0x51, 0x22, 0x90, 0xD0, 0x33, 0x43, 0xAC, 0x34, 0xFF, 0x52,
    0x29, 0, 18, 0xF6, 0x45, 0x98, 0x1F, 0x55, 0x94, 0xF6, 0x66, 0x54, 0xA0, 0x78, 0xC4, 0x40, 0x88, 0x5B, 0x6B, 0x80, 0x6B,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x07, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x39, 0x00, 0x63, 0x7E, 0x00, 0x98, 0xC9, 0x01, 0xFF, 0x40, 0x12, 0xCE, 0x5C, 0x23, 0xD3, 0x2F,
    0x29, 0, 18, 0xF2, 0x34, 0x86, 0x08, 0x44, 0x8C, 0xEF, 0x55, 0x4C, 0x9F, 0x67, 0xB9, 0x2A, 0x77, 0x51, 0x65, 0x70, 0x65,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0xCE, 0x00, 0xE0, 0xEF, 0x01, 0xFA, 0x11, 0x11, 0x25, 0x40, 0x11, 0x83, 0xD4, 0x22, 0x26, 0x6F,
    0x29, 0, 18, 0xF4, 0x23, 0xBB, 0x31, 0x33, 0xA2, 0xFA, 0x44, 0x4F, 0x9A, 0x56, 0x9A, 0x03, 0x66, 0x24, 0x37, 0x60, 0x37,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x2B, 0x22, 0x59, 0x73, 0x22, 0x85, 0x9A, 0x22, 0xB3, 0xDB, 0x33, 0x05, 0x31, 0x33, 0x87, 0xDD, 0x44, 0x31, 0x78,
    0x29, 0, 18, 0xF6, 0x45, 0xC0, 0x36, 0x56, 0xB0, 0x10, 0x66, 0x68, 0xB7, 0x78, 0xCE, 0x43, 0x88, 0x6A, 0x80, 0x80, 0x80,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x08, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x62, 0x8D, 0x00, 0xA2, 0xC9, 0x01, 0xF9, 0x2A, 0x12, 0xA7, 0x3B, 0x23, 0xBF, 0x2B,
    0x29, 0, 18, 0xF2, 0x34, 0x84, 0x1B, 0x45, 0x9C, 0x05, 0x55, 0x69, 0xC0, 0x67, 0xDF, 0x5E, 0x77, 0x78, 0x95, 0x70, 0x95,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x18, 0x11, 0x25, 0x3C, 0x11, 0x4B, 0x64, 0x11, 0x81, 0x96, 0x12, 0xCC, 0x0E, 0x22, 0x53, 0x9A,
    0x29, 0, 18, 0xF4, 0x23, 0xDC, 0x53, 0x34, 0xBB, 0x18, 0x44, 0x6B, 0xBB, 0x56, 0xBE, 0x34, 0x66, 0x4F, 0x66, 0x60, 0x66,
    0x29, 0, 22, 0xF5, 0x01, 0x00, 0x29, 0x23, 0x15, 0x1E, 0x33, 0x30, 0x3D, 0x33, 0x4C, 0x6C, 0x33, 0x8E, 0xB1, 0x34, 0xF0, 0x3C, 0x44, 0x82, 0xC8,
    0x29, 0, 18, 0xF6, 0x55, 0x06, 0x82, 0x56, 0xF0, 0x4B, 0x66, 0xA4, 0xF0, 0x88, 0x07, 0x8C, 0x88, 0xA1, 0xBD, 0x80, 0xBD,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x09, 0x00, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x70, 0x9C, 0x00, 0xB3, 0xD2, 0x11, 0x04, 0x4C, 0x12, 0xA5, 0x06,
    0x29, 0, 18, 0xF2, 0x23, 0x69, 0x03, 0x33, 0x84, 0xE4, 0x44, 0x42, 0x90, 0x56, 0x98, 0x06, 0x66, 0x21, 0x36, 0x60, 0x36,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x08, 0x0E, 0x11, 0x28, 0x40, 0x11, 0x55, 0x64, 0x11, 0x82, 0xA3, 0x11, 0xC9, 0xF2,
    0x29, 0, 18, 0xF4, 0x22, 0x23, 0x7B, 0x23, 0xD9, 0x23, 0x33, 0x6E, 0xAD, 0x44, 0x93, 0xF6, 0x55, 0x0E, 0x23, 0x50, 0x23,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x02, 0x11, 0x72, 0xB8, 0x33, 0x1E, 0x24, 0x33, 0x2E, 0x42, 0x33, 0x59, 0x6D, 0x33, 0x98, 0xC1, 0x34, 0xF0, 0x1E,
    0x29, 0, 18, 0xF6, 0x44, 0x52, 0xA9, 0x55, 0x05, 0x53, 0x55, 0x9C, 0xE1, 0x67, 0xCE, 0x34, 0x77, 0x4E, 0x64, 0x70, 0x64,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x00, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0xE4, 0x11, 0x37, 0x96, 0x12, 0xF5, 0x4D, 0x23, 0x9A, 0x20, 0x33, 0x8E, 0xEE, 0x45, 0x8C, 0x0D, 0x55, 0x7E, 0xE6,
    0x29, 0, 18, 0xF2, 0x66, 0x44, 0xF2, 0x78, 0x8A, 0x16, 0x89, 0x97, 0x19, 0xAB, 0xF7, 0xE5, 0xCC, 0x20, 0x62, 0xC0, 0x62,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0xF8, 0x11, 0x28, 0x57, 0x11, 0x8E, 0xC8, 0x22, 0x02, 0x71, 0x23, 0xD1, 0x28, 0x34, 0xBB, 0x32, 0x44, 0x99, 0xF5,
    0x29, 0, 18, 0xF4, 0x55, 0x4A, 0xE0, 0x66, 0x68, 0xE4, 0x77, 0x57, 0xC6, 0x9A, 0x5D, 0x23, 0xAA, 0x56, 0x8E, 0xA0, 0x8E,
    0x29, 0, 22, 0xF5, 0x01, 0x00, 0xF9, 0x22, 0x47, 0x96, 0x23, 0xEC, 0x3B, 0x34, 0x86, 0x09, 0x44, 0x76, 0xD6, 0x56, 0x7A, 0x03, 0x66, 0x7A, 0xE6,
    0x29, 0, 18, 0xF6, 0x77, 0x4A, 0xFF, 0x89, 0x9E, 0x33, 0x9A, 0xBE, 0x47, 0xCD, 0x4A, 0x55, 0xDD, 0x9B, 0xE0, 0xD0, 0xE0,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x01, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x01, 0x00, 0x4F, 0x11, 0x8D, 0xCF, 0x22, 0x1B, 0x66, 0x23, 0xAD, 0x29, 0x33, 0x92, 0xEE, 0x45, 0x86, 0x07, 0x55, 0x75, 0xDA,
    0x29, 0, 18, 0xF2, 0x66, 0x39, 0xE1, 0x77, 0x73, 0xF9, 0x88, 0x7A, 0xF3, 0xAB, 0xC0, 0xA4, 0xBC, 0xE0, 0x1B, 0xC0, 0x1B,
    0x29, 0, 22, 0xF3, 0x01, 0x00, 0x5F, 0x11, 0x82, 0xA2, 0x11, 0xC6, 0xF1, 0x22, 0x22, 0x81, 0x23, 0xDA, 0x2A, 0x34, 0xB4, 0x29, 0x44, 0x8C, 0xE6,
    0x29, 0, 18, 0xF4, 0x55, 0x39, 0xCD, 0x66, 0x50, 0xC8, 0x77, 0x3A, 0xA4, 0x99, 0x2B, 0xEB, 0xAA, 0x1C, 0x4B, 0xA0, 0x4B,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0x43, 0x22, 0x83, 0xC4, 0x33, 0x0C, 0x51, 0x34, 0x96, 0x0F, 0x44, 0x78, 0xD4, 0x55, 0x74, 0xFA, 0x66, 0x6F, 0xD9,
    0x29, 0, 18, 0xF6, 0x77, 0x3B, 0xEA, 0x89, 0x84, 0x13, 0x9A, 0x9C, 0x1D, 0xCD, 0x0B, 0x0F, 0xDD, 0x56, 0x93, 0xD0, 0x93,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x02, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x01, 0x00, 0x48, 0x11, 0x87, 0xC5, 0x22, 0x09, 0x51, 0x23, 0x94, 0x0B, 0x33, 0x73, 0xCD, 0x44, 0x61, 0xDD, 0x55, 0x4C, 0xAF,
    0x29, 0, 18, 0xF2, 0x66, 0x09, 0xA9, 0x77, 0x3A, 0xBD, 0x88, 0x38, 0xA9, 0xAB, 0x5B, 0x31, 0xBB, 0x66, 0x94, 0xB0, 0x94,
    0x29, 0, 22, 0xF3, 0x01, 0x00, 0x5E, 0x11, 0x80, 0x9C, 0x11, 0xBE, 0xE5, 0x22, 0x11, 0x6B, 0x23, 0xC0, 0x0C, 0x34, 0x92, 0x03, 0x44, 0x66, 0xBF,
    0x29, 0, 18, 0xF4, 0x55, 0x0F, 0x9E, 0x66, 0x1C, 0x91, 0x67, 0xFD, 0x62, 0x89, 0xD7, 0x8C, 0x99, 0xB8, 0xE3, 0x90, 0xE3,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x22, 0x7D, 0xB9, 0x23, 0xFB, 0x3C, 0x33, 0x7E, 0xF3, 0x44, 0x59, 0xB3, 0x55, 0x4D, 0xD0, 0x66, 0x44, 0xAD,
    0x29, 0, 18, 0xF6, 0x77, 0x0A, 0xB2, 0x88, 0x48, 0xD2, 0x99, 0x54, 0xCF, 0xBC, 0x9E, 0x8B, 0xCC, 0xC8, 0xFE, 0xC0, 0xFE,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x03, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x59, 0x11, 0x76, 0xA2, 0x12, 0xD2, 0x07, 0x22, 0x3F, 0xA9, 0x33, 0x04, 0x56, 0x34, 0xDF, 0x53, 0x45, 0xB9, 0x10,
    0x29, 0, 18, 0xF2, 0x55, 0x62, 0xF5, 0x66, 0x76, 0xED, 0x77, 0x59, 0xBA, 0x99, 0x23, 0xCB, 0x9A, 0xF3, 0x23, 0xA0, 0x23,
    0x29, 0, 22, 0xF3, 0x01, 0x00, 0x4E, 0x11, 0x78, 0x8D, 0x11, 0xA3, 0xBC, 0x12, 0xDB, 0x1F, 0x22, 0x65, 0xA7, 0x33, 0x1E, 0x85, 0x34, 0xE2, 0x32,
    0x29, 0, 18, 0xF4, 0x44, 0x7A, 0xFE, 0x55, 0x71, 0xD6, 0x66, 0x36, 0x8F, 0x78, 0xCE, 0x5C, 0x88, 0x81, 0xA4, 0x80, 0xA4,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0x37, 0x22, 0x6C, 0x97, 0x22, 0xC5, 0xF8, 0x33, 0x2E, 0x91, 0x34, 0xEC, 0x3D, 0x45, 0xC6, 0x3E, 0x56, 0xAA, 0x06,
    0x29, 0, 18, 0xF6, 0x66, 0x5B, 0xF5, 0x77, 0x7B, 0xF6, 0x88, 0x66, 0xCF, 0xAB, 0x50, 0x04, 0xBB, 0x32, 0x5A, 0xB0, 0x5A,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x04, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x61, 0x7E, 0x11, 0x9E, 0xC3, 0x12, 0xEA, 0x3A, 0x22, 0x88, 0xD0, 0x33, 0x4E, 0xBA, 0x44, 0x16, 0x66,
    0x29, 0, 18, 0xF2, 0x45, 0xB1, 0x33, 0x56, 0xA4, 0x0B, 0x66, 0x6A, 0xBF, 0x78, 0xF4, 0x7A, 0x88, 0x9A, 0xB9, 0x80, 0xB9,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x6B, 0x7E, 0x11, 0x8E, 0x9F, 0x11, 0xB0, 0xDA, 0x22, 0x0A, 0x3D, 0x22, 0xA0, 0xFA, 0x33, 0x4C, 0x96,
    0x29, 0, 18, 0xF4, 0x34, 0xD9, 0x50, 0x45, 0xB6, 0x11, 0x55, 0x65, 0xB4, 0x67, 0xC3, 0x3B, 0x77, 0x58, 0x74, 0x70, 0x74,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0x32, 0x22, 0x61, 0x80, 0x22, 0x9F, 0xC2, 0x23, 0xE5, 0x32, 0x33, 0x7B, 0xC3, 0x44, 0x3C, 0xA5, 0x55, 0x03, 0x56,
    0x29, 0, 18, 0xF6, 0x56, 0xA3, 0x2C, 0x67, 0xA2, 0x0D, 0x77, 0x72, 0xCF, 0x99, 0x0F, 0x9E, 0x99, 0xC1, 0xE1, 0x90, 0xE1,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x05, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x42, 0x65, 0x11, 0x82, 0xA1, 0x12, 0xC2, 0x07, 0x22, 0x50, 0x97, 0x33, 0x14, 0x7E, 0x34, 0xDA, 0x2A,
    0x29, 0, 18, 0xF2, 0x44, 0x71, 0xED, 0x55, 0x5C, 0xBB, 0x66, 0x16, 0x69, 0x78, 0x8B, 0x03, 0x88, 0x26, 0x39, 0x80, 0x39,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x7F, 0x90, 0x11, 0x9D, 0xAA, 0x11, 0xB7, 0xD5, 0x12, 0xF7, 0x20, 0x22, 0x78, 0xCC, 0x33, 0x18, 0x60,
    0x29, 0, 18, 0xF4, 0x34, 0xA0, 0x11, 0x44, 0x74, 0xCB, 0x55, 0x1A, 0x64, 0x66, 0x5F, 0xD2, 0x67, 0xEC, 0x06, 0x70, 0x06,
    0x29, 0, 22, 0xF5, 0x01, 0x00, 0x49, 0x22, 0x7C, 0x97, 0x22, 0xB3, 0xCD, 0x23, 0xE9, 0x26, 0x33, 0x64, 0xA1, 0x44, 0x11, 0x75, 0x45, 0xCA, 0x1B,
    0x29, 0, 18, 0xF6, 0x55, 0x64, 0xE4, 0x66, 0x58, 0xBD, 0x77, 0x1B, 0x70, 0x89, 0x9A, 0x1E, 0x99, 0x3D, 0x5D, 0x90, 0x5D,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x06, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x97, 0xBB, 0x12, 0xDD, 0x03, 0x22, 0x2E, 0x87, 0x23, 0xDA, 0x2B, 0x34, 0xB6, 0x23, 0x44, 0x83, 0xD9,
    0x29, 0, 18, 0xF2, 0x55, 0x29, 0xAD, 0x66, 0x2B, 0x97, 0x67, 0xFB, 0x58, 0x89, 0x9A, 0x2C, 0x99, 0x4E, 0x76, 0x90, 0x76,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0xE5, 0xF8, 0x22, 0x08, 0x17, 0x22, 0x28, 0x50, 0x22, 0x7B, 0xAC, 0x33, 0x0F, 0x6B, 0x34, 0xBF, 0x09,
    0x29, 0, 18, 0xF4, 0x44, 0x4E, 0xC5, 0x55, 0x31, 0x90, 0x56, 0xEA, 0x3C, 0x77, 0x59, 0xD6, 0x78, 0xF3, 0x11, 0x80, 0x11,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0x0E, 0x23, 0xF8, 0x15, 0x33, 0x35, 0x54, 0x33, 0x75, 0xB9, 0x34, 0xFB, 0x3E, 0x45, 0xB8, 0x21, 0x55, 0x80, 0xD7,
    0x29, 0, 18, 0xF6, 0x66, 0x29, 0xB5, 0x77, 0x33, 0xA4, 0x88, 0x0B, 0x6A, 0x9A, 0xC0, 0x5C, 0xAA, 0x81, 0xA4, 0xA0, 0xA4,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x07, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x22, 0x25, 0x55, 0x22, 0x75, 0x93, 0x23, 0xB9, 0x06, 0x33, 0x52, 0x99, 0x44, 0x1D, 0x93, 0x45, 0xF4, 0x4A,
    0x29, 0, 18, 0xF2, 0x56, 0x99, 0x2A, 0x67, 0xA9, 0x1A, 0x77, 0x85, 0xE8, 0x99, 0x41, 0xDF, 0xAA, 0x05, 0x27, 0xA0, 0x27,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x22, 0xB8, 0xD1, 0x22, 0xE2, 0xEF, 0x23, 0xFB, 0x15, 0x33, 0x35, 0x58, 0x33, 0xA4, 0xF3, 0x44, 0x3F, 0x87,
    0x29, 0, 18, 0xF4, 0x45, 0xC8, 0x41, 0x56, 0xAC, 0x0D, 0x66, 0x6B, 0xC0, 0x78, 0xEB, 0x6E, 0x88, 0x8E, 0xAD, 0x80, 0xAD,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0x2C, 0x33, 0xEB, 0xFF, 0x44, 0x15, 0x2A, 0x44, 0x43, 0x77, 0x44, 0xAC, 0xE0, 0x55, 0x4A, 0xB2, 0x66, 0x0D, 0x63,
    0x29, 0, 18, 0xF6, 0x67, 0xB0, 0x40, 0x78, 0xC1, 0x33, 0x89, 0xA0, 0x08, 0xAB, 0x77, 0x20, 0xBB, 0x49, 0x6F, 0xB0, 0x6F,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x08, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x22, 0xC7, 0xDD, 0x23, 0xF0, 0x18, 0x33, 0x3F, 0x6E, 0x34, 0xC3, 0x16, 0x44, 0x64, 0xAD,
    0x29, 0, 18, 0xF2, 0x45, 0xF3, 0x73, 0x56, 0xDF, 0x3F, 0x66, 0x99, 0xEE, 0x88, 0x12, 0x91, 0x88, 0xB0, 0xC8, 0x80, 0xC8,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x03, 0x02, 0x54, 0x33, 0x6C, 0x79, 0x33, 0x83, 0x90, 0x33, 0xA0, 0xAF, 0x33, 0xCD, 0xF0, 0x44, 0x17, 0x41,
    0x29, 0, 18, 0xF4, 0x44, 0x6B, 0xC2, 0x55, 0x18, 0x67, 0x55, 0xB1, 0xF7, 0x67, 0xEE, 0x5C, 0x77, 0x76, 0x8E, 0x70, 0x8E,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x63, 0x34, 0x9F, 0x96, 0x44, 0xA7, 0xB4, 0x44, 0xBC, 0xD5, 0x45, 0xED, 0x08, 0x55, 0x44, 0x7E, 0x55, 0xB9, 0xF7,
    0x29, 0, 18, 0xF6, 0x66, 0x33, 0xA6, 0x77, 0x0C, 0x6A, 0x78, 0xC2, 0x16, 0x99, 0x40, 0xC6, 0x9A, 0xE6, 0x03, 0xA0, 0x03,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x09, 0x01, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x55, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xA4,
    0x29, 0, 18, 0xF2, 0x34, 0xBC, 0x0C, 0x44, 0x56, 0x9D, 0x45, 0xE1, 0x25, 0x56, 0xF9, 0x54, 0x66, 0x6A, 0x7C, 0x60, 0x7C,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x07, 0x04, 0xB0, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xCD,
    0x29, 0, 18, 0xF4, 0x33, 0xC9, 0xEA, 0x44, 0x11, 0x37, 0x44, 0x5F, 0x89, 0x55, 0x2E, 0x78, 0x55, 0x8A, 0x9B, 0x50, 0x9B,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x37, 0x0F, 0xD5, 0xEF, 0xB7, 0xFD, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF5, 0xFA, 0x36,
    0x29, 0, 18, 0xF6, 0x55, 0x3E, 0x76, 0x55, 0xB0, 0xEA, 0x66, 0x23, 0x5F, 0x77, 0x27, 0x7F, 0x77, 0x94, 0xA7, 0x70, 0xA7,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x00, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x00, 0x6B, 0xC7, 0x11, 0x1B, 0xA8, 0x22, 0x1C, 0x88, 0x33, 0x34, 0xBF, 0x44, 0x35, 0xA7,
    0x29, 0, 18, 0xF2, 0x55, 0x0C, 0xC7, 0x67, 0x73, 0x05, 0x78, 0x9D, 0x1E, 0xAB, 0x35, 0x46, 0xBB, 0x92, 0xCA, 0xB0, 0xCA,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x3F, 0x00, 0x7B, 0xED, 0x11, 0x53, 0xB1, 0x22, 0x50, 0xD1, 0x33, 0x40, 0xA1,
    0x29, 0, 18, 0xF4, 0x34, 0xFB, 0x9F, 0x55, 0x38, 0xBF, 0x66, 0x40, 0xB9, 0x89, 0x78, 0x55, 0x99, 0x93, 0xC5, 0x90, 0xC5,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0xD3, 0x21, 0x11, 0x75, 0xC5, 0x22, 0x0F, 0x97, 0x33, 0x0E, 0x77, 0x44, 0x1C, 0xB1, 0x55, 0x39, 0xAD,
    0x29, 0, 18, 0xF6, 0x66, 0x19, 0xD9, 0x78, 0x87, 0x27, 0x89, 0xBF, 0x50, 0xBC, 0x8F, 0xB8, 0xDD, 0x06, 0x42, 0xD0, 0x42,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x01, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x15, 0x4A, 0x00, 0x8C, 0xD2, 0x11, 0x17, 0x96, 0x22, 0x03, 0x61, 0x33, 0x00, 0x88, 0x34, 0xF9, 0x60,
    0x29, 0, 18, 0xF2, 0x45, 0xC7, 0x76, 0x66, 0x15, 0xA4, 0x77, 0x29, 0xAC, 0x9A, 0x84, 0x74, 0xAA, 0xAD, 0xE9, 0xA0, 0xE9,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x1E, 0x00, 0x3F, 0x65, 0x00, 0x92, 0xED, 0x11, 0x43, 0x95, 0x22, 0x23, 0x9F, 0x33, 0x07, 0x64,
    0x29, 0, 18, 0xF4, 0x34, 0xBB, 0x54, 0x45, 0xE0, 0x62, 0x56, 0xDA, 0x4B, 0x78, 0xDD, 0xA0, 0x89, 0xD2, 0x08, 0x90, 0x08,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x11, 0x19, 0x4D, 0x11, 0x8A, 0xCB, 0x22, 0x08, 0x82, 0x23, 0xED, 0x4D, 0x34, 0xEB, 0x7A, 0x45, 0xF2, 0x65,
    0x29, 0, 18, 0xF6, 0x56, 0xCD, 0x85, 0x77, 0x29, 0xBD, 0x88, 0x48, 0xD1, 0xAB, 0xD5, 0xD5, 0xCC, 0x15, 0x52, 0xC0, 0x52,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x02, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x03, 0x26, 0x00, 0x4F, 0x7E, 0x01, 0xB0, 0x16, 0x11, 0x75, 0xC9, 0x22, 0x58, 0xD4, 0x33, 0x3C, 0x98,
    0x29, 0, 18, 0xF2, 0x34, 0xEB, 0x85, 0x55, 0x0D, 0x8A, 0x56, 0xFF, 0x69, 0x78, 0xE6, 0x98, 0x88, 0xC0, 0xE8, 0x80, 0xE8,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x0C, 0x00, 0x21, 0x38, 0x00, 0x54, 0x91, 0x01, 0xD2, 0x14, 0x11, 0x8C, 0xF9, 0x22, 0x59, 0xAD,
    0x29, 0, 18, 0xF4, 0x23, 0xFB, 0x82, 0x34, 0xF7, 0x65, 0x45, 0xCB, 0x2C, 0x67, 0x7F, 0x15, 0x77, 0x39, 0x60, 0x70, 0x60,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0xC9, 0x11, 0x04, 0x2B, 0x11, 0x51, 0x7E, 0x12, 0xAD, 0x09, 0x22, 0x63, 0xB9, 0x33, 0x44, 0xBE, 0x44, 0x26, 0x89,
    0x29, 0, 18, 0xF6, 0x45, 0xE4, 0x89, 0x66, 0x19, 0x9A, 0x77, 0x10, 0x81, 0x99, 0x13, 0xD1, 0x9A, 0xFE, 0x2D, 0xA0, 0x2D,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x03, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x14, 0x2A, 0x00, 0x41, 0x77, 0x00, 0xB2, 0xEA, 0x11, 0x5B, 0xBF, 0x22, 0x17, 0x64,
    0x29, 0, 18, 0xF2, 0x23, 0xAC, 0x28, 0x33, 0x97, 0xF7, 0x44, 0x4D, 0xA4, 0x56, 0xCA, 0x47, 0x66, 0x67, 0x86, 0x60, 0x86,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x0D, 0x00, 0x1B, 0x34, 0x00, 0x53, 0x76, 0x01, 0xC1, 0x0B, 0x11, 0x54, 0x97,
    0x29, 0, 18, 0xF4, 0x12, 0xD6, 0x48, 0x23, 0xAC, 0x04, 0x33, 0x54, 0x9D, 0x45, 0x9D, 0x0D, 0x55, 0x29, 0x45, 0x50, 0x45,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x20, 0x01, 0xE7, 0x02, 0x11, 0x18, 0x2F, 0x11, 0x45, 0x76, 0x11, 0xAB, 0xE3, 0x22, 0x48, 0xAB, 0x33, 0x04, 0x50,
    0x29, 0, 18, 0xF6, 0x34, 0x9A, 0x13, 0x44, 0x88, 0xF0, 0x55, 0x53, 0xAC, 0x67, 0xDC, 0x5E, 0x77, 0x7F, 0x9F, 0x70, 0x9F,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x04, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x09, 0x23, 0x00, 0x3B, 0x77, 0x00, 0xAF, 0xEC, 0x11, 0x64, 0xCC, 0x22, 0x24, 0x78,
    0x29, 0, 18, 0xF2, 0x23, 0xC1, 0x43, 0x34, 0xB2, 0x10, 0x44, 0x6E, 0xC4, 0x56, 0xF4, 0x78, 0x66, 0x8F, 0xAF, 0x60, 0xAF,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x0B, 0x00, 0x16, 0x32, 0x00, 0x52, 0x78, 0x01, 0xC6, 0x14, 0x11, 0x60, 0xA5,
    0x29, 0, 18, 0xF4, 0x12, 0xE6, 0x5C, 0x23, 0xC3, 0x1D, 0x33, 0x6F, 0xB7, 0x45, 0xC0, 0x31, 0x55, 0x4C, 0x68, 0x50, 0x68,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0xED, 0x06, 0x11, 0x20, 0x38, 0x11, 0x4B, 0x80, 0x11, 0xB9, 0xF3, 0x22, 0x5D, 0xC3, 0x33, 0x1C, 0x6B,
    0x29, 0, 18, 0xF6, 0x34, 0xB4, 0x31, 0x45, 0xA9, 0x13, 0x55, 0x77, 0xCE, 0x77, 0x05, 0x8D, 0x77, 0xAD, 0xCA, 0x70, 0xCA,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x05, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x15, 0x00, 0x28, 0x3C, 0x00, 0x4D, 0x7F, 0x00, 0xB2, 0xE7, 0x11, 0x54, 0xBB, 0x22, 0x12, 0x65,
    0x29, 0, 18, 0xF2, 0x23, 0xAB, 0x2F, 0x33, 0x99, 0xF9, 0x44, 0x52, 0xA6, 0x56, 0xCC, 0x4C, 0x66, 0x6A, 0x85, 0x60, 0x85,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x13, 0x00, 0x1F, 0x2D, 0x00, 0x36, 0x4E, 0x00, 0x68, 0x86, 0x01, 0xC8, 0x0F, 0x11, 0x57, 0x9B,
    0x29, 0, 18, 0xF4, 0x12, 0xDA, 0x4B, 0x23, 0xAF, 0x07, 0x33, 0x57, 0xA0, 0x45, 0x9F, 0x10, 0x55, 0x2A, 0x45, 0x50, 0x45,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x43, 0x11, 0x23, 0x3F, 0x11, 0x50, 0x65, 0x11, 0x79, 0xA4, 0x12, 0xD4, 0x05, 0x22, 0x66, 0xC3, 0x33, 0x18, 0x63,
    0x29, 0, 18, 0xF6, 0x34, 0xA7, 0x24, 0x44, 0x94, 0xFB, 0x55, 0x5C, 0xB6, 0x67, 0xE2, 0x66, 0x77, 0x85, 0xA5, 0x70, 0xA5,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x06, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x2A, 0x00, 0x40, 0x51, 0x00, 0x63, 0x8B, 0x00, 0xB7, 0xE9, 0x11, 0x55, 0xB8, 0x22, 0x12, 0x64,
    0x29, 0, 18, 0xF2, 0x23, 0xAF, 0x2F, 0x33, 0x9B, 0xFB, 0x44, 0x56, 0xA9, 0x56, 0xC9, 0x46, 0x66, 0x62, 0x84, 0x60, 0x84,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x44, 0x5B, 0x00, 0x6C, 0x77, 0x00, 0x83, 0x95, 0x00, 0xAA, 0xC2, 0x01, 0xF8, 0x33, 0x11, 0x72, 0xAD,
    0x29, 0, 18, 0xF4, 0x12, 0xEA, 0x5A, 0x23, 0xB9, 0x0E, 0x33, 0x5E, 0xA5, 0x45, 0xA1, 0x0C, 0x55, 0x28, 0x42, 0x50, 0x42,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0xBE, 0x11, 0x8A, 0xA3, 0x11, 0xB8, 0xC9, 0x12, 0xDD, 0x00, 0x22, 0x22, 0x49, 0x22, 0x9B, 0xE7, 0x33, 0x33, 0x7A,
    0x29, 0, 18, 0xF6, 0x34, 0xBE, 0x32, 0x45, 0xA0, 0x06, 0x55, 0x67, 0xBC, 0x67, 0xE0, 0x62, 0x77, 0x7D, 0x9E, 0x70, 0x9E,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x07, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x98, 0x00, 0xC5, 0xD5, 0x01, 0xE6, 0x05, 0x11, 0x25, 0x45, 0x11, 0x92, 0xE3, 0x22, 0x34, 0x7D,
    0x29, 0, 18, 0xF2, 0x23, 0xC4, 0x3D, 0x34, 0xAB, 0x04, 0x44, 0x61, 0xB3, 0x56, 0xCF, 0x49, 0x66, 0x6B, 0x84, 0x60, 0x84,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0x02, 0x1F, 0x11, 0x36, 0x41, 0x11, 0x4E, 0x60, 0x11, 0x70, 0x82, 0x11, 0x9F, 0xC0, 0x12, 0xE7, 0x11,
    0x29, 0, 18, 0xF4, 0x22, 0x3D, 0x90, 0x23, 0xE2, 0x2D, 0x33, 0x7A, 0xBB, 0x45, 0xAE, 0x18, 0x55, 0x34, 0x4B, 0x50, 0x4B,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x7A, 0x22, 0x80, 0x96, 0x22, 0xA4, 0xB3, 0x22, 0xBF, 0xD4, 0x23, 0xED, 0x06, 0x33, 0x36, 0x66, 0x33, 0xA0, 0xD4,
    0x29, 0, 18, 0xF6, 0x44, 0x0A, 0x72, 0x45, 0xDB, 0x34, 0x55, 0x8C, 0xDF, 0x67, 0xF8, 0x73, 0x77, 0x92, 0xAC, 0x70, 0xAC,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x08, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x1F, 0x11, 0x0F, 0x57, 0x11, 0x70, 0x8B, 0x11, 0xA7, 0xC4, 0x22, 0x04, 0x41, 0x22, 0x80, 0xC0,
    0x29, 0, 18, 0xF2, 0x33, 0x00, 0x70, 0x34, 0xD8, 0x38, 0x44, 0x90, 0xE4, 0x66, 0x01, 0x7C, 0x66, 0x98, 0xB5, 0x60, 0xB5,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x08, 0x11, 0xEB, 0xFF, 0x22, 0x0A, 0x1C, 0x22, 0x29, 0x37, 0x22, 0x4D, 0x66, 0x22, 0x82, 0x9C,
    0x29, 0, 18, 0xF4, 0x22, 0xB9, 0xF9, 0x33, 0x3D, 0x7B, 0x33, 0xBB, 0xFB, 0x45, 0xE3, 0x4B, 0x55, 0x65, 0x82, 0x50, 0x82,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x13, 0x03, 0x23, 0x33, 0x72, 0x7B, 0x33, 0x85, 0x96, 0x33, 0xA7, 0xBA, 0x34, 0xE2, 0x03, 0x44, 0x2D, 0x5A,
    0x29, 0, 18, 0xF6, 0x44, 0x87, 0xE0, 0x55, 0x38, 0x8F, 0x56, 0xE5, 0x30, 0x77, 0x41, 0xBA, 0x77, 0xD7, 0xF0, 0x70, 0xF0,
    0x29, 0, 2, 0xFF, 0x01,
    0x29, 0, 5, 0xFE, 0x01, 0x09, 0x02, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x28, 0x01, 0xB4, 0x61, 0x11, 0x7A, 0x8A, 0x11, 0xAF, 0xD7, 0x22, 0x02, 0x2C,
    0x29, 0, 18, 0xF2, 0x22, 0x54, 0xAA, 0x23, 0xF6, 0x48, 0x33, 0x8E, 0xCC, 0x45, 0xC1, 0x25, 0x55, 0x3F, 0x5B, 0x50, 0x5B,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0x7E, 0x12, 0xF1, 0x03, 0x22, 0x11, 0x1C, 0x22, 0x2C, 0x40, 0x22, 0x4C, 0x5D,
    0x29, 0, 18, 0xF4, 0x22, 0x6E, 0x90, 0x22, 0xB9, 0xE0, 0x33, 0x0A, 0x33, 0x34, 0xE2, 0x2F, 0x44, 0x46, 0x5A, 0x40, 0x5A,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x97, 0x02, 0xE4, 0xB3, 0x33, 0x53, 0x66, 0x33, 0x71, 0x80, 0x33, 0x8B, 0x96, 0x33, 0xAD, 0xC6, 0x33, 0xE1, 0xFB,
    0x29, 0, 18, 0xF6, 0x44, 0x0F, 0x48, 0x44, 0x82, 0xC1, 0x45, 0xFC, 0x34, 0x66, 0x14, 0x70, 0x66, 0x87, 0xA1, 0x60, 0xA1,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x00, 0x04, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x24, 0x53, 0x00, 0x87, 0xF5, 0x11, 0x4D, 0xB6, 0x22, 0x4E, 0xCD, 0x33, 0x42, 0xA0,
    0x29, 0, 18, 0xF2, 0x34, 0xFE, 0x90, 0x55, 0x14, 0x89, 0x56, 0xFC, 0x61, 0x78, 0xA1, 0x34, 0x88, 0x50, 0x74, 0x80, 0x74,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x05, 0x15, 0x00, 0x26, 0x37, 0x00, 0x4A, 0x7C, 0x00, 0xAC, 0xF5, 0x11, 0x70, 0xDF, 0x22, 0x48, 0x9E,
    0x29, 0, 18, 0xF4, 0x23, 0xFA, 0x7A, 0x34, 0xF3, 0x59, 0x45, 0xC1, 0x15, 0x66, 0x4B, 0xCA, 0x67, 0xEC, 0x05, 0x70, 0x05,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x83, 0x01, 0xEC, 0x0C, 0x11, 0x38, 0x6B, 0x12, 0x9F, 0x0A, 0x22, 0x60, 0xC5, 0x33, 0x5D, 0xDD, 0x44, 0x4B, 0xB6,
    0x29, 0, 18, 0xF6, 0x55, 0x1B, 0xBA, 0x66, 0x40, 0xB9, 0x77, 0x26, 0x89, 0x89, 0xDB, 0x72, 0x99, 0x91, 0xB9, 0x90, 0xB9,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x01, 0x04, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x22, 0xA1, 0xA8, 0x22, 0xAF, 0xB6, 0x22, 0xBD, 0xC4, 0x22, 0xCB, 0xD2, 0x23, 0xD9, 0x1C,
    0x29, 0, 18, 0xF2, 0x33, 0x6E, 0xFE, 0x44, 0x79, 0xEB, 0x55, 0x50, 0xB5, 0x67, 0xE5, 0x66, 0x77, 0x7E, 0xA0, 0x70, 0xA0,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0xEA, 0xAD, 0x11, 0xB0, 0xB7, 0x11, 0xBE, 0xC5, 0x11, 0xCC, 0xD3, 0x11, 0xDA, 0xE1, 0x12, 0xE8, 0x21,
    0x29, 0, 18, 0xF4, 0x22, 0x6E, 0xF7, 0x33, 0x66, 0xCC, 0x44, 0x22, 0x7C, 0x56, 0x97, 0x0F, 0x66, 0x2E, 0x47, 0x60, 0x47,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x33, 0xA9, 0xAC, 0x33, 0xAF, 0xB6, 0x33, 0xBD, 0xC4, 0x33, 0xCB, 0xD2, 0x33, 0xD9, 0xE0, 0x34, 0xE7, 0x2C,
    0x29, 0, 18, 0xF6, 0x45, 0x80, 0x1A, 0x56, 0x9E, 0x13, 0x66, 0x7D, 0xDD, 0x88, 0x14, 0x99, 0x88, 0xBA, 0xD9, 0x80, 0xD9,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x02, 0x04, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x06, 0x04, 0x80, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x29, 0, 18, 0xF2, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x0F, 0x02, 0x99, 0xFF, 0x9C, 0x9F, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x29, 0, 18, 0xF4, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x29, 0, 22, 0xF5, 0x02, 0x00, 0xF4, 0xFF, 0x96, 0x99, 0xFF, 0x9C, 0x9F, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x29, 0, 18, 0xF6, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x29, 0, 2, 0xFF, 0x01,

    0x29, 0, 5, 0xFE, 0x01, 0x03, 0x04, 0x00,
    0x29, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x06, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x29, 0, 18, 0xF2, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x29, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0xFF, 0xA0, 0xA3, 0xFF, 0xA6, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x29, 0, 18, 0xF4, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x29, 0, 22, 0xF5, 0x00, 0x00, 0x40, 0xFF, 0x9A, 0x9D, 0xFF, 0xA0, 0xA3, 0xFF, 0xA6, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x29, 0, 18, 0xF6, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x29, 0, 2, 0xFF, 0x01,
/////////////GAMMA2end///////////////

#endif
    0x29, 0, 2, 0x9F, 0x05,
    0x29, 0, 2, 0xF9, 0x00,
    0x29, 0, 2, 0xF7, 0x00,
    0x29, 0, 2, 0x9F, 0x02,
    0x29, 0, 8, 0xC3, 0x11, 0xC0, 0x05, 0xC0, 0x00, 0x00, 0x7F,
    0x29, 0, 2, 0x9F, 0x04,
    0x29, 0, 3, 0xBA, 0x10, 0x00,
    0x29, 0, 2, 0x9F, 0x0A,
    0x29, 0, 2, 0xB2, 0x1B,
    0x29, 0, 19, 0xB7, 0x13, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0x20, 0x20, 0x21,
    0x29, 0, 2, 0x9F, 0x0A,
    0x29, 0, 2, 0xB2, 0x1B,
    0x29, 0, 46, 0xB8, 0x07, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 43, 0xB9, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 43, 0xBA, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x29, 0, 2, 0x9F, 0x00,
    0x29, 0, 2, 0x48, 0x03,
//	0x29,0,2,0x48,0x33,  // video mode
    0x29, 0, 3, 0x51, 0x00, 0x00,
    0x29, 0, 2, 0x53, 0xE0,
    0x29, 0, 2, 0x35, 0x00,
    //	0x05, 0, 1, 0x38,

	// add 解决红绿边问题
	 0x39, 0,  2, 0x9F, 0x0A,
	 0x39, 0,  2, 0xB2, 0x1B,
	 
	 0x39, 0, 46, 0xB8, 0x07, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	 0x39, 0, 43, 0xB9, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	 0x39, 0, 43, 0xBA, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	 
	 0x39, 0,  2, 0x9F, 0x0B, //R&N20230315 add  by weidong
	 0x39, 0,  9, 0xB2, 0x01, 0x2F, 0x4F, 0x00, 0x00, 0x00, 0x00, 0x00,
	 0x39, 0, 49, 0xB9, 0x02, 0x00, 0x00, 0x00, 0x00, 0x80, 0x4A, 0x4A, 0x24, 0x1C, 0xB0, 0x14, 0xD2, 0x66, 0x49, 0x38, 0x60, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x88, 0x88, 0x88,
	 0x39, 0, 49, 0xBA, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x1F, 0x20, 0x1C, 0x34, 0x00, 0x00, 0x00, 0x49, 0x38, 0x60, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x88, 0x88, 0x88,

//  bist mode
//	0x29, 0, 2, 0xA5, 0xA5,
//	0x29, 0, 2, 0x5A, 0x5A,
//	0x29, 0, 2, 0x9F, 0x01,
//	0x29, 0, 2, 0xC6, 0x01,


#else
    0x39, 0, 3, 0x9C, 0xA5, 0xA5,
    0x39, 0, 3, 0xFD, 0x5A, 0x5A,
    0x39, 0, 2, 0x9F, 0x0F,
    0x39, 0, 2, 0xB3, 0x00,
    0x39, 0, 2, 0x9F, 0x01,
    0x39, 0, 2, 0xD0, 0x01,
//	0x39,0,2,0xD3,0x01,
    0x39, 0, 4, 0xB2, 0x5A, 0x04, 0xAF,
    0x39, 0, 36, 0xB3, 0x00, 0xD0, 0xA0, 0x10, 0xBC, 0x00, 0x00, 0xDD, 0x00, 0x10, 0x10, 0x00, 0x00, 0xB3, 0x00, 0x10, 0x10, 0x00, 0x00, 0xB3, 0x00, 0x10, 0x10, 0x22, 0x00, 0xEF, 0x00, 0x10, 0x10, 0x33, 0x18, 0x18, 0x18, 0x18, 0x18,
    0x39, 0, 17, 0xCA, 0x03, 0x01, 0x03, 0x03, 0x04, 0xE5, 0x06, 0x06, 0x04, 0xE5, 0x06, 0x06, 0x04, 0xE5, 0x06, 0x06,
    0x39, 0, 15, 0xCB, 0x03, 0x03, 0x05, 0x85, 0x07, 0x07, 0x05, 0x85, 0x07, 0x07, 0x05, 0x85, 0x07, 0x07,
    0x39, 0, 4, 0xD7, 0x00, 0x00, 0x02,
    0x39, 0, 2, 0x9F, 0x02,
    0x39, 0, 26, 0xB2, 0x00, 0xC0, 0x31, 0x10, 0x11, 0x12, 0x12, 0x10, 0x18, 0x78, 0x90, 0x50, 0x11, 0x11, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x11, 0x17,
    0x39, 0, 10, 0xB3, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 13, 0xB4, 0x00, 0x8A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 7, 0xB5, 0x00, 0x30, 0x30, 0x30, 0x30, 0x2B,
    0x39, 0, 20, 0xB6, 0x01, 0x01, 0x00, 0x11, 0x11, 0x11, 0x1C, 0x1F, 0x1F, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22,
    0x39, 0, 11, 0xB7, 0x00, 0x10, 0x0F, 0x10, 0x10, 0x15, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 14, 0xB8, 0x00, 0x00, 0x00, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28,
    0x39, 0, 13, 0xB9, 0x00, 0x00, 0x50, 0x00, 0x00, 0x0A, 0x0F, 0x00, 0x00, 0x00, 0x19, 0x0A,
    0x39, 0, 9, 0xBA, 0x00, 0xFF, 0x44, 0x04, 0x44, 0x04, 0x44, 0x04,
    0x39, 0, 26, 0xBB, 0x01, 0x4A, 0x64, 0x16, 0x17, 0x01, 0x4A, 0x64, 0x16, 0x17, 0x01, 0x4A, 0x64, 0x16, 0x14, 0x01, 0x4A, 0x64, 0x16, 0x14, 0x01, 0x31, 0x64, 0x16, 0x0F,
    0x39, 0, 17, 0xC1, 0x00, 0x00, 0x00, 0x23, 0x23, 0x24, 0x24, 0x05, 0x05, 0x21, 0x21, 0x22, 0x22, 0x01, 0x01, 0x00,
    0x39, 0, 17, 0xC2, 0x00, 0x00, 0x00, 0x23, 0x23, 0x24, 0x24, 0x05, 0x05, 0x21, 0x21, 0x22, 0x22, 0x01, 0x01, 0x00,
    0x39, 0, 8, 0xC3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 15, 0xC4, 0x00, 0x05, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x1F, 0x00, 0x00, 0x06,
    0x39, 0, 26, 0xC6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x03, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x55, 0x00, 0x01,
    0x39, 0, 14, 0xC7, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x30, 0x30,
    0x39, 0, 14, 0xC8, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x30, 0x30,
    0x39, 0, 27, 0xCC, 0x00, 0x57, 0xBA, 0x57, 0xBA, 0x00, 0x57, 0xBA, 0x57, 0xBA, 0x00, 0x57, 0xBC, 0x00, 0x30, 0x6C, 0x30, 0x6C, 0x00, 0x30, 0x6C, 0x30, 0x6C, 0x00, 0x30, 0x6C,
    0x39, 0, 17, 0xD2, 0x00, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09,
    0x39, 0, 12, 0xD7, 0x44, 0x01, 0x3F, 0x26, 0x37, 0x26, 0x37, 0x01, 0x11, 0x00, 0x00,
    0x39, 0, 26, 0xD8, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x00, 0x00,
    0x39, 0, 12, 0xD9, 0x10, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x30,
    0x39, 0, 6, 0xE1, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 26, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 13, 0xE3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 6, 0xEF, 0x00, 0x80, 0x85, 0x81, 0x82,
    0x39, 0, 9, 0xBE, 0x5F, 0x16, 0x04, 0x5F, 0x75, 0x00, 0x00, 0x00,
    0x39, 0, 2, 0xBF, 0x08,
    0x39, 0, 2, 0x9F, 0x04,
    0x39, 0, 3, 0xB2, 0x01, 0x00,
    0x39, 0, 19, 0xB3, 0x00, 0x00, 0x10, 0x00, 0x30, 0x50, 0x00, 0x70, 0x90, 0x00, 0xB0, 0xF0, 0x11, 0x30, 0x70, 0x12, 0xF0, 0x70,
    0x39, 0, 21, 0xB4, 0x23, 0xF0, 0x70, 0x34, 0xF0, 0xF0, 0x56, 0xF0, 0xF0, 0x78, 0xF0, 0xF0, 0xCE, 0xF0, 0xF0, 0xFF, 0x70, 0xF0, 0x0F, 0xFF,
    0x39, 0, 14, 0xB5, 0x11, 0x10, 0x27, 0x1C, 0xD0, 0x00, 0x64, 0x64, 0x10, 0x3F, 0xFF, 0xFF, 0xFF,
    0x39, 0, 7, 0xB6, 0x11, 0x00, 0x00, 0x0F, 0xF0, 0x10,
    0x39, 0, 3, 0xB9, 0x91, 0x83,
    //  0x39, 0, 3, 0xBA, 0x10, 0x00,
    0x39, 0, 5, 0xC4, 0x01, 0x10, 0x00, 0x00,
    0x39, 0, 20, 0xC5, 0x00, 0x20, 0x88, 0xC1, 0xCF, 0x50, 0x4F, 0x00, 0x4E, 0x57, 0x35, 0x22, 0x22, 0x2A, 0x05, 0x3F, 0x00, 0x20, 0x0F,
    0x39, 0, 13, 0xC6, 0x4B, 0x00, 0x90, 0x00, 0x02, 0xD5, 0x00, 0x02, 0xCB, 0x01, 0x10, 0x43,
    0x39, 0, 5, 0xC8, 0x29, 0x29, 0x28, 0x28,
    0x39, 0, 21, 0xC9, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCA, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCB, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCC, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCD, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xCE, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xCF, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD0, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD1, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD2, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD3, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD4, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 2, 0x9F, 0x05,
    0x39, 0, 7, 0xB2, 0x24, 0x20, 0x05, 0x0F, 0xFF, 0xFF,
    0x39, 0, 9, 0xB3, 0xA0, 0x00, 0x28, 0x00, 0x00, 0x00, 0x3F, 0xFF,
    0x39, 0, 11, 0xB4, 0x00, 0x60, 0x0E, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 16, 0xB5, 0x33, 0xFE, 0x6E, 0x22, 0xEC, 0x68, 0x11, 0xE4, 0x64, 0x10, 0x62, 0xEC, 0x00, 0x76, 0x02,
    0x39, 0, 7, 0xB6, 0x31, 0xFE, 0xD8, 0x00, 0x58, 0x00,
    0x39, 0, 16, 0xB9, 0x71, 0x20, 0x05, 0x78, 0x70, 0x5A, 0x3C, 0x78, 0x70, 0x5A, 0x3C, 0x78, 0x70, 0x5A, 0x3C,
    0x39, 0, 2, 0x9F, 0x07,
    0x39, 0, 8, 0xB2, 0x08, 0x08, 0x08, 0x08, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x03, 0x8C,
    0x39, 0, 8, 0xB4, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB5, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB6, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB7, 0x08, 0x08, 0x08, 0x08, 0x02, 0x0B, 0xB8,
    0x39, 0, 8, 0xB8, 0x02, 0x04, 0x04, 0x04, 0x01, 0x0A, 0xBE,
    0x39, 0, 17, 0xB9, 0x01, 0x05, 0x03, 0x07, 0x02, 0x06, 0x04, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBA, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBB, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBC, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBD, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBE, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBF, 0x01, 0x02, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 16, 0xC0, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x39, 0, 16, 0xC1, 0x33, 0x8C, 0x8C, 0x33, 0x8C, 0x8C, 0x32, 0x20, 0x18, 0x10, 0x0C, 0x58, 0x00, 0x2C, 0x2C,
    0x39, 0, 16, 0xC2, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x39, 0, 16, 0xC3, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x39, 0, 7, 0xC4, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8,
    0x39, 0, 7, 0xC5, 0x97, 0xC4, 0xD0, 0x76, 0x08, 0x40,
    0x39, 0, 4, 0xC6, 0x97, 0x2E, 0x9E,
    0x39, 0, 3, 0xC7, 0x02, 0x00,
    0x39, 0, 8, 0xC8, 0x10, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 8, 0xC9, 0x0F, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 8, 0xCA, 0x0E, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 8, 0xCB, 0x0D, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 17, 0xCC, 0x01, 0x09, 0x03, 0x0B, 0x05, 0x0D, 0x07, 0x0F, 0x02, 0x0A, 0x04, 0x0C, 0x06, 0x0E, 0x08, 0x10,
    0x39, 0, 17, 0xCD, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x0F, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x0E, 0x00,
    0x39, 0, 17, 0xCE, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x0E, 0x00, 0x00,
    0x39, 0, 17, 0xCF, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x00, 0x00, 0x00,
    0x39, 0, 16, 0xD0, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 16, 0xD1, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 16, 0xD2, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 16, 0xD3, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 2, 0x9F, 0x0F,
    0x39, 0, 2, 0xF8, 0x11,
    0x39, 0, 2, 0x9F, 0x00,
    0x39, 0, 2, 0x48, 0x00,
    0x39, 0, 3, 0x51, 0x00, 0x00,
    0x39, 0, 2, 0x53, 0xE0,
    0x39, 0, 2, 0x35, 0x00,
    0x39, 0, 1, 0x11,

    0x39, 0, 2, 0x9F, 0x05,
    0x39, 0, 2, 0xF9, 0x80,
    0x39, 0, 2, 0xF7, 0x10,
    0x39, 0, 2, 0x9F, 0x06,
    0x39, 0, 41, 0xB2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 41, 0xB3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 21, 0xB4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 41, 0xB5, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
    0x39, 0, 41, 0xB6, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
    0x39, 0, 21, 0xB7, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
#if 1
/////////////GAMMA1///////////////
    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x23, 0x01, 0xB7, 0x47, 0x12, 0xBF, 0x26, 0x23, 0x7C, 0x0E, 0x33, 0x83, 0xE8, 0x45, 0x8A, 0x10, 0x55, 0x82, 0xEB,
    0x39, 0, 18, 0xF2, 0x66, 0x4B, 0xF9, 0x78, 0x92, 0x1F, 0x89, 0xA5, 0x23, 0xBB, 0x07, 0xF4, 0xCC, 0x32, 0x71, 0xC0, 0x71,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x49, 0x00, 0x8C, 0xDC, 0x11, 0x33, 0x83, 0x12, 0xCB, 0x4C, 0x23, 0xB9, 0x16, 0x34, 0xB0, 0x2E, 0x44, 0x97, 0xF7,
    0x39, 0, 18, 0xF4, 0x55, 0x4D, 0xE6, 0x66, 0x6E, 0xED, 0x77, 0x65, 0xCF, 0x9A, 0x6C, 0x33, 0xAA, 0x67, 0x9E, 0xA0, 0x9E,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x5C, 0x12, 0xC5, 0x3C, 0x23, 0xAE, 0x12, 0x33, 0x66, 0xF5, 0x44, 0x6A, 0xCF, 0x56, 0x77, 0x03, 0x66, 0x7D, 0xEC,
    0x39, 0, 18, 0xF6, 0x78, 0x51, 0x06, 0x89, 0xA5, 0x3C, 0x9A, 0xCA, 0x4F, 0xCD, 0x58, 0x66, 0xDD, 0xAD, 0xEE, 0xD0, 0xEE,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x9E, 0x01, 0xF9, 0x5D, 0x12, 0xBF, 0x17, 0x22, 0x6A, 0xF2, 0x33, 0x60, 0xC1, 0x44, 0x5C, 0xDE, 0x55, 0x4F, 0xB3,
    0x39, 0, 18, 0xF2, 0x66, 0x0E, 0xB2, 0x77, 0x43, 0xC5, 0x88, 0x3F, 0xB4, 0xAB, 0x66, 0x3A, 0xBB, 0x72, 0x9D, 0xB0, 0x9D,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0xBA, 0x01, 0xE1, 0x0D, 0x11, 0x47, 0x87, 0x12, 0xC4, 0x35, 0x22, 0x98, 0xEF, 0x33, 0x82, 0xFB, 0x44, 0x62, 0xBD,
    0x39, 0, 18, 0xF4, 0x55, 0x10, 0xA2, 0x66, 0x22, 0x97, 0x77, 0x05, 0x6E, 0x89, 0xE3, 0x97, 0x99, 0xC5, 0xEF, 0x90, 0xEF,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0xA0, 0x12, 0xEF, 0x4D, 0x23, 0xAC, 0x03, 0x33, 0x52, 0xD9, 0x44, 0x47, 0xA8, 0x55, 0x49, 0xD1, 0x66, 0x47, 0xB1,
    0x39, 0, 18, 0xF6, 0x77, 0x10, 0xBB, 0x88, 0x50, 0xDA, 0x99, 0x5D, 0xD8, 0xBC, 0xA9, 0x93, 0xCD, 0xD1, 0x06, 0xD0, 0x06,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x01, 0xD7, 0x18, 0x11, 0x65, 0xAD, 0x12, 0xEE, 0x68, 0x23, 0xD0, 0x27, 0x34, 0xB9, 0x30, 0x44, 0x95, 0xEE,
    0x39, 0, 18, 0xF2, 0x55, 0x42, 0xD3, 0x66, 0x52, 0xC4, 0x77, 0x2E, 0x91, 0x89, 0xEF, 0x8E, 0x99, 0xBB, 0xDF, 0x90, 0xDF,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x9D, 0x00, 0xD4, 0xEE, 0x11, 0x12, 0x3C, 0x11, 0x69, 0xC2, 0x22, 0x15, 0x63, 0x23, 0xE9, 0x57, 0x34, 0xB8, 0x0C,
    0x39, 0, 18, 0xF4, 0x44, 0x57, 0xDB, 0x55, 0x4D, 0xB4, 0x66, 0x11, 0x6B, 0x78, 0xA1, 0x2B, 0x88, 0x4B, 0x70, 0x80, 0x70,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x96, 0x12, 0xD0, 0x0D, 0x22, 0x53, 0x98, 0x23, 0xDA, 0x50, 0x34, 0xB6, 0x0E, 0x45, 0xA0, 0x19, 0x55, 0x85, 0xE2,
    0x39, 0, 18, 0xF6, 0x66, 0x3A, 0xD3, 0x77, 0x56, 0xCF, 0x88, 0x3C, 0xA3, 0xAA, 0x19, 0xC1, 0xAB, 0xEE, 0x11, 0xB0, 0x11,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0xAD, 0xD2, 0x01, 0xF5, 0x22, 0x11, 0x4E, 0xA3, 0x12, 0xF0, 0x39, 0x23, 0xB6, 0x1E, 0x33, 0x77, 0xC8,
    0x39, 0, 18, 0xF2, 0x44, 0x0E, 0x87, 0x45, 0xEE, 0x4E, 0x55, 0xA2, 0xF2, 0x67, 0xFD, 0x75, 0x77, 0x93, 0xAE, 0x70, 0xAE,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xC1, 0xD1, 0x00, 0xE0, 0xF2, 0x11, 0x06, 0x35, 0x11, 0x6B, 0x9C, 0x22, 0x01, 0x5B, 0x22, 0xAD, 0xF5,
    0x39, 0, 18, 0xF4, 0x33, 0x37, 0xA9, 0x44, 0x0B, 0x60, 0x44, 0xAE, 0xF6, 0x56, 0xE6, 0x50, 0x66, 0x69, 0x84, 0x60, 0x84,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x29, 0x11, 0xAD, 0xCE, 0x12, 0xED, 0x14, 0x22, 0x3D, 0x8F, 0x23, 0xDC, 0x22, 0x34, 0x9D, 0x05, 0x44, 0x5D, 0xAE,
    0x39, 0, 18, 0xF6, 0x45, 0xF7, 0x75, 0x56, 0xE1, 0x47, 0x66, 0xA0, 0xF2, 0x88, 0x0B, 0x84, 0x88, 0xA2, 0xC3, 0x80, 0xC3,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x68, 0x98, 0x00, 0xCC, 0xFE, 0x11, 0x32, 0x95, 0x12, 0xEA, 0x3A, 0x23, 0xBD, 0x29, 0x33, 0x85, 0xD8,
    0x39, 0, 18, 0xF2, 0x44, 0x23, 0x9E, 0x55, 0x0A, 0x6C, 0x56, 0xC2, 0x0F, 0x77, 0x25, 0x9D, 0x77, 0xBB, 0xD8, 0x70, 0xD8,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xAF, 0xC2, 0x00, 0xD2, 0xE3, 0x01, 0xF7, 0x2B, 0x11, 0x64, 0x9B, 0x22, 0x04, 0x62, 0x23, 0xB7, 0x00,
    0x39, 0, 18, 0xF4, 0x33, 0x47, 0xBD, 0x44, 0x22, 0x7B, 0x45, 0xC9, 0x11, 0x66, 0x08, 0x76, 0x66, 0x8E, 0xA9, 0x60, 0xA9,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xCB, 0x11, 0xA7, 0xCA, 0x12, 0xEC, 0x14, 0x22, 0x3F, 0x94, 0x23, 0xE5, 0x2E, 0x34, 0xB0, 0x1A, 0x44, 0x76, 0xC8,
    0x39, 0, 18, 0xF6, 0x55, 0x13, 0x93, 0x66, 0x03, 0x69, 0x67, 0xC3, 0x14, 0x88, 0x35, 0xB3, 0x88, 0xD0, 0xF0, 0x80, 0xF0,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x61, 0x92, 0x00, 0xC0, 0xEE, 0x11, 0x1E, 0x7A, 0x12, 0xD1, 0x1D, 0x23, 0xA3, 0x13, 0x33, 0x76, 0xC8,
    0x39, 0, 18, 0xF2, 0x44, 0x12, 0x8E, 0x45, 0xFB, 0x5C, 0x56, 0xB2, 0x01, 0x77, 0x12, 0x84, 0x77, 0xA5, 0xC0, 0x70, 0xC0,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xC0, 0xD1, 0x00, 0xDF, 0xEF, 0x11, 0x00, 0x2B, 0x11, 0x5B, 0x8E, 0x12, 0xF0, 0x4C, 0x22, 0xA2, 0xF0,
    0x39, 0, 18, 0xF4, 0x33, 0x35, 0xAD, 0x44, 0x12, 0x6C, 0x45, 0xBA, 0x02, 0x56, 0xF6, 0x5F, 0x66, 0x7A, 0x94, 0x60, 0x94,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x5D, 0x11, 0xC7, 0xE6, 0x22, 0x06, 0x28, 0x22, 0x4E, 0x9C, 0x23, 0xE9, 0x31, 0x34, 0xAF, 0x17, 0x44, 0x72, 0xC1,
    0x39, 0, 18, 0xF6, 0x55, 0x0B, 0x89, 0x56, 0xF8, 0x5C, 0x67, 0xB6, 0x07, 0x88, 0x23, 0x9B, 0x88, 0xBA, 0xD8, 0x80, 0xD8,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x87, 0x00, 0xAD, 0xD0, 0x01, 0xF8, 0x48, 0x11, 0x99, 0xE7, 0x22, 0x7E, 0xF9, 0x33, 0x61, 0xBB,
    0x39, 0, 18, 0xF2, 0x44, 0x09, 0x8A, 0x45, 0xF7, 0x58, 0x56, 0xB2, 0x01, 0x77, 0x10, 0x84, 0x77, 0xA2, 0xBA, 0x70, 0xBA,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xDB, 0xF9, 0x11, 0x05, 0x11, 0x11, 0x1D, 0x39, 0x11, 0x5D, 0x86, 0x12, 0xDD, 0x3A, 0x22, 0x94, 0xE4,
    0x39, 0, 18, 0xF4, 0x33, 0x2B, 0xA7, 0x44, 0x0F, 0x68, 0x45, 0xB9, 0x00, 0x56, 0xF5, 0x5D, 0x66, 0x77, 0x8D, 0x60, 0x8D,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xBA, 0x22, 0x0A, 0x28, 0x22, 0x45, 0x63, 0x22, 0x80, 0xC3, 0x33, 0x06, 0x48, 0x34, 0xBF, 0x22, 0x44, 0x7A, 0xCB,
    0x39, 0, 18, 0xF6, 0x55, 0x12, 0x90, 0x56, 0xFF, 0x61, 0x67, 0xBC, 0x0C, 0x88, 0x23, 0x9A, 0x88, 0xB8, 0xD1, 0x80, 0xD1,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x27, 0x00, 0xBD, 0xDE, 0x01, 0xF8, 0x30, 0x11, 0x6C, 0xA6, 0x22, 0x2C, 0xBD, 0x33, 0x34, 0x98,
    0x39, 0, 18, 0xF2, 0x34, 0xEB, 0x76, 0x45, 0xEC, 0x50, 0x55, 0xAC, 0xFC, 0x77, 0x0C, 0x80, 0x77, 0x9E, 0xB5, 0x70, 0xB5,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0x02, 0x40, 0x11, 0x5C, 0x67, 0x11, 0x70, 0x83, 0x11, 0x97, 0xAF, 0x12, 0xE9, 0x38, 0x22, 0x8C, 0xD9,
    0x39, 0, 18, 0xF4, 0x33, 0x21, 0x9E, 0x44, 0x07, 0x62, 0x44, 0xB4, 0xFF, 0x56, 0xF1, 0x59, 0x66, 0x74, 0x8A, 0x60, 0x8A,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x10, 0x12, 0xEE, 0xCC, 0x22, 0xE1, 0xF9, 0x33, 0x10, 0x3D, 0x33, 0x6D, 0x9D, 0x34, 0xF9, 0x52, 0x44, 0xA3, 0xEE,
    0x39, 0, 18, 0xF6, 0x55, 0x2F, 0xA9, 0x66, 0x15, 0x74, 0x67, 0xCC, 0x1C, 0x88, 0x2B, 0xA0, 0x88, 0xBE, 0xD7, 0x80, 0xD7,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x28, 0xEB, 0x11, 0x02, 0x32, 0x11, 0x5D, 0x91, 0x12, 0xFB, 0x90, 0x33, 0x15, 0x86,
    0x39, 0, 18, 0xF2, 0x34, 0xE5, 0x7B, 0x45, 0xF6, 0x64, 0x56, 0xC2, 0x16, 0x77, 0x30, 0xA6, 0x77, 0xC2, 0xDC, 0x70, 0xDC,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x11, 0x9A, 0xA8, 0x11, 0xB7, 0xCA, 0x11, 0xDB, 0xEE, 0x22, 0x22, 0x62, 0x22, 0xAB, 0xF4,
    0x39, 0, 18, 0xF4, 0x33, 0x39, 0xB3, 0x44, 0x1D, 0x7A, 0x45, 0xCB, 0x17, 0x66, 0x13, 0x7D, 0x66, 0x95, 0xAD, 0x60, 0xAD,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x0D, 0x13, 0x27, 0x06, 0x33, 0x7F, 0x93, 0x33, 0xA3, 0xC9, 0x34, 0xEC, 0x10, 0x44, 0x5C, 0xA6, 0x45, 0xEB, 0x30,
    0x39, 0, 18, 0xF6, 0x55, 0x6F, 0xE6, 0x66, 0x4E, 0xAC, 0x77, 0x02, 0x51, 0x88, 0x61, 0xD6, 0x89, 0xF3, 0x0F, 0x90, 0x0F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x2A, 0xF9, 0x11, 0x14, 0x35, 0x11, 0x74, 0xB4, 0x22, 0x00, 0x5C,
    0x39, 0, 18, 0xF2, 0x23, 0xBB, 0x5D, 0x34, 0xE0, 0x49, 0x44, 0xA1, 0xF2, 0x56, 0xF2, 0x5C, 0x66, 0x74, 0x8C, 0x60, 0x8C,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0xB8, 0x11, 0xA1, 0xAE, 0x11, 0xBF, 0xCC, 0x11, 0xE1, 0xFC, 0x22, 0x1E, 0x49,
    0x39, 0, 18, 0xF4, 0x22, 0x78, 0xD7, 0x33, 0x35, 0x89, 0x34, 0xD2, 0x17, 0x45, 0xF6, 0x55, 0x55, 0x6B, 0x7F, 0x50, 0x7F,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0x2B, 0x41, 0x33, 0x68, 0x7F, 0x33, 0x82, 0x9A, 0x33, 0xB4, 0xCB, 0x34, 0xFA, 0x28, 0x44, 0x58, 0x8C,
    0x39, 0, 18, 0xF6, 0x45, 0xBB, 0x18, 0x55, 0x6C, 0xBC, 0x66, 0x04, 0x48, 0x77, 0x30, 0x94, 0x77, 0xAC, 0xC0, 0x70, 0xC0,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0xE4, 0x11, 0x37, 0x96, 0x12, 0xF5, 0x4D, 0x23, 0x9A, 0x20, 0x33, 0x8E, 0xEE, 0x45, 0x8C, 0x0D, 0x55, 0x7E, 0xE6,
    0x39, 0, 18, 0xF2, 0x66, 0x44, 0xF2, 0x78, 0x8A, 0x16, 0x89, 0x97, 0x19, 0xAB, 0xF7, 0xE5, 0xCC, 0x20, 0x62, 0xC0, 0x62,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0xF8, 0x11, 0x28, 0x57, 0x11, 0x8E, 0xC8, 0x22, 0x02, 0x71, 0x23, 0xD1, 0x28, 0x34, 0xBB, 0x32, 0x44, 0x99, 0xF5,
    0x39, 0, 18, 0xF4, 0x55, 0x4A, 0xE0, 0x66, 0x68, 0xE4, 0x77, 0x57, 0xC6, 0x9A, 0x5D, 0x23, 0xAA, 0x56, 0x8E, 0xA0, 0x8E,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0xF9, 0x22, 0x47, 0x96, 0x23, 0xEC, 0x3B, 0x34, 0x86, 0x09, 0x44, 0x76, 0xD6, 0x56, 0x7A, 0x03, 0x66, 0x7A, 0xE6,
    0x39, 0, 18, 0xF6, 0x77, 0x4A, 0xFF, 0x89, 0x9E, 0x33, 0x9A, 0xBE, 0x47, 0xCD, 0x4A, 0x55, 0xDD, 0x9B, 0xE0, 0xD0, 0xE0,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x4F, 0x11, 0x8D, 0xCF, 0x22, 0x1B, 0x66, 0x23, 0xAD, 0x29, 0x33, 0x92, 0xEE, 0x45, 0x86, 0x07, 0x55, 0x75, 0xDA,
    0x39, 0, 18, 0xF2, 0x66, 0x39, 0xE1, 0x77, 0x73, 0xF9, 0x88, 0x7A, 0xF3, 0xAB, 0xC0, 0xA4, 0xBC, 0xE0, 0x1B, 0xC0, 0x1B,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5F, 0x11, 0x82, 0xA2, 0x11, 0xC6, 0xF1, 0x22, 0x22, 0x81, 0x23, 0xDA, 0x2A, 0x34, 0xB4, 0x29, 0x44, 0x8C, 0xE6,
    0x39, 0, 18, 0xF4, 0x55, 0x39, 0xCD, 0x66, 0x50, 0xC8, 0x77, 0x3A, 0xA4, 0x99, 0x2B, 0xEB, 0xAA, 0x1C, 0x4B, 0xA0, 0x4B,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x43, 0x22, 0x83, 0xC4, 0x33, 0x0C, 0x51, 0x34, 0x96, 0x0F, 0x44, 0x78, 0xD4, 0x55, 0x74, 0xFA, 0x66, 0x6F, 0xD9,
    0x39, 0, 18, 0xF6, 0x77, 0x3B, 0xEA, 0x89, 0x84, 0x13, 0x9A, 0x9C, 0x1D, 0xCD, 0x0B, 0x0F, 0xDD, 0x56, 0x93, 0xD0, 0x93,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x48, 0x11, 0x87, 0xC5, 0x22, 0x09, 0x51, 0x23, 0x94, 0x0B, 0x33, 0x73, 0xCD, 0x44, 0x61, 0xDD, 0x55, 0x4C, 0xAF,
    0x39, 0, 18, 0xF2, 0x66, 0x09, 0xA9, 0x77, 0x3A, 0xBD, 0x88, 0x38, 0xA9, 0xAB, 0x5B, 0x31, 0xBB, 0x66, 0x94, 0xB0, 0x94,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5E, 0x11, 0x80, 0x9C, 0x11, 0xBE, 0xE5, 0x22, 0x11, 0x6B, 0x23, 0xC0, 0x0C, 0x34, 0x92, 0x03, 0x44, 0x66, 0xBF,
    0x39, 0, 18, 0xF4, 0x55, 0x0F, 0x9E, 0x66, 0x1C, 0x91, 0x67, 0xFD, 0x62, 0x89, 0xD7, 0x8C, 0x99, 0xB8, 0xE3, 0x90, 0xE3,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x22, 0x7D, 0xB9, 0x23, 0xFB, 0x3C, 0x33, 0x7E, 0xF3, 0x44, 0x59, 0xB3, 0x55, 0x4D, 0xD0, 0x66, 0x44, 0xAD,
    0x39, 0, 18, 0xF6, 0x77, 0x0A, 0xB2, 0x88, 0x48, 0xD2, 0x99, 0x54, 0xCF, 0xBC, 0x9E, 0x8B, 0xCC, 0xC8, 0xFE, 0xC0, 0xFE,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x59, 0x11, 0x76, 0xA2, 0x12, 0xD2, 0x07, 0x22, 0x3F, 0xA9, 0x33, 0x04, 0x56, 0x34, 0xDF, 0x53, 0x45, 0xB9, 0x10,
    0x39, 0, 18, 0xF2, 0x55, 0x62, 0xF5, 0x66, 0x76, 0xED, 0x77, 0x59, 0xBA, 0x99, 0x23, 0xCB, 0x9A, 0xF3, 0x23, 0xA0, 0x23,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x4E, 0x11, 0x78, 0x8D, 0x11, 0xA3, 0xBC, 0x12, 0xDB, 0x1F, 0x22, 0x65, 0xA7, 0x33, 0x1E, 0x85, 0x34, 0xE2, 0x32,
    0x39, 0, 18, 0xF4, 0x44, 0x7A, 0xFE, 0x55, 0x71, 0xD6, 0x66, 0x36, 0x8F, 0x78, 0xCE, 0x5C, 0x88, 0x81, 0xA4, 0x80, 0xA4,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x37, 0x22, 0x6C, 0x97, 0x22, 0xC5, 0xF8, 0x33, 0x2E, 0x91, 0x34, 0xEC, 0x3D, 0x45, 0xC6, 0x3E, 0x56, 0xAA, 0x06,
    0x39, 0, 18, 0xF6, 0x66, 0x5B, 0xF5, 0x77, 0x7B, 0xF6, 0x88, 0x66, 0xCF, 0xAB, 0x50, 0x04, 0xBB, 0x32, 0x5A, 0xB0, 0x5A,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x61, 0x7E, 0x11, 0x9E, 0xC3, 0x12, 0xEA, 0x3A, 0x22, 0x88, 0xD0, 0x33, 0x4E, 0xBA, 0x44, 0x16, 0x66,
    0x39, 0, 18, 0xF2, 0x45, 0xB1, 0x33, 0x56, 0xA4, 0x0B, 0x66, 0x6A, 0xBF, 0x78, 0xF4, 0x7A, 0x88, 0x9A, 0xB9, 0x80, 0xB9,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x6B, 0x7E, 0x11, 0x8E, 0x9F, 0x11, 0xB0, 0xDA, 0x22, 0x0A, 0x3D, 0x22, 0xA0, 0xFA, 0x33, 0x4C, 0x96,
    0x39, 0, 18, 0xF4, 0x34, 0xD9, 0x50, 0x45, 0xB6, 0x11, 0x55, 0x65, 0xB4, 0x67, 0xC3, 0x3B, 0x77, 0x58, 0x74, 0x70, 0x74,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x32, 0x22, 0x61, 0x80, 0x22, 0x9F, 0xC2, 0x23, 0xE5, 0x32, 0x33, 0x7B, 0xC3, 0x44, 0x3C, 0xA5, 0x55, 0x03, 0x56,
    0x39, 0, 18, 0xF6, 0x56, 0xA3, 0x2C, 0x67, 0xA2, 0x0D, 0x77, 0x72, 0xCF, 0x99, 0x0F, 0x9E, 0x99, 0xC1, 0xE1, 0x90, 0xE1,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x42, 0x65, 0x11, 0x82, 0xA1, 0x12, 0xC2, 0x07, 0x22, 0x50, 0x97, 0x33, 0x14, 0x7E, 0x34, 0xDA, 0x2A,
    0x39, 0, 18, 0xF2, 0x44, 0x71, 0xED, 0x55, 0x5C, 0xBB, 0x66, 0x16, 0x69, 0x78, 0x8B, 0x03, 0x88, 0x26, 0x39, 0x80, 0x39,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x7F, 0x90, 0x11, 0x9D, 0xAA, 0x11, 0xB7, 0xD5, 0x12, 0xF7, 0x20, 0x22, 0x78, 0xCC, 0x33, 0x18, 0x60,
    0x39, 0, 18, 0xF4, 0x34, 0xA0, 0x11, 0x44, 0x74, 0xCB, 0x55, 0x1A, 0x64, 0x66, 0x5F, 0xD2, 0x67, 0xEC, 0x06, 0x70, 0x06,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x49, 0x22, 0x7C, 0x97, 0x22, 0xB3, 0xCD, 0x23, 0xE9, 0x26, 0x33, 0x64, 0xA1, 0x44, 0x11, 0x75, 0x45, 0xCA, 0x1B,
    0x39, 0, 18, 0xF6, 0x55, 0x64, 0xE4, 0x66, 0x58, 0xBD, 0x77, 0x1B, 0x70, 0x89, 0x9A, 0x1E, 0x99, 0x3D, 0x5D, 0x90, 0x5D,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x97, 0xBB, 0x12, 0xDD, 0x03, 0x22, 0x2E, 0x87, 0x23, 0xDA, 0x2B, 0x34, 0xB6, 0x23, 0x44, 0x83, 0xD9,
    0x39, 0, 18, 0xF2, 0x55, 0x29, 0xAD, 0x66, 0x2B, 0x97, 0x67, 0xFB, 0x58, 0x89, 0x9A, 0x2C, 0x99, 0x4E, 0x76, 0x90, 0x76,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0xE5, 0xF8, 0x22, 0x08, 0x17, 0x22, 0x28, 0x50, 0x22, 0x7B, 0xAC, 0x33, 0x0F, 0x6B, 0x34, 0xBF, 0x09,
    0x39, 0, 18, 0xF4, 0x44, 0x4E, 0xC5, 0x55, 0x31, 0x90, 0x56, 0xEA, 0x3C, 0x77, 0x59, 0xD6, 0x78, 0xF3, 0x11, 0x80, 0x11,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x0E, 0x23, 0xF8, 0x15, 0x33, 0x35, 0x54, 0x33, 0x75, 0xB9, 0x34, 0xFB, 0x3E, 0x45, 0xB8, 0x21, 0x55, 0x80, 0xD7,
    0x39, 0, 18, 0xF6, 0x66, 0x29, 0xB5, 0x77, 0x33, 0xA4, 0x88, 0x0B, 0x6A, 0x9A, 0xC0, 0x5C, 0xAA, 0x81, 0xA4, 0xA0, 0xA4,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x22, 0x25, 0x55, 0x22, 0x75, 0x93, 0x23, 0xB9, 0x06, 0x33, 0x52, 0x99, 0x44, 0x1D, 0x93, 0x45, 0xF4, 0x4A,
    0x39, 0, 18, 0xF2, 0x56, 0x99, 0x2A, 0x67, 0xA9, 0x1A, 0x77, 0x85, 0xE8, 0x99, 0x41, 0xDF, 0xAA, 0x05, 0x27, 0xA0, 0x27,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x22, 0xB8, 0xD1, 0x22, 0xE2, 0xEF, 0x23, 0xFB, 0x15, 0x33, 0x35, 0x58, 0x33, 0xA4, 0xF3, 0x44, 0x3F, 0x87,
    0x39, 0, 18, 0xF4, 0x45, 0xC8, 0x41, 0x56, 0xAC, 0x0D, 0x66, 0x6B, 0xC0, 0x78, 0xEB, 0x6E, 0x88, 0x8E, 0xAD, 0x80, 0xAD,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x2C, 0x33, 0xEB, 0xFF, 0x44, 0x15, 0x2A, 0x44, 0x43, 0x77, 0x44, 0xAC, 0xE0, 0x55, 0x4A, 0xB2, 0x66, 0x0D, 0x63,
    0x39, 0, 18, 0xF6, 0x67, 0xB0, 0x40, 0x78, 0xC1, 0x33, 0x89, 0xA0, 0x08, 0xAB, 0x77, 0x20, 0xBB, 0x49, 0x6F, 0xB0, 0x6F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x22, 0xC7, 0xDD, 0x23, 0xF0, 0x18, 0x33, 0x3F, 0x6E, 0x34, 0xC3, 0x16, 0x44, 0x64, 0xAD,
    0x39, 0, 18, 0xF2, 0x45, 0xF3, 0x73, 0x56, 0xDF, 0x3F, 0x66, 0x99, 0xEE, 0x88, 0x12, 0x91, 0x88, 0xB0, 0xC8, 0x80, 0xC8,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x03, 0x02, 0x54, 0x33, 0x6C, 0x79, 0x33, 0x83, 0x90, 0x33, 0xA0, 0xAF, 0x33, 0xCD, 0xF0, 0x44, 0x17, 0x41,
    0x39, 0, 18, 0xF4, 0x44, 0x6B, 0xC2, 0x55, 0x18, 0x67, 0x55, 0xB1, 0xF7, 0x67, 0xEE, 0x5C, 0x77, 0x76, 0x8E, 0x70, 0x8E,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x63, 0x34, 0x9F, 0x96, 0x44, 0xA7, 0xB4, 0x44, 0xBC, 0xD5, 0x45, 0xED, 0x08, 0x55, 0x44, 0x7E, 0x55, 0xB9, 0xF7,
    0x39, 0, 18, 0xF6, 0x66, 0x33, 0xA6, 0x77, 0x0C, 0x6A, 0x78, 0xC2, 0x16, 0x99, 0x40, 0xC6, 0x9A, 0xE6, 0x03, 0xA0, 0x03,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x55, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xA4,
    0x39, 0, 18, 0xF2, 0x34, 0xBC, 0x0C, 0x44, 0x56, 0x9D, 0x45, 0xE1, 0x25, 0x56, 0xF9, 0x54, 0x66, 0x6A, 0x7C, 0x60, 0x7C,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x07, 0x04, 0xB0, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xCD,
    0x39, 0, 18, 0xF4, 0x33, 0xC9, 0xEA, 0x44, 0x11, 0x37, 0x44, 0x5F, 0x89, 0x55, 0x2E, 0x78, 0x55, 0x8A, 0x9B, 0x50, 0x9B,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x37, 0x0F, 0xD5, 0xEF, 0xB7, 0xFD, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF5, 0xFA, 0x36,
    0x39, 0, 18, 0xF6, 0x55, 0x3E, 0x76, 0x55, 0xB0, 0xEA, 0x66, 0x23, 0x5F, 0x77, 0x27, 0x7F, 0x77, 0x94, 0xA7, 0x70, 0xA7,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x44, 0x98, 0x01, 0xF7, 0x4C, 0x12, 0x9C, 0x1E, 0x22, 0x98, 0xFD, 0x34, 0xAC, 0x2E, 0x45, 0xA7, 0x15,
    0x39, 0, 18, 0xF2, 0x56, 0x78, 0x28, 0x67, 0xCA, 0x5D, 0x78, 0xEB, 0x74, 0xAB, 0x76, 0x71, 0xBB, 0xB3, 0xF3, 0xB0, 0xF3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x2F, 0x58, 0x00, 0x8F, 0xC8, 0x11, 0x03, 0x6A, 0x12, 0xCF, 0x29, 0x23, 0xC8, 0x42, 0x34, 0xB5, 0x16,
    0x39, 0, 18, 0xF4, 0x45, 0x6F, 0x0D, 0x56, 0x98, 0x1A, 0x67, 0x95, 0x0A, 0x89, 0xBA, 0x92, 0x9A, 0xC9, 0x03, 0xA0, 0x03,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x17, 0x11, 0x61, 0xA5, 0x12, 0xF3, 0x44, 0x23, 0x92, 0x18, 0x33, 0x91, 0xF5, 0x45, 0x9F, 0x2D, 0x56, 0xAB, 0x1B,
    0x39, 0, 18, 0xF6, 0x67, 0x85, 0x40, 0x78, 0xEB, 0x88, 0x99, 0x1E, 0xAF, 0xBC, 0xD5, 0xF3, 0xDD, 0x3E, 0x81, 0xD0, 0x81,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x66, 0x00, 0xA0, 0xD4, 0x11, 0x13, 0x57, 0x12, 0x98, 0x0F, 0x22, 0x80, 0xDA, 0x33, 0x7C, 0xFD, 0x44, 0x70, 0xD7,
    0x39, 0, 18, 0xF2, 0x55, 0x35, 0xDB, 0x67, 0x75, 0x00, 0x77, 0x88, 0xFB, 0x9A, 0xCE, 0xB1, 0xAB, 0xE6, 0x1E, 0xB0, 0x1E,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x6A, 0x00, 0x8F, 0xA9, 0x00, 0xC9, 0xEC, 0x11, 0x14, 0x6B, 0x12, 0xC5, 0x0B, 0x23, 0x9C, 0x10, 0x33, 0x7B, 0xDC,
    0x39, 0, 18, 0xF4, 0x44, 0x2E, 0xC1, 0x55, 0x49, 0xC3, 0x66, 0x35, 0xA1, 0x88, 0x2C, 0xEC, 0x99, 0x17, 0x4C, 0x90, 0x4C,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x65, 0x11, 0x9B, 0xCF, 0x22, 0x0A, 0x4A, 0x23, 0x8D, 0x07, 0x33, 0x77, 0xD0, 0x44, 0x70, 0xF6, 0x55, 0x70, 0xDD,
    0x39, 0, 18, 0xF6, 0x66, 0x3E, 0xF0, 0x78, 0x94, 0x26, 0x89, 0xAF, 0x31, 0xBC, 0x1E, 0x18, 0xCC, 0x57, 0x98, 0xC0, 0x98,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x07, 0x00, 0x8F, 0xAE, 0x01, 0xD9, 0x0B, 0x11, 0x38, 0x99, 0x12, 0xF2, 0x45, 0x23, 0xD6, 0x4F, 0x34, 0xB8, 0x12,
    0x39, 0, 18, 0xF2, 0x44, 0x64, 0xF9, 0x55, 0x7C, 0xF4, 0x66, 0x63, 0xCA, 0x88, 0x3C, 0xE8, 0x99, 0x11, 0x3B, 0x90, 0x3B,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x57, 0x00, 0x87, 0x97, 0x00, 0xAE, 0xC4, 0x01, 0xDB, 0x18, 0x11, 0x58, 0x95, 0x22, 0x0A, 0x76, 0x23, 0xD1, 0x27,
    0x39, 0, 18, 0xF4, 0x33, 0x70, 0xFA, 0x44, 0x72, 0xD7, 0x55, 0x3A, 0x94, 0x67, 0xD4, 0x6A, 0x77, 0x8E, 0xB6, 0x70, 0xB6,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x5A, 0x11, 0x89, 0xAB, 0x12, 0xD5, 0x01, 0x22, 0x2C, 0x8E, 0x23, 0xE9, 0x3C, 0x34, 0xCC, 0x43, 0x45, 0xAD, 0x0E,
    0x39, 0, 18, 0xF6, 0x56, 0x63, 0x00, 0x67, 0x8A, 0x09, 0x77, 0x7D, 0xE8, 0x9A, 0x74, 0x2B, 0xAA, 0x56, 0x84, 0xA0, 0x84,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x74, 0x8D, 0x00, 0xA1, 0xB3, 0x00, 0xC9, 0xFC, 0x11, 0x39, 0x6D, 0x12, 0xD9, 0x3A, 0x22, 0x90, 0xE0,
    0x39, 0, 18, 0xF2, 0x33, 0x2A, 0xA6, 0x44, 0x0F, 0x6D, 0x45, 0xC3, 0x15, 0x66, 0x30, 0xA4, 0x66, 0xC7, 0xE3, 0x60, 0xE3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x72, 0x84, 0x00, 0x90, 0x9A, 0x00, 0xA4, 0xBC, 0x00, 0xDA, 0xFA, 0x11, 0x42, 0x8E, 0x12, 0xCD, 0x13,
    0x39, 0, 18, 0xF4, 0x22, 0x54, 0xC2, 0x33, 0x1F, 0x79, 0x34, 0xC7, 0x11, 0x55, 0x0B, 0x74, 0x55, 0x8F, 0xA9, 0x50, 0xA9,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xBF, 0x11, 0x6F, 0x87, 0x11, 0x9D, 0xB0, 0x11, 0xC4, 0xF5, 0x22, 0x2D, 0x61, 0x23, 0xCF, 0x30, 0x33, 0x86, 0xD6,
    0x39, 0, 18, 0xF6, 0x44, 0x1C, 0x99, 0x55, 0x08, 0x6D, 0x56, 0xC8, 0x1C, 0x77, 0x46, 0xC8, 0x78, 0xEA, 0x09, 0x80, 0x09,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x60, 0x7C, 0x00, 0x92, 0xA8, 0x00, 0xC2, 0xFC, 0x11, 0x36, 0x70, 0x12, 0xE0, 0x43, 0x22, 0xA0, 0xEC,
    0x39, 0, 18, 0xF2, 0x33, 0x3C, 0xBD, 0x44, 0x29, 0x8B, 0x45, 0xE0, 0x34, 0x66, 0x52, 0xD2, 0x67, 0xF2, 0x12, 0x70, 0x12,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x6B, 0x7F, 0x00, 0x8A, 0x94, 0x00, 0xA2, 0xBD, 0x00, 0xD7, 0xFB, 0x11, 0x45, 0x91, 0x12, 0xDD, 0x19,
    0x39, 0, 18, 0xF4, 0x22, 0x61, 0xD4, 0x33, 0x3C, 0x94, 0x34, 0xE2, 0x2C, 0x55, 0x2A, 0x96, 0x55, 0xB3, 0xCD, 0x50, 0xCD,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x73, 0x11, 0x73, 0x8D, 0x11, 0xA1, 0xB6, 0x11, 0xCC, 0xFE, 0x22, 0x34, 0x6E, 0x23, 0xDE, 0x44, 0x33, 0xA1, 0xEE,
    0x39, 0, 18, 0xF6, 0x44, 0x38, 0xB8, 0x55, 0x2C, 0x91, 0x56, 0xEA, 0x44, 0x77, 0x73, 0xF7, 0x88, 0x17, 0x35, 0x80, 0x35,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x7E, 0x99, 0x00, 0xAB, 0xBD, 0x01, 0xD1, 0x02, 0x11, 0x33, 0x69, 0x12, 0xCC, 0x30, 0x22, 0x8C, 0xDB,
    0x39, 0, 18, 0xF2, 0x33, 0x24, 0xA5, 0x44, 0x11, 0x71, 0x45, 0xC9, 0x18, 0x66, 0x31, 0xAD, 0x66, 0xCF, 0xEC, 0x60, 0xEC,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x8F, 0x9F, 0x00, 0xAD, 0xB4, 0x00, 0xC1, 0xD5, 0x01, 0xEF, 0x07, 0x11, 0x46, 0x8A, 0x12, 0xD2, 0x0A,
    0x39, 0, 18, 0xF4, 0x22, 0x50, 0xC1, 0x33, 0x24, 0x7F, 0x34, 0xCC, 0x14, 0x55, 0x0C, 0x76, 0x55, 0x8F, 0xAC, 0x50, 0xAC,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x0C, 0x11, 0xA1, 0xB8, 0x11, 0xCE, 0xDD, 0x12, 0xF1, 0x1F, 0x22, 0x51, 0x81, 0x23, 0xE3, 0x41, 0x33, 0x9A, 0xE5,
    0x39, 0, 18, 0xF6, 0x44, 0x28, 0xA6, 0x55, 0x17, 0x7A, 0x56, 0xD4, 0x26, 0x77, 0x4F, 0xD0, 0x78, 0xF3, 0x0F, 0x80, 0x0F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x22, 0xA7, 0x00, 0xBA, 0xCD, 0x01, 0xDE, 0x06, 0x11, 0x2E, 0x61, 0x12, 0xC6, 0x28, 0x22, 0x87, 0xDA,
    0x39, 0, 18, 0xF2, 0x33, 0x25, 0xA4, 0x44, 0x0C, 0x70, 0x45, 0xC7, 0x18, 0x66, 0x2F, 0xA7, 0x66, 0xC4, 0xE0, 0x60, 0xE0,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xC7, 0xE4, 0x00, 0xEF, 0xFB, 0x11, 0x03, 0x13, 0x11, 0x25, 0x3B, 0x11, 0x6D, 0xA5, 0x12, 0xE5, 0x22,
    0x39, 0, 18, 0xF4, 0x22, 0x5D, 0xC9, 0x33, 0x27, 0x81, 0x34, 0xCE, 0x16, 0x55, 0x0B, 0x73, 0x55, 0x8D, 0xA7, 0x50, 0xA7,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x63, 0x12, 0xF7, 0x15, 0x22, 0x29, 0x3C, 0x22, 0x52, 0x72, 0x22, 0x94, 0xBF, 0x33, 0x11, 0x63, 0x33, 0xB4, 0xFD,
    0x39, 0, 18, 0xF6, 0x44, 0x3A, 0xB4, 0x55, 0x1C, 0x80, 0x56, 0xD8, 0x2B, 0x77, 0x4E, 0xCC, 0x78, 0xEA, 0x0B, 0x80, 0x0B,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0xB4, 0x11, 0x36, 0x47, 0x11, 0x55, 0x71, 0x11, 0x90, 0xAE, 0x12, 0xF3, 0x4F, 0x22, 0x9C, 0xE9,
    0x39, 0, 18, 0xF2, 0x33, 0x28, 0xAE, 0x44, 0x20, 0x7C, 0x45, 0xCF, 0x20, 0x66, 0x2A, 0xA7, 0x66, 0xC4, 0xE1, 0x60, 0xE1,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0x02, 0x8E, 0x11, 0xA2, 0xAF, 0x11, 0xBA, 0xCB, 0x11, 0xD8, 0xE6, 0x22, 0x04, 0x26, 0x22, 0x4C, 0x7A,
    0x39, 0, 18, 0xF4, 0x23, 0x9D, 0x01, 0x33, 0x54, 0x9E, 0x34, 0xE8, 0x2E, 0x55, 0x11, 0x7B, 0x55, 0x95, 0xAC, 0x50, 0xAC,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x22, 0xE1, 0xFB, 0x33, 0x0B, 0x1A, 0x33, 0x27, 0x40, 0x33, 0x5B, 0x75, 0x33, 0xA4, 0xDE, 0x44, 0x14, 0x4F,
    0x39, 0, 18, 0xF6, 0x44, 0x7F, 0xED, 0x55, 0x54, 0xAB, 0x56, 0xFB, 0x4C, 0x77, 0x58, 0xD8, 0x78, 0xF7, 0x16, 0x80, 0x16,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x1F, 0xEA, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xFB, 0x33, 0x24, 0x20,
    0x39, 0, 18, 0xF2, 0x33, 0x5F, 0xD6, 0x44, 0x3F, 0xA3, 0x45, 0xF7, 0x4A, 0x66, 0x5D, 0xD4, 0x67, 0xF4, 0x05, 0x70, 0x05,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0xFF, 0xFA, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xFB, 0x32, 0x13, 0xFB,
    0x39, 0, 18, 0xF4, 0x33, 0x17, 0x5C, 0x33, 0xA6, 0xEA, 0x44, 0x29, 0x69, 0x55, 0x4A, 0xAD, 0x55, 0xC8, 0xD8, 0x50, 0xD8,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x5F, 0x83, 0xFD, 0xFF, 0xFA, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xFB, 0x44, 0xF3, 0xCA,
    0x39, 0, 18, 0xF6, 0x45, 0xF7, 0x52, 0x55, 0xAA, 0xFE, 0x66, 0x4B, 0x99, 0x78, 0xA6, 0x1B, 0x88, 0x3A, 0x4C, 0x80, 0x4C,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x11, 0x09, 0xB3, 0x11, 0xC9, 0xDC, 0x22, 0x01, 0x24, 0x22, 0x51, 0x7A,
    0x39, 0, 18, 0xF2, 0x23, 0xAD, 0x08, 0x33, 0x61, 0xAD, 0x34, 0xF0, 0x3F, 0x55, 0x2C, 0x8F, 0x55, 0xA9, 0xBD, 0x50, 0xBD,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0xD0, 0x22, 0x4E, 0x62, 0x22, 0x72, 0x7F, 0x22, 0x8C, 0x9E, 0x22, 0xAB, 0xBB,
    0x39, 0, 18, 0xF4, 0x22, 0xCC, 0xEF, 0x33, 0x15, 0x44, 0x33, 0x6B, 0xA3, 0x44, 0x51, 0xA1, 0x44, 0xBA, 0xC3, 0x40, 0xC3,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x0C, 0x02, 0x15, 0x9C, 0x33, 0xB7, 0xC5, 0x33, 0xD4, 0xE4, 0x33, 0xF0, 0xFF, 0x44, 0x17, 0x31, 0x44, 0x4C, 0x64,
    0x39, 0, 18, 0xF6, 0x44, 0x80, 0xB9, 0x45, 0xF6, 0x33, 0x55, 0x68, 0xA8, 0x66, 0x7C, 0xDB, 0x67, 0xF6, 0x07, 0x70, 0x07,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x4C, 0x77, 0x00, 0x9F, 0xD2, 0x01, 0xFE, 0x69, 0x12, 0xC3, 0x1F, 0x23, 0xB7, 0x39, 0x34, 0xA8, 0x08,
    0x39, 0, 18, 0xF2, 0x44, 0x5E, 0xF1, 0x55, 0x72, 0xDE, 0x66, 0x45, 0xA5, 0x78, 0xE8, 0x72, 0x88, 0x8D, 0xB0, 0x80, 0xB0,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x83, 0x8C, 0x00, 0x9B, 0xAD, 0x00, 0xB8, 0xEE, 0x11, 0x23, 0x63, 0x12, 0xD0, 0x41, 0x23, 0xA6, 0x06,
    0x39, 0, 18, 0xF4, 0x33, 0x54, 0xDB, 0x44, 0x48, 0xBB, 0x55, 0x0F, 0x69, 0x67, 0x89, 0x0A, 0x77, 0x2B, 0x45, 0x70, 0x45,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xD8, 0x11, 0x59, 0x7C, 0x11, 0xA4, 0xDA, 0x22, 0x0C, 0x7A, 0x23, 0xD9, 0x39, 0x34, 0xCB, 0x4E, 0x45, 0xBE, 0x23,
    0x39, 0, 18, 0xF6, 0x56, 0x7D, 0x12, 0x67, 0x9B, 0x0D, 0x77, 0x7D, 0xDA, 0x99, 0x29, 0xB9, 0x99, 0xDC, 0xFD, 0x90, 0xFD,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x39, 0x65, 0x00, 0x82, 0xB0, 0x01, 0xCF, 0x21, 0x11, 0x7A, 0xBF, 0x22, 0x48, 0xBF, 0x33, 0x2A, 0x82,
    0x39, 0, 18, 0xF2, 0x34, 0xDB, 0x67, 0x45, 0xD9, 0x43, 0x56, 0xA8, 0x01, 0x77, 0x26, 0xA6, 0x77, 0xC0, 0xE1, 0x70, 0xE1,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x7F, 0x88, 0x00, 0x92, 0x9D, 0x00, 0xAD, 0xC9, 0x01, 0xF3, 0x23, 0x11, 0x7C, 0xD9, 0x22, 0x31, 0x82,
    0x39, 0, 18, 0xF4, 0x23, 0xDC, 0x5D, 0x34, 0xC4, 0x2A, 0x44, 0x7E, 0xD2, 0x56, 0xDD, 0x4E, 0x66, 0x70, 0x85, 0x60, 0x85,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x1B, 0x11, 0x51, 0x73, 0x11, 0x8D, 0xB8, 0x12, 0xD7, 0x2F, 0x22, 0x88, 0xD7, 0x33, 0x66, 0xD4, 0x44, 0x42, 0x99,
    0x39, 0, 18, 0xF6, 0x45, 0xF7, 0x82, 0x66, 0x01, 0x72, 0x67, 0xD2, 0x33, 0x88, 0x60, 0xE2, 0x99, 0x01, 0x20, 0x90, 0x20,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x15, 0x09, 0x00, 0x25, 0x47, 0x00, 0x56, 0x6A, 0x00, 0x85, 0xA7, 0x00, 0xC9, 0xF7,
    0x39, 0, 18, 0xF2, 0x11, 0x1C, 0x64, 0x11, 0xA8, 0xEA, 0x22, 0x2F, 0x6F, 0x33, 0x3A, 0x89, 0x33, 0x94, 0xB3, 0x30, 0xB3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x32, 0x00, 0x74, 0x83, 0x00, 0x85, 0x87, 0x00, 0x94, 0x9D, 0x00, 0xAC, 0xB8,
    0x39, 0, 18, 0xF4, 0x00, 0xCA, 0xE5, 0x11, 0x0F, 0x3E, 0x11, 0x71, 0xA4, 0x22, 0x42, 0x93, 0x22, 0x8E, 0xB6, 0x20, 0xB6,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x00, 0x02, 0x46, 0x11, 0x32, 0x3F, 0x11, 0x43, 0x53, 0x11, 0x64, 0x76, 0x11, 0x8C, 0xAF, 0x11, 0xD5, 0xFF,
    0x39, 0, 18, 0xF6, 0x22, 0x21, 0x71, 0x23, 0xC0, 0x00, 0x33, 0x43, 0x82, 0x44, 0x4F, 0xA5, 0x44, 0xAD, 0xC6, 0x40, 0xC6,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x17, 0x00, 0x18, 0x2B, 0x00, 0x40, 0x4E, 0x00, 0x64, 0x7B, 0x00, 0x94, 0xAF,
    0x39, 0, 18, 0xF2, 0x00, 0xC9, 0xFC, 0x11, 0x32, 0x6C, 0x11, 0x97, 0xCF, 0x22, 0x7F, 0xCD, 0x22, 0xE0, 0xF3, 0x20, 0xF3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x73, 0x00, 0x7E, 0x81, 0x00, 0x87, 0x8F, 0x00, 0x98, 0x9F,
    0x39, 0, 18, 0xF4, 0x00, 0xAC, 0xBE, 0x00, 0xD3, 0xF4, 0x11, 0x06, 0x29, 0x11, 0xA8, 0xEC, 0x11, 0xF7, 0xFF, 0x10, 0xFF,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x00, 0x02, 0x10, 0x01, 0x57, 0x2F, 0x11, 0x3D, 0x43, 0x11, 0x51, 0x5D, 0x11, 0x73, 0x83, 0x11, 0x9E, 0xB8,
    0x39, 0, 18, 0xF6, 0x12, 0xD4, 0x06, 0x22, 0x3E, 0x7D, 0x22, 0xAB, 0xE4, 0x33, 0x97, 0xE9, 0x34, 0xFB, 0x06, 0x40, 0x06,
    0x39, 0, 2, 0xFF, 0x01,
////////////////////////GAMMA1 END///////////////////////////////
#else

/////////////GAMMA2///////////////
    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x39, 0xC7, 0x11, 0x48, 0xB0, 0x22, 0x0B, 0x96, 0x33, 0x12, 0x79, 0x44, 0x1D, 0xA3, 0x55, 0x21, 0x8D,
    0x39, 0, 18, 0xF2, 0x56, 0xF4, 0xA3, 0x77, 0x3C, 0xC9, 0x88, 0x50, 0xD6, 0xAB, 0xCE, 0xCB, 0xCC, 0x14, 0x51, 0xC0, 0x51,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x0B, 0x5B, 0x01, 0xB9, 0x05, 0x11, 0x58, 0xD7, 0x22, 0x46, 0xAA, 0x33, 0x44, 0xBE, 0x44, 0x29, 0x8C,
    0x39, 0, 18, 0xF4, 0x45, 0xE8, 0x8C, 0x66, 0x1E, 0x98, 0x77, 0x11, 0x83, 0x99, 0x2E, 0xFE, 0xAA, 0x37, 0x68, 0xA0, 0x68,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xE1, 0x11, 0x4D, 0xC3, 0x22, 0x36, 0x94, 0x23, 0xEC, 0x78, 0x34, 0xEE, 0x59, 0x55, 0x0A, 0x97, 0x66, 0x18, 0x87,
    0x39, 0, 18, 0xF6, 0x67, 0xEF, 0xA5, 0x88, 0x47, 0xD9, 0x99, 0x71, 0xFB, 0xCD, 0x17, 0x2D, 0xDD, 0x79, 0xBC, 0xD0, 0xBC,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x2B, 0x00, 0x7D, 0xDC, 0x11, 0x44, 0xA1, 0x12, 0xF5, 0x82, 0x23, 0xF0, 0x4A, 0x34, 0xEA, 0x72, 0x45, 0xE3, 0x4C,
    0x39, 0, 18, 0xF2, 0x56, 0xAB, 0x58, 0x67, 0xED, 0x73, 0x78, 0xEF, 0x65, 0xAB, 0x2C, 0x0E, 0xBB, 0x43, 0x7B, 0xB0, 0x7B,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x37, 0x00, 0x62, 0x8D, 0x01, 0xCA, 0x0A, 0x11, 0x4D, 0xC6, 0x22, 0x29, 0x7C, 0x33, 0x13, 0x8E, 0x34, 0xEF, 0x4F,
    0x39, 0, 18, 0xF4, 0x45, 0xA6, 0x43, 0x56, 0xC9, 0x46, 0x67, 0xB5, 0x1E, 0x89, 0xA0, 0x56, 0x99, 0x83, 0xB7, 0x90, 0xB7,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x2C, 0x11, 0x77, 0xCF, 0x22, 0x2F, 0x86, 0x23, 0xD5, 0x60, 0x34, 0xCC, 0x29, 0x45, 0xD4, 0x63, 0x56, 0xDC, 0x46,
    0x39, 0, 18, 0xF6, 0x67, 0xA8, 0x58, 0x78, 0xF4, 0x7F, 0x99, 0x05, 0x82, 0xBC, 0x6C, 0x60, 0xCC, 0x99, 0xD1, 0xC0, 0xD1,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x09, 0x00, 0x5A, 0x9A, 0x01, 0xE3, 0x2F, 0x11, 0x78, 0xEF, 0x22, 0x5A, 0xB1, 0x33, 0x46, 0xBD, 0x44, 0x23, 0x7E,
    0x39, 0, 18, 0xF2, 0x45, 0xD6, 0x6E, 0x56, 0xF3, 0x68, 0x67, 0xD9, 0x3D, 0x89, 0x9F, 0x44, 0x99, 0x6D, 0x95, 0x90, 0x95,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x26, 0x00, 0x52, 0x6E, 0x00, 0x91, 0xBE, 0x01, 0xED, 0x46, 0x11, 0xA0, 0xF0, 0x22, 0x79, 0xE6, 0x33, 0x45, 0x98,
    0x39, 0, 18, 0xF4, 0x34, 0xE5, 0x6E, 0x45, 0xE5, 0x51, 0x56, 0xB5, 0x14, 0x77, 0x4D, 0xDE, 0x78, 0xFE, 0x26, 0x80, 0x26,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x25, 0x11, 0x57, 0x92, 0x12, 0xD5, 0x1B, 0x22, 0x5E, 0xD0, 0x33, 0x38, 0x8F, 0x44, 0x23, 0xA2, 0x55, 0x10, 0x70,
    0x39, 0, 18, 0xF6, 0x56, 0xCC, 0x6A, 0x67, 0xF0, 0x6A, 0x78, 0xDF, 0x46, 0x9A, 0xC0, 0x74, 0xAA, 0x9F, 0xCD, 0xA0, 0xCD,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x36, 0x5C, 0x00, 0x7D, 0xA2, 0x01, 0xCD, 0x23, 0x11, 0x75, 0xC1, 0x22, 0x3E, 0xAA, 0x33, 0x06, 0x53,
    0x39, 0, 18, 0xF2, 0x34, 0x96, 0x0F, 0x44, 0x79, 0xE5, 0x55, 0x3D, 0x90, 0x67, 0xA4, 0x1A, 0x77, 0x37, 0x51, 0x70, 0x51,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x3F, 0x55, 0x00, 0x60, 0x6F, 0x00, 0x84, 0xB5, 0x01, 0xEB, 0x23, 0x11, 0x8A, 0xE8, 0x22, 0x3C, 0x84,
    0x39, 0, 18, 0xF4, 0x23, 0xC2, 0x35, 0x33, 0x95, 0xF1, 0x44, 0x41, 0x8C, 0x55, 0x87, 0xF4, 0x66, 0x0F, 0x25, 0x60, 0x25,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x01, 0x11, 0x37, 0x59, 0x11, 0x75, 0x99, 0x12, 0xC0, 0x10, 0x22, 0x5F, 0xA6, 0x33, 0x1D, 0x88, 0x34, 0xE2, 0x33,
    0x39, 0, 18, 0xF6, 0x44, 0x7A, 0xFD, 0x55, 0x6C, 0xDD, 0x66, 0x38, 0x8C, 0x78, 0xA8, 0x24, 0x88, 0x41, 0x5D, 0x80, 0x5D,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x03, 0x2D, 0x00, 0x59, 0x86, 0x01, 0xB9, 0x1B, 0x11, 0x71, 0xBF, 0x22, 0x45, 0xB3, 0x33, 0x14, 0x63,
    0x39, 0, 18, 0xF2, 0x34, 0xAE, 0x2B, 0x45, 0x9A, 0x01, 0x55, 0x5B, 0xAF, 0x67, 0xC9, 0x44, 0x77, 0x61, 0x7F, 0x70, 0x7F,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x2E, 0x42, 0x00, 0x52, 0x61, 0x00, 0x76, 0xAB, 0x01, 0xE3, 0x1F, 0x11, 0x89, 0xEE, 0x22, 0x44, 0x8E,
    0x39, 0, 18, 0xF4, 0x23, 0xD4, 0x4A, 0x34, 0xAE, 0x08, 0x44, 0x5C, 0xA7, 0x56, 0xA9, 0x1A, 0x66, 0x33, 0x4E, 0x60, 0x4E,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x07, 0x11, 0x34, 0x53, 0x11, 0x74, 0x9A, 0x12, 0xC2, 0x16, 0x22, 0x65, 0xAC, 0x33, 0x2F, 0x9C, 0x34, 0xFA, 0x4B,
    0x39, 0, 18, 0xF6, 0x45, 0x99, 0x1E, 0x55, 0x91, 0xFE, 0x66, 0x59, 0xAE, 0x78, 0xD2, 0x51, 0x88, 0x70, 0x8F, 0x80, 0x8F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x27, 0x00, 0x4F, 0x7B, 0x01, 0xA4, 0x02, 0x11, 0x57, 0xA5, 0x22, 0x2D, 0xA4, 0x23, 0xFF, 0x55,
    0x39, 0, 18, 0xF2, 0x34, 0x9F, 0x1D, 0x44, 0x8E, 0xF1, 0x55, 0x4B, 0x9A, 0x67, 0xB5, 0x32, 0x77, 0x4A, 0x67, 0x70, 0x67,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x3A, 0x4E, 0x00, 0x5F, 0x6D, 0x00, 0x80, 0xA9, 0x01, 0xDD, 0x10, 0x11, 0x76, 0xDD, 0x22, 0x2F, 0x7E,
    0x39, 0, 18, 0xF4, 0x23, 0xC6, 0x3E, 0x33, 0xA4, 0xFB, 0x44, 0x4D, 0x94, 0x56, 0x96, 0x07, 0x66, 0x20, 0x3A, 0x60, 0x3A,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xD6, 0x11, 0x56, 0x70, 0x11, 0x91, 0xB0, 0x12, 0xD2, 0x21, 0x22, 0x6E, 0xB4, 0x33, 0x2F, 0x9C, 0x34, 0xF0, 0x44,
    0x39, 0, 18, 0xF6, 0x45, 0x92, 0x15, 0x55, 0x89, 0xF1, 0x66, 0x4C, 0x9C, 0x78, 0xBE, 0x3F, 0x88, 0x59, 0x79, 0x80, 0x79,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x22, 0x00, 0x41, 0x63, 0x00, 0x87, 0xD7, 0x11, 0x24, 0x76, 0x22, 0x10, 0x90, 0x23, 0xF2, 0x4E,
    0x39, 0, 18, 0xF2, 0x34, 0x96, 0x1B, 0x44, 0x90, 0xEE, 0x55, 0x4E, 0x9A, 0x67, 0xB9, 0x31, 0x77, 0x4B, 0x5C, 0x70, 0x5C,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x5D, 0x78, 0x00, 0x85, 0x92, 0x00, 0xA2, 0xC0, 0x01, 0xE1, 0x0C, 0x11, 0x68, 0xD1, 0x22, 0x26, 0x7A,
    0x39, 0, 18, 0xF4, 0x23, 0xBD, 0x39, 0x33, 0xA5, 0xF7, 0x44, 0x4E, 0x96, 0x56, 0x99, 0x08, 0x66, 0x20, 0x2E, 0x60, 0x2E,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xAC, 0x11, 0xA0, 0xBE, 0x11, 0xD8, 0xF4, 0x22, 0x10, 0x51, 0x22, 0x90, 0xD0, 0x33, 0x43, 0xAC, 0x34, 0xFF, 0x52,
    0x39, 0, 18, 0xF6, 0x45, 0x98, 0x1F, 0x55, 0x94, 0xF6, 0x66, 0x54, 0xA0, 0x78, 0xC4, 0x40, 0x88, 0x5B, 0x6B, 0x80, 0x6B,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x39, 0x00, 0x63, 0x7E, 0x00, 0x98, 0xC9, 0x01, 0xFF, 0x40, 0x12, 0xCE, 0x5C, 0x23, 0xD3, 0x2F,
    0x39, 0, 18, 0xF2, 0x34, 0x86, 0x08, 0x44, 0x8C, 0xEF, 0x55, 0x4C, 0x9F, 0x67, 0xB9, 0x2A, 0x77, 0x51, 0x65, 0x70, 0x65,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0xCE, 0x00, 0xE0, 0xEF, 0x01, 0xFA, 0x11, 0x11, 0x25, 0x40, 0x11, 0x83, 0xD4, 0x22, 0x26, 0x6F,
    0x39, 0, 18, 0xF4, 0x23, 0xBB, 0x31, 0x33, 0xA2, 0xFA, 0x44, 0x4F, 0x9A, 0x56, 0x9A, 0x03, 0x66, 0x24, 0x37, 0x60, 0x37,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x2B, 0x22, 0x59, 0x73, 0x22, 0x85, 0x9A, 0x22, 0xB3, 0xDB, 0x33, 0x05, 0x31, 0x33, 0x87, 0xDD, 0x44, 0x31, 0x78,
    0x39, 0, 18, 0xF6, 0x45, 0xC0, 0x36, 0x56, 0xB0, 0x10, 0x66, 0x68, 0xB7, 0x78, 0xCE, 0x43, 0x88, 0x6A, 0x80, 0x80, 0x80,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x62, 0x8D, 0x00, 0xA2, 0xC9, 0x01, 0xF9, 0x2A, 0x12, 0xA7, 0x3B, 0x23, 0xBF, 0x2B,
    0x39, 0, 18, 0xF2, 0x34, 0x84, 0x1B, 0x45, 0x9C, 0x05, 0x55, 0x69, 0xC0, 0x67, 0xDF, 0x5E, 0x77, 0x78, 0x95, 0x70, 0x95,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x18, 0x11, 0x25, 0x3C, 0x11, 0x4B, 0x64, 0x11, 0x81, 0x96, 0x12, 0xCC, 0x0E, 0x22, 0x53, 0x9A,
    0x39, 0, 18, 0xF4, 0x23, 0xDC, 0x53, 0x34, 0xBB, 0x18, 0x44, 0x6B, 0xBB, 0x56, 0xBE, 0x34, 0x66, 0x4F, 0x66, 0x60, 0x66,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x29, 0x23, 0x15, 0x1E, 0x33, 0x30, 0x3D, 0x33, 0x4C, 0x6C, 0x33, 0x8E, 0xB1, 0x34, 0xF0, 0x3C, 0x44, 0x82, 0xC8,
    0x39, 0, 18, 0xF6, 0x55, 0x06, 0x82, 0x56, 0xF0, 0x4B, 0x66, 0xA4, 0xF0, 0x88, 0x07, 0x8C, 0x88, 0xA1, 0xBD, 0x80, 0xBD,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x70, 0x9C, 0x00, 0xB3, 0xD2, 0x11, 0x04, 0x4C, 0x12, 0xA5, 0x06,
    0x39, 0, 18, 0xF2, 0x23, 0x69, 0x03, 0x33, 0x84, 0xE4, 0x44, 0x42, 0x90, 0x56, 0x98, 0x06, 0x66, 0x21, 0x36, 0x60, 0x36,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x08, 0x0E, 0x11, 0x28, 0x40, 0x11, 0x55, 0x64, 0x11, 0x82, 0xA3, 0x11, 0xC9, 0xF2,
    0x39, 0, 18, 0xF4, 0x22, 0x23, 0x7B, 0x23, 0xD9, 0x23, 0x33, 0x6E, 0xAD, 0x44, 0x93, 0xF6, 0x55, 0x0E, 0x23, 0x50, 0x23,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x02, 0x11, 0x72, 0xB8, 0x33, 0x1E, 0x24, 0x33, 0x2E, 0x42, 0x33, 0x59, 0x6D, 0x33, 0x98, 0xC1, 0x34, 0xF0, 0x1E,
    0x39, 0, 18, 0xF6, 0x44, 0x52, 0xA9, 0x55, 0x05, 0x53, 0x55, 0x9C, 0xE1, 0x67, 0xCE, 0x34, 0x77, 0x4E, 0x64, 0x70, 0x64,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0xE4, 0x11, 0x37, 0x96, 0x12, 0xF5, 0x4D, 0x23, 0x9A, 0x20, 0x33, 0x8E, 0xEE, 0x45, 0x8C, 0x0D, 0x55, 0x7E, 0xE6,
    0x39, 0, 18, 0xF2, 0x66, 0x44, 0xF2, 0x78, 0x8A, 0x16, 0x89, 0x97, 0x19, 0xAB, 0xF7, 0xE5, 0xCC, 0x20, 0x62, 0xC0, 0x62,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0xF8, 0x11, 0x28, 0x57, 0x11, 0x8E, 0xC8, 0x22, 0x02, 0x71, 0x23, 0xD1, 0x28, 0x34, 0xBB, 0x32, 0x44, 0x99, 0xF5,
    0x39, 0, 18, 0xF4, 0x55, 0x4A, 0xE0, 0x66, 0x68, 0xE4, 0x77, 0x57, 0xC6, 0x9A, 0x5D, 0x23, 0xAA, 0x56, 0x8E, 0xA0, 0x8E,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0xF9, 0x22, 0x47, 0x96, 0x23, 0xEC, 0x3B, 0x34, 0x86, 0x09, 0x44, 0x76, 0xD6, 0x56, 0x7A, 0x03, 0x66, 0x7A, 0xE6,
    0x39, 0, 18, 0xF6, 0x77, 0x4A, 0xFF, 0x89, 0x9E, 0x33, 0x9A, 0xBE, 0x47, 0xCD, 0x4A, 0x55, 0xDD, 0x9B, 0xE0, 0xD0, 0xE0,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x4F, 0x11, 0x8D, 0xCF, 0x22, 0x1B, 0x66, 0x23, 0xAD, 0x29, 0x33, 0x92, 0xEE, 0x45, 0x86, 0x07, 0x55, 0x75, 0xDA,
    0x39, 0, 18, 0xF2, 0x66, 0x39, 0xE1, 0x77, 0x73, 0xF9, 0x88, 0x7A, 0xF3, 0xAB, 0xC0, 0xA4, 0xBC, 0xE0, 0x1B, 0xC0, 0x1B,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5F, 0x11, 0x82, 0xA2, 0x11, 0xC6, 0xF1, 0x22, 0x22, 0x81, 0x23, 0xDA, 0x2A, 0x34, 0xB4, 0x29, 0x44, 0x8C, 0xE6,
    0x39, 0, 18, 0xF4, 0x55, 0x39, 0xCD, 0x66, 0x50, 0xC8, 0x77, 0x3A, 0xA4, 0x99, 0x2B, 0xEB, 0xAA, 0x1C, 0x4B, 0xA0, 0x4B,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x43, 0x22, 0x83, 0xC4, 0x33, 0x0C, 0x51, 0x34, 0x96, 0x0F, 0x44, 0x78, 0xD4, 0x55, 0x74, 0xFA, 0x66, 0x6F, 0xD9,
    0x39, 0, 18, 0xF6, 0x77, 0x3B, 0xEA, 0x89, 0x84, 0x13, 0x9A, 0x9C, 0x1D, 0xCD, 0x0B, 0x0F, 0xDD, 0x56, 0x93, 0xD0, 0x93,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x48, 0x11, 0x87, 0xC5, 0x22, 0x09, 0x51, 0x23, 0x94, 0x0B, 0x33, 0x73, 0xCD, 0x44, 0x61, 0xDD, 0x55, 0x4C, 0xAF,
    0x39, 0, 18, 0xF2, 0x66, 0x09, 0xA9, 0x77, 0x3A, 0xBD, 0x88, 0x38, 0xA9, 0xAB, 0x5B, 0x31, 0xBB, 0x66, 0x94, 0xB0, 0x94,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5E, 0x11, 0x80, 0x9C, 0x11, 0xBE, 0xE5, 0x22, 0x11, 0x6B, 0x23, 0xC0, 0x0C, 0x34, 0x92, 0x03, 0x44, 0x66, 0xBF,
    0x39, 0, 18, 0xF4, 0x55, 0x0F, 0x9E, 0x66, 0x1C, 0x91, 0x67, 0xFD, 0x62, 0x89, 0xD7, 0x8C, 0x99, 0xB8, 0xE3, 0x90, 0xE3,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x22, 0x7D, 0xB9, 0x23, 0xFB, 0x3C, 0x33, 0x7E, 0xF3, 0x44, 0x59, 0xB3, 0x55, 0x4D, 0xD0, 0x66, 0x44, 0xAD,
    0x39, 0, 18, 0xF6, 0x77, 0x0A, 0xB2, 0x88, 0x48, 0xD2, 0x99, 0x54, 0xCF, 0xBC, 0x9E, 0x8B, 0xCC, 0xC8, 0xFE, 0xC0, 0xFE,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x59, 0x11, 0x76, 0xA2, 0x12, 0xD2, 0x07, 0x22, 0x3F, 0xA9, 0x33, 0x04, 0x56, 0x34, 0xDF, 0x53, 0x45, 0xB9, 0x10,
    0x39, 0, 18, 0xF2, 0x55, 0x62, 0xF5, 0x66, 0x76, 0xED, 0x77, 0x59, 0xBA, 0x99, 0x23, 0xCB, 0x9A, 0xF3, 0x23, 0xA0, 0x23,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x4E, 0x11, 0x78, 0x8D, 0x11, 0xA3, 0xBC, 0x12, 0xDB, 0x1F, 0x22, 0x65, 0xA7, 0x33, 0x1E, 0x85, 0x34, 0xE2, 0x32,
    0x39, 0, 18, 0xF4, 0x44, 0x7A, 0xFE, 0x55, 0x71, 0xD6, 0x66, 0x36, 0x8F, 0x78, 0xCE, 0x5C, 0x88, 0x81, 0xA4, 0x80, 0xA4,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x37, 0x22, 0x6C, 0x97, 0x22, 0xC5, 0xF8, 0x33, 0x2E, 0x91, 0x34, 0xEC, 0x3D, 0x45, 0xC6, 0x3E, 0x56, 0xAA, 0x06,
    0x39, 0, 18, 0xF6, 0x66, 0x5B, 0xF5, 0x77, 0x7B, 0xF6, 0x88, 0x66, 0xCF, 0xAB, 0x50, 0x04, 0xBB, 0x32, 0x5A, 0xB0, 0x5A,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x61, 0x7E, 0x11, 0x9E, 0xC3, 0x12, 0xEA, 0x3A, 0x22, 0x88, 0xD0, 0x33, 0x4E, 0xBA, 0x44, 0x16, 0x66,
    0x39, 0, 18, 0xF2, 0x45, 0xB1, 0x33, 0x56, 0xA4, 0x0B, 0x66, 0x6A, 0xBF, 0x78, 0xF4, 0x7A, 0x88, 0x9A, 0xB9, 0x80, 0xB9,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x6B, 0x7E, 0x11, 0x8E, 0x9F, 0x11, 0xB0, 0xDA, 0x22, 0x0A, 0x3D, 0x22, 0xA0, 0xFA, 0x33, 0x4C, 0x96,
    0x39, 0, 18, 0xF4, 0x34, 0xD9, 0x50, 0x45, 0xB6, 0x11, 0x55, 0x65, 0xB4, 0x67, 0xC3, 0x3B, 0x77, 0x58, 0x74, 0x70, 0x74,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x32, 0x22, 0x61, 0x80, 0x22, 0x9F, 0xC2, 0x23, 0xE5, 0x32, 0x33, 0x7B, 0xC3, 0x44, 0x3C, 0xA5, 0x55, 0x03, 0x56,
    0x39, 0, 18, 0xF6, 0x56, 0xA3, 0x2C, 0x67, 0xA2, 0x0D, 0x77, 0x72, 0xCF, 0x99, 0x0F, 0x9E, 0x99, 0xC1, 0xE1, 0x90, 0xE1,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x42, 0x65, 0x11, 0x82, 0xA1, 0x12, 0xC2, 0x07, 0x22, 0x50, 0x97, 0x33, 0x14, 0x7E, 0x34, 0xDA, 0x2A,
    0x39, 0, 18, 0xF2, 0x44, 0x71, 0xED, 0x55, 0x5C, 0xBB, 0x66, 0x16, 0x69, 0x78, 0x8B, 0x03, 0x88, 0x26, 0x39, 0x80, 0x39,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x7F, 0x90, 0x11, 0x9D, 0xAA, 0x11, 0xB7, 0xD5, 0x12, 0xF7, 0x20, 0x22, 0x78, 0xCC, 0x33, 0x18, 0x60,
    0x39, 0, 18, 0xF4, 0x34, 0xA0, 0x11, 0x44, 0x74, 0xCB, 0x55, 0x1A, 0x64, 0x66, 0x5F, 0xD2, 0x67, 0xEC, 0x06, 0x70, 0x06,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x49, 0x22, 0x7C, 0x97, 0x22, 0xB3, 0xCD, 0x23, 0xE9, 0x26, 0x33, 0x64, 0xA1, 0x44, 0x11, 0x75, 0x45, 0xCA, 0x1B,
    0x39, 0, 18, 0xF6, 0x55, 0x64, 0xE4, 0x66, 0x58, 0xBD, 0x77, 0x1B, 0x70, 0x89, 0x9A, 0x1E, 0x99, 0x3D, 0x5D, 0x90, 0x5D,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x97, 0xBB, 0x12, 0xDD, 0x03, 0x22, 0x2E, 0x87, 0x23, 0xDA, 0x2B, 0x34, 0xB6, 0x23, 0x44, 0x83, 0xD9,
    0x39, 0, 18, 0xF2, 0x55, 0x29, 0xAD, 0x66, 0x2B, 0x97, 0x67, 0xFB, 0x58, 0x89, 0x9A, 0x2C, 0x99, 0x4E, 0x76, 0x90, 0x76,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0xE5, 0xF8, 0x22, 0x08, 0x17, 0x22, 0x28, 0x50, 0x22, 0x7B, 0xAC, 0x33, 0x0F, 0x6B, 0x34, 0xBF, 0x09,
    0x39, 0, 18, 0xF4, 0x44, 0x4E, 0xC5, 0x55, 0x31, 0x90, 0x56, 0xEA, 0x3C, 0x77, 0x59, 0xD6, 0x78, 0xF3, 0x11, 0x80, 0x11,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x0E, 0x23, 0xF8, 0x15, 0x33, 0x35, 0x54, 0x33, 0x75, 0xB9, 0x34, 0xFB, 0x3E, 0x45, 0xB8, 0x21, 0x55, 0x80, 0xD7,
    0x39, 0, 18, 0xF6, 0x66, 0x29, 0xB5, 0x77, 0x33, 0xA4, 0x88, 0x0B, 0x6A, 0x9A, 0xC0, 0x5C, 0xAA, 0x81, 0xA4, 0xA0, 0xA4,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x22, 0x25, 0x55, 0x22, 0x75, 0x93, 0x23, 0xB9, 0x06, 0x33, 0x52, 0x99, 0x44, 0x1D, 0x93, 0x45, 0xF4, 0x4A,
    0x39, 0, 18, 0xF2, 0x56, 0x99, 0x2A, 0x67, 0xA9, 0x1A, 0x77, 0x85, 0xE8, 0x99, 0x41, 0xDF, 0xAA, 0x05, 0x27, 0xA0, 0x27,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x22, 0xB8, 0xD1, 0x22, 0xE2, 0xEF, 0x23, 0xFB, 0x15, 0x33, 0x35, 0x58, 0x33, 0xA4, 0xF3, 0x44, 0x3F, 0x87,
    0x39, 0, 18, 0xF4, 0x45, 0xC8, 0x41, 0x56, 0xAC, 0x0D, 0x66, 0x6B, 0xC0, 0x78, 0xEB, 0x6E, 0x88, 0x8E, 0xAD, 0x80, 0xAD,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x2C, 0x33, 0xEB, 0xFF, 0x44, 0x15, 0x2A, 0x44, 0x43, 0x77, 0x44, 0xAC, 0xE0, 0x55, 0x4A, 0xB2, 0x66, 0x0D, 0x63,
    0x39, 0, 18, 0xF6, 0x67, 0xB0, 0x40, 0x78, 0xC1, 0x33, 0x89, 0xA0, 0x08, 0xAB, 0x77, 0x20, 0xBB, 0x49, 0x6F, 0xB0, 0x6F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x22, 0xC7, 0xDD, 0x23, 0xF0, 0x18, 0x33, 0x3F, 0x6E, 0x34, 0xC3, 0x16, 0x44, 0x64, 0xAD,
    0x39, 0, 18, 0xF2, 0x45, 0xF3, 0x73, 0x56, 0xDF, 0x3F, 0x66, 0x99, 0xEE, 0x88, 0x12, 0x91, 0x88, 0xB0, 0xC8, 0x80, 0xC8,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x03, 0x02, 0x54, 0x33, 0x6C, 0x79, 0x33, 0x83, 0x90, 0x33, 0xA0, 0xAF, 0x33, 0xCD, 0xF0, 0x44, 0x17, 0x41,
    0x39, 0, 18, 0xF4, 0x44, 0x6B, 0xC2, 0x55, 0x18, 0x67, 0x55, 0xB1, 0xF7, 0x67, 0xEE, 0x5C, 0x77, 0x76, 0x8E, 0x70, 0x8E,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x63, 0x34, 0x9F, 0x96, 0x44, 0xA7, 0xB4, 0x44, 0xBC, 0xD5, 0x45, 0xED, 0x08, 0x55, 0x44, 0x7E, 0x55, 0xB9, 0xF7,
    0x39, 0, 18, 0xF6, 0x66, 0x33, 0xA6, 0x77, 0x0C, 0x6A, 0x78, 0xC2, 0x16, 0x99, 0x40, 0xC6, 0x9A, 0xE6, 0x03, 0xA0, 0x03,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x55, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xA4,
    0x39, 0, 18, 0xF2, 0x34, 0xBC, 0x0C, 0x44, 0x56, 0x9D, 0x45, 0xE1, 0x25, 0x56, 0xF9, 0x54, 0x66, 0x6A, 0x7C, 0x60, 0x7C,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x07, 0x04, 0xB0, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xCD,
    0x39, 0, 18, 0xF4, 0x33, 0xC9, 0xEA, 0x44, 0x11, 0x37, 0x44, 0x5F, 0x89, 0x55, 0x2E, 0x78, 0x55, 0x8A, 0x9B, 0x50, 0x9B,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x37, 0x0F, 0xD5, 0xEF, 0xB7, 0xFD, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF5, 0xFA, 0x36,
    0x39, 0, 18, 0xF6, 0x55, 0x3E, 0x76, 0x55, 0xB0, 0xEA, 0x66, 0x23, 0x5F, 0x77, 0x27, 0x7F, 0x77, 0x94, 0xA7, 0x70, 0xA7,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x00, 0x6B, 0xC7, 0x11, 0x1B, 0xA8, 0x22, 0x1C, 0x88, 0x33, 0x34, 0xBF, 0x44, 0x35, 0xA7,
    0x39, 0, 18, 0xF2, 0x55, 0x0C, 0xC7, 0x67, 0x73, 0x05, 0x78, 0x9D, 0x1E, 0xAB, 0x35, 0x46, 0xBB, 0x92, 0xCA, 0xB0, 0xCA,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x3F, 0x00, 0x7B, 0xED, 0x11, 0x53, 0xB1, 0x22, 0x50, 0xD1, 0x33, 0x40, 0xA1,
    0x39, 0, 18, 0xF4, 0x34, 0xFB, 0x9F, 0x55, 0x38, 0xBF, 0x66, 0x40, 0xB9, 0x89, 0x78, 0x55, 0x99, 0x93, 0xC5, 0x90, 0xC5,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0xD3, 0x21, 0x11, 0x75, 0xC5, 0x22, 0x0F, 0x97, 0x33, 0x0E, 0x77, 0x44, 0x1C, 0xB1, 0x55, 0x39, 0xAD,
    0x39, 0, 18, 0xF6, 0x66, 0x19, 0xD9, 0x78, 0x87, 0x27, 0x89, 0xBF, 0x50, 0xBC, 0x8F, 0xB8, 0xDD, 0x06, 0x42, 0xD0, 0x42,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x15, 0x4A, 0x00, 0x8C, 0xD2, 0x11, 0x17, 0x96, 0x22, 0x03, 0x61, 0x33, 0x00, 0x88, 0x34, 0xF9, 0x60,
    0x39, 0, 18, 0xF2, 0x45, 0xC7, 0x76, 0x66, 0x15, 0xA4, 0x77, 0x29, 0xAC, 0x9A, 0x84, 0x74, 0xAA, 0xAD, 0xE9, 0xA0, 0xE9,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x1E, 0x00, 0x3F, 0x65, 0x00, 0x92, 0xED, 0x11, 0x43, 0x95, 0x22, 0x23, 0x9F, 0x33, 0x07, 0x64,
    0x39, 0, 18, 0xF4, 0x34, 0xBB, 0x54, 0x45, 0xE0, 0x62, 0x56, 0xDA, 0x4B, 0x78, 0xDD, 0xA0, 0x89, 0xD2, 0x08, 0x90, 0x08,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x11, 0x19, 0x4D, 0x11, 0x8A, 0xCB, 0x22, 0x08, 0x82, 0x23, 0xED, 0x4D, 0x34, 0xEB, 0x7A, 0x45, 0xF2, 0x65,
    0x39, 0, 18, 0xF6, 0x56, 0xCD, 0x85, 0x77, 0x29, 0xBD, 0x88, 0x48, 0xD1, 0xAB, 0xD5, 0xD5, 0xCC, 0x15, 0x52, 0xC0, 0x52,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x03, 0x26, 0x00, 0x4F, 0x7E, 0x01, 0xB0, 0x16, 0x11, 0x75, 0xC9, 0x22, 0x58, 0xD4, 0x33, 0x3C, 0x98,
    0x39, 0, 18, 0xF2, 0x34, 0xEB, 0x85, 0x55, 0x0D, 0x8A, 0x56, 0xFF, 0x69, 0x78, 0xE6, 0x98, 0x88, 0xC0, 0xE8, 0x80, 0xE8,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x0C, 0x00, 0x21, 0x38, 0x00, 0x54, 0x91, 0x01, 0xD2, 0x14, 0x11, 0x8C, 0xF9, 0x22, 0x59, 0xAD,
    0x39, 0, 18, 0xF4, 0x23, 0xFB, 0x82, 0x34, 0xF7, 0x65, 0x45, 0xCB, 0x2C, 0x67, 0x7F, 0x15, 0x77, 0x39, 0x60, 0x70, 0x60,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xC9, 0x11, 0x04, 0x2B, 0x11, 0x51, 0x7E, 0x12, 0xAD, 0x09, 0x22, 0x63, 0xB9, 0x33, 0x44, 0xBE, 0x44, 0x26, 0x89,
    0x39, 0, 18, 0xF6, 0x45, 0xE4, 0x89, 0x66, 0x19, 0x9A, 0x77, 0x10, 0x81, 0x99, 0x13, 0xD1, 0x9A, 0xFE, 0x2D, 0xA0, 0x2D,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x14, 0x2A, 0x00, 0x41, 0x77, 0x00, 0xB2, 0xEA, 0x11, 0x5B, 0xBF, 0x22, 0x17, 0x64,
    0x39, 0, 18, 0xF2, 0x23, 0xAC, 0x28, 0x33, 0x97, 0xF7, 0x44, 0x4D, 0xA4, 0x56, 0xCA, 0x47, 0x66, 0x67, 0x86, 0x60, 0x86,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x0D, 0x00, 0x1B, 0x34, 0x00, 0x53, 0x76, 0x01, 0xC1, 0x0B, 0x11, 0x54, 0x97,
    0x39, 0, 18, 0xF4, 0x12, 0xD6, 0x48, 0x23, 0xAC, 0x04, 0x33, 0x54, 0x9D, 0x45, 0x9D, 0x0D, 0x55, 0x29, 0x45, 0x50, 0x45,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x20, 0x01, 0xE7, 0x02, 0x11, 0x18, 0x2F, 0x11, 0x45, 0x76, 0x11, 0xAB, 0xE3, 0x22, 0x48, 0xAB, 0x33, 0x04, 0x50,
    0x39, 0, 18, 0xF6, 0x34, 0x9A, 0x13, 0x44, 0x88, 0xF0, 0x55, 0x53, 0xAC, 0x67, 0xDC, 0x5E, 0x77, 0x7F, 0x9F, 0x70, 0x9F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x09, 0x23, 0x00, 0x3B, 0x77, 0x00, 0xAF, 0xEC, 0x11, 0x64, 0xCC, 0x22, 0x24, 0x78,
    0x39, 0, 18, 0xF2, 0x23, 0xC1, 0x43, 0x34, 0xB2, 0x10, 0x44, 0x6E, 0xC4, 0x56, 0xF4, 0x78, 0x66, 0x8F, 0xAF, 0x60, 0xAF,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x0B, 0x00, 0x16, 0x32, 0x00, 0x52, 0x78, 0x01, 0xC6, 0x14, 0x11, 0x60, 0xA5,
    0x39, 0, 18, 0xF4, 0x12, 0xE6, 0x5C, 0x23, 0xC3, 0x1D, 0x33, 0x6F, 0xB7, 0x45, 0xC0, 0x31, 0x55, 0x4C, 0x68, 0x50, 0x68,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0xED, 0x06, 0x11, 0x20, 0x38, 0x11, 0x4B, 0x80, 0x11, 0xB9, 0xF3, 0x22, 0x5D, 0xC3, 0x33, 0x1C, 0x6B,
    0x39, 0, 18, 0xF6, 0x34, 0xB4, 0x31, 0x45, 0xA9, 0x13, 0x55, 0x77, 0xCE, 0x77, 0x05, 0x8D, 0x77, 0xAD, 0xCA, 0x70, 0xCA,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x15, 0x00, 0x28, 0x3C, 0x00, 0x4D, 0x7F, 0x00, 0xB2, 0xE7, 0x11, 0x54, 0xBB, 0x22, 0x12, 0x65,
    0x39, 0, 18, 0xF2, 0x23, 0xAB, 0x2F, 0x33, 0x99, 0xF9, 0x44, 0x52, 0xA6, 0x56, 0xCC, 0x4C, 0x66, 0x6A, 0x85, 0x60, 0x85,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x13, 0x00, 0x1F, 0x2D, 0x00, 0x36, 0x4E, 0x00, 0x68, 0x86, 0x01, 0xC8, 0x0F, 0x11, 0x57, 0x9B,
    0x39, 0, 18, 0xF4, 0x12, 0xDA, 0x4B, 0x23, 0xAF, 0x07, 0x33, 0x57, 0xA0, 0x45, 0x9F, 0x10, 0x55, 0x2A, 0x45, 0x50, 0x45,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x43, 0x11, 0x23, 0x3F, 0x11, 0x50, 0x65, 0x11, 0x79, 0xA4, 0x12, 0xD4, 0x05, 0x22, 0x66, 0xC3, 0x33, 0x18, 0x63,
    0x39, 0, 18, 0xF6, 0x34, 0xA7, 0x24, 0x44, 0x94, 0xFB, 0x55, 0x5C, 0xB6, 0x67, 0xE2, 0x66, 0x77, 0x85, 0xA5, 0x70, 0xA5,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x2A, 0x00, 0x40, 0x51, 0x00, 0x63, 0x8B, 0x00, 0xB7, 0xE9, 0x11, 0x55, 0xB8, 0x22, 0x12, 0x64,
    0x39, 0, 18, 0xF2, 0x23, 0xAF, 0x2F, 0x33, 0x9B, 0xFB, 0x44, 0x56, 0xA9, 0x56, 0xC9, 0x46, 0x66, 0x62, 0x84, 0x60, 0x84,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x44, 0x5B, 0x00, 0x6C, 0x77, 0x00, 0x83, 0x95, 0x00, 0xAA, 0xC2, 0x01, 0xF8, 0x33, 0x11, 0x72, 0xAD,
    0x39, 0, 18, 0xF4, 0x12, 0xEA, 0x5A, 0x23, 0xB9, 0x0E, 0x33, 0x5E, 0xA5, 0x45, 0xA1, 0x0C, 0x55, 0x28, 0x42, 0x50, 0x42,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xBE, 0x11, 0x8A, 0xA3, 0x11, 0xB8, 0xC9, 0x12, 0xDD, 0x00, 0x22, 0x22, 0x49, 0x22, 0x9B, 0xE7, 0x33, 0x33, 0x7A,
    0x39, 0, 18, 0xF6, 0x34, 0xBE, 0x32, 0x45, 0xA0, 0x06, 0x55, 0x67, 0xBC, 0x67, 0xE0, 0x62, 0x77, 0x7D, 0x9E, 0x70, 0x9E,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x98, 0x00, 0xC5, 0xD5, 0x01, 0xE6, 0x05, 0x11, 0x25, 0x45, 0x11, 0x92, 0xE3, 0x22, 0x34, 0x7D,
    0x39, 0, 18, 0xF2, 0x23, 0xC4, 0x3D, 0x34, 0xAB, 0x04, 0x44, 0x61, 0xB3, 0x56, 0xCF, 0x49, 0x66, 0x6B, 0x84, 0x60, 0x84,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0x02, 0x1F, 0x11, 0x36, 0x41, 0x11, 0x4E, 0x60, 0x11, 0x70, 0x82, 0x11, 0x9F, 0xC0, 0x12, 0xE7, 0x11,
    0x39, 0, 18, 0xF4, 0x22, 0x3D, 0x90, 0x23, 0xE2, 0x2D, 0x33, 0x7A, 0xBB, 0x45, 0xAE, 0x18, 0x55, 0x34, 0x4B, 0x50, 0x4B,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x7A, 0x22, 0x80, 0x96, 0x22, 0xA4, 0xB3, 0x22, 0xBF, 0xD4, 0x23, 0xED, 0x06, 0x33, 0x36, 0x66, 0x33, 0xA0, 0xD4,
    0x39, 0, 18, 0xF6, 0x44, 0x0A, 0x72, 0x45, 0xDB, 0x34, 0x55, 0x8C, 0xDF, 0x67, 0xF8, 0x73, 0x77, 0x92, 0xAC, 0x70, 0xAC,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x1F, 0x11, 0x0F, 0x57, 0x11, 0x70, 0x8B, 0x11, 0xA7, 0xC4, 0x22, 0x04, 0x41, 0x22, 0x80, 0xC0,
    0x39, 0, 18, 0xF2, 0x33, 0x00, 0x70, 0x34, 0xD8, 0x38, 0x44, 0x90, 0xE4, 0x66, 0x01, 0x7C, 0x66, 0x98, 0xB5, 0x60, 0xB5,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x08, 0x11, 0xEB, 0xFF, 0x22, 0x0A, 0x1C, 0x22, 0x29, 0x37, 0x22, 0x4D, 0x66, 0x22, 0x82, 0x9C,
    0x39, 0, 18, 0xF4, 0x22, 0xB9, 0xF9, 0x33, 0x3D, 0x7B, 0x33, 0xBB, 0xFB, 0x45, 0xE3, 0x4B, 0x55, 0x65, 0x82, 0x50, 0x82,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x13, 0x03, 0x23, 0x33, 0x72, 0x7B, 0x33, 0x85, 0x96, 0x33, 0xA7, 0xBA, 0x34, 0xE2, 0x03, 0x44, 0x2D, 0x5A,
    0x39, 0, 18, 0xF6, 0x44, 0x87, 0xE0, 0x55, 0x38, 0x8F, 0x56, 0xE5, 0x30, 0x77, 0x41, 0xBA, 0x77, 0xD7, 0xF0, 0x70, 0xF0,
    0x39, 0, 2, 0xFF, 0x01,
    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x28, 0x01, 0xB4, 0x61, 0x11, 0x7A, 0x8A, 0x11, 0xAF, 0xD7, 0x22, 0x02, 0x2C,
    0x39, 0, 18, 0xF2, 0x22, 0x54, 0xAA, 0x23, 0xF6, 0x48, 0x33, 0x8E, 0xCC, 0x45, 0xC1, 0x25, 0x55, 0x3F, 0x5B, 0x50, 0x5B,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0x7E, 0x12, 0xF1, 0x03, 0x22, 0x11, 0x1C, 0x22, 0x2C, 0x40, 0x22, 0x4C, 0x5D,
    0x39, 0, 18, 0xF4, 0x22, 0x6E, 0x90, 0x22, 0xB9, 0xE0, 0x33, 0x0A, 0x33, 0x34, 0xE2, 0x2F, 0x44, 0x46, 0x5A, 0x40, 0x5A,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x97, 0x02, 0xE4, 0xB3, 0x33, 0x53, 0x66, 0x33, 0x71, 0x80, 0x33, 0x8B, 0x96, 0x33, 0xAD, 0xC6, 0x33, 0xE1, 0xFB,
    0x39, 0, 18, 0xF6, 0x44, 0x0F, 0x48, 0x44, 0x82, 0xC1, 0x45, 0xFC, 0x34, 0x66, 0x14, 0x70, 0x66, 0x87, 0xA1, 0x60, 0xA1,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x24, 0x53, 0x00, 0x87, 0xF5, 0x11, 0x4D, 0xB6, 0x22, 0x4E, 0xCD, 0x33, 0x42, 0xA0,
    0x39, 0, 18, 0xF2, 0x34, 0xFE, 0x90, 0x55, 0x14, 0x89, 0x56, 0xFC, 0x61, 0x78, 0xA1, 0x34, 0x88, 0x50, 0x74, 0x80, 0x74,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x05, 0x15, 0x00, 0x26, 0x37, 0x00, 0x4A, 0x7C, 0x00, 0xAC, 0xF5, 0x11, 0x70, 0xDF, 0x22, 0x48, 0x9E,
    0x39, 0, 18, 0xF4, 0x23, 0xFA, 0x7A, 0x34, 0xF3, 0x59, 0x45, 0xC1, 0x15, 0x66, 0x4B, 0xCA, 0x67, 0xEC, 0x05, 0x70, 0x05,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x83, 0x01, 0xEC, 0x0C, 0x11, 0x38, 0x6B, 0x12, 0x9F, 0x0A, 0x22, 0x60, 0xC5, 0x33, 0x5D, 0xDD, 0x44, 0x4B, 0xB6,
    0x39, 0, 18, 0xF6, 0x55, 0x1B, 0xBA, 0x66, 0x40, 0xB9, 0x77, 0x26, 0x89, 0x89, 0xDB, 0x72, 0x99, 0x91, 0xB9, 0x90, 0xB9,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x22, 0xA1, 0xA8, 0x22, 0xAF, 0xB6, 0x22, 0xBD, 0xC4, 0x22, 0xCB, 0xD2, 0x23, 0xD9, 0x1C,
    0x39, 0, 18, 0xF2, 0x33, 0x6E, 0xFE, 0x44, 0x79, 0xEB, 0x55, 0x50, 0xB5, 0x67, 0xE5, 0x66, 0x77, 0x7E, 0xA0, 0x70, 0xA0,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0xEA, 0xAD, 0x11, 0xB0, 0xB7, 0x11, 0xBE, 0xC5, 0x11, 0xCC, 0xD3, 0x11, 0xDA, 0xE1, 0x12, 0xE8, 0x21,
    0x39, 0, 18, 0xF4, 0x22, 0x6E, 0xF7, 0x33, 0x66, 0xCC, 0x44, 0x22, 0x7C, 0x56, 0x97, 0x0F, 0x66, 0x2E, 0x47, 0x60, 0x47,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x33, 0xA9, 0xAC, 0x33, 0xAF, 0xB6, 0x33, 0xBD, 0xC4, 0x33, 0xCB, 0xD2, 0x33, 0xD9, 0xE0, 0x34, 0xE7, 0x2C,
    0x39, 0, 18, 0xF6, 0x45, 0x80, 0x1A, 0x56, 0x9E, 0x13, 0x66, 0x7D, 0xDD, 0x88, 0x14, 0x99, 0x88, 0xBA, 0xD9, 0x80, 0xD9,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x06, 0x04, 0x80, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x39, 0, 18, 0xF2, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x0F, 0x02, 0x99, 0xFF, 0x9C, 0x9F, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x39, 0, 18, 0xF4, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0xF4, 0xFF, 0x96, 0x99, 0xFF, 0x9C, 0x9F, 0xFF, 0xA4, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x39, 0, 18, 0xF6, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x06, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x39, 0, 18, 0xF2, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0xFF, 0xA0, 0xA3, 0xFF, 0xA6, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x39, 0, 18, 0xF4, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x40, 0xFF, 0x9A, 0x9D, 0xFF, 0xA0, 0xA3, 0xFF, 0xA6, 0xA9, 0xFF, 0xAE, 0xB3, 0xFF, 0xB8, 0xBD, 0xFF, 0xC2, 0xC7,
    0x39, 0, 18, 0xF6, 0xFF, 0xCC, 0xD1, 0xFF, 0xD6, 0xDB, 0xFF, 0xE0, 0xE5, 0xFF, 0xEA, 0xEF, 0xFF, 0xF4, 0xF9, 0xF0, 0xF9,
    0x39, 0, 2, 0xFF, 0x01,
/////////////GAMMA2end///////////////

#endif
    0x39, 0, 2, 0x9F, 0x05,
    0x39, 0, 2, 0xF9, 0x00,
    0x39, 0, 2, 0xF7, 0x00,
    0x39, 0, 2, 0x9F, 0x02,
    0x39, 0, 8, 0xC3, 0x11, 0xC0, 0x05, 0xC0, 0x00, 0x00, 0x7F,
    0x39, 0, 2, 0x9F, 0x04,
    0x39, 0, 3, 0xBA, 0x10, 0x00,
    0x39, 0, 2, 0x9F, 0x0A,
    0x39, 0, 2, 0xB2, 0x1B,
    0x39, 0, 19, 0xB7, 0x13, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0x20, 0x20, 0x21,
    0x39, 0, 2, 0x9F, 0x0A,
    0x39, 0, 2, 0xB2, 0x1B,
    0x39, 0, 46, 0xB8, 0x07, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 43, 0xB9, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 43, 0xBA, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 2, 0x9F, 0x00,
    0x39, 0, 2, 0x48, 0x03,
//	0x39,0,2,0x48,0x33,  // video mode
    0x39, 0, 3, 0x51, 0x00, 0x00,
    0x39, 0, 2, 0x53, 0xE0,
    0x39, 0, 2, 0x35, 0x00,

#endif
};


#else

const uint8_t panel_init_code[] =
{

#ifdef  USE_PARAS_OLED_VIDEO

    0x39, 0, 3, 0x9C, 0xA5, 0xA5,
    0x39, 0, 3, 0xFD, 0x5A, 0x5A,
    0x39, 0, 2, 0x9F, 0x0F,
    0x39, 0, 2, 0xB3, 0x00,
    0x39, 0, 2, 0x9F, 0x01,
    0x39, 0, 2, 0xD0, 0x01,
//	0x39,0,2,0xD3,0x01,
    0x39, 0, 4, 0xB2, 0x5A, 0x04, 0xAF,
    0x39, 0, 36, 0xB3, 0x00, 0xD0, 0xA0, 0x10, 0xBC, 0x00, 0x00, 0xDD, 0x00, 0x10, 0x10, 0x00, 0x00, 0xB3, 0x00, 0x10, 0x10, 0x00, 0x00, 0xB3, 0x00, 0x10, 0x10, 0x22, 0x00, 0xEF, 0x00, 0x10, 0x10, 0x33, 0x18, 0x18, 0x18, 0x18, 0x18,
    0x39, 0, 17, 0xCA, 0x03, 0x01, 0x03, 0x03, 0x04, 0xE5, 0x06, 0x06, 0x04, 0xE5, 0x06, 0x06, 0x04, 0xE5, 0x06, 0x06,
    0x39, 0, 15, 0xCB, 0x03, 0x03, 0x05, 0x85, 0x07, 0x07, 0x05, 0x85, 0x07, 0x07, 0x05, 0x85, 0x07, 0x07,
    0x39, 0, 4, 0xD7, 0x00, 0x00, 0x02,
    0x39, 0, 2, 0x9F, 0x02,
    0x39, 0, 26, 0xB2, 0x00, 0xC0, 0x31, 0x10, 0x11, 0x12, 0x12, 0x10, 0x18, 0x78, 0x90, 0x50, 0x11, 0x11, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x11, 0x17,
    0x39, 0, 10, 0xB3, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 13, 0xB4, 0x00, 0x8A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 7, 0xB5, 0x00, 0x30, 0x30, 0x30, 0x30, 0x2B,
    0x39, 0, 20, 0xB6, 0x01, 0x01, 0x00, 0x11, 0x11, 0x11, 0x1C, 0x1F, 0x1F, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22, 0x22,
    0x39, 0, 11, 0xB7, 0x00, 0x10, 0x0F, 0x10, 0x10, 0x15, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 14, 0xB8, 0x00, 0x00, 0x00, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28, 0x43, 0x28,
    0x39, 0, 13, 0xB9, 0x00, 0x00, 0x50, 0x00, 0x00, 0x0A, 0x0F, 0x00, 0x00, 0x00, 0x19, 0x0A,
    0x39, 0, 9, 0xBA, 0x00, 0xFF, 0x44, 0x04, 0x44, 0x04, 0x44, 0x04,
    0x39, 0, 26, 0xBB, 0x01, 0x4A, 0x64, 0x16, 0x17, 0x01, 0x4A, 0x64, 0x16, 0x17, 0x01, 0x4A, 0x64, 0x16, 0x14, 0x01, 0x4A, 0x64, 0x16, 0x14, 0x01, 0x31, 0x64, 0x16, 0x0F,
    0x39, 0, 17, 0xC1, 0x00, 0x00, 0x00, 0x23, 0x23, 0x24, 0x24, 0x05, 0x05, 0x21, 0x21, 0x22, 0x22, 0x01, 0x01, 0x00,
    0x39, 0, 17, 0xC2, 0x00, 0x00, 0x00, 0x23, 0x23, 0x24, 0x24, 0x05, 0x05, 0x21, 0x21, 0x22, 0x22, 0x01, 0x01, 0x00,
    0x39, 0, 8, 0xC3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 15, 0xC4, 0x00, 0x05, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1F, 0x1F, 0x00, 0x00, 0x06,
    0x39, 0, 26, 0xC6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x03, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00, 0x55, 0x00, 0x01,
    0x39, 0, 14, 0xC7, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x30, 0x30,
    0x39, 0, 14, 0xC8, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x2E, 0x2E, 0x2E, 0x2E, 0x00, 0x30, 0x30,
    0x39, 0, 27, 0xCC, 0x00, 0x57, 0xBA, 0x57, 0xBA, 0x00, 0x57, 0xBA, 0x57, 0xBA, 0x00, 0x57, 0xBC, 0x00, 0x30, 0x6C, 0x30, 0x6C, 0x00, 0x30, 0x6C, 0x30, 0x6C, 0x00, 0x30, 0x6C,
    0x39, 0, 17, 0xD2, 0x00, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09, 0x00, 0x09, 0x09,
    0x39, 0, 12, 0xD7, 0x44, 0x01, 0x3F, 0x26, 0x37, 0x26, 0x37, 0x01, 0x11, 0x00, 0x00,
    0x39, 0, 26, 0xD8, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x9F, 0x40, 0x00, 0x00, 0xC3, 0x00, 0x00,
    0x39, 0, 12, 0xD9, 0x10, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x33, 0x00, 0x30,
    0x39, 0, 6, 0xE1, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 26, 0xE2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 13, 0xE3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 6, 0xEF, 0x00, 0x80, 0x85, 0x81, 0x82,
    0x39, 0, 9, 0xBE, 0x5F, 0x16, 0x04, 0x5F, 0x75, 0x00, 0x00, 0x00,
    0x39, 0, 2, 0xBF, 0x08,
    0x39, 0, 2, 0x9F, 0x04,
    0x39, 0, 3, 0xB2, 0x01, 0x00,
    0x39, 0, 19, 0xB3, 0x00, 0x00, 0x10, 0x00, 0x30, 0x50, 0x00, 0x70, 0x90, 0x00, 0xB0, 0xF0, 0x11, 0x30, 0x70, 0x12, 0xF0, 0x70,
    0x39, 0, 21, 0xB4, 0x23, 0xF0, 0x70, 0x34, 0xF0, 0xF0, 0x56, 0xF0, 0xF0, 0x78, 0xF0, 0xF0, 0xCE, 0xF0, 0xF0, 0xFF, 0x70, 0xF0, 0x0F, 0xFF,
    0x39, 0, 14, 0xB5, 0x11, 0x10, 0x27, 0x1C, 0xD0, 0x00, 0x64, 0x64, 0x10, 0x3F, 0xFF, 0xFF, 0xFF,
    0x39, 0, 7, 0xB6, 0x11, 0x00, 0x00, 0x0F, 0xF0, 0x10,
    0x39, 0, 3, 0xB9, 0x91, 0x83,
    0x39, 0, 3, 0xBA, 0x10, 0x00,
    0x39, 0, 5, 0xC4, 0x01, 0x10, 0x00, 0x00,
    0x39, 0, 20, 0xC5, 0x00, 0x20, 0x88, 0xC1, 0xCF, 0x50, 0x4F, 0x00, 0x4E, 0x57, 0x35, 0x22, 0x22, 0x2A, 0x05, 0x3F, 0x00, 0x20, 0x0F,
    0x39, 0, 13, 0xC6, 0x4B, 0x00, 0x90, 0x00, 0x02, 0xD5, 0x00, 0x02, 0xCB, 0x01, 0x10, 0x43,
    0x39, 0, 5, 0xC8, 0x29, 0x29, 0x28, 0x28,
    0x39, 0, 21, 0xC9, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCA, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCB, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCC, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28, 0x29, 0x29, 0x29, 0x29, 0x28, 0x28, 0x28, 0x28, 0x28, 0x28,
    0x39, 0, 21, 0xCD, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xCE, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xCF, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD0, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD1, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD2, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD3, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 21, 0xD4, 0x21, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1C, 0x1C, 0x1C, 0x1C, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F, 0x1F,
    0x39, 0, 2, 0x9F, 0x05,
    0x39, 0, 7, 0xB2, 0x24, 0x20, 0x05, 0x0F, 0xFF, 0xFF,
    0x39, 0, 9, 0xB3, 0xA0, 0x00, 0x28, 0x00, 0x00, 0x00, 0x3F, 0xFF,
    0x39, 0, 11, 0xB4, 0x00, 0x60, 0x0E, 0x38, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 16, 0xB5, 0x33, 0xFE, 0x6E, 0x22, 0xEC, 0x68, 0x11, 0xE4, 0x64, 0x10, 0x62, 0xEC, 0x00, 0x76, 0x02,
    0x39, 0, 7, 0xB6, 0x31, 0xFE, 0xD8, 0x00, 0x58, 0x00,
    0x39, 0, 16, 0xB9, 0x71, 0x20, 0x05, 0x78, 0x70, 0x5A, 0x3C, 0x78, 0x70, 0x5A, 0x3C, 0x78, 0x70, 0x5A, 0x3C,
    0x39, 0, 2, 0x9F, 0x07,
    0x39, 0, 8, 0xB2, 0x08, 0x08, 0x08, 0x08, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB3, 0x04, 0x04, 0x04, 0x04, 0x04, 0x03, 0x8C,
    0x39, 0, 8, 0xB4, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB5, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB6, 0x04, 0x04, 0x04, 0x04, 0x04, 0x02, 0xA8,
    0x39, 0, 8, 0xB7, 0x08, 0x08, 0x08, 0x08, 0x02, 0x0B, 0xB8,
    0x39, 0, 8, 0xB8, 0x02, 0x04, 0x04, 0x04, 0x01, 0x0A, 0xBE,
    0x39, 0, 17, 0xB9, 0x01, 0x05, 0x03, 0x07, 0x02, 0x06, 0x04, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBA, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBB, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBC, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBD, 0x01, 0x03, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBE, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 17, 0xBF, 0x01, 0x02, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 16, 0xC0, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x39, 0, 16, 0xC1, 0x33, 0x8C, 0x8C, 0x33, 0x8C, 0x8C, 0x32, 0x20, 0x18, 0x10, 0x0C, 0x58, 0x00, 0x2C, 0x2C,
    0x39, 0, 16, 0xC2, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x39, 0, 16, 0xC3, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8, 0x21, 0x58, 0x90, 0x00, 0xC8, 0x44, 0x00, 0x20, 0x20,
    0x39, 0, 7, 0xC4, 0x22, 0xA8, 0xA8, 0x22, 0xA8, 0xA8,
    0x39, 0, 7, 0xC5, 0x97, 0xC4, 0xD0, 0x76, 0x08, 0x40,
    0x39, 0, 4, 0xC6, 0x97, 0x2E, 0x9E,
    0x39, 0, 3, 0xC7, 0x02, 0x00,
    0x39, 0, 8, 0xC8, 0x10, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 8, 0xC9, 0x0F, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 8, 0xCA, 0x0E, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 8, 0xCB, 0x0D, 0x20, 0x20, 0x20, 0x02, 0x00, 0x7E,
    0x39, 0, 17, 0xCC, 0x01, 0x09, 0x03, 0x0B, 0x05, 0x0D, 0x07, 0x0F, 0x02, 0x0A, 0x04, 0x0C, 0x06, 0x0E, 0x08, 0x10,
    0x39, 0, 17, 0xCD, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x0F, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x0E, 0x00,
    0x39, 0, 17, 0xCE, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x0E, 0x00, 0x00,
    0x39, 0, 17, 0xCF, 0x01, 0x07, 0x03, 0x09, 0x05, 0x0B, 0x0D, 0x02, 0x08, 0x04, 0x0A, 0x06, 0x0C, 0x00, 0x00, 0x00,
    0x39, 0, 16, 0xD0, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 16, 0xD1, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 16, 0xD2, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 16, 0xD3, 0x00, 0x7E, 0x72, 0x00, 0x64, 0x58, 0x00, 0x4C, 0x40, 0x00, 0x32, 0x26, 0x00, 0x1A, 0x16,
    0x39, 0, 2, 0x9F, 0x0F,
    0x39, 0, 2, 0xF8, 0x11,
    0x39, 0, 2, 0x9F, 0x00,
    0x39, 0, 2, 0x48, 0x00,
    0x39, 0, 3, 0x51, 0x00, 0x00,
    0x39, 0, 2, 0x53, 0xE0,
    0x39, 0, 2, 0x35, 0x00,
    0x39, 0, 1, 0x11,

    0x39, 0, 2, 0x9F, 0x05,
    0x39, 0, 2, 0xF9, 0x80,
    0x39, 0, 2, 0xF7, 0x10,
    0x39, 0, 2, 0x9F, 0x06,
    0x39, 0, 41, 0xB2, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 41, 0xB3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 21, 0xB4, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 41, 0xB5, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
    0x39, 0, 41, 0xB6, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
    0x39, 0, 21, 0xB7, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED, 0x01, 0xED,
    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x23, 0x01, 0xB7, 0x47, 0x12, 0xBF, 0x26, 0x23, 0x7C, 0x0E, 0x33, 0x83, 0xE8, 0x45, 0x8A, 0x10, 0x55, 0x82, 0xEB,
    0x39, 0, 18, 0xF2, 0x66, 0x4B, 0xF9, 0x78, 0x92, 0x1F, 0x89, 0xA5, 0x23, 0xBB, 0x07, 0xF4, 0xCC, 0x32, 0x71, 0xC0, 0x71,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x49, 0x00, 0x8C, 0xDC, 0x11, 0x33, 0x83, 0x12, 0xCB, 0x4C, 0x23, 0xB9, 0x16, 0x34, 0xB0, 0x2E, 0x44, 0x97, 0xF7,
    0x39, 0, 18, 0xF4, 0x55, 0x4D, 0xE6, 0x66, 0x6E, 0xED, 0x77, 0x65, 0xCF, 0x9A, 0x6C, 0x33, 0xAA, 0x67, 0x9E, 0xA0, 0x9E,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x5C, 0x12, 0xC5, 0x3C, 0x23, 0xAE, 0x12, 0x33, 0x66, 0xF5, 0x44, 0x6A, 0xCF, 0x56, 0x77, 0x03, 0x66, 0x7D, 0xEC,
    0x39, 0, 18, 0xF6, 0x78, 0x51, 0x06, 0x89, 0xA5, 0x3C, 0x9A, 0xCA, 0x4F, 0xCD, 0x58, 0x66, 0xDD, 0xAD, 0xEE, 0xD0, 0xEE,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x9E, 0x01, 0xF9, 0x5D, 0x12, 0xBF, 0x17, 0x22, 0x6A, 0xF2, 0x33, 0x60, 0xC1, 0x44, 0x5C, 0xDE, 0x55, 0x4F, 0xB3,
    0x39, 0, 18, 0xF2, 0x66, 0x0E, 0xB2, 0x77, 0x43, 0xC5, 0x88, 0x3F, 0xB4, 0xAB, 0x66, 0x3A, 0xBB, 0x72, 0x9D, 0xB0, 0x9D,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0xBA, 0x01, 0xE1, 0x0D, 0x11, 0x47, 0x87, 0x12, 0xC4, 0x35, 0x22, 0x98, 0xEF, 0x33, 0x82, 0xFB, 0x44, 0x62, 0xBD,
    0x39, 0, 18, 0xF4, 0x55, 0x10, 0xA2, 0x66, 0x22, 0x97, 0x77, 0x05, 0x6E, 0x89, 0xE3, 0x97, 0x99, 0xC5, 0xEF, 0x90, 0xEF,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0xA0, 0x12, 0xEF, 0x4D, 0x23, 0xAC, 0x03, 0x33, 0x52, 0xD9, 0x44, 0x47, 0xA8, 0x55, 0x49, 0xD1, 0x66, 0x47, 0xB1,
    0x39, 0, 18, 0xF6, 0x77, 0x10, 0xBB, 0x88, 0x50, 0xDA, 0x99, 0x5D, 0xD8, 0xBC, 0xA9, 0x93, 0xCD, 0xD1, 0x06, 0xD0, 0x06,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x01, 0xD7, 0x18, 0x11, 0x65, 0xAD, 0x12, 0xEE, 0x68, 0x23, 0xD0, 0x27, 0x34, 0xB9, 0x30, 0x44, 0x95, 0xEE,
    0x39, 0, 18, 0xF2, 0x55, 0x42, 0xD3, 0x66, 0x52, 0xC4, 0x77, 0x2E, 0x91, 0x89, 0xEF, 0x8E, 0x99, 0xBB, 0xDF, 0x90, 0xDF,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x9D, 0x00, 0xD4, 0xEE, 0x11, 0x12, 0x3C, 0x11, 0x69, 0xC2, 0x22, 0x15, 0x63, 0x23, 0xE9, 0x57, 0x34, 0xB8, 0x0C,
    0x39, 0, 18, 0xF4, 0x44, 0x57, 0xDB, 0x55, 0x4D, 0xB4, 0x66, 0x11, 0x6B, 0x78, 0xA1, 0x2B, 0x88, 0x4B, 0x70, 0x80, 0x70,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x96, 0x12, 0xD0, 0x0D, 0x22, 0x53, 0x98, 0x23, 0xDA, 0x50, 0x34, 0xB6, 0x0E, 0x45, 0xA0, 0x19, 0x55, 0x85, 0xE2,
    0x39, 0, 18, 0xF6, 0x66, 0x3A, 0xD3, 0x77, 0x56, 0xCF, 0x88, 0x3C, 0xA3, 0xAA, 0x19, 0xC1, 0xAB, 0xEE, 0x11, 0xB0, 0x11,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0xAD, 0xD2, 0x01, 0xF5, 0x22, 0x11, 0x4E, 0xA3, 0x12, 0xF0, 0x39, 0x23, 0xB6, 0x1E, 0x33, 0x77, 0xC8,
    0x39, 0, 18, 0xF2, 0x44, 0x0E, 0x87, 0x45, 0xEE, 0x4E, 0x55, 0xA2, 0xF2, 0x67, 0xFD, 0x75, 0x77, 0x93, 0xAE, 0x70, 0xAE,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xC1, 0xD1, 0x00, 0xE0, 0xF2, 0x11, 0x06, 0x35, 0x11, 0x6B, 0x9C, 0x22, 0x01, 0x5B, 0x22, 0xAD, 0xF5,
    0x39, 0, 18, 0xF4, 0x33, 0x37, 0xA9, 0x44, 0x0B, 0x60, 0x44, 0xAE, 0xF6, 0x56, 0xE6, 0x50, 0x66, 0x69, 0x84, 0x60, 0x84,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x29, 0x11, 0xAD, 0xCE, 0x12, 0xED, 0x14, 0x22, 0x3D, 0x8F, 0x23, 0xDC, 0x22, 0x34, 0x9D, 0x05, 0x44, 0x5D, 0xAE,
    0x39, 0, 18, 0xF6, 0x45, 0xF7, 0x75, 0x56, 0xE1, 0x47, 0x66, 0xA0, 0xF2, 0x88, 0x0B, 0x84, 0x88, 0xA2, 0xC3, 0x80, 0xC3,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x68, 0x98, 0x00, 0xCC, 0xFE, 0x11, 0x32, 0x95, 0x12, 0xEA, 0x3A, 0x23, 0xBD, 0x29, 0x33, 0x85, 0xD8,
    0x39, 0, 18, 0xF2, 0x44, 0x23, 0x9E, 0x55, 0x0A, 0x6C, 0x56, 0xC2, 0x0F, 0x77, 0x25, 0x9D, 0x77, 0xBB, 0xD8, 0x70, 0xD8,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xAF, 0xC2, 0x00, 0xD2, 0xE3, 0x01, 0xF7, 0x2B, 0x11, 0x64, 0x9B, 0x22, 0x04, 0x62, 0x23, 0xB7, 0x00,
    0x39, 0, 18, 0xF4, 0x33, 0x47, 0xBD, 0x44, 0x22, 0x7B, 0x45, 0xC9, 0x11, 0x66, 0x08, 0x76, 0x66, 0x8E, 0xA9, 0x60, 0xA9,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xCB, 0x11, 0xA7, 0xCA, 0x12, 0xEC, 0x14, 0x22, 0x3F, 0x94, 0x23, 0xE5, 0x2E, 0x34, 0xB0, 0x1A, 0x44, 0x76, 0xC8,
    0x39, 0, 18, 0xF6, 0x55, 0x13, 0x93, 0x66, 0x03, 0x69, 0x67, 0xC3, 0x14, 0x88, 0x35, 0xB3, 0x88, 0xD0, 0xF0, 0x80, 0xF0,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x61, 0x92, 0x00, 0xC0, 0xEE, 0x11, 0x1E, 0x7A, 0x12, 0xD1, 0x1D, 0x23, 0xA3, 0x13, 0x33, 0x76, 0xC8,
    0x39, 0, 18, 0xF2, 0x44, 0x12, 0x8E, 0x45, 0xFB, 0x5C, 0x56, 0xB2, 0x01, 0x77, 0x12, 0x84, 0x77, 0xA5, 0xC0, 0x70, 0xC0,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xC0, 0xD1, 0x00, 0xDF, 0xEF, 0x11, 0x00, 0x2B, 0x11, 0x5B, 0x8E, 0x12, 0xF0, 0x4C, 0x22, 0xA2, 0xF0,
    0x39, 0, 18, 0xF4, 0x33, 0x35, 0xAD, 0x44, 0x12, 0x6C, 0x45, 0xBA, 0x02, 0x56, 0xF6, 0x5F, 0x66, 0x7A, 0x94, 0x60, 0x94,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x5D, 0x11, 0xC7, 0xE6, 0x22, 0x06, 0x28, 0x22, 0x4E, 0x9C, 0x23, 0xE9, 0x31, 0x34, 0xAF, 0x17, 0x44, 0x72, 0xC1,
    0x39, 0, 18, 0xF6, 0x55, 0x0B, 0x89, 0x56, 0xF8, 0x5C, 0x67, 0xB6, 0x07, 0x88, 0x23, 0x9B, 0x88, 0xBA, 0xD8, 0x80, 0xD8,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x87, 0x00, 0xAD, 0xD0, 0x01, 0xF8, 0x48, 0x11, 0x99, 0xE7, 0x22, 0x7E, 0xF9, 0x33, 0x61, 0xBB,
    0x39, 0, 18, 0xF2, 0x44, 0x09, 0x8A, 0x45, 0xF7, 0x58, 0x56, 0xB2, 0x01, 0x77, 0x10, 0x84, 0x77, 0xA2, 0xBA, 0x70, 0xBA,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xDB, 0xF9, 0x11, 0x05, 0x11, 0x11, 0x1D, 0x39, 0x11, 0x5D, 0x86, 0x12, 0xDD, 0x3A, 0x22, 0x94, 0xE4,
    0x39, 0, 18, 0xF4, 0x33, 0x2B, 0xA7, 0x44, 0x0F, 0x68, 0x45, 0xB9, 0x00, 0x56, 0xF5, 0x5D, 0x66, 0x77, 0x8D, 0x60, 0x8D,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xBA, 0x22, 0x0A, 0x28, 0x22, 0x45, 0x63, 0x22, 0x80, 0xC3, 0x33, 0x06, 0x48, 0x34, 0xBF, 0x22, 0x44, 0x7A, 0xCB,
    0x39, 0, 18, 0xF6, 0x55, 0x12, 0x90, 0x56, 0xFF, 0x61, 0x67, 0xBC, 0x0C, 0x88, 0x23, 0x9A, 0x88, 0xB8, 0xD1, 0x80, 0xD1,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x27, 0x00, 0xBD, 0xDE, 0x01, 0xF8, 0x30, 0x11, 0x6C, 0xA6, 0x22, 0x2C, 0xBD, 0x33, 0x34, 0x98,
    0x39, 0, 18, 0xF2, 0x34, 0xEB, 0x76, 0x45, 0xEC, 0x50, 0x55, 0xAC, 0xFC, 0x77, 0x0C, 0x80, 0x77, 0x9E, 0xB5, 0x70, 0xB5,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0x02, 0x40, 0x11, 0x5C, 0x67, 0x11, 0x70, 0x83, 0x11, 0x97, 0xAF, 0x12, 0xE9, 0x38, 0x22, 0x8C, 0xD9,
    0x39, 0, 18, 0xF4, 0x33, 0x21, 0x9E, 0x44, 0x07, 0x62, 0x44, 0xB4, 0xFF, 0x56, 0xF1, 0x59, 0x66, 0x74, 0x8A, 0x60, 0x8A,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x10, 0x12, 0xEE, 0xCC, 0x22, 0xE1, 0xF9, 0x33, 0x10, 0x3D, 0x33, 0x6D, 0x9D, 0x34, 0xF9, 0x52, 0x44, 0xA3, 0xEE,
    0x39, 0, 18, 0xF6, 0x55, 0x2F, 0xA9, 0x66, 0x15, 0x74, 0x67, 0xCC, 0x1C, 0x88, 0x2B, 0xA0, 0x88, 0xBE, 0xD7, 0x80, 0xD7,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x28, 0xEB, 0x11, 0x02, 0x32, 0x11, 0x5D, 0x91, 0x12, 0xFB, 0x90, 0x33, 0x15, 0x86,
    0x39, 0, 18, 0xF2, 0x34, 0xE5, 0x7B, 0x45, 0xF6, 0x64, 0x56, 0xC2, 0x16, 0x77, 0x30, 0xA6, 0x77, 0xC2, 0xDC, 0x70, 0xDC,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x11, 0x9A, 0xA8, 0x11, 0xB7, 0xCA, 0x11, 0xDB, 0xEE, 0x22, 0x22, 0x62, 0x22, 0xAB, 0xF4,
    0x39, 0, 18, 0xF4, 0x33, 0x39, 0xB3, 0x44, 0x1D, 0x7A, 0x45, 0xCB, 0x17, 0x66, 0x13, 0x7D, 0x66, 0x95, 0xAD, 0x60, 0xAD,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x0D, 0x13, 0x27, 0x06, 0x33, 0x7F, 0x93, 0x33, 0xA3, 0xC9, 0x34, 0xEC, 0x10, 0x44, 0x5C, 0xA6, 0x45, 0xEB, 0x30,
    0x39, 0, 18, 0xF6, 0x55, 0x6F, 0xE6, 0x66, 0x4E, 0xAC, 0x77, 0x02, 0x51, 0x88, 0x61, 0xD6, 0x89, 0xF3, 0x0F, 0x90, 0x0F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x00, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x2A, 0xF9, 0x11, 0x14, 0x35, 0x11, 0x74, 0xB4, 0x22, 0x00, 0x5C,
    0x39, 0, 18, 0xF2, 0x23, 0xBB, 0x5D, 0x34, 0xE0, 0x49, 0x44, 0xA1, 0xF2, 0x56, 0xF2, 0x5C, 0x66, 0x74, 0x8C, 0x60, 0x8C,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0xB8, 0x11, 0xA1, 0xAE, 0x11, 0xBF, 0xCC, 0x11, 0xE1, 0xFC, 0x22, 0x1E, 0x49,
    0x39, 0, 18, 0xF4, 0x22, 0x78, 0xD7, 0x33, 0x35, 0x89, 0x34, 0xD2, 0x17, 0x45, 0xF6, 0x55, 0x55, 0x6B, 0x7F, 0x50, 0x7F,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x01, 0x2B, 0x41, 0x33, 0x68, 0x7F, 0x33, 0x82, 0x9A, 0x33, 0xB4, 0xCB, 0x34, 0xFA, 0x28, 0x44, 0x58, 0x8C,
    0x39, 0, 18, 0xF6, 0x45, 0xBB, 0x18, 0x55, 0x6C, 0xBC, 0x66, 0x04, 0x48, 0x77, 0x30, 0x94, 0x77, 0xAC, 0xC0, 0x70, 0xC0,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0xE4, 0x11, 0x37, 0x96, 0x12, 0xF5, 0x4D, 0x23, 0x9A, 0x20, 0x33, 0x8E, 0xEE, 0x45, 0x8C, 0x0D, 0x55, 0x7E, 0xE6,
    0x39, 0, 18, 0xF2, 0x66, 0x44, 0xF2, 0x78, 0x8A, 0x16, 0x89, 0x97, 0x19, 0xAB, 0xF7, 0xE5, 0xCC, 0x20, 0x62, 0xC0, 0x62,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0xF8, 0x11, 0x28, 0x57, 0x11, 0x8E, 0xC8, 0x22, 0x02, 0x71, 0x23, 0xD1, 0x28, 0x34, 0xBB, 0x32, 0x44, 0x99, 0xF5,
    0x39, 0, 18, 0xF4, 0x55, 0x4A, 0xE0, 0x66, 0x68, 0xE4, 0x77, 0x57, 0xC6, 0x9A, 0x5D, 0x23, 0xAA, 0x56, 0x8E, 0xA0, 0x8E,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0xF9, 0x22, 0x47, 0x96, 0x23, 0xEC, 0x3B, 0x34, 0x86, 0x09, 0x44, 0x76, 0xD6, 0x56, 0x7A, 0x03, 0x66, 0x7A, 0xE6,
    0x39, 0, 18, 0xF6, 0x77, 0x4A, 0xFF, 0x89, 0x9E, 0x33, 0x9A, 0xBE, 0x47, 0xCD, 0x4A, 0x55, 0xDD, 0x9B, 0xE0, 0xD0, 0xE0,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x4F, 0x11, 0x8D, 0xCF, 0x22, 0x1B, 0x66, 0x23, 0xAD, 0x29, 0x33, 0x92, 0xEE, 0x45, 0x86, 0x07, 0x55, 0x75, 0xDA,
    0x39, 0, 18, 0xF2, 0x66, 0x39, 0xE1, 0x77, 0x73, 0xF9, 0x88, 0x7A, 0xF3, 0xAB, 0xC0, 0xA4, 0xBC, 0xE0, 0x1B, 0xC0, 0x1B,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5F, 0x11, 0x82, 0xA2, 0x11, 0xC6, 0xF1, 0x22, 0x22, 0x81, 0x23, 0xDA, 0x2A, 0x34, 0xB4, 0x29, 0x44, 0x8C, 0xE6,
    0x39, 0, 18, 0xF4, 0x55, 0x39, 0xCD, 0x66, 0x50, 0xC8, 0x77, 0x3A, 0xA4, 0x99, 0x2B, 0xEB, 0xAA, 0x1C, 0x4B, 0xA0, 0x4B,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x43, 0x22, 0x83, 0xC4, 0x33, 0x0C, 0x51, 0x34, 0x96, 0x0F, 0x44, 0x78, 0xD4, 0x55, 0x74, 0xFA, 0x66, 0x6F, 0xD9,
    0x39, 0, 18, 0xF6, 0x77, 0x3B, 0xEA, 0x89, 0x84, 0x13, 0x9A, 0x9C, 0x1D, 0xCD, 0x0B, 0x0F, 0xDD, 0x56, 0x93, 0xD0, 0x93,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x01, 0x00, 0x48, 0x11, 0x87, 0xC5, 0x22, 0x09, 0x51, 0x23, 0x94, 0x0B, 0x33, 0x73, 0xCD, 0x44, 0x61, 0xDD, 0x55, 0x4C, 0xAF,
    0x39, 0, 18, 0xF2, 0x66, 0x09, 0xA9, 0x77, 0x3A, 0xBD, 0x88, 0x38, 0xA9, 0xAB, 0x5B, 0x31, 0xBB, 0x66, 0x94, 0xB0, 0x94,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x5E, 0x11, 0x80, 0x9C, 0x11, 0xBE, 0xE5, 0x22, 0x11, 0x6B, 0x23, 0xC0, 0x0C, 0x34, 0x92, 0x03, 0x44, 0x66, 0xBF,
    0x39, 0, 18, 0xF4, 0x55, 0x0F, 0x9E, 0x66, 0x1C, 0x91, 0x67, 0xFD, 0x62, 0x89, 0xD7, 0x8C, 0x99, 0xB8, 0xE3, 0x90, 0xE3,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x42, 0x22, 0x7D, 0xB9, 0x23, 0xFB, 0x3C, 0x33, 0x7E, 0xF3, 0x44, 0x59, 0xB3, 0x55, 0x4D, 0xD0, 0x66, 0x44, 0xAD,
    0x39, 0, 18, 0xF6, 0x77, 0x0A, 0xB2, 0x88, 0x48, 0xD2, 0x99, 0x54, 0xCF, 0xBC, 0x9E, 0x8B, 0xCC, 0xC8, 0xFE, 0xC0, 0xFE,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x59, 0x11, 0x76, 0xA2, 0x12, 0xD2, 0x07, 0x22, 0x3F, 0xA9, 0x33, 0x04, 0x56, 0x34, 0xDF, 0x53, 0x45, 0xB9, 0x10,
    0x39, 0, 18, 0xF2, 0x55, 0x62, 0xF5, 0x66, 0x76, 0xED, 0x77, 0x59, 0xBA, 0x99, 0x23, 0xCB, 0x9A, 0xF3, 0x23, 0xA0, 0x23,
    0x39, 0, 22, 0xF3, 0x01, 0x00, 0x4E, 0x11, 0x78, 0x8D, 0x11, 0xA3, 0xBC, 0x12, 0xDB, 0x1F, 0x22, 0x65, 0xA7, 0x33, 0x1E, 0x85, 0x34, 0xE2, 0x32,
    0x39, 0, 18, 0xF4, 0x44, 0x7A, 0xFE, 0x55, 0x71, 0xD6, 0x66, 0x36, 0x8F, 0x78, 0xCE, 0x5C, 0x88, 0x81, 0xA4, 0x80, 0xA4,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x37, 0x22, 0x6C, 0x97, 0x22, 0xC5, 0xF8, 0x33, 0x2E, 0x91, 0x34, 0xEC, 0x3D, 0x45, 0xC6, 0x3E, 0x56, 0xAA, 0x06,
    0x39, 0, 18, 0xF6, 0x66, 0x5B, 0xF5, 0x77, 0x7B, 0xF6, 0x88, 0x66, 0xCF, 0xAB, 0x50, 0x04, 0xBB, 0x32, 0x5A, 0xB0, 0x5A,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x61, 0x7E, 0x11, 0x9E, 0xC3, 0x12, 0xEA, 0x3A, 0x22, 0x88, 0xD0, 0x33, 0x4E, 0xBA, 0x44, 0x16, 0x66,
    0x39, 0, 18, 0xF2, 0x45, 0xB1, 0x33, 0x56, 0xA4, 0x0B, 0x66, 0x6A, 0xBF, 0x78, 0xF4, 0x7A, 0x88, 0x9A, 0xB9, 0x80, 0xB9,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x6B, 0x7E, 0x11, 0x8E, 0x9F, 0x11, 0xB0, 0xDA, 0x22, 0x0A, 0x3D, 0x22, 0xA0, 0xFA, 0x33, 0x4C, 0x96,
    0x39, 0, 18, 0xF4, 0x34, 0xD9, 0x50, 0x45, 0xB6, 0x11, 0x55, 0x65, 0xB4, 0x67, 0xC3, 0x3B, 0x77, 0x58, 0x74, 0x70, 0x74,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x32, 0x22, 0x61, 0x80, 0x22, 0x9F, 0xC2, 0x23, 0xE5, 0x32, 0x33, 0x7B, 0xC3, 0x44, 0x3C, 0xA5, 0x55, 0x03, 0x56,
    0x39, 0, 18, 0xF6, 0x56, 0xA3, 0x2C, 0x67, 0xA2, 0x0D, 0x77, 0x72, 0xCF, 0x99, 0x0F, 0x9E, 0x99, 0xC1, 0xE1, 0x90, 0xE1,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x42, 0x65, 0x11, 0x82, 0xA1, 0x12, 0xC2, 0x07, 0x22, 0x50, 0x97, 0x33, 0x14, 0x7E, 0x34, 0xDA, 0x2A,
    0x39, 0, 18, 0xF2, 0x44, 0x71, 0xED, 0x55, 0x5C, 0xBB, 0x66, 0x16, 0x69, 0x78, 0x8B, 0x03, 0x88, 0x26, 0x39, 0x80, 0x39,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0x7F, 0x90, 0x11, 0x9D, 0xAA, 0x11, 0xB7, 0xD5, 0x12, 0xF7, 0x20, 0x22, 0x78, 0xCC, 0x33, 0x18, 0x60,
    0x39, 0, 18, 0xF4, 0x34, 0xA0, 0x11, 0x44, 0x74, 0xCB, 0x55, 0x1A, 0x64, 0x66, 0x5F, 0xD2, 0x67, 0xEC, 0x06, 0x70, 0x06,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x49, 0x22, 0x7C, 0x97, 0x22, 0xB3, 0xCD, 0x23, 0xE9, 0x26, 0x33, 0x64, 0xA1, 0x44, 0x11, 0x75, 0x45, 0xCA, 0x1B,
    0x39, 0, 18, 0xF6, 0x55, 0x64, 0xE4, 0x66, 0x58, 0xBD, 0x77, 0x1B, 0x70, 0x89, 0x9A, 0x1E, 0x99, 0x3D, 0x5D, 0x90, 0x5D,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x11, 0x97, 0xBB, 0x12, 0xDD, 0x03, 0x22, 0x2E, 0x87, 0x23, 0xDA, 0x2B, 0x34, 0xB6, 0x23, 0x44, 0x83, 0xD9,
    0x39, 0, 18, 0xF2, 0x55, 0x29, 0xAD, 0x66, 0x2B, 0x97, 0x67, 0xFB, 0x58, 0x89, 0x9A, 0x2C, 0x99, 0x4E, 0x76, 0x90, 0x76,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x11, 0xE5, 0xF8, 0x22, 0x08, 0x17, 0x22, 0x28, 0x50, 0x22, 0x7B, 0xAC, 0x33, 0x0F, 0x6B, 0x34, 0xBF, 0x09,
    0x39, 0, 18, 0xF4, 0x44, 0x4E, 0xC5, 0x55, 0x31, 0x90, 0x56, 0xEA, 0x3C, 0x77, 0x59, 0xD6, 0x78, 0xF3, 0x11, 0x80, 0x11,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x0E, 0x23, 0xF8, 0x15, 0x33, 0x35, 0x54, 0x33, 0x75, 0xB9, 0x34, 0xFB, 0x3E, 0x45, 0xB8, 0x21, 0x55, 0x80, 0xD7,
    0x39, 0, 18, 0xF6, 0x66, 0x29, 0xB5, 0x77, 0x33, 0xA4, 0x88, 0x0B, 0x6A, 0x9A, 0xC0, 0x5C, 0xAA, 0x81, 0xA4, 0xA0, 0xA4,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x22, 0x25, 0x55, 0x22, 0x75, 0x93, 0x23, 0xB9, 0x06, 0x33, 0x52, 0x99, 0x44, 0x1D, 0x93, 0x45, 0xF4, 0x4A,
    0x39, 0, 18, 0xF2, 0x56, 0x99, 0x2A, 0x67, 0xA9, 0x1A, 0x77, 0x85, 0xE8, 0x99, 0x41, 0xDF, 0xAA, 0x05, 0x27, 0xA0, 0x27,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x22, 0xB8, 0xD1, 0x22, 0xE2, 0xEF, 0x23, 0xFB, 0x15, 0x33, 0x35, 0x58, 0x33, 0xA4, 0xF3, 0x44, 0x3F, 0x87,
    0x39, 0, 18, 0xF4, 0x45, 0xC8, 0x41, 0x56, 0xAC, 0x0D, 0x66, 0x6B, 0xC0, 0x78, 0xEB, 0x6E, 0x88, 0x8E, 0xAD, 0x80, 0xAD,
    0x39, 0, 22, 0xF5, 0x02, 0x00, 0x2C, 0x33, 0xEB, 0xFF, 0x44, 0x15, 0x2A, 0x44, 0x43, 0x77, 0x44, 0xAC, 0xE0, 0x55, 0x4A, 0xB2, 0x66, 0x0D, 0x63,
    0x39, 0, 18, 0xF6, 0x67, 0xB0, 0x40, 0x78, 0xC1, 0x33, 0x89, 0xA0, 0x08, 0xAB, 0x77, 0x20, 0xBB, 0x49, 0x6F, 0xB0, 0x6F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x16, 0x22, 0xC7, 0xDD, 0x23, 0xF0, 0x18, 0x33, 0x3F, 0x6E, 0x34, 0xC3, 0x16, 0x44, 0x64, 0xAD,
    0x39, 0, 18, 0xF2, 0x45, 0xF3, 0x73, 0x56, 0xDF, 0x3F, 0x66, 0x99, 0xEE, 0x88, 0x12, 0x91, 0x88, 0xB0, 0xC8, 0x80, 0xC8,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x03, 0x02, 0x54, 0x33, 0x6C, 0x79, 0x33, 0x83, 0x90, 0x33, 0xA0, 0xAF, 0x33, 0xCD, 0xF0, 0x44, 0x17, 0x41,
    0x39, 0, 18, 0xF4, 0x44, 0x6B, 0xC2, 0x55, 0x18, 0x67, 0x55, 0xB1, 0xF7, 0x67, 0xEE, 0x5C, 0x77, 0x76, 0x8E, 0x70, 0x8E,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x63, 0x34, 0x9F, 0x96, 0x44, 0xA7, 0xB4, 0x44, 0xBC, 0xD5, 0x45, 0xED, 0x08, 0x55, 0x44, 0x7E, 0x55, 0xB9, 0xF7,
    0x39, 0, 18, 0xF6, 0x66, 0x33, 0xA6, 0x77, 0x0C, 0x6A, 0x78, 0xC2, 0x16, 0x99, 0x40, 0xC6, 0x9A, 0xE6, 0x03, 0xA0, 0x03,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x01, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x0F, 0x55, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xA4,
    0x39, 0, 18, 0xF2, 0x34, 0xBC, 0x0C, 0x44, 0x56, 0x9D, 0x45, 0xE1, 0x25, 0x56, 0xF9, 0x54, 0x66, 0x6A, 0x7C, 0x60, 0x7C,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x07, 0x04, 0xB0, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF3, 0xFA, 0xCD,
    0x39, 0, 18, 0xF4, 0x33, 0xC9, 0xEA, 0x44, 0x11, 0x37, 0x44, 0x5F, 0x89, 0x55, 0x2E, 0x78, 0x55, 0x8A, 0x9B, 0x50, 0x9B,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xDC, 0x37, 0x0F, 0xD5, 0xEF, 0xB7, 0xFD, 0xFF, 0xFB, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xF5, 0xFA, 0x36,
    0x39, 0, 18, 0xF6, 0x55, 0x3E, 0x76, 0x55, 0xB0, 0xEA, 0x66, 0x23, 0x5F, 0x77, 0x27, 0x7F, 0x77, 0x94, 0xA7, 0x70, 0xA7,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x44, 0x98, 0x01, 0xF7, 0x4C, 0x12, 0x9C, 0x1E, 0x22, 0x98, 0xFD, 0x34, 0xAC, 0x2E, 0x45, 0xA7, 0x15,
    0x39, 0, 18, 0xF2, 0x56, 0x78, 0x28, 0x67, 0xCA, 0x5D, 0x78, 0xEB, 0x74, 0xAB, 0x76, 0x71, 0xBB, 0xB3, 0xF3, 0xB0, 0xF3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x2F, 0x58, 0x00, 0x8F, 0xC8, 0x11, 0x03, 0x6A, 0x12, 0xCF, 0x29, 0x23, 0xC8, 0x42, 0x34, 0xB5, 0x16,
    0x39, 0, 18, 0xF4, 0x45, 0x6F, 0x0D, 0x56, 0x98, 0x1A, 0x67, 0x95, 0x0A, 0x89, 0xBA, 0x92, 0x9A, 0xC9, 0x03, 0xA0, 0x03,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x17, 0x11, 0x61, 0xA5, 0x12, 0xF3, 0x44, 0x23, 0x92, 0x18, 0x33, 0x91, 0xF5, 0x45, 0x9F, 0x2D, 0x56, 0xAB, 0x1B,
    0x39, 0, 18, 0xF6, 0x67, 0x85, 0x40, 0x78, 0xEB, 0x88, 0x99, 0x1E, 0xAF, 0xBC, 0xD5, 0xF3, 0xDD, 0x3E, 0x81, 0xD0, 0x81,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x66, 0x00, 0xA0, 0xD4, 0x11, 0x13, 0x57, 0x12, 0x98, 0x0F, 0x22, 0x80, 0xDA, 0x33, 0x7C, 0xFD, 0x44, 0x70, 0xD7,
    0x39, 0, 18, 0xF2, 0x55, 0x35, 0xDB, 0x67, 0x75, 0x00, 0x77, 0x88, 0xFB, 0x9A, 0xCE, 0xB1, 0xAB, 0xE6, 0x1E, 0xB0, 0x1E,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x6A, 0x00, 0x8F, 0xA9, 0x00, 0xC9, 0xEC, 0x11, 0x14, 0x6B, 0x12, 0xC5, 0x0B, 0x23, 0x9C, 0x10, 0x33, 0x7B, 0xDC,
    0x39, 0, 18, 0xF4, 0x44, 0x2E, 0xC1, 0x55, 0x49, 0xC3, 0x66, 0x35, 0xA1, 0x88, 0x2C, 0xEC, 0x99, 0x17, 0x4C, 0x90, 0x4C,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x65, 0x11, 0x9B, 0xCF, 0x22, 0x0A, 0x4A, 0x23, 0x8D, 0x07, 0x33, 0x77, 0xD0, 0x44, 0x70, 0xF6, 0x55, 0x70, 0xDD,
    0x39, 0, 18, 0xF6, 0x66, 0x3E, 0xF0, 0x78, 0x94, 0x26, 0x89, 0xAF, 0x31, 0xBC, 0x1E, 0x18, 0xCC, 0x57, 0x98, 0xC0, 0x98,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x07, 0x00, 0x8F, 0xAE, 0x01, 0xD9, 0x0B, 0x11, 0x38, 0x99, 0x12, 0xF2, 0x45, 0x23, 0xD6, 0x4F, 0x34, 0xB8, 0x12,
    0x39, 0, 18, 0xF2, 0x44, 0x64, 0xF9, 0x55, 0x7C, 0xF4, 0x66, 0x63, 0xCA, 0x88, 0x3C, 0xE8, 0x99, 0x11, 0x3B, 0x90, 0x3B,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x57, 0x00, 0x87, 0x97, 0x00, 0xAE, 0xC4, 0x01, 0xDB, 0x18, 0x11, 0x58, 0x95, 0x22, 0x0A, 0x76, 0x23, 0xD1, 0x27,
    0x39, 0, 18, 0xF4, 0x33, 0x70, 0xFA, 0x44, 0x72, 0xD7, 0x55, 0x3A, 0x94, 0x67, 0xD4, 0x6A, 0x77, 0x8E, 0xB6, 0x70, 0xB6,
    0x39, 0, 22, 0xF5, 0x01, 0x00, 0x5A, 0x11, 0x89, 0xAB, 0x12, 0xD5, 0x01, 0x22, 0x2C, 0x8E, 0x23, 0xE9, 0x3C, 0x34, 0xCC, 0x43, 0x45, 0xAD, 0x0E,
    0x39, 0, 18, 0xF6, 0x56, 0x63, 0x00, 0x67, 0x8A, 0x09, 0x77, 0x7D, 0xE8, 0x9A, 0x74, 0x2B, 0xAA, 0x56, 0x84, 0xA0, 0x84,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x74, 0x8D, 0x00, 0xA1, 0xB3, 0x00, 0xC9, 0xFC, 0x11, 0x39, 0x6D, 0x12, 0xD9, 0x3A, 0x22, 0x90, 0xE0,
    0x39, 0, 18, 0xF2, 0x33, 0x2A, 0xA6, 0x44, 0x0F, 0x6D, 0x45, 0xC3, 0x15, 0x66, 0x30, 0xA4, 0x66, 0xC7, 0xE3, 0x60, 0xE3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x72, 0x84, 0x00, 0x90, 0x9A, 0x00, 0xA4, 0xBC, 0x00, 0xDA, 0xFA, 0x11, 0x42, 0x8E, 0x12, 0xCD, 0x13,
    0x39, 0, 18, 0xF4, 0x22, 0x54, 0xC2, 0x33, 0x1F, 0x79, 0x34, 0xC7, 0x11, 0x55, 0x0B, 0x74, 0x55, 0x8F, 0xA9, 0x50, 0xA9,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xBF, 0x11, 0x6F, 0x87, 0x11, 0x9D, 0xB0, 0x11, 0xC4, 0xF5, 0x22, 0x2D, 0x61, 0x23, 0xCF, 0x30, 0x33, 0x86, 0xD6,
    0x39, 0, 18, 0xF6, 0x44, 0x1C, 0x99, 0x55, 0x08, 0x6D, 0x56, 0xC8, 0x1C, 0x77, 0x46, 0xC8, 0x78, 0xEA, 0x09, 0x80, 0x09,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x04, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x60, 0x7C, 0x00, 0x92, 0xA8, 0x00, 0xC2, 0xFC, 0x11, 0x36, 0x70, 0x12, 0xE0, 0x43, 0x22, 0xA0, 0xEC,
    0x39, 0, 18, 0xF2, 0x33, 0x3C, 0xBD, 0x44, 0x29, 0x8B, 0x45, 0xE0, 0x34, 0x66, 0x52, 0xD2, 0x67, 0xF2, 0x12, 0x70, 0x12,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x6B, 0x7F, 0x00, 0x8A, 0x94, 0x00, 0xA2, 0xBD, 0x00, 0xD7, 0xFB, 0x11, 0x45, 0x91, 0x12, 0xDD, 0x19,
    0x39, 0, 18, 0xF4, 0x22, 0x61, 0xD4, 0x33, 0x3C, 0x94, 0x34, 0xE2, 0x2C, 0x55, 0x2A, 0x96, 0x55, 0xB3, 0xCD, 0x50, 0xCD,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x73, 0x11, 0x73, 0x8D, 0x11, 0xA1, 0xB6, 0x11, 0xCC, 0xFE, 0x22, 0x34, 0x6E, 0x23, 0xDE, 0x44, 0x33, 0xA1, 0xEE,
    0x39, 0, 18, 0xF6, 0x44, 0x38, 0xB8, 0x55, 0x2C, 0x91, 0x56, 0xEA, 0x44, 0x77, 0x73, 0xF7, 0x88, 0x17, 0x35, 0x80, 0x35,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x05, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x7E, 0x99, 0x00, 0xAB, 0xBD, 0x01, 0xD1, 0x02, 0x11, 0x33, 0x69, 0x12, 0xCC, 0x30, 0x22, 0x8C, 0xDB,
    0x39, 0, 18, 0xF2, 0x33, 0x24, 0xA5, 0x44, 0x11, 0x71, 0x45, 0xC9, 0x18, 0x66, 0x31, 0xAD, 0x66, 0xCF, 0xEC, 0x60, 0xEC,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x8F, 0x9F, 0x00, 0xAD, 0xB4, 0x00, 0xC1, 0xD5, 0x01, 0xEF, 0x07, 0x11, 0x46, 0x8A, 0x12, 0xD2, 0x0A,
    0x39, 0, 18, 0xF4, 0x22, 0x50, 0xC1, 0x33, 0x24, 0x7F, 0x34, 0xCC, 0x14, 0x55, 0x0C, 0x76, 0x55, 0x8F, 0xAC, 0x50, 0xAC,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x0C, 0x11, 0xA1, 0xB8, 0x11, 0xCE, 0xDD, 0x12, 0xF1, 0x1F, 0x22, 0x51, 0x81, 0x23, 0xE3, 0x41, 0x33, 0x9A, 0xE5,
    0x39, 0, 18, 0xF6, 0x44, 0x28, 0xA6, 0x55, 0x17, 0x7A, 0x56, 0xD4, 0x26, 0x77, 0x4F, 0xD0, 0x78, 0xF3, 0x0F, 0x80, 0x0F,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x06, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x22, 0xA7, 0x00, 0xBA, 0xCD, 0x01, 0xDE, 0x06, 0x11, 0x2E, 0x61, 0x12, 0xC6, 0x28, 0x22, 0x87, 0xDA,
    0x39, 0, 18, 0xF2, 0x33, 0x25, 0xA4, 0x44, 0x0C, 0x70, 0x45, 0xC7, 0x18, 0x66, 0x2F, 0xA7, 0x66, 0xC4, 0xE0, 0x60, 0xE0,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0xC7, 0xE4, 0x00, 0xEF, 0xFB, 0x11, 0x03, 0x13, 0x11, 0x25, 0x3B, 0x11, 0x6D, 0xA5, 0x12, 0xE5, 0x22,
    0x39, 0, 18, 0xF4, 0x22, 0x5D, 0xC9, 0x33, 0x27, 0x81, 0x34, 0xCE, 0x16, 0x55, 0x0B, 0x73, 0x55, 0x8D, 0xA7, 0x50, 0xA7,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x63, 0x12, 0xF7, 0x15, 0x22, 0x29, 0x3C, 0x22, 0x52, 0x72, 0x22, 0x94, 0xBF, 0x33, 0x11, 0x63, 0x33, 0xB4, 0xFD,
    0x39, 0, 18, 0xF6, 0x44, 0x3A, 0xB4, 0x55, 0x1C, 0x80, 0x56, 0xD8, 0x2B, 0x77, 0x4E, 0xCC, 0x78, 0xEA, 0x0B, 0x80, 0x0B,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x07, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0xB4, 0x11, 0x36, 0x47, 0x11, 0x55, 0x71, 0x11, 0x90, 0xAE, 0x12, 0xF3, 0x4F, 0x22, 0x9C, 0xE9,
    0x39, 0, 18, 0xF2, 0x33, 0x28, 0xAE, 0x44, 0x20, 0x7C, 0x45, 0xCF, 0x20, 0x66, 0x2A, 0xA7, 0x66, 0xC4, 0xE1, 0x60, 0xE1,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x01, 0x02, 0x8E, 0x11, 0xA2, 0xAF, 0x11, 0xBA, 0xCB, 0x11, 0xD8, 0xE6, 0x22, 0x04, 0x26, 0x22, 0x4C, 0x7A,
    0x39, 0, 18, 0xF4, 0x23, 0x9D, 0x01, 0x33, 0x54, 0x9E, 0x34, 0xE8, 0x2E, 0x55, 0x11, 0x7B, 0x55, 0x95, 0xAC, 0x50, 0xAC,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x22, 0xE1, 0xFB, 0x33, 0x0B, 0x1A, 0x33, 0x27, 0x40, 0x33, 0x5B, 0x75, 0x33, 0xA4, 0xDE, 0x44, 0x14, 0x4F,
    0x39, 0, 18, 0xF6, 0x44, 0x7F, 0xED, 0x55, 0x54, 0xAB, 0x56, 0xFB, 0x4C, 0x77, 0x58, 0xD8, 0x78, 0xF7, 0x16, 0x80, 0x16,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x08, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x1F, 0xEA, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xFB, 0x33, 0x24, 0x20,
    0x39, 0, 18, 0xF2, 0x33, 0x5F, 0xD6, 0x44, 0x3F, 0xA3, 0x45, 0xF7, 0x4A, 0x66, 0x5D, 0xD4, 0x67, 0xF4, 0x05, 0x70, 0x05,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0xFF, 0xFA, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xFB, 0x32, 0x13, 0xFB,
    0x39, 0, 18, 0xF4, 0x33, 0x17, 0x5C, 0x33, 0xA6, 0xEA, 0x44, 0x29, 0x69, 0x55, 0x4A, 0xAD, 0x55, 0xC8, 0xD8, 0x50, 0xD8,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x5F, 0x83, 0xFD, 0xFF, 0xFA, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xF9, 0xFF, 0xF9, 0xFB, 0x44, 0xF3, 0xCA,
    0x39, 0, 18, 0xF6, 0x45, 0xF7, 0x52, 0x55, 0xAA, 0xFE, 0x66, 0x4B, 0x99, 0x78, 0xA6, 0x1B, 0x88, 0x3A, 0x4C, 0x80, 0x4C,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x09, 0x02, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x11, 0x09, 0xB3, 0x11, 0xC9, 0xDC, 0x22, 0x01, 0x24, 0x22, 0x51, 0x7A,
    0x39, 0, 18, 0xF2, 0x23, 0xAD, 0x08, 0x33, 0x61, 0xAD, 0x34, 0xF0, 0x3F, 0x55, 0x2C, 0x8F, 0x55, 0xA9, 0xBD, 0x50, 0xBD,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0xD0, 0x22, 0x4E, 0x62, 0x22, 0x72, 0x7F, 0x22, 0x8C, 0x9E, 0x22, 0xAB, 0xBB,
    0x39, 0, 18, 0xF4, 0x22, 0xCC, 0xEF, 0x33, 0x15, 0x44, 0x33, 0x6B, 0xA3, 0x44, 0x51, 0xA1, 0x44, 0xBA, 0xC3, 0x40, 0xC3,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x0C, 0x02, 0x15, 0x9C, 0x33, 0xB7, 0xC5, 0x33, 0xD4, 0xE4, 0x33, 0xF0, 0xFF, 0x44, 0x17, 0x31, 0x44, 0x4C, 0x64,
    0x39, 0, 18, 0xF6, 0x44, 0x80, 0xB9, 0x45, 0xF6, 0x33, 0x55, 0x68, 0xA8, 0x66, 0x7C, 0xDB, 0x67, 0xF6, 0x07, 0x70, 0x07,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x00, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x4C, 0x77, 0x00, 0x9F, 0xD2, 0x01, 0xFE, 0x69, 0x12, 0xC3, 0x1F, 0x23, 0xB7, 0x39, 0x34, 0xA8, 0x08,
    0x39, 0, 18, 0xF2, 0x44, 0x5E, 0xF1, 0x55, 0x72, 0xDE, 0x66, 0x45, 0xA5, 0x78, 0xE8, 0x72, 0x88, 0x8D, 0xB0, 0x80, 0xB0,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x83, 0x8C, 0x00, 0x9B, 0xAD, 0x00, 0xB8, 0xEE, 0x11, 0x23, 0x63, 0x12, 0xD0, 0x41, 0x23, 0xA6, 0x06,
    0x39, 0, 18, 0xF4, 0x33, 0x54, 0xDB, 0x44, 0x48, 0xBB, 0x55, 0x0F, 0x69, 0x67, 0x89, 0x0A, 0x77, 0x2B, 0x45, 0x70, 0x45,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0xD8, 0x11, 0x59, 0x7C, 0x11, 0xA4, 0xDA, 0x22, 0x0C, 0x7A, 0x23, 0xD9, 0x39, 0x34, 0xCB, 0x4E, 0x45, 0xBE, 0x23,
    0x39, 0, 18, 0xF6, 0x56, 0x7D, 0x12, 0x67, 0x9B, 0x0D, 0x77, 0x7D, 0xDA, 0x99, 0x29, 0xB9, 0x99, 0xDC, 0xFD, 0x90, 0xFD,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x01, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x39, 0x65, 0x00, 0x82, 0xB0, 0x01, 0xCF, 0x21, 0x11, 0x7A, 0xBF, 0x22, 0x48, 0xBF, 0x33, 0x2A, 0x82,
    0x39, 0, 18, 0xF2, 0x34, 0xDB, 0x67, 0x45, 0xD9, 0x43, 0x56, 0xA8, 0x01, 0x77, 0x26, 0xA6, 0x77, 0xC0, 0xE1, 0x70, 0xE1,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x7F, 0x88, 0x00, 0x92, 0x9D, 0x00, 0xAD, 0xC9, 0x01, 0xF3, 0x23, 0x11, 0x7C, 0xD9, 0x22, 0x31, 0x82,
    0x39, 0, 18, 0xF4, 0x23, 0xDC, 0x5D, 0x34, 0xC4, 0x2A, 0x44, 0x7E, 0xD2, 0x56, 0xDD, 0x4E, 0x66, 0x70, 0x85, 0x60, 0x85,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x1B, 0x11, 0x51, 0x73, 0x11, 0x8D, 0xB8, 0x12, 0xD7, 0x2F, 0x22, 0x88, 0xD7, 0x33, 0x66, 0xD4, 0x44, 0x42, 0x99,
    0x39, 0, 18, 0xF6, 0x45, 0xF7, 0x82, 0x66, 0x01, 0x72, 0x67, 0xD2, 0x33, 0x88, 0x60, 0xE2, 0x99, 0x01, 0x20, 0x90, 0x20,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x02, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x15, 0x09, 0x00, 0x25, 0x47, 0x00, 0x56, 0x6A, 0x00, 0x85, 0xA7, 0x00, 0xC9, 0xF7,
    0x39, 0, 18, 0xF2, 0x11, 0x1C, 0x64, 0x11, 0xA8, 0xEA, 0x22, 0x2F, 0x6F, 0x33, 0x3A, 0x89, 0x33, 0x94, 0xB3, 0x30, 0xB3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x32, 0x00, 0x74, 0x83, 0x00, 0x85, 0x87, 0x00, 0x94, 0x9D, 0x00, 0xAC, 0xB8,
    0x39, 0, 18, 0xF4, 0x00, 0xCA, 0xE5, 0x11, 0x0F, 0x3E, 0x11, 0x71, 0xA4, 0x22, 0x42, 0x93, 0x22, 0x8E, 0xB6, 0x20, 0xB6,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x00, 0x02, 0x46, 0x11, 0x32, 0x3F, 0x11, 0x43, 0x53, 0x11, 0x64, 0x76, 0x11, 0x8C, 0xAF, 0x11, 0xD5, 0xFF,
    0x39, 0, 18, 0xF6, 0x22, 0x21, 0x71, 0x23, 0xC0, 0x00, 0x33, 0x43, 0x82, 0x44, 0x4F, 0xA5, 0x44, 0xAD, 0xC6, 0x40, 0xC6,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 5, 0xFE, 0x01, 0x03, 0x04, 0x00,
    0x39, 0, 22, 0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x17, 0x00, 0x18, 0x2B, 0x00, 0x40, 0x4E, 0x00, 0x64, 0x7B, 0x00, 0x94, 0xAF,
    0x39, 0, 18, 0xF2, 0x00, 0xC9, 0xFC, 0x11, 0x32, 0x6C, 0x11, 0x97, 0xCF, 0x22, 0x7F, 0xCD, 0x22, 0xE0, 0xF3, 0x20, 0xF3,
    0x39, 0, 22, 0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x73, 0x00, 0x7E, 0x81, 0x00, 0x87, 0x8F, 0x00, 0x98, 0x9F,
    0x39, 0, 18, 0xF4, 0x00, 0xAC, 0xBE, 0x00, 0xD3, 0xF4, 0x11, 0x06, 0x29, 0x11, 0xA8, 0xEC, 0x11, 0xF7, 0xFF, 0x10, 0xFF,
    0x39, 0, 22, 0xF5, 0x00, 0x00, 0x01, 0x00, 0x02, 0x10, 0x01, 0x57, 0x2F, 0x11, 0x3D, 0x43, 0x11, 0x51, 0x5D, 0x11, 0x73, 0x83, 0x11, 0x9E, 0xB8,
    0x39, 0, 18, 0xF6, 0x12, 0xD4, 0x06, 0x22, 0x3E, 0x7D, 0x22, 0xAB, 0xE4, 0x33, 0x97, 0xE9, 0x34, 0xFB, 0x06, 0x40, 0x06,
    0x39, 0, 2, 0xFF, 0x01,

    0x39, 0, 2, 0x9F, 0x05,
    0x39, 0, 2, 0xF9, 0x00,
    0x39, 0, 2, 0xF7, 0x00,
    0x39, 0, 2, 0x9F, 0x02,
    0x39, 0, 8, 0xC3, 0x11, 0xC0, 0x05, 0xC0, 0x00, 0x00, 0x7F,
    0x39, 0, 2, 0x9F, 0x04,
    0x39, 0, 3, 0xBA, 0x10, 0x00,
    0x39, 0, 2, 0x9F, 0x0A,
    0x39, 0, 2, 0xB2, 0x1B,
    0x39, 0, 19, 0xB7, 0x13, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0x20, 0x20, 0x21,
    0x39, 0, 2, 0x9F, 0x0A,
    0x39, 0, 2, 0xB2, 0x1B,
    0x39, 0, 46, 0xB8, 0x07, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x06, 0x0A, 0x00, 0x06, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 43, 0xB9, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x40, 0x00, 0x00, 0x4C, 0x0C, 0x00, 0x00, 0x04, 0x04, 0x00, 0x0C, 0x0C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 43, 0xBA, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x0D, 0x03, 0x00, 0x0D, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x39, 0, 2, 0x9F, 0x00,
    0x39, 0, 2, 0x48, 0x03,
//	0x39,0,2,0x48,0x33,  // video mode
    0x39, 0, 3, 0x51, 0x00, 0x00,
    0x39, 0, 2, 0x53, 0xE0,
    0x39, 0, 2, 0x35, 0x00,

//    0x39, 0, 3, 0x51, 0x03,0x00,//0x05, 0xDD,
//	0x39,0,1,0x29,
//	delayMs(20);
//	delayMs(20);
#endif
};

#endif

static void init_panel(void)
{
    /* reset panel*/
    tx_panel_reset();

    hal_gpio_init_output(IO_PAD_TD_LEDPWM, IO_LVL_LOW);

    /* enter send initial code mode*/
    hal_dsi_tx_ctrl_enter_init_panel_mode();

    send_panel_init_code(sizeof(panel_init_code), panel_init_code);
    TAU_LOGD("init_code\n");
    hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x11);
//	delayMs(10);
//    delayMs(40);
    hal_gpio_set_output_data(IO_PAD_PWMEN, IO_LVL_HIGH); //LED_ON
    delayMs(60);
    //  hal_gpio_set_output_data(IO_PAD_ADCIN, IO_LVL_HIGH);
    soft_swire_init();
    // bist mode
//	hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x9C,0xA5,0xA5);
//	hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0xFD,0x5A,0x5A);
//	hal_dsi_tx_ctrl_write_cmd(0x39, 0, 2, 0x9F,0x01);
//	hal_dsi_tx_ctrl_write_cmd(0x39, 0, 2, 0xC6,0x01);

//	hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x29);
//	hal_dsi_tx_ctrl_write_cmd(0x29, 0, 3, 0x51, 0x09, 0xFF);
//	delayMs(10);

    /* exit send initial code mode*/
    hal_dsi_tx_ctrl_exit_init_panel_mode();
//    delayMs(10);
}

//static void frame_start_cb(hal_rx_dbg_event_e event)
//{
//    TAU_LOGD("frame start\n");
//}

static void open_mipi_rx(void)
{
    /* 配置TE引脚 */
    hal_gpio_set_mode(IO_PAD_AP_TE, IO_MODE_TEAR);

    if(g_rx_ctrl_handle == NULL)
    {
        /* 创建rx   ctrl handle */
        g_rx_ctrl_handle = hal_dsi_rx_ctrl_create_handle();
    }
    /* 配置参数 */
    g_rx_ctrl_handle->base_info.src_w = INPUT_WIDTH;
    g_rx_ctrl_handle->base_info.src_h = INPUT_HEIGHT;
    g_rx_ctrl_handle->base_info.dst_w = OUTPUT_WIDTH;
    g_rx_ctrl_handle->base_info.dst_h = OUTPUT_HEIGHT;
    g_rx_ctrl_handle->base_info.src_frate = INPUT_FRAME_RATE;
    g_rx_ctrl_handle->base_info.src_mode = INPUT_DATA_MODE;
    g_rx_ctrl_handle->rx_color_mode = INPUT_COLOR_MODE;
    g_rx_ctrl_handle->rx_lanes = INPUT_MIPI_LANE_NUM;
    g_rx_ctrl_handle->rx_nonburst_models = INPUT_VIDEO_MODEL; /* 可不配置 */
    g_rx_ctrl_handle->rx_vc = INPUT_VC;
    g_rx_ctrl_handle->compress_en = INPUT_COMPRESS;
    g_rx_ctrl_handle->rx_hsclk_rate = INPUT_MIPI_LANE_RATE;
    g_rx_ctrl_handle->cus_dcs_entry_table = g_cus_rx_dcs_execute_table; /* 注册 DCS处理列表 */
    g_rx_ctrl_handle->rx_dcs_read_entry = ap_dcs_read; /* 注册dsc read 回调函数,可选,此函数为空时由cus_dcs_entry_table执行 */
    g_rx_ctrl_handle->pps_update_entry = pps_update_handle;
    g_rx_ctrl_handle->hight_performan_mode = HIGHT_PERFORMAN_L2;

	  g_rx_ctrl_handle->pu_optimize = true;
	  g_rx_ctrl_handle->base_info.extra_info.ltpo = LTPO_MODE_2;  /// true
//    g_rx_ctrl_handle->pq_marginal = PQ_TYPE_6;
//	g_rx_ctrl_handle->err_handler_level = ERR_HANDLE_L1;
//	  g_rx_ctrl_handle->rx_debug_cb = frame_start_cb;
    /* 提前预置PPS,  AP 有PPS cmd也会更新 */
    if(g_rx_ctrl_handle->compress_en == true)
    {
        uint8_t pps[128 ] =
        {
            0x11, 0x00, 0x00, 0x89, 0x30, 0x80, 0x09, 0x60, 0x04, 0x38, 0x00, 0x78, 0x02,
            0x1C, 0x02, 0x1C, 0x02, 0x00, 0x02, 0x0E, 0x00, 0x20, 0x0B, 0xAF, 0x00, 0x07,
            0x00, 0x0C, 0x00, 0xCF, 0x00, 0xD9, 0x18, 0x00, 0x10, 0xF0, 0x03, 0x0C, 0x20,
            0x00, 0x06, 0x0B, 0x0B, 0x33, 0x0E, 0x1C, 0x2A, 0x38, 0x46, 0x54, 0x62, 0x69,
            0x70, 0x77, 0x79, 0x7B, 0x7D, 0x7E, 0x01, 0x02, 0x01, 0x00, 0x09, 0x40, 0x09,
            0xBE, 0x19, 0xFC, 0x19, 0xFA, 0x19, 0xF8, 0x1A, 0x38, 0x1A, 0x78, 0x1A, 0xB6,
            0x2A, 0xF6, 0x2B, 0x34, 0x2B, 0x74, 0x3B, 0x74, 0x6B, 0xF4, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
        };
        hal_dsi_rx_ctrl_pre_init_pps(g_rx_ctrl_handle, pps, 128);
    }

    /* 初始化rx ctrl */
    hal_dsi_rx_ctrl_init(g_rx_ctrl_handle);

#ifdef CUS_SCLD_FILTER
    hal_dsi_rx_ctrl_set_cus_scld_filter(g_rx_ctrl_handle, rx_filter_H_3, rx_filter_V_3);
#endif
	
    hal_dsi_rx_ctrl_set_cus_scld_filter(g_rx_ctrl_handle,rx_filter_1080_h_4_96,rx_filter_2400_v_4_96);

    hal_dsi_rx_ctrl_set_cus_esc_clk(g_rx_ctrl_handle, 20000000);
//    hal_dsi_rx_ctrl_hight_performan_mode(g_rx_ctrl_handle);
    hal_dsi_rx_ctrl_set_cus_sync_line(g_rx_ctrl_handle, 2000);
    /* 启动rx ctrl */
    hal_dsi_rx_ctrl_start(g_rx_ctrl_handle);
}

static void init_mipi_tx(void)
{
    if(g_tx_ctrl_handle == NULL)
    {
        g_tx_ctrl_handle = hal_dsi_tx_ctrl_create_handle();
    }
    g_tx_ctrl_handle->channel_id = OUTPUT_VC;
    g_tx_ctrl_handle->lane_num = OUTPUT_LANE_NUMBER;
    g_tx_ctrl_handle->vid_mode = OUTPUT_VIDEO_MODEL;
    g_tx_ctrl_handle->cmd_tx_type = DSI_CMD_TX_HS;
    g_tx_ctrl_handle->dpi_vsa = OUTPUT_VSA;
    g_tx_ctrl_handle->dpi_vbp = OUTPUT_VBP;
    g_tx_ctrl_handle->dpi_vfp = OUTPUT_VFP;
    g_tx_ctrl_handle->dpi_hsa = OUTPUT_HSA;
    g_tx_ctrl_handle->dpi_hbp = OUTPUT_HBP;
    g_tx_ctrl_handle->dpi_hfp = OUTPUT_HFP;
    g_tx_ctrl_handle->base_info.src_w = INPUT_WIDTH;
    g_tx_ctrl_handle->base_info.src_h = INPUT_HEIGHT;
    g_tx_ctrl_handle->base_info.dst_w = OUTPUT_WIDTH;
    g_tx_ctrl_handle->base_info.dst_h = OUTPUT_HEIGHT;
    g_tx_ctrl_handle->base_info.src_frate = INPUT_FRAME_RATE;
    g_tx_ctrl_handle->base_info.src_mode = INPUT_DATA_MODE;

//	g_tx_ctrl_handle->tx_cmd_mode_sync = true;
//	g_tx_ctrl_handle->base_info.extra_info.dst_mode = DSI_DATA_CMD_MODE;
//	g_tx_ctrl_handle->tx_frame_rate = 58;
//		g_tx_ctrl_handle->tx_clkawayshs = true;
//	g_tx_ctrl_handle->tx_line_delay = 800;
    hal_dsi_tx_ctrl_init(g_tx_ctrl_handle);
    /* AP 没有发送数据时默认的显示颜色, 量产为0 0 0(黑色), 配置其他颜色仅为debug使用 */
    hal_dsi_tx_ctrl_set_overwrite_rgb(0x00, 0x00, 0x00);
//    TAU_LOGD("BLUE\n");
}

static void tx_display_on(void)
{
    init_panel();
//	delayMs(50);
    hal_dsi_tx_ctrl_start(g_tx_ctrl_handle);
    delayMs(120);
    hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x29);
    delayMs(20);
}

static void soft_swire_start(uint8_t pulse)
{
    do
    {
        hal_gpio_init_output(IO_PAD_ADCIN, IO_LVL_LOW); // 3us
        delayUs(10);
        hal_gpio_init_output(IO_PAD_ADCIN, IO_LVL_HIGH); // 3us
        delayUs(10);
    }
    while(pulse--);
}
static void soft_swire_timer_callback(void* data)
{
    s_swire_pwm_counter++;
    if(s_swire_pwm_counter < SWIRE_MAX_NUM)
    {
        soft_swire_start(g_swire_num);
        hal_timer_start(SWIRE_TIMER, 16, soft_swire_timer_callback, NULL);
    }
    else
    {
        hal_timer_deinit(SWIRE_TIMER);
        hal_timer_stop(SWIRE_TIMER);
        hal_gpio_init_output(IO_PAD_ADCIN, IO_LVL_HIGH);
    }
}

static void soft_swire_init(void)
{
    hal_gpio_init_output(IO_PAD_ADCIN, IO_LVL_HIGH);
    delayMs(3);
    s_swire_pwm_counter = 0;
    soft_swire_start(g_swire_num);
    hal_timer_init(SWIRE_TIMER);
    hal_timer_start(SWIRE_TIMER, 16, soft_swire_timer_callback, NULL);
}



void tp_heartbeat_exec(void)
{
    if(s_screen_init_complate)
    {
        if(hal_gpio_get_input_data(IO_PAD_TD_INT))
        {
            s_heartbeat = 0;
        }
        else
        {
            if(s_heartbeat < (65536 / 50)) // 65536*3 = 900ms  65536/50 = 6ms
            {
                s_heartbeat ++;
            }
            else
            {
                TAU_LOGD("hb...");
                s_heartbeat = 0;
          //      ap_tp_st_touch_software_reset();
				ap_tp_st_touch_hardware_reset();
            }
        }
    }
}

#ifdef ADD_TIMER3_FUNCTION
static void soft_timer3_cb(void* data)
{
    hal_timer_start(TIMER_NUM3, 10, soft_timer3_cb, NULL);
    g_tp_sleep_delay_count++;
	s_tp_delay_count++;

#if AUTO_CAL_TP
    if(g_exit_sleep_mode)
    {
        if(g_cal_cnt > 0)
        {
            g_cal_cnt--;
            if(g_cal_cnt == 0)
            {
                s_calibration_flag = true;
                TAU_LOGD("Start cal tp!\n");
            }
        }
    }
#endif
}
#endif

void tp_power_up_restart(void)
{
	if(s_power_up_flag == true && s_tp_delay_count >= (100*6))	// 开机6秒后重启
	{
		s_power_up_flag = false;
		ap_tp_st_touch_hardware_reset();
	//	TAU_LOGD("tp_hardware_reset");
	}
}

#if ENABLE_SOFT_TIMER_TE
static void soft_te_timer_cb(void *data)
{
    /*
        S8 的屏接的是TP1.8V, AC 启动后需要等到TP1.8 起来后再初始化屏, 所以在TP 起来前需要通过软件产生TE给手机，避免手机卡死
    */
    if (start_display_on == false)
    {
        hal_dsi_rx_ctrl_gen_a_tear_signal(g_rx_ctrl_handle);
        hal_timer_start(TE_TIMER, 17, soft_te_timer_cb, NULL);
    }
    else
    {
        hal_dsi_rx_ctrl_set_hw_tear_mode(g_rx_ctrl_handle);
    }
}

static void soft_te_timer_init()
{
    TAU_LOGD("soft_te_timer_init\n");
    hal_dsi_rx_ctrl_set_sw_tear_mode(g_rx_ctrl_handle);
    hal_timer_init(TE_TIMER);
    hal_timer_start(TE_TIMER, 1, soft_te_timer_cb, NULL);
}
#endif

void S21P_demo(void)
{
    /* mipi rx初始化 */
		hal_gpio_init_output(IO_PAD_TD_LEDPWM, IO_LVL_LOW);
		hal_gpio_init_output(IO_PAD_AP_INT, IO_LVL_LOW);
		hal_gpio_init_output(IO_PAD_TD_TPRSTN, IO_LVL_HIGH);

    hal_gpio_init_output(IO_PAD_AP_SWIRE, IO_LVL_LOW);
    hal_gpio_init_output(IO_PAD_PWMEN, IO_LVL_LOW);
    hal_gpio_init_output(IO_PAD_ADCIN, IO_LVL_LOW);	
//	hal_gpio_init_output(IO_PAD_TD_TPRSTN, IO_LVL_HIGH);
    //hal_gpio_init_output(IO_PAD_AP_TPRSTN, IO_LVL_HIGH);
//    hal_gpio_set_mode(IO_PAD_AP_SPIS_CLK, IO_MODE_I2C1_SCL);
//    hal_gpio_set_mode(IO_PAD_AP_SPIS_CSN, IO_MODE_I2C1_SDA);
		app_tp_I2C_init();

    open_mipi_rx();
		hal_gpio_set_output_data(IO_PAD_AP_INT, IO_LVL_HIGH);
//	hal_system_set_vcc(true);	
    TAU_LOGD("S21P rx done \n");
    /* swire 初始化 */
//   swire_init();
//    app_tp_init();
    /* 次应用中,屏的1.8V 接 AP TP1.8, PWMEN 接到 AP AVDD_SWIRE, 用于检查是息屏开屏还是AC */
    /* 在TP1.8有电之前，使用软件产生TE，屏显示之后切换为硬件产生TE S9 可以删掉 */
#if ENABLE_SOFT_TIMER_TE
	soft_te_timer_init();
#endif
    /* mipi tx 初始化 */
    init_mipi_tx();
    /* 屏初始化 */
    //tx_display_on(); /* S9 打开,删除While循环的屏初始化 */
//	app_tp_init();
//    app_tp_transfer_screen_start();
		app_tp_transfer_screen_start_init();

		app_tp_init();

#ifdef ADD_TIMER3_FUNCTION
    g_tp_sleep_delay_count = 0;
    hal_timer_init(TIMER_NUM3);
    hal_timer_start(TIMER_NUM3, 10, soft_timer3_cb, NULL);
//    TAU_LOGD("start timer3");
#endif
    while(1)
    {
        /* 等待 AP TP 上电*/
        if(start_display_on == true)
        {
            if(g_exit_sleep_mode || s_sys_power_up_flag)
            {
                /* 屏初始化 */
                tx_display_on();
                TAU_LOGD("tx_display_on\n");

	//			app_tp_transfer_screen_start();
	//			s_screen_init_complate = true;
				if(s_sys_power_up_flag == true)
				{
					// AC //
					s_sys_power_up_flag = false;
					app_tp_transfer_screen_start();
					TAU_LOGD("AC\n");
				}
				else
				{
					// 息屏唤醒 //
					s_screen_init_complate = true;
					TAU_LOGD("DC\n");
			//		ap_tp_st_touch_get_status();
			//		ap_tp_st_touch_hardware_reset();
				}
				
			//	hal_gpio_set_output_data(IO_PAD_AP_INT, IO_LVL_LOW);//必须拉低，否则待机或者双击唤醒2~3s无触摸
				
                start_display_on = false;
                panel_display_done = true;
#if ENABLE_TP_WAKE_UP//将启动中断放这里的原因是当开机时，复位会有一个连续拉低拉高(70ms)的过程，为了区分开机和待机，所以将中断启动放这里大于70ms,使得复位连续第二次拉高时不识别
                hal_gpio_set_ap_reset_int(ENABLE, ap_reset_cb, DETECT_RISING_EDGE);
#endif
            }
        }
	
        /* 与屏的TP 模块通讯并初始化 */
        app_tp_transfer_screen_int();

        tp_power_up_restart();
		tp_heartbeat_exec();
        app_tp_calibration_exec();
        ap_tp_st_touch_scan_point_record_event_exec();

        while(hal_dsi_rx_ctrl_dsc_async_handler(g_rx_ctrl_handle))
        {

        }

#if  ENABLE_TP_WAKE_UP
			
				ap_reset_exec();

        if(g_need_enter_sleep_mode)
        {
//			g_mipi_path_off = true;
//            hal_gpio_set_output_data(IO_PAD_TD_LEDPWM, IO_LVL_HIGH);
            /* FIXME stop more model */
            hal_dsi_tx_ctrl_stop(g_tx_ctrl_handle);
            hal_dsi_tx_ctrl_deinit(g_tx_ctrl_handle);
            hal_dsi_rx_ctrl_stop(g_rx_ctrl_handle);
            hal_dsi_rx_ctrl_deinit(g_rx_ctrl_handle);

            hal_swire_open(DISABLE);
            hal_swire_deinit();
            hal_timer_stop(SWIRE_TIMER);
            hal_timer_deinit(SWIRE_TIMER);
            g_tp_sleep_in = true;
            //hal_gpio_init_output(IO_PAD_TD_TPRSTN, IO_LVL_LOW);
//			hal_system_set_vcc(false);	 //关VCC有屏唤不醒
//			hal_system_set_pvd(false);	 //		
            hal_gpio_set_output_data(IO_PAD_TD_LEDPWM, IO_LVL_HIGH);
            TAU_LOGD("disable video path \n");
            g_need_enter_sleep_mode = false;
        }
#endif
#if RUN_TEST
        static uint32_t test_cnt = 0;
        if(test_cnt++ > 0x1fffff)
        {
            test_cnt = 0;
            TAU_LOGD("System run 1...");
        }
#endif
        /* enter idle mode*/
        //hal_system_idle_mode(true);
    }
}






